package org.rcisoft.business.applicationtrial.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.business.applicationtrial.dto.ApplicationTrialDto;
import org.rcisoft.business.applicationtrial.entity.ApplicationTrial;
import org.rcisoft.business.applicationtrial.service.ApplicationTrialService;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.exception.CyServiceException;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;

import java.util.List;

/**
* Created by cy on 2024年4月1日 上午10:07:11.
*/
@RestController
@RequestMapping("/applicationtrial")
public class ApplicationTrialController extends CyPaginationController<ApplicationTrial> {


    @Autowired
    private ApplicationTrialService applicationTrialServiceImpl;


    @PreAuthorize("@cyPerm.hasPerm('opm:applicationtrial:deleteLogical')")
    @CyOpeLogAnno(title = "system-试用申请管理-删除试用申请", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="逻辑删除试用申请", notes="逻辑删除试用申请")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable Integer businessId,ApplicationTrial applicationTrial) {
        applicationTrial.setBusinessId(businessId);
        CyPersistModel data = applicationTrialServiceImpl.removeLogical(applicationTrial);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:licationTrial:delete')")
    @CyOpeLogAnno(title = "system-试用申请管理-删除试用申请", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="删除试用申请", notes="删除试用申请")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable Integer businessId,ApplicationTrial applicationTrial) {
        applicationTrial.setBusinessId(businessId);
        CyPersistModel data = applicationTrialServiceImpl.remove(applicationTrial);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:applicationtrial:update')")
    @CyOpeLogAnno(title = "system-试用申请管理-修改试用申请", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改试用申请", notes="修改试用申请")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable Integer businessId, @Valid ApplicationTrial applicationTrial, BindingResult bindingResult) {
        applicationTrial.setBusinessId(businessId);
        CyPersistModel data = applicationTrialServiceImpl.merge(applicationTrial);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        applicationTrial);
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:applicationtrial:detail')")
    @CyOpeLogAnno(title = "system-试用申请管理-查询试用申请", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单一试用申请", notes="查询单一试用申请")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable Integer businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        applicationTrialServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:licationTrial:list')")
    @CyOpeLogAnno(title = "system-试用申请管理-查询试用申请", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询试用申请集合", notes="查询试用申请集合")
    @GetMapping(value = "/queryApplicationTrials")
    public CyResult queryApplicationTrials(ApplicationTrial applicationTrial) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            applicationTrialServiceImpl.findAll(applicationTrial));
    }

//    @PreAuthorize("@cyPerm.hasPerm('opm:applicationtrial:queryApplicationTrialByPagination')")
    @CyOpeLogAnno(title = "system-试用申请管理-查询试用申请", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="分页查询试用申请集合", notes="分页查询试用申请集合")
    @GetMapping(value = "/queryApplicationTrialByPagination")
    public CyGridModel listByPagination(ApplicationTrial applicationTrial) {
        applicationTrialServiceImpl.findAllByPagination(getPaginationUtility(), applicationTrial);
        return getGridModelResponse();
    }
    @PreAuthorize("@cyPerm.hasPerm('opm:applicationtrial:export')")
    @CyOpeLogAnno(title = "system-试用申请管理-查询试用申请", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出试用申请信息", notes = "导出试用申请信息")
    @GetMapping(value = "/export")
    public void outApplicationTrial(HttpServletResponse response,ApplicationTrial applicationTrial,@PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="试用申请信息.xls";break;
            case "1": excelName="试用申请信息.xlsx";break;
            case "2": excelName="试用申请信息.csv";break;
        }
        List<ApplicationTrial> applicationTrialList = applicationTrialServiceImpl.export(applicationTrial);
        CyEpExcelUtil.exportExcel(applicationTrialList, "试用申请信息", "试用申请信息", ApplicationTrial.class, excelName, response);
    }
    @PreAuthorize("@cyPerm.hasPerm('opm:applicationtrial:add')")
    @CyOpeLogAnno(title = "system-试用申请管理-新增试用申请", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="添加试用申请", notes="添加试用申请")
    @PostMapping(value = "/add")
    public CyResult add(String ids) {
        CyPersistModel data = applicationTrialServiceImpl.persist(ids);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                ids);
    }
}
