package org.rcisoft.business.applicationtrial.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.rcisoft.business.applicationtrial.dao.ApplicationTrialRepository;
import org.rcisoft.business.applicationtrial.entity.ApplicationTrial;
import org.rcisoft.business.applicationtrial.service.ApplicationTrialService;
import org.rcisoft.business.sysuser.dao.PCSysUserRepository;
import org.rcisoft.business.sysuser.entity.SysUser;
import org.rcisoft.business.sysuser.enums.PCUserInfoExceptionEnums;
import org.rcisoft.business.tealessonandapplication.dao.TeaLessonAndApplicationRepository;
import org.rcisoft.business.tealessonandapplication.entity.TeaLessonAndApplication;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyUserUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;

import java.util.Arrays;
import java.util.Date;
import java.util.List;

/**
 * Created by cy on 2024年4月1日 上午10:07:11.
 */
@Service
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class ApplicationTrialServiceImpl extends ServiceImpl<ApplicationTrialRepository, ApplicationTrial> implements ApplicationTrialService {

    @Autowired
    private TeaLessonAndApplicationRepository teaLessonAndApplicationRepository;

    @Autowired
    private PCSysUserRepository pcSysUserRepository;


    /**
     * 保存 试用申请
     *
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(String ids) {
        //获取当前登录用户信息
        String authenBusinessId = CyUserUtil.getAuthenBusinessId();
        if (authenBusinessId == null) {
            throw new CyServiceException(PCUserInfoExceptionEnums.USERNAME_NOT_EXISTS);
        }
        SysUser sysUser = pcSysUserRepository.selectById(authenBusinessId);
        Date date = new Date();
        ApplicationTrial applicationTrial = new ApplicationTrial();
        applicationTrial.setUserType(sysUser.getIdentity());
        applicationTrial.setApplicant(Integer.parseInt(authenBusinessId));
        if (sysUser.getDeptId() != null) {
            applicationTrial.setApplicantUnit(Integer.parseInt(sysUser.getDeptId().toString()));
        }
        applicationTrial.setApplicantUnitName(sysUser.getPhone());
        applicationTrial.setApplicantTime(date);
        baseMapper.insert(applicationTrial);

        //插入关联表
        if (ids.contains(",")) {
            String[] id = ids.split(",");
            List<String> list = Arrays.stream(id).toList();
            if (!CollectionUtils.isEmpty(list)) {
                list.forEach(lessonId -> {
                    TeaLessonAndApplication teaLessonAndApplication = new TeaLessonAndApplication();
                    teaLessonAndApplication.setApplicationId(applicationTrial.getBusinessId());
                    teaLessonAndApplication.setLessonId(lessonId.trim());
                    teaLessonAndApplicationRepository.insert(teaLessonAndApplication);
                });
            }
        }else {
            TeaLessonAndApplication teaLessonAndApplication = new TeaLessonAndApplication();
            teaLessonAndApplication.setApplicationId(applicationTrial.getBusinessId());
            teaLessonAndApplication.setLessonId(ids.trim());
            teaLessonAndApplicationRepository.insert(teaLessonAndApplication);
        }
        return new CyPersistModel(1);
    }

    /**
     * 删除 试用申请
     *
     * @param applicationTrial
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(ApplicationTrial applicationTrial) {
        int line = baseMapper.realDelete(applicationTrial);
        log.debug(CyUserUtil.getAuthenUsername() + "删除了ID为" +
                applicationTrial.getBusinessId() + "的试用申请信息");
        return new CyPersistModel(line);
    }

    /**
     * 逻辑删除 试用申请
     *
     * @param applicationTrial
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(ApplicationTrial applicationTrial) {
        applicationTrial.setDeleted();
        int line = baseMapper.deleteById(applicationTrial);
        log.debug(CyUserUtil.getAuthenUsername() + "逻辑删除了ID为" +
                applicationTrial.getBusinessId() + "的试用申请信息");
        return new CyPersistModel(line);
    }

    /**
     * 修改 试用申请
     *
     * @param applicationTrial
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(ApplicationTrial applicationTrial) {
        int line = baseMapper.updateById(applicationTrial);
        log.debug(CyUserUtil.getAuthenUsername() + "修改了ID为" + applicationTrial.getBusinessId() + "的试用申请信息");
        return new CyPersistModel(line);
    }

    /**
     * 根据id查询 试用申请
     *
     * @param id
     * @return
     */
    @Override
    public ApplicationTrial findById(Integer id) {
        return baseMapper.selectById(id);
    }

    /**
     * 分页查询 试用申请
     *
     * @param applicationTrial
     * @return
     */
    @Override
    public IPage<ApplicationTrial> findAllByPagination(CyPageInfo<ApplicationTrial> paginationUtility,
                                                       ApplicationTrial applicationTrial) {
        IPage<ApplicationTrial> applicationTrialIPage = baseMapper.queryApplicationTrialsPaged(paginationUtility, applicationTrial);
        if (!applicationTrialIPage.getRecords().isEmpty()) {
            // 设置每个申请 申请的课程
            applicationTrialIPage.getRecords().stream().forEach(item -> {
                item.setCoursesNumber(String.valueOf(teaLessonAndApplicationRepository.getCourseNumberByApplicationId(item.getBusinessId())));
            });
        }
        return applicationTrialIPage;

    }

    /**
     * 查询list 试用申请
     *
     * @param applicationTrial
     * @return
     */
    @Override
    public List<ApplicationTrial> findAll(ApplicationTrial applicationTrial) {
        return baseMapper.queryApplicationTrials(applicationTrial);

    }

    /**
     * 导出试用申请
     *
     * @return
     */
    @Override
    public List<ApplicationTrial> export(ApplicationTrial applicationTrial) {
        List<ApplicationTrial> applicationTrialList = baseMapper.queryApplicationTrials(applicationTrial);
        return applicationTrialList;
    }

}
