package org.rcisoft.business.auditlogs.controller;


/*固定导入*/

import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.business.auditlogs.entity.AuditLogs;
import org.rcisoft.business.auditlogs.service.AuditLogsService;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.core.util.CyResultGenUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.util.List;

/**
 * Created by cy on 2024年8月8日 下午6:35:03.
 */
@RestController
@RequestMapping("/auditlogs")
public class AuditLogsController extends CyPaginationController<AuditLogs> {

    @Autowired
    private AuditLogsService auditLogsServiceImpl;

    //@PreAuthorize("@cyPerm.hasPerm('sys:itLogs:add')")
    @CyOpeLogAnno(title = "system-课程审核历史记录及意见管理-新增课程审核历史记录及意见", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value = "添加课程审核历史记录及意见", notes = "添加课程审核历史记录及意见")
    @PostMapping(value = "/add")
    public CyResult add(@Valid AuditLogs auditLogs, BindingResult bindingResult) {
        CyPersistModel data = auditLogsServiceImpl.persist(auditLogs);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                auditLogs);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:itLogs:delete')")
    @CyOpeLogAnno(title = "system-课程审核历史记录及意见管理-删除课程审核历史记录及意见", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value = "删除课程审核历史记录及意见", notes = "删除课程审核历史记录及意见")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable String businessId, AuditLogs auditLogs) {
        auditLogs.setBusinessId(businessId);
        CyPersistModel data = auditLogsServiceImpl.remove(auditLogs);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:itLogs:update')")
    @CyOpeLogAnno(title = "system-课程审核历史记录及意见管理-修改课程审核历史记录及意见", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value = "修改课程审核历史记录及意见", notes = "修改课程审核历史记录及意见")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable String businessId, @Valid AuditLogs auditLogs, BindingResult bindingResult) {
        auditLogs.setBusinessId(businessId);
        CyPersistModel data = auditLogsServiceImpl.merge(auditLogs);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                auditLogs);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:itLogs:query')")
    @CyOpeLogAnno(title = "system-课程审核历史记录及意见管理-查询课程审核历史记录及意见", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询单一课程审核历史记录及意见", notes = "查询单一课程审核历史记录及意见")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable String businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                auditLogsServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:itLogs:list')")
    @CyOpeLogAnno(title = "system-课程审核历史记录及意见管理-查询课程审核历史记录及意见", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询课程审核历史记录及意见集合", notes = "查询课程审核历史记录及意见集合")
    @GetMapping(value = "/listAll")
    public CyResult listAll(AuditLogs auditLogs) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                auditLogsServiceImpl.findAll(auditLogs));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:itLogs:list')")
    @CyOpeLogAnno(title = "system-课程审核历史记录及意见管理-查询课程审核历史记录及意见", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "分页查询课程审核历史记录及意见集合", notes = "分页查询课程审核历史记录及意见集合")
    @GetMapping(value = "/list")
    public CyGridModel listByPagination(AuditLogs auditLogs) {
        auditLogsServiceImpl.findAllByPagination(getPaginationUtility(), auditLogs);
        return getGridModelResponse();
    }

    @CyOpeLogAnno(title = "system-课程审核历史记录及意见管理-查询课程审核历史记录及意见", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出课程审核历史记录及意见信息", notes = "导出课程审核历史记录及意见信息")
    @GetMapping(value = "/export")
    public void outAuditLogs(HttpServletResponse response, AuditLogs auditLogs, @PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName = "";
        switch (excelId) {
            case "0":
                excelName = "课程审核历史记录及意见信息.xls";
                break;
            case "1":
                excelName = "课程审核历史记录及意见信息.xlsx";
                break;
            case "2":
                excelName = "课程审核历史记录及意见信息.csv";
                break;
        }
        List<AuditLogs> auditLogsList = auditLogsServiceImpl.export(auditLogs);
        CyEpExcelUtil.exportExcel(auditLogsList, "课程审核历史记录及意见信息", "课程审核历史记录及意见信息", AuditLogs.class, excelName, response);
    }
}
