package org.rcisoft.business.auditlogs.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.rcisoft.business.auditlogs.dao.AuditLogsRepository;
import org.rcisoft.business.auditlogs.entity.AuditLogs;
import org.rcisoft.business.auditlogs.service.AuditLogsService;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyUserUtil;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * Created by cy on 2024年8月8日 下午6:35:03.
 */
@Service
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class AuditLogsServiceImpl extends ServiceImpl<AuditLogsRepository, AuditLogs> implements AuditLogsService {


    /**
     * 保存 课程审核历史记录及意见
     *
     * @param auditLogs
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(AuditLogs auditLogs) {
        //增加操作
        int line = baseMapper.insert(auditLogs);
        log.debug(CyUserUtil.getAuthenUsername() + "新增了ID为" +
                auditLogs.getBusinessId() + "的课程审核历史记录及意见信息");
        return new CyPersistModel(line);
    }

    /**
     * 删除 课程审核历史记录及意见
     *
     * @param auditLogs
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(AuditLogs auditLogs) {
        int line = baseMapper.realDelete(auditLogs);
        log.debug(CyUserUtil.getAuthenUsername() + "删除了ID为" +
                auditLogs.getBusinessId() + "的课程审核历史记录及意见信息");
        return new CyPersistModel(line);
    }

    /**
     * 修改 课程审核历史记录及意见
     *
     * @param auditLogs
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(AuditLogs auditLogs) {
        int line = baseMapper.updateById(auditLogs);
        log.debug(CyUserUtil.getAuthenUsername() + "修改了ID为" + auditLogs.getBusinessId() + "的课程审核历史记录及意见信息");
        return new CyPersistModel(line);
    }

    /**
     * 根据id查询 课程审核历史记录及意见
     *
     * @param id
     * @return
     */
    @Override
    public AuditLogs findById(String id) {
        return baseMapper.selectById(id);
    }

    /**
     * 分页查询 课程审核历史记录及意见
     *
     * @param auditLogs
     * @return
     */
    @Override
    public IPage<AuditLogs> findAllByPagination(CyPageInfo<AuditLogs> paginationUtility,
                                                AuditLogs auditLogs) {
        return baseMapper.queryAuditLogssPaged(paginationUtility, auditLogs);

    }

    /**
     * 查询list 课程审核历史记录及意见
     *
     * @param auditLogs
     * @return
     */
    @Override
    public List<AuditLogs> findAll(AuditLogs auditLogs) {
        return baseMapper.queryAuditLogss(auditLogs);

    }

    /**
     * 导出课程审核历史记录及意见
     *
     * @return
     */
    @Override
    public List<AuditLogs> export(AuditLogs auditLogs) {
        List<AuditLogs> auditLogsList = baseMapper.queryAuditLogss(auditLogs);
        return auditLogsList;
    }

}
