package org.rcisoft.business.bchapter.controller;


/*固定导入*/

import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.collections4.map.HashedMap;
import org.apache.commons.lang3.StringUtils;
import org.rcisoft.business.bchapter.entity.BChapter;
import org.rcisoft.business.bchapter.service.BChapterService;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.core.util.CyResultGenUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.util.Arrays;
import java.util.List;
import java.util.Map;

/**
 * Created by cy on 2024年3月23日 上午9:54:38.
 */
@RestController
@RequestMapping("/bchapter")
public class BChapterController extends CyPaginationController<BChapter> {


    @Autowired
    private BChapterService bChapterServiceImpl;


    //@PreAuthorize("@cyPerm.hasPerm('sys:apter:delete')")
    @CyOpeLogAnno(title = "system-章节表管理-删除章节表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value = "逻辑删除章节表", notes = "逻辑删除章节表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable String businessId, BChapter bChapter) {
        bChapter.setBusinessId(businessId);
        CyPersistModel data = bChapterServiceImpl.removeLogical(bChapter);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:apter:delete')")
    @CyOpeLogAnno(title = "system-章节表管理-删除章节表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value = "删除章节表", notes = "删除章节表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable String businessId, BChapter bChapter) {
        bChapter.setBusinessId(businessId);
        CyPersistModel data = bChapterServiceImpl.remove(bChapter);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:apter:update')")
    @CyOpeLogAnno(title = "system-章节表管理-修改章节表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value = "修改章节表", notes = "修改章节表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable String businessId, @Valid BChapter bChapter, BindingResult bindingResult) {
        bChapter.setBusinessId(businessId);
        CyPersistModel data = bChapterServiceImpl.merge(bChapter);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bChapter);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:apter:query')")
    @CyOpeLogAnno(title = "system-章节表管理-查询章节表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询单一章节表", notes = "查询单一章节表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable String businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bChapterServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:apter:list')")
    @CyOpeLogAnno(title = "system-章节表管理-查询章节表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "分页查询章节表集合", notes = "分页查询章节表集合")
    @GetMapping(value = "/queryBChapterByPagination")
    public CyGridModel listByPagination(BChapter bChapter) {
        bChapterServiceImpl.findAllByPagination(getPaginationUtility(), bChapter);
        return getGridModelResponse();
    }

    @CyOpeLogAnno(title = "system-章节表管理-查询章节表", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出章节表信息", notes = "导出章节表信息")
    @GetMapping(value = "/export")
    public void outBChapter(HttpServletResponse response, BChapter bChapter, @PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName = "";
        switch (excelId) {
            case "0":
                excelName = "章节表信息.xls";
                break;
            case "1":
                excelName = "章节表信息.xlsx";
                break;
            case "2":
                excelName = "章节表信息.csv";
                break;
        }
        List<BChapter> bChapterList = bChapterServiceImpl.export(bChapter);
        CyEpExcelUtil.exportExcel(bChapterList, "章节表信息", "章节表信息", BChapter.class, excelName, response);
    }


    @ApiOperation(value = "分页查询章节", notes = "根据条件分页查询章节")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "slId", value = "开课id", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "lessonOrSl", value = "课程或开课;0：开课  1：课程", required = true, dataType = "varchar"),
            @ApiImplicitParam(name = "lessonId", value = "课程ID(课程ID和开课ID只能存在一个)", required = false, dataType = "varchar")})
    @PostMapping(value = "/queryBChaptersByPagination")
    public CyGridModel queryBChaptersByPagination(BChapter param) {
        bChapterServiceImpl.queryBChaptersByPagination(getPaginationUtility(), param);
        CyGridModel gridModel = getGridModelResponse();
        return gridModel;
    }

    @ApiOperation(value = "根据条件查询章节", notes = "根据条件查询章节")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "slId", value = "开课id", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "lessonOrSl", value = "课程或开课;0：开课  1：课程", required = true, dataType = "varchar"),
            @ApiImplicitParam(name = "lessonId", value = "课程ID(课程ID和开课ID只能存在一个)", required = false, dataType = "varchar")})
    @GetMapping(value = "/queryBChaptersWithoutAuth")
    public CyResult queryBChapters(BChapter param) {
        Map<String, Object> map = new HashedMap();

        map.put("chapterList", bChapterServiceImpl.queryBChapters(param, getToken()));
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                map);
    }

    //web端 查询课程详细信息
    @ApiOperation(value = "根据条件查询章节", notes = "根据条件查询章节")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "slId", value = "开课id", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "lessonOrSl", value = "课程或开课;0：开课  1：课程", required = true, dataType = "varchar"),
            @ApiImplicitParam(name = "lessonId", value = "课程ID(课程ID和开课ID只能存在一个)", required = false, dataType = "varchar")})
    @GetMapping(value = "/queryBChaptersWithoutAuthWEB")
    public CyResult queryBChaptersWithoutAuthWEB(BChapter param) {
        Map<String, Object> map = new HashedMap();
        map.put("chapterList", bChapterServiceImpl.queryBChaptersWithoutAuthWEB(param, getToken()));
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                map);
    }

    @ApiOperation(value = "根据条件查询章节讲师", notes = "根据条件查询章节")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "slId", value = "开课id", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "lessonOrSl", value = "课程或开课;0：开课  1：课程", required = true, dataType = "varchar"),
            @ApiImplicitParam(name = "lessonId", value = "课程ID(课程ID和开课ID只能存在一个)", required = false, dataType = "varchar")})
    @GetMapping(value = "/queryBChaptersWithoutAuthTeacher")
    public CyResult queryBChaptersWithoutAuthTeacher(BChapter param) {
        Map<String, Object> map = new HashedMap();

        map.put("chapterList", bChapterServiceImpl.queryBChaptersWithoutAuthTeacher(param, getToken()));
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                map);
    }


    @ApiOperation(value = "添加/编辑章节", notes = "businessId为空时是添加方法，不为空时是修改方法")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "slId", value = "开课id", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "chapterName", value = "章节名称(1-50)", required = true, dataType = "varchar"),
            @ApiImplicitParam(name = "pid", value = "上一级(1-50)", required = true, dataType = "varchar"),
            @ApiImplicitParam(name = "classHour", value = "课时", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "experimentType", value = "实验类型,1:java单文件 2:java工程 3:html单文件 4:html工程", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "lessonOrSl", value = "课程或开课;0：开课  1：课程", required = true, dataType = "varchar"),
            @ApiImplicitParam(name = "isTest", value = "1:实验  2:视频   3:PPT  4:pdf   5:资料   6试题", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "lessonId", value = "课程ID(课程ID和开课ID只能存在一个)", required = false, dataType = "varchar")})
//    @PreAuthorize("@cyPerm.hasPerm('sys:apter:add')")
    @PostMapping(value = "/add")
    public CyResult add(@Valid BChapter bChapter, BindingResult bindingResult) {
        CyPersistModel data = bChapterServiceImpl.persist(bChapter, getToken());
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bChapter);
    }

    @ApiOperation(value = "删除章节", notes = "根据ID删除一条记录")
    @ApiImplicitParams({@ApiImplicitParam(name = "id", value = "businessId", required = true, dataType = "varchar"),
            @ApiImplicitParam(name = "lessonOrSl", value = "区分课程开课 0开课，1课程", required = true, dataType = "varchar")})
//    @PreAuthorize("@cyPerm.hasPerm('sys:apter:delete')")
    @PostMapping(value = "/remove")
    public CyResult remove(String id, String lessonOrSl) {
        CyPersistModel data = bChapterServiceImpl.removeBChapter(id, lessonOrSl);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                id);
    }


    @ApiOperation(value = "章节向上调顺序", notes = "章节向上调顺序")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar"),
            @ApiImplicitParam(name = "pid", value = "父节点ID", required = true, dataType = "varchar"),
            @ApiImplicitParam(name = "slId", value = "开课ID", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "lessonId", value = "课程ID", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "sort", value = "当前顺序", required = true, dataType = "Integer")})
    @PostMapping(value = "/updateTopChapter")
    public CyResult updateTopChapter(BChapter bChapter) {
        int data = bChapterServiceImpl.updateTopChapter(bChapter);
        return CyResultGenUtil.builder(new CyPersistModel(data),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bChapter);
    }

    @ApiOperation(value = "章节向下调顺序", notes = "章节向下调顺序")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar"),
            @ApiImplicitParam(name = "pid", value = "父节点ID", required = true, dataType = "varchar"),
            @ApiImplicitParam(name = "slId", value = "开课ID", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "lessonId", value = "课程ID", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "sort", value = "当前顺序", required = true, dataType = "Integer")})
    @PostMapping(value = "/updateDownChapter")
    public CyResult updateDownChapter(BChapter bChapter) {
        int data = bChapterServiceImpl.updateDownChapter(bChapter);
        return CyResultGenUtil.builder(new CyPersistModel(data),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bChapter);
    }

    @ApiOperation(value = "查询小节信息", notes = "查询小节信息")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @GetMapping(value = "/querySections")
    public CyResult querySections(BChapter param) {
        //查询小结信息
        List<BChapter> list = bChapterServiceImpl.querySections(param);
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                list);
    }

    //试看
    @ApiOperation(value = "试看", notes = "试看")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @GetMapping(value = "/getVideoUrl")
    public CyResult getVideoUrl(String lessonId) {
        //查询小结信息
        BChapter bChapter = bChapterServiceImpl.getVideoUrl(lessonId);
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bChapter);
    }

    //树批量修改 ，分割
    @ApiOperation(value = "批量修改", notes = "批量修改")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @GetMapping(value = "/merges")
    public CyResult merge(String pid, String sid, String status) {
        //pid ,分割成list
        if (StringUtils.isNotEmpty(pid)) {
            List<String> pidList = Arrays.asList(pid.split(","));
            for (String p : pidList) {
                BChapter byId = bChapterServiceImpl.findById(p);
                byId.setParentNodeState(status);
                bChapterServiceImpl.merge(byId);
            }
        }
        //sid跟上边一样
        List<String> sidList = Arrays.asList(sid.split(","));
        for (String s : sidList) {
            BChapter byId = bChapterServiceImpl.findById(s);
            byId.setIsOnTrial(status);
            bChapterServiceImpl.merge(byId);
        }
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                null);
    }


}
