package org.rcisoft.business.bchapter.dao;

import org.apache.ibatis.annotations.*;
import org.apache.ibatis.annotations.Param;
import org.rcisoft.business.blesson.entity.BLesson;
import org.rcisoft.core.mapper.CyBaseMapper;
import org.rcisoft.business.bchapter.entity.BChapter;
import org.springframework.stereotype.Repository;
import org.rcisoft.core.model.CyPageInfo;
import com.baomidou.mybatisplus.core.metadata.IPage;

import java.util.List;
import java.util.Map;

/**
 * Created with cy on 2024年3月23日 上午9:54:38.
 */
@Repository
public interface BChapterRepository extends CyBaseMapper<BChapter> {


    List<BChapter> queryBChapters(@Param("entity") BChapter bChapter);

    /**
     * 分页查询 bChapter
     */
    IPage<BChapter> queryBChaptersPaged(CyPageInfo cyPageInfo, @Param("entity") BChapter bChapter);

    /**
     * 根据课程id查找全部课程节点
     *
     * @param lessonId 课程id
     * @return
     */
    List<BChapter> queryAllChapter(@Param("lessonId") String lessonId);

    /**
     * 根据条件查找
     *
     * @param param
     * @return
     */
    List<BChapter> queryBChaptersByMap(Map<String, Object> param);

    /**
     * 获取用户全部课程全部章节的最后一条学习记录
     *
     * @return
     */
    List<BChapter> getLatestLearnRecord(@Param("userId") String userId);

    /**
     * 根据父节点查找子节点列表
     *
     * @param pid
     * @return
     */
    List<BChapter> queryBChaptersByPid(String pid);

    @Select("<script>select DISTINCT IFNULL((select max(sort) from tea_lesson_chapter where pid = #{pid} " +
            "and del_flag = 0 and flag = 1 " +
            "<if test=\"SlId !=null and SlId !=''\">AND sl_id = #{SlId} </if>" +
            "<if test=\"lessonId !=null and lessonId !=''\">AND lesson_id = #{lessonId} </if>),0)+1 as sort</script>")
    int selectMaxSort(@Param("pid") String pid,
                      @Param("SlId") String SlId,
                      @Param("lessonId") String lessonId);


    @Select("<script>select * from tea_lesson_chapter where sort &lt; #{sort} " +
            "AND pid = #{pid} and del_flag = 0 and flag = 1 " +
            "<if test=\"slId !=null and slId !=''\">AND sl_id = #{slId} </if> " +
            "<if test=\"lessonId !=null and lessonId !=''\">AND lesson_id = #{lessonId} </if> " +
            "ORDER BY sort desc LIMIT 1</script>")
    @ResultMap(value = "BaseResultMap")
    BChapter getlessChapter(BChapter bChapter);

    @Update("<script>update tea_lesson_chapter set sort = #{sort} where business_id = #{businessId}</script>")
    int updateSortById(@Param("businessId") String businessId, @Param("sort") int sort);

    @Select("<script>select * from tea_lesson_chapter where sort &gt; #{sort} " +
            "AND pid = #{pid} and del_flag = 0 and flag = 1 " +
            "<if test=\"slId !=null and slId !=''\">AND sl_id = #{slId} </if> " +
            "<if test=\"lessonId !=null and lessonId !=''\">AND lesson_id = #{lessonId} </if> " +
            "ORDER BY sort asc LIMIT 1</script>")
    @ResultMap(value = "BaseResultMap")
    BChapter getBigChapter(BChapter bChapter);

    BChapter getVideoUrl(String businessId);

    BLesson selectByliessonId(@Param("liessonId") String liessonId);

    Integer tryOrPayEnterprise(@Param("userId") String userId, @Param("lessonId") String lessonId, @Param("dept") String dept);

    Integer tryOrPayIndividual(@Param("userId") String userId, @Param("lessonId") String lessonId);

    String selectByUserId(@Param("dept") String dept);

    Integer validTime(@Param("lessonId") String lessonId, @Param("authenDept") String authenDept);

    Integer validTimeIndividual(@Param("id") String id, @Param("lessonId") String lessonId);

    Integer validTimeUnitAdmin(@Param("lessonId") String lessonId, @Param("authenDept") String authenDept);

    List<BLesson> selectLessonsByLessonIdAndUserId(@Param("lessonId") String lessonId,@Param("userId") Integer userId);
}

