package org.rcisoft.business.bchapter.service.impl;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.rcisoft.business.bchapter.dao.BChapterRepository;
import org.rcisoft.business.bchapter.entity.BChapter;
import org.rcisoft.business.bchapter.enums.ChapterLevelEnum;
import org.rcisoft.business.bchapter.service.BChapterService;
import org.rcisoft.business.bfile.dao.BFileRepository;
import org.rcisoft.business.blesson.entity.BLesson;
import org.rcisoft.business.pclessonlearntime.dao.PcLessonLearntimeRepository;
import org.rcisoft.business.pclessonlearntime.entity.PcLessonLearntime;
import org.rcisoft.business.sysuser.entity.SysUser;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.result.ResultServiceEnums;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;

import java.math.BigDecimal;
import java.util.*;
import java.util.stream.Collectors;

/**
 * Created by cy on 2024年3月23日 上午9:54:38.
 */
@Service
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class BChapterServiceImpl extends ServiceImpl<BChapterRepository, BChapter> implements BChapterService {

    @Autowired
    private BChapterRepository bChapterRepository;

    @Autowired
    private PcLessonLearntimeRepository pcLessonLearntimeRepository;

    @Autowired
    private BFileRepository bFileRepository;

    /**
     * 删除 章节表
     *
     * @param bChapter
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(BChapter bChapter) {
        int line = baseMapper.realDelete(bChapter);
        log.debug(CyUserUtil.getAuthenUsername() + "删除了ID为" +
                bChapter.getBusinessId() + "的章节表信息");
        return new CyPersistModel(line);
    }

    /**
     * 逻辑删除 章节表
     *
     * @param bChapter
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(BChapter bChapter) {
        bChapter.setDeleted();
        int line = baseMapper.deleteById(bChapter);
        log.debug(CyUserUtil.getAuthenUsername() + "逻辑删除了ID为" +
                bChapter.getBusinessId() + "的章节表信息");
        return new CyPersistModel(line);
    }

    /**
     * 修改 章节表
     *
     * @param bChapter
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(BChapter bChapter) {
        int line = baseMapper.updateById(bChapter);
        log.debug(CyUserUtil.getAuthenUsername() + "修改了ID为" + bChapter.getBusinessId() + "的章节表信息");
        return new CyPersistModel(line);
    }

    /**
     * 根据id查询 章节表
     *
     * @param id
     * @return
     */
    @Override
    public BChapter findById(String id) {
        return baseMapper.selectById(id);
    }

    /**
     * 分页查询 章节表
     *
     * @param bChapter
     * @return
     */
    @Override
    public IPage<BChapter> findAllByPagination(CyPageInfo<BChapter> paginationUtility,
                                               BChapter bChapter) {
        return baseMapper.queryBChaptersPaged(paginationUtility, bChapter);

    }

    /**
     * 查询list 章节表
     *
     * @param bChapter
     * @return
     */
    @Override
    public List<BChapter> findAll(BChapter bChapter) {
        return baseMapper.queryBChapters(bChapter);
    }

    /**
     * 获取用户全部课程全部章节的最后一条学习记录
     *
     * @return
     */
    @Override
    public List<BChapter> getLatestLearnRecord(String userId) {
        // 获取当前登录人id
        String loginUserId = CyUserUtil.getAuthenBusinessId();
        if (StringUtils.isNotBlank(userId)) {
            return baseMapper.getLatestLearnRecord(userId);
        } else {
            return baseMapper.getLatestLearnRecord(loginUserId);
        }
    }

    /**
     * 导出章节表 exam
     *
     * @return
     */
    @Override
    public List<BChapter> export(BChapter bChapter) {
        List<BChapter> bChapterList = baseMapper.queryBChapters(bChapter);
        return bChapterList;
    }

    @Override
    public List<BChapter> queryBChaptersByPagination(CyPageInfo<BChapter> paginationUtility, BChapter model) {
        Map param = new HashMap<String, Object>();
        return bChapterRepository.queryBChaptersByMap(param);
    }

    @Override
    public List<BChapter> queryBChapters(BChapter bChapter, String token) {
        //当前课程的详细信息
        BLesson bLesson = bChapterRepository.selectByliessonId(bChapter.getLessonId());
        //当前章节id BLesson
        String currentChapter = null;
        List<BChapter> allChapter = bChapterRepository.queryAllChapter(bChapter.getLessonId());
        allChapter.forEach(chapter -> {
            if (chapter.getVideoUrl() != null) {
                chapter.setIsVideo("1");
            } else {
                chapter.setIsVideo("0");
            }
        });

        Object uesr = CyUserUtil.getUserInfoObjProp(token, "username:" + CyUserUtil.getAuthenUsername());
        SysUser sysUser = null;
        if (uesr != null) {
            //将object 转换为 user对象
            sysUser = JSON.parseObject(JSON.toJSONString(uesr), SysUser.class);
            if (!sysUser.getIdentity().equals("1")) {
                //1.免费课程不需要隐藏url 及价格 = 0
                if (BigDecimal.ZERO.compareTo(bLesson.getLessonPrice()) != 0) {
                    //查询当前人物 个人还是单位 是试用还是已开课
                    String authenDept = CyUserUtil.getAuthenDept();
                    String id = CyUserUtil.getAuthenBusinessId();
                    //1.单位开了试用课后 给了那些人看
                    if (authenDept != null && !"null".equals(authenDept)) {
                        //判断一下当前用户是否为单位管理员
                        String s = bChapterRepository.selectByUserId(authenDept);
                        if (s.equals(id)) {
                            //单位管理员不添加课程 所以不需要添加课程
                            Integer i = bChapterRepository.tryOrPayEnterprise(null, bChapter.getLessonId(), authenDept);
                            //判断课程的使用时间是否有效
                            Integer i1 = bChapterRepository.validTimeUnitAdmin(bChapter.getLessonId(), authenDept);
                            // i= null 没有当前课程  i= 0 试用 i1 = 0 是过期
                            if (i == null || i == 0 || i1 == 0) {
                                //未购买只展示试听 /有效时间过了
                                if (i == null || i1 == 0) {
                                    allChapter.forEach(chapter -> {
                                        //当课程不是试听
                                        if (chapter.getIsAudition().equals("0")) {
                                            chapter.setVideoUrl(null);
                                        }
                                    });
                                } else if (i == 0 && i1 == 1) {//试用
                                    allChapter.forEach(chapter -> {
                                        //当课程不是试看或者试听
                                        if (chapter.getIsOnTrial().equals("0") && chapter.getIsAudition().equals("0")) {
                                            chapter.setVideoUrl(null);
                                        }
                                    });
                                }
                            }
                        } else {
                            //查询当前单位的课程是否开课付费
                            Integer i = bChapterRepository.tryOrPayEnterprise(id, bChapter.getLessonId(), authenDept);
                            //判断课程的使用时间是否有效
//                            Integer i1 = bChapterRepository.validTime(bChapter.getLessonId(), authenDept);
                            Integer i1 = 1;
                            //查询出当前用户拥有的不同角色下的这门课程
                            List<BLesson> list = bChapterRepository.selectLessonsByLessonIdAndUserId(bChapter.getLessonId(),sysUser.getBusinessId());
                            //找出当前课程的最小开始时间和最大结束时间
                            if (!list.isEmpty()) {
                                BLesson one = new BLesson();
                                BeanUtils.copyProperties(list.get(0), one);
                                // 找出具有最小startTime的BLesson
                                Optional<BLesson> minStartTime = list.stream()
                                        .min(Comparator.comparing(BLesson::getStartTime));
                                Optional<BLesson> maxEndTime = list.stream()
                                        .max(Comparator.comparing(BLesson::getEndTime));
                                Date startTime = minStartTime.map(BLesson::getStartTime).orElse(null);
                                Date endTime = maxEndTime.map(BLesson::getEndTime).orElse(null);
                                one.setStartTime(startTime);
                                one.setEndTime(endTime);
                                // 使用 Calendar 让endTime 增加 23 小时 59 分钟 59 秒
                                Calendar calendar = Calendar.getInstance();
                                calendar.setTime(endTime);
                                calendar.add(Calendar.HOUR_OF_DAY, 23);
                                calendar.add(Calendar.MINUTE, 59);
                                calendar.add(Calendar.SECOND, 59);

                                Date newEndTime = calendar.getTime();
                                //与当前时间进行比对 如果过期，就把blesson.isExpired设置为1
                                if (new Date().after(newEndTime)) {
                                    one.setIsExpired("1");
                                } else {
                                    one.setIsExpired("0");
                                }
                                //判断当前时间是否在课程时间范围内,如果不在范围内，将i1设为0
                                if (new Date().after(startTime) && new Date().before(newEndTime)) {
                                    //没过期
                                    i1 = 1;
                                } else {
                                    //过期
                                    i1 = 0;
                                }
                            }
                            //因为 上边查询课程返回的是全部的 章节+视频id 所以当 试看时需要将 非试看的 视频id 置空
                            if (i == null || i == 0 || i1 == 0) {
                                //未购买只展示试听
                                if (i == null || i1 == 0) {
                                    allChapter.forEach(chapter -> {
                                        //当课程不是试看或者试听
                                        if (chapter.getIsAudition().equals("0")) {
                                            chapter.setVideoUrl(null);
                                        }
                                    });
                                } else if (i == 0 && i1 == 1) {//试用
                                    allChapter.forEach(chapter -> {
                                        //当课程不是试看或者试听
                                        if (chapter.getIsOnTrial().equals("0") && chapter.getIsAudition().equals("0")) {
                                            chapter.setVideoUrl(null);
                                        }
                                    });
                                }


                            }
                        }


                    }
                    //2.个人是否 开课付费看了
                    if ("null".equals(authenDept)) {
                        //查询当前人是否付费    返回0 未付费  试看     / 1付费1付费
                        Integer i = bChapterRepository.tryOrPayIndividual(id, bChapter.getLessonId());
                        //判断当前时间是否在开始日志以及结束日期之间 0 未在时间内/ 1在时间内
                        Integer i1 = bChapterRepository.validTimeIndividual(id, bChapter.getLessonId());

                        //因为 上边查询课程返回的是全部的 章节+视频id 所以当 试看时需要将 非试看的 视频id 置空
                        if (i == null || i == 0 || i1 == 0) {
                            //未购买只展示试听
                            if (i == null || i1 == 0) {
                                allChapter.forEach(chapter -> {
                                    //当课程不是试看或者试听
                                    if (chapter.getIsAudition().equals("0")) {
                                        chapter.setVideoUrl(null);
                                    }
                                });
                            } else if (i == 0 && i1 == 1) {//试用
                                allChapter.forEach(chapter -> {
                                    //当课程不是试看或者试听
                                    if (chapter.getIsOnTrial().equals("0") && chapter.getIsAudition().equals("0")) {
                                        chapter.setVideoUrl(null);
                                    }
                                });
                            }

                        }
                    }
                }
            }
        } else {
            allChapter.forEach(chapter -> {
                //没有用户的时候
                if (chapter.getIsAudition().equals("0")) {
                    chapter.setVideoUrl(null);
                }
            });
        }


        //查询课程中的每节是否学习完成
        String authenBusinessId = CyUserUtil.getAuthenBusinessId();
        if (StringUtils.isNotEmpty(authenBusinessId)) {
            QueryWrapper<PcLessonLearntime> qw = new QueryWrapper<>();
            qw.eq("user_id", authenBusinessId)
                    .eq("lesson_id", bChapter.getLessonId())
                    .eq("del_flag", 0)
                    .orderByDesc("update_date");
            List<PcLessonLearntime> pcLessonLearntimes = pcLessonLearntimeRepository.selectList(qw);
            if (!CollectionUtils.isEmpty(allChapter) && !CollectionUtils.isEmpty(pcLessonLearntimes)) {
                currentChapter = pcLessonLearntimes.get(0).getChapterId();
                allChapter.forEach(chapter -> {
                    if (pcLessonLearntimes.stream().anyMatch(pcLessonLearntime -> pcLessonLearntime.getChapterId().equals(chapter.getBusinessId()))) {
                        chapter.setIsComplete(pcLessonLearntimes.stream().filter(pcLessonLearntime ->
                                pcLessonLearntime.getChapterId()
                                        .equals(chapter.getBusinessId())).findFirst().get().getChapterComplete());
                    }
                });
            }
        }

        // 获取一级节点并按sort字段升序排序
        List<BChapter> chapterList = allChapter.stream()
                .filter(chapter -> chapter.getPid().equals("-1"))
                .sorted(Comparator.comparing(BChapter::getSort))
                .peek(chapter -> chapter.setChildList(buildChildList(chapter, allChapter)))
                .collect(Collectors.toList());

        //设置当前章节
        if (StringUtils.isNotEmpty(currentChapter)) {
            chapterList.get(0).setCurrentChapter(currentChapter);
        }
        return chapterList;
    }

    /**
     * 递归组装目录子节点数据
     *
     * @param parentChapter
     * @param allChapter
     * @return
     */
    private List<BChapter> buildChildList(BChapter parentChapter, List<BChapter> allChapter) {
        return allChapter.stream()
                .filter(chapter -> chapter.getPid().equals(parentChapter.getBusinessId()))
                .sorted(Comparator.comparing(BChapter::getSort))
                .peek(chapter -> chapter.setChildList(buildChildList(chapter, allChapter)))
                .collect(Collectors.toList());
    }

    @Override
    @Transactional(propagation = Propagation.REQUIRED, readOnly = false)
    public CyPersistModel removeBChapter(String id, String lessonOrSl) {
        BChapter bChapter = bChapterRepository.selectById(id);
        if (bChapter == null)
            throw new CyServiceException(ResultServiceEnums.CHAPTER_NOT_EXISTS.getCode(), ResultServiceEnums.CHAPTER_NOT_EXISTS.getMessage());
        List<BChapter> childList = bChapterRepository.queryBChaptersByPid(id);
        boolean hasChild = childList != null && childList.size() > 0;
        boolean isChapter = bChapter.getChapterLevel() == ChapterLevelEnum.CHAPTER.getCode();
        if (isChapter && hasChild) {
            throw new CyServiceException(ResultServiceEnums.CHAPTER_HAS_CHILD.getCode(), ResultServiceEnums.CHAPTER_HAS_CHILD.getMessage());
        }
        int line = bChapterRepository.deleteById(id);
        return new CyPersistModel(line);
    }

    /**
     * 章节向上调整顺序
     *
     * @param bChapter
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, readOnly = false)
    @Override
    public int updateTopChapter(BChapter bChapter) {
        int result = 0;
        BChapter lessChapter = bChapterRepository.getlessChapter(bChapter);
        int sort = bChapter.getSort();
        int lessSort = lessChapter.getSort();
        int data = bChapterRepository.updateSortById(bChapter.getBusinessId(), lessSort);
        int data2 = bChapterRepository.updateSortById(lessChapter.getBusinessId(), sort);
        if (data == data2) {
            result = 1;
        }
        return result;
    }

    /**
     * 章节向上调整顺序
     *
     * @param bChapter
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, readOnly = false)
    @Override
    public int updateDownChapter(BChapter bChapter) {
        int result = 0;
        BChapter bigChapter = bChapterRepository.getBigChapter(bChapter);
        int sort = bChapter.getSort();
        int bigSort = bigChapter.getSort();
        int data = bChapterRepository.updateSortById(bChapter.getBusinessId(), bigSort);
        int data2 = bChapterRepository.updateSortById(bigChapter.getBusinessId(), sort);
        if (data == data2) {
            result = 1;
        }
        return result;
    }

    /**
     * 查询节信息
     *
     * @param param
     * @return
     */
    @Override
    public List<BChapter> querySections(BChapter param) {
        List<BChapter> list = bChapterRepository.queryBChaptersByPid(param.getBusinessId());
        return list;
    }

    @Override
    public BChapter getVideoUrl(String businessId) {
        return baseMapper.getVideoUrl(businessId);
    }

    @Override
    public Object queryBChaptersWithoutAuthTeacher(BChapter bChapter, String token) {
        //当前课程的详细信息
        BLesson bLesson = bChapterRepository.selectByliessonId(bChapter.getLessonId());
        //当前章节id BLesson
        String currentChapter = null;
        List<BChapter> allChapter = bChapterRepository.queryAllChapter(bChapter.getLessonId());
        allChapter.forEach(chapter -> {
            if (chapter.getVideoUrl() != null) {
                chapter.setIsVideo("1");
            } else {
                chapter.setIsVideo("0");
            }
        });
        // 获取一级节点并按sort字段升序排序
        List<BChapter> chapterList = allChapter.stream()
                .filter(chapter -> chapter.getPid().equals("-1"))
                .sorted(Comparator.comparing(BChapter::getSort))
                .peek(chapter -> chapter.setChildList(buildChildList(chapter, allChapter)))
                .collect(Collectors.toList());

        //设置当前章节
        if (StringUtils.isNotEmpty(currentChapter)) {
            chapterList.get(0).setCurrentChapter(currentChapter);
        }
        return chapterList;
    }

    @Override
    public List<BChapter> queryBChaptersWithoutAuthWEB(BChapter bChapter, String token) {
        //当前课程的详细信息
        BLesson bLesson = bChapterRepository.selectByliessonId(bChapter.getLessonId());
        //当前章节id BLesson
        String currentChapter = null;
        List<BChapter> allChapter = bChapterRepository.queryAllChapter(bChapter.getLessonId());
        allChapter.forEach(chapter -> {
            if (chapter.getVideoUrl() != null) {
                chapter.setIsVideo("1");
            } else {
                chapter.setIsVideo("0");
            }
        });
        List<BChapter> chapterList = allChapter.stream()
                .filter(chapter -> chapter.getPid().equals("-1"))
                .sorted(Comparator.comparing(BChapter::getSort))
                .peek(chapter -> chapter.setChildList(buildChildList(chapter, allChapter)))
                .collect(Collectors.toList());

        //设置当前章节
        if (StringUtils.isNotEmpty(currentChapter)) {
            chapterList.get(0).setCurrentChapter(currentChapter);
        }
        return chapterList;
    }


    /**
     * 保存 章节表
     *
     * @param model
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, readOnly = false)
    @Override
    public CyPersistModel persist(BChapter model, String token) {
        int line = 0;
        if (model.getBusinessId() == null) {
            CyUserUtil.setCurrentPersistOperation(model);
            if (model.getClassHour() == null || model.getClassHour().equals("")) {
                model.setClassHour("");
            }
            if (model.getIsTest() == null || model.getIsTest().equals("")) {
                model.setIsTest("");
            }
            int sort = bChapterRepository.selectMaxSort(model.getPid(), model.getSlId(), model.getLessonId());
            model.setSort(sort);
            line = bChapterRepository.insert(model);
        } else {
            CyUserUtil.setCurrentMergeOperation(model);
            line = bChapterRepository.updateById(model);
        }
        return new CyPersistModel(line);
    }
}
