package org.rcisoft.business.bdirection.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.model.SelectModel;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.exception.CyServiceException;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;


import org.rcisoft.business.bdirection.entity.BDirection;
import org.rcisoft.business.bdirection.service.BDirectionService;

import java.util.List;

/**
* Created by cy on 2024年3月25日 上午10:46:10.
*/
@RestController
@RequestMapping("/bdirection")
public class BDirectionController extends CyPaginationController<BDirection> {


    @Autowired
    private BDirectionService bDirectionServiceImpl;

    //@PreAuthorize("@cyPerm.hasPerm('sys:rection:add')")
    @CyOpeLogAnno(title = "system-BDirection管理-新增BDirection", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="添加BDirection", notes="添加BDirection")
    @PostMapping(value = "/add")
    public CyResult add(@Valid BDirection bDirection, BindingResult bindingResult) {
        CyPersistModel data = bDirectionServiceImpl.persist(bDirection);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        bDirection);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:rection:delete')")
    @CyOpeLogAnno(title = "system-BDirection管理-删除BDirection", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="逻辑删除BDirection", notes="逻辑删除BDirection")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable String businessId,BDirection bDirection) {
        bDirection.setBusinessId(businessId);
        CyPersistModel data = bDirectionServiceImpl.removeLogical(bDirection);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:rection:delete')")
    @CyOpeLogAnno(title = "system-BDirection管理-删除BDirection", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="删除BDirection", notes="删除BDirection")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable String businessId,BDirection bDirection) {
        bDirection.setBusinessId(businessId);
        CyPersistModel data = bDirectionServiceImpl.remove(bDirection);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:rection:update')")
    @CyOpeLogAnno(title = "system-BDirection管理-修改BDirection", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改BDirection", notes="修改BDirection")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable String businessId, @Valid BDirection bDirection, BindingResult bindingResult) {
        bDirection.setBusinessId(businessId);
        CyPersistModel data = bDirectionServiceImpl.merge(bDirection);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        bDirection);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:rection:query')")
    @CyOpeLogAnno(title = "system-BDirection管理-查询BDirection", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单一BDirection", notes="查询单一BDirection")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable String businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        bDirectionServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:rection:list')")
    @CyOpeLogAnno(title = "system-BDirection管理-查询BDirection", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询BDirection集合", notes="查询BDirection集合")
    @GetMapping(value = "/queryBDirections")
    public CyResult queryBDirections(BDirection bDirection) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            bDirectionServiceImpl.findAll(bDirection));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:rection:list')")
    @CyOpeLogAnno(title = "system-BDirection管理-查询BDirection", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="分页查询BDirection集合", notes="分页查询BDirection集合")
    @GetMapping(value = "/queryBDirectionByPagination")
    public CyGridModel listByPagination(BDirection bDirection) {
        bDirectionServiceImpl.findAllByPagination(getPaginationUtility(), bDirection);
        return getGridModelResponse();
    }

    @CyOpeLogAnno(title = "system-BDirection管理-查询BDirection", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出BDirection信息", notes = "导出BDirection信息")
    @GetMapping(value = "/export")
    public void outBDirection(HttpServletResponse response,BDirection bDirection,@PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="BDirection信息.xls";break;
            case "1": excelName="BDirection信息.xlsx";break;
            case "2": excelName="BDirection信息.csv";break;
        }
        List<BDirection> bDirectionList = bDirectionServiceImpl.export(bDirection);
        CyEpExcelUtil.exportExcel(bDirectionList, "BDirection信息", "BDirection信息", BDirection.class, excelName, response);
    }



    @ApiOperation(value="查询方向列表", notes="查询方向列表赋值在下拉框中")
    @GetMapping(value = "/queryDirectionsList")
    public CyResult queryDirectionsList() {
        List<SelectModel> directions = bDirectionServiceImpl.queryDirectionsList();
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                directions);
    }
}
