package org.rcisoft.business.bdirection.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.rcisoft.core.model.SelectModel;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.aop.CyPageUtilAsp;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.business.bdirection.dao.BDirectionRepository;
import org.rcisoft.business.bdirection.entity.BDirection;
import org.rcisoft.business.bdirection.service.BDirectionService;
import org.rcisoft.core.service.CyBaseService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.rcisoft.core.model.CyPageInfo;

import java.util.ArrayList;
import java.util.List;
import lombok.extern.slf4j.Slf4j;

/**
 * Created by cy on 2024年3月25日 上午10:46:10.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class BDirectionServiceImpl extends ServiceImpl<BDirectionRepository,BDirection>  implements BDirectionService {

    @Autowired
    private BDirectionRepository bDirectionRepository;


    /**
    * 保存
    * @param bDirection
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(BDirection bDirection){
        //增加操作
        int line = baseMapper.insert(bDirection);
        log.debug(CyUserUtil.getAuthenUsername()+"新增了ID为"+
            bDirection.getBusinessId()+"的信息");
        return new CyPersistModel(line);
    }

    /**
    * 删除
    * @param bDirection
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(BDirection bDirection){
        int line = baseMapper.realDelete(bDirection);
        log.debug(CyUserUtil.getAuthenUsername()+"删除了ID为"+
            bDirection.getBusinessId()+"的信息");
        return new CyPersistModel(line);
    }

    /**
    * 逻辑删除
    * @param bDirection
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(BDirection bDirection){
        bDirection.setDeleted();
        int line = baseMapper.deleteById(bDirection);
            log.debug(CyUserUtil.getAuthenUsername()+"逻辑删除了ID为"+
                bDirection.getBusinessId()+"的信息");
            return new CyPersistModel(line);
    }

    /**
    * 修改
    * @param bDirection
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(BDirection bDirection){
        int line = baseMapper.updateById(bDirection);
        log.debug(CyUserUtil.getAuthenUsername()+"修改了ID为"+ bDirection.getBusinessId()+"的信息");
        return new CyPersistModel(line);
    }

    /**
    * 根据id查询
    * @param id
    * @return
    */
    @Override
    public BDirection findById(String id){
        return baseMapper.selectById(id);
    }

    /**
    * 分页查询
    * @param bDirection
    * @return
    */
    @Override
    public IPage<BDirection> findAllByPagination(CyPageInfo<BDirection> paginationUtility,
        BDirection bDirection){
        return baseMapper.queryBDirectionsPaged(paginationUtility,bDirection);

    }

    /**
    * 查询list
    * @param bDirection
    * @return
    */
    @Override
    public List<BDirection> findAll(BDirection bDirection){
        return baseMapper.queryBDirections(bDirection);

    }

    /**
    * 导出
    * @return
    */
    @Override
    public List<BDirection> export(BDirection bDirection) {
        List<BDirection> bDirectionList = baseMapper.queryBDirections(bDirection);
        return bDirectionList;
    }

    @Override
    public List<SelectModel> queryDirectionsList() {
        List<BDirection> bDirection = bDirectionRepository.queryDirectionsList();
        ArrayList<SelectModel> comBoxModel = new ArrayList<SelectModel>();
        for(BDirection c : bDirection){
            SelectModel selectModel = new SelectModel();
            selectModel.setId(c.getBusinessId());
            selectModel.setText(c.getName());
            comBoxModel.add(selectModel);
        }
        return comBoxModel;
    }

}
