package org.rcisoft.business.bfile.controller;


/*固定导入*/

import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.business.bfile.entity.BFile;
import org.rcisoft.business.bfile.service.BFileService;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.core.util.CyResultGenUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.util.List;

/**
 * Created by cy on 2024年3月23日 上午9:54:37.
 */
@RestController
@RequestMapping("/bfile")
public class BFileController extends CyPaginationController<BFile> {


    @Autowired
    private BFileService bFileServiceImpl;

    //@PreAuthorize("@cyPerm.hasPerm('sys:le:add')")
    @CyOpeLogAnno(title = "system-视频表管理-新增视频表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value = "添加视频表", notes = "添加视频表")
    @PostMapping(value = "/add")
    public CyResult add(@Valid BFile bFile, BindingResult bindingResult) {
        CyPersistModel data = bFileServiceImpl.persist(bFile);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bFile);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:le:delete')")
    @CyOpeLogAnno(title = "system-视频表管理-删除视频表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value = "逻辑删除视频表", notes = "逻辑删除视频表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable String businessId, BFile bFile) {
        bFile.setBusinessId(businessId);
        CyPersistModel data = bFileServiceImpl.removeLogical(bFile);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:le:delete')")
    @CyOpeLogAnno(title = "system-视频表管理-删除视频表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value = "删除视频表", notes = "删除视频表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable String businessId, BFile bFile) {
        bFile.setBusinessId(businessId);
        CyPersistModel data = bFileServiceImpl.remove(bFile);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:le:update')")
    @CyOpeLogAnno(title = "system-视频表管理-修改视频表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value = "修改视频表", notes = "修改视频表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable String businessId, @Valid BFile bFile, BindingResult bindingResult) {
        bFile.setBusinessId(businessId);
        CyPersistModel data = bFileServiceImpl.merge(bFile);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bFile);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:le:query')")
    @CyOpeLogAnno(title = "system-视频表管理-查询视频表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询单一视频表", notes = "查询单一视频表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable String businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bFileServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:le:list')")
    @CyOpeLogAnno(title = "system-视频表管理-查询视频表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询视频表集合", notes = "查询视频表集合")
    @GetMapping(value = "/queryBFiles")
    public CyResult queryBFiles(BFile bFile) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bFileServiceImpl.findAll(bFile));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:le:list')")
    @CyOpeLogAnno(title = "system-视频表管理-查询视频表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "分页查询视频表集合", notes = "分页查询视频表集合")
    @GetMapping(value = "/queryBFileByPagination")
    public CyGridModel listByPagination(BFile bFile) {
        bFileServiceImpl.findAllByPagination(getPaginationUtility(), bFile);
        return getGridModelResponse();
    }

    @CyOpeLogAnno(title = "system-视频表管理-查询视频表", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出视频表信息", notes = "导出视频表信息")
    @GetMapping(value = "/export")
    public void outBFile(HttpServletResponse response, BFile bFile, @PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName = "";
        switch (excelId) {
            case "0":
                excelName = "视频表信息.xls";
                break;
            case "1":
                excelName = "视频表信息.xlsx";
                break;
            case "2":
                excelName = "视频表信息.csv";
                break;
        }
        List<BFile> bFileList = bFileServiceImpl.export(bFile);
        CyEpExcelUtil.exportExcel(bFileList, "视频表信息", "视频表信息", BFile.class, excelName, response);
    }


    @ApiOperation(value = "上传文件", notes = "上传文件")
    @ApiImplicitParams({@ApiImplicitParam(name = "chapterId", value = "章节ID", required = true, dataType = "varchar"),
            @ApiImplicitParam(name = "lessonId", value = "课程ID", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "slId", value = "开课ID", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "type", value = "'0'为视频，'1'为pdf", required = true, dataType = "varchar"),
            @ApiImplicitParam(name = "temp", value = "video，pdf", required = true, dataType = "varchar"),
            @ApiImplicitParam(name = "file", value = "视频文件", required = true, dataType = "MultipartFile")})
    // @PreAuthorize("@cyPerm.hasPerm('sys:le:uploadVideo')")
    @PostMapping(value = "/uploadVideo")
    public CyResult uploadVideo(BFile bFile, String temp, HttpServletRequest request) {
        List<MultipartFile> list = ((MultipartHttpServletRequest) request).getFiles("file");
        String videoUrl = bFileServiceImpl.uploadVideoToServer(list, bFile, temp, getToken());
        return CyResultGenUtil.builder(new CyPersistModel(1),
                "上传成功",
                CyMessCons.MESSAGE_ALERT_ERROR,
                videoUrl);
    }

    // @PreAuthorize("@cyPerm.hasPerm('sys:le:delete')")
    @CyOpeLogAnno(title = "system-视频表管理-删除视频表_删除上传文件", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value = "删除视频表_删除上传文件", notes = "删除视频表_删除上传文件")
    @ApiImplicitParams({@ApiImplicitParam(name = "chapterId", value = "章节ID", required = true, dataType = "varchar"),
            @ApiImplicitParam(name = "lessonId", value = "课程ID", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "slId", value = "开课ID", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "type", value = "'0'为视频，'1'为pdf", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteFile")
    public CyResult deleteFile(BFile bFile, String ossId) {
        BFile file = bFileServiceImpl.removeFile(bFile, ossId);
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                file);
    }

    @ApiOperation(value = "章节查询视频url地址", notes = "章节查询视频url地址")
    @ApiImplicitParams({@ApiImplicitParam(name = "chapterId", value = "章节ID", required = true, dataType = "varchar"),
            @ApiImplicitParam(name = "lessonId", value = "课程ID", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "slId", value = "开课ID", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "type", value = "'0'为视频，'1'为pdf", required = true, dataType = "varchar")})
//   // @PreAuthorize("@cyPerm.hasPerm('sys:le:findVideoUrl')")
    @PostMapping(value = "/findVideoUrl")
    public CyResult findVideoUrl(BFile bFile) {
        BFile file = bFileServiceImpl.findVideoUrl(bFile, getToken());
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                file);
    }

    @ApiOperation(value = "章节查询视频url地址", notes = "章节查询视频url地址")
    @ApiImplicitParams({@ApiImplicitParam(name = "chapterId", value = "章节ID", required = true, dataType = "varchar"),
            @ApiImplicitParam(name = "lessonId", value = "课程ID", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "slId", value = "开课ID", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "type", value = "'0'为视频，'1'为pdf", required = true, dataType = "varchar")})
//   // @PreAuthorize("@cyPerm.hasPerm('sys:le:findVideoUrl')")
    @PostMapping(value = "/findVideoUrlTeacher")
    public CyResult findVideoUrlTeacher(BFile bFile) throws Exception {
        BFile file = bFileServiceImpl.findVideoUrlTeacher(bFile, getToken());
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                file);
    }


    @ApiOperation(value = "章节查询PDF信息", notes = "章节查询PDF信息")
    @ApiImplicitParams({@ApiImplicitParam(name = "chapterId", value = "章节ID", required = true, dataType = "varchar"),
            @ApiImplicitParam(name = "lessonId", value = "课程ID", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "slId", value = "开课ID", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "type", value = "'0'为视频，'1'为pdf", required = true, dataType = "varchar")})
    // @PreAuthorize("@cyPerm.hasPerm('sys:le:findPdfInfo')")
    @PostMapping(value = "/findPdfInfo")
    public CyResult findPdfInfo(BFile bFile) {
        BFile file = bFileServiceImpl.findPdfInfo(bFile, getToken());
        return CyResultGenUtil.builder(new CyPersistModel(1),
                "上传成功",
                CyMessCons.MESSAGE_ALERT_ERROR,
                file);
    }

    @ApiOperation(value = "章节查询PDF_url信息", notes = "章节查询PDF_url信息")
    @ApiImplicitParams({@ApiImplicitParam(name = "chapterId", value = "章节ID", required = true, dataType = "varchar"),
            @ApiImplicitParam(name = "lessonId", value = "课程ID", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "slId", value = "开课ID", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "type", value = "'0'为视频，'1'为pdf", required = true, dataType = "varchar")})
    // @PreAuthorize("@cyPerm.hasPerm('sys:le:findPdfUrl')")
    @PostMapping(value = "/findPdfUrl")
    public CyResult findPdfUrl(BFile bFile) {
        BFile pdfUrl = bFileServiceImpl.findPdfUrl(bFile, getToken());
        return CyResultGenUtil.builder(new CyPersistModel(1),
                "上传成功",
                CyMessCons.MESSAGE_ALERT_ERROR,
                pdfUrl);
    }

    @ApiOperation(value = "上传课程资料", notes = "上传课程资料")
    @ApiImplicitParams({@ApiImplicitParam(name = "chapterId", value = "章节ID", required = true, dataType = "varchar"),
            @ApiImplicitParam(name = "lessonId", value = "课程ID", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "slId", value = "开课ID", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "type", value = "'0'为视频，'1'为pdf", required = true, dataType = "varchar"),
            @ApiImplicitParam(name = "temp", value = "package", required = true, dataType = "varchar"),
            @ApiImplicitParam(name = "file", value = "压缩包", required = true, dataType = "MultipartFile")})
    // @PreAuthorize("@cyPerm.hasPerm('sys:le:uploadVideo')")
    @PostMapping(value = "/uploadData")
    public CyResult uploadData(BFile bFile, String temp, HttpServletRequest request) {
        List<MultipartFile> list = ((MultipartHttpServletRequest) request).getFiles("file");
        String videoUrl = bFileServiceImpl.uploadDataToServer(list, bFile, temp, getToken());
        return CyResultGenUtil.builder(new CyPersistModel(1),
                "上传成功",
                CyMessCons.MESSAGE_ALERT_ERROR,
                videoUrl);
    }


    @ApiOperation(value = "课程查询课程文件路径", notes = "课程查询课程文件路径")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "lessonId", value = "课程ID", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "slId", value = "开课ID", required = false, dataType = "varchar"),})
//   // @PreAuthorize("@cyPerm.hasPerm('sys:le:findPdfUrl')")
    @PostMapping(value = "/findDataUrl")
    public CyResult findDataUrl(BFile bFile) {
        BFile pdfUrl = bFileServiceImpl.findDataUrl(bFile, getToken());
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                pdfUrl);
    }

    @ApiOperation(value = "下载课程文件", notes = "下载课程文件")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "lessonId", value = "课程ID", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "lessonId", value = "课程ID", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "lessonId", value = "课程ID", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "slId", value = "开课ID", required = false, dataType = "varchar"),})
    // @PreAuthorize("@cyPerm.hasPerm('sys:le:download')")
    @PostMapping(value = "/download")
    public CyResult downloadData(BFile bFile, HttpServletResponse response) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bFileServiceImpl.download(bFile, response, getToken()));
    }

    // @PreAuthorize("@cyPerm.hasPerm('sys:le:delete')")
    @CyOpeLogAnno(title = "删除课程文件", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value = "删除课程文件", notes = "删除课程文件")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "lessonId", value = "课程ID", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "slId", value = "开课ID", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "ossId", value = "文件ID", required = false, dataType = "varchar")})
    @DeleteMapping("/deleteDataFile")
    public CyResult deleteDataFile(BFile bFile, String ossId) {
        BFile file = bFileServiceImpl.removeDataFile(bFile, ossId);
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                file);
    }

}
