package org.rcisoft.business.bfile.service.impl;

import com.alibaba.fastjson.JSON;
import com.aliyun.oss.HttpMethod;
import com.aliyun.oss.OSS;
import com.aliyun.oss.OSSClientBuilder;
import com.aliyun.oss.model.GeneratePresignedUrlRequest;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fasterxml.jackson.databind.ObjectMapper;
import lombok.SneakyThrows;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.io.FileUtils;
import org.apache.commons.lang3.StringUtils;
import org.rcisoft.business.bchapter.dao.BChapterRepository;
import org.rcisoft.business.bchapter.entity.BChapter;
import org.rcisoft.business.bfile.dao.BFileRepository;
import org.rcisoft.business.bfile.entity.BFile;
import org.rcisoft.business.bfile.service.BFileService;
import org.rcisoft.business.blesson.entity.BLesson;
import org.rcisoft.business.blesson.service.BLessonService;
import org.rcisoft.business.ossinfo.dao.OssInfoRepository;
import org.rcisoft.business.ossinfo.entity.OssInfo;
import org.rcisoft.business.sysuser.dao.PCSysUserRepository;
import org.rcisoft.business.sysuser.entity.SysUser;
import org.rcisoft.business.sysuser.enums.IdentityStaCons;
import org.rcisoft.business.teatrialcourse.dao.TeaTrialCourseRepository;
import org.rcisoft.business.teatrialcourse.dto.TrialCourseDto;
import org.rcisoft.common.component.Global;
import org.rcisoft.common.component.OssGlobal;
import org.rcisoft.core.controller.CyCommonController;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyIdGenUtil;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.util.RSAUtil;
import org.rcisoft.result.ResultServiceEnums;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.io.File;
import java.io.IOException;
import java.math.BigDecimal;
import java.net.URL;
import java.util.*;

/**
 * Created by cy on 2024年3月23日 上午9:54:37.
 */
@Service
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class BFileServiceImpl extends ServiceImpl<BFileRepository, BFile> implements BFileService {

    @Autowired
    private BFileRepository bFileRepository;

    @Autowired
    private Global global;

    @Autowired
    private CyCommonController cyCommonController;

    @Autowired
    private OssInfoRepository ossInfoRepository;

    @Autowired
    private PCSysUserRepository pcSysUserRepository;

    @Autowired
    private TeaTrialCourseRepository teaTrialCourseRepository;
    @Autowired
    private BLessonService bLessonService;

    @Autowired
    private BChapterRepository bChapterRepository;
    @Autowired
    private OssGlobal ossGlobal;

    /**
     * 保存 视频表
     *
     * @param bFile
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(BFile bFile) {
        //增加操作
        int line = baseMapper.insert(bFile);
        log.debug(CyUserUtil.getAuthenUsername() + "新增了ID为" +
                bFile.getBusinessId() + "的视频表信息");
        return new CyPersistModel(line);
    }

    /**
     * 删除 视频表
     *
     * @param bFile
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(BFile bFile) {
        int line = baseMapper.realDelete(bFile);
        log.debug(CyUserUtil.getAuthenUsername() + "删除了ID为" +
                bFile.getBusinessId() + "的视频表信息");
        return new CyPersistModel(line);
    }

    /**
     * 逻辑删除 视频表
     *
     * @param bFile
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(BFile bFile) {
        bFile.setDeleted();
        int line = baseMapper.deleteById(bFile);
        log.debug(CyUserUtil.getAuthenUsername() + "逻辑删除了ID为" +
                bFile.getBusinessId() + "的视频表信息");
        return new CyPersistModel(line);
    }

    /**
     * 修改 视频表
     *
     * @param bFile
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(BFile bFile) {
        int line = baseMapper.updateById(bFile);
        log.debug(CyUserUtil.getAuthenUsername() + "修改了ID为" + bFile.getBusinessId() + "的视频表信息");
        return new CyPersistModel(line);
    }

    /**
     * 根据id查询 视频表
     *
     * @param id
     * @return
     */
    @Override
    public BFile findById(String id) {
        return baseMapper.selectById(id);
    }

    /**
     * 分页查询 视频表
     *
     * @param bFile
     * @return
     */
    @Override
    public IPage<BFile> findAllByPagination(CyPageInfo<BFile> paginationUtility,
                                            BFile bFile) {
        return baseMapper.queryBFilesPaged(paginationUtility, bFile);

    }

    /**
     * 查询list 视频表
     *
     * @param bFile
     * @return
     */
    @Override
    public List<BFile> findAll(BFile bFile) {
        return baseMapper.queryBFiles(bFile);

    }

    /**
     * 导出视频表
     *
     * @return
     */
    @Override
    public List<BFile> export(BFile bFile) {
        List<BFile> bFileList = baseMapper.queryBFiles(bFile);
        return bFileList;
    }

    /**
     * 上传文件
     *
     * @param list
     * @param bFile
     * @param token
     * @return
     */
    @SneakyThrows
    @Override
    public String uploadVideoToServer(List<MultipartFile> list, BFile bFile, String temp, String token) {
        String videoUrl = "";

        if (list.size() > 0) {
            try {
                //查询此章节是否已有视频和文件
                BFile video = bFileRepository.selectInfoByChapterId(bFile.getChapterId());
                //此节已有视频或文件，将已有的视频或文件放置到temp目录下，然后上传新视频或文件
                if (video != null) {
                    video.setType(bFile.getType());
                    //上传文件并保存
                    BFile newVideo = this.uploadVideo(list, video, temp);
                    newVideo.setBusinessId(video.getBusinessId());
                    CyUserUtil.setCurrentMergeOperation(newVideo);
                    bFileRepository.updateById(newVideo);//更新表中信息
                    if (bFile.getType().equals("0")) {
                        videoUrl = newVideo.getVideoUrl();
                    } else {
                        videoUrl = newVideo.getPdfUrl();
                    }
                } else {
                    //上传文件
                    BFile newVideo = this.uploadVideo(list, bFile, temp);
                    //插入表信息
                    this.persist(newVideo);
                    if (bFile.getType().equals("0")) {
                        videoUrl = newVideo.getVideoUrl();
                    } else {
                        videoUrl = newVideo.getPdfUrl();
                    }
                }
            } catch (Exception e) {
                e.printStackTrace();
                throw new CyServiceException(ResultServiceEnums.UPLOAD_ERROR.getCode()
                        , ResultServiceEnums.UPLOAD_ERROR.getMessage());
            }
        }
        return videoUrl;
    }

    @SneakyThrows
    @Override
    public BFile findVideoUrl(BFile bFile, String token) {
        if (lessonPermission(bFile, token) || hasAuditionChapter(bFile)) {
            if (bFile.getType().equals("0")) {
                //视频路径
                String videoUrl = bFile.getVideoUrl();
                //根据ossId查询上传文件信息以及url
                if (StringUtils.isNotEmpty(videoUrl)) {
                    OssInfo ossInfo = ossInfoRepository.selectById(videoUrl);
                    //判断当前来源 本地或oss
                    if (ossInfo != null && StringUtils.isNotEmpty(ossInfo.getBucket())) {
                        if (ossInfo != null) {
                            //因为url 是 https -》 .mp4 结束  所以需要去掉头
                            String replace = ossInfo.getPath().replace(ossGlobal.getRequest() + ossGlobal.getEndpoint() + "/", "");
                            // 创建 OSS 客户端
                            OSS ossClient = new OSSClientBuilder().build(ossGlobal.getRequest() + ossGlobal.getEndpoint(), ossGlobal.getReadAcessKey(), ossGlobal.getReadSecretKey());
                            // 设置 URL 的过期时间
                            Date expiration = new Date(System.currentTimeMillis() + (ossGlobal.getReadTime())); // 5 分钟后过期
                            // 生成签名 URL 请求
                            GeneratePresignedUrlRequest req = new GeneratePresignedUrlRequest(ossGlobal.getBucket(), replace, HttpMethod.GET);
                            req.setExpiration(expiration);
                            // 生成签名 URL
                            URL signedUrl = ossClient.generatePresignedUrl(req);
                            // 关闭客户端
                            ossClient.shutdown();
                            bFile.setVideoUrl(signedUrl.toString().replace("%2F", "/"));
                        } else {
                            return null;
                        }
                        ArrayList<OssInfo> ossInfos = new ArrayList<>();
                        //url加密
                        ossInfos.add(ossInfo);
                        bFile.setOssInfoList(ossInfos);
                    } else {
                        if (ossInfo != null) {
                            bFile.setVideoUrl(global.getBase_Discovery() + ossInfo.getUrl());
                        } else {
                            return null;
                        }
                        ArrayList<OssInfo> ossInfos = new ArrayList<>();
                        //url加密
                        if (StringUtils.isNotEmpty(ossInfo.getUrl()) && StringUtils.isNotEmpty(ossInfo.getPath())) {
                            ossInfo.setUrl(RSAUtil.encryptByPublicKey(null, ossInfo.getUrl()));
                            ossInfo.setPath(RSAUtil.encryptByPublicKey(null, ossInfo.getPath()));
                        }
                        ossInfos.add(ossInfo);
                        bFile.setOssInfoList(ossInfos);

                    }
                }
            }
            bFile.setVideoUrl(RSAUtil.encryptByPublicKey(null, bFile.getVideoUrl()));
            return bFile;
        }
        return null;
    }


    @Override
    public BFile findPdfInfo(BFile bFile, String token) {
        if (bFile.getType().equals("1")) {
            //PDF路径
            String pdfUrl = bFile.getPdfUrl();
            if (pdfUrl != null && pdfUrl.contains(",")) {
                String[] ossIdList = pdfUrl.split(",");
                List<OssInfo> ossInfos = ossInfoRepository.selectBatchIds(Arrays.stream(ossIdList).toList());
                if (ossInfos != null) {
                    ossInfos.forEach(ossInfo -> {
                        ossInfo.setUrl("");
                        ossInfo.setPath("");
                    });
                    bFile.setOssInfoList(ossInfos);
                }
            } else if (pdfUrl != null) {
                //根据ossId查询上传文件信息以及ur
                OssInfo ossInfo = ossInfoRepository.selectById(pdfUrl);
                if (ossInfo != null) {
                    ossInfo.setUrl("");
                    ossInfo.setPath("");
                    bFile.setOssInfoList(List.of(ossInfo));
                }
            }
        }
        return bFile;
    }

    @SneakyThrows
    @Override
    public BFile findPdfUrl(BFile bFile, String token) {
        if (bFile.getType().equals("1")) {
            //PDF路径
            String pdfUrl = bFile.getPdfUrl();
            if (pdfUrl != null && pdfUrl.contains(",")) {
                String[] ossIdList = pdfUrl.split(",");
                List<OssInfo> ossInfos = ossInfoRepository.selectBatchIds(Arrays.stream(ossIdList).toList());
                if (ossInfos != null) {
                    ossInfos.forEach(ossInfo -> {
                        ossInfo.setUrl(global.getBase_Discovery() + ossInfo.getUrl());
                        try {
                            ossInfo.setUrl(RSAUtil.encryptByPublicKey(null,
                                    global.getBase_Discovery() + ossInfo.getUrl()));
                        } catch (Exception e) {
                            throw new CyServiceException(ResultServiceEnums.URL_ENCODE.getCode(), ResultServiceEnums.URL_ENCODE.getMessage());
                        }
                        try {
                            ossInfo.setPath(RSAUtil.encryptByPublicKey(null, ossInfo.getPath()));
                        } catch (Exception e) {
                            throw new CyServiceException(ResultServiceEnums.URL_ENCODE.getCode(), ResultServiceEnums.URL_ENCODE.getMessage());
                        }
                    });
                    bFile.setOssInfoList(ossInfos);
                }
            } else if (pdfUrl != null) {
                //根据ossId查询上传文件信息以及ur
                OssInfo ossInfo = ossInfoRepository.selectById(pdfUrl);
                if (ossInfo != null) {
                    ossInfo.setUrl(global.getBase_Discovery() + ossInfo.getUrl());
                    ossInfo.setUrl(RSAUtil.encryptByPublicKey(null,
                            global.getBase_Discovery() + ossInfo.getUrl()));
                    ossInfo.setPath(RSAUtil.encryptByPublicKey(null, ossInfo.getPath()));
                    bFile.setOssInfoList(List.of(ossInfo));
                }
            }
        }
        return bFile;
    }

    @SneakyThrows
    @Override
    public BFile removeFile(BFile bFile, String ossId) {
        //根据条件查询bFile对象
        bFile = bFileRepository.selectOne(new QueryWrapper<BFile>().eq("chapter_id", bFile.getChapterId()));
        OssInfo ossInfo = ossInfoRepository.selectById(ossId);
        //路径list
        List<String> tempPathList = new ArrayList<>();
        if (bFile.getType().equals("0")) {
            //删除视频
            tempPathList.add(ossInfo.getPath());
            bFile.setVideoUrl(null);
            UpdateWrapper<BFile> up = new UpdateWrapper<>();
            up.eq("chapter_id", bFile.getChapterId())
                    .set("video_url", bFile.getVideoUrl());
            bFileRepository.update(null, up);
            ossInfoRepository.deleteById(ossId);
        } else if (bFile.getType().equals("1")) {
            //pdf路径
            tempPathList.add(ossInfo.getPath());
            //删除 可能存在包含或者不包含的关系
            String pdfUrl = bFile.getPdfUrl();
            if (pdfUrl != null && pdfUrl.contains(",")) {
                String[] ossIdList = pdfUrl.split(",");
                List<String> ossIdAllList = new ArrayList<>(Arrays.stream(ossIdList).toList());
                ossIdAllList.remove(ossId);
                bFile.setPdfUrl(StringUtils.strip(ossIdAllList.toString(), "[]"));
            } else {
                bFile.setPdfUrl(null);
            }
            UpdateWrapper<BFile> up = new UpdateWrapper<>();
            up.eq("chapter_id", bFile.getChapterId())
                    .set("pdf_url", bFile.getPdfUrl());
            bFileRepository.update(null, up);
            ossInfoRepository.deleteById(ossId);
        }
        //删除
        if (!CollectionUtils.isEmpty(tempPathList)) {
            for (String tempPath : tempPathList) {
                File tempFilePath = new File(tempPath);
                if (tempFilePath.exists()) {
                    FileUtils.deleteDirectory(tempFilePath);
                }
                //移动文件
                String realFilePath = global.getTEMP_LOCATION() + tempFilePath;
                File directory = new File(realFilePath);
                if (directory.exists()) {
                    FileUtils.moveDirectory(directory, tempFilePath);
                }
            }
        }
        return bFile;
    }

    /**
     * 上传课程资料
     *
     * @param list
     * @param bFile
     * @param temp
     * @param token
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public String uploadDataToServer(List<MultipartFile> list, BFile bFile, String temp, String token) {
        String dataUrl = "";
        if (list.size() > 0) {
            try {
                //查询此课程是否有课程文件
                BFile dataFile = bFileRepository.selectInfoByBLessonId(bFile.getLessonId());
                //此课程下是有课程文件
                if (dataFile != null) {
                    //上传课程资料并保存
                    BFile newVideo = this.uploadLesson(list, dataFile, temp);
                    newVideo.setBusinessId(dataFile.getBusinessId());
                    CyUserUtil.setCurrentMergeOperation(newVideo);
                    bFileRepository.updateById(newVideo);//更新表中信息
                    dataUrl = newVideo.getFileUrl();
                } else {
                    //上传文件
                    BFile newFile = this.uploadLesson(list, bFile, temp);
                    //如果上传课程资料，插入章节id为-1
                    newFile.setChapterId("-1");
                    //插入表信息
                    this.persist(newFile);
                    dataUrl = newFile.getFileUrl();
                }
            } catch (Exception e) {
                e.printStackTrace();
                throw new CyServiceException(ResultServiceEnums.UPLOAD_ERROR.getCode()
                        , ResultServiceEnums.UPLOAD_ERROR.getMessage());
            }
        }
        return dataUrl;
    }

    @SneakyThrows
    @Override
    public BFile findDataUrl(BFile bFile, String token) {
        //根据课程id查询课程文件信息
        BFile bFile1 = bFileRepository.selectOne(new QueryWrapper<BFile>()
                .eq("lesson_id", bFile.getLessonId())
                .eq("chapter_id", "-1"));
        if (Objects.isNull(bFile1)) {
            return bFile;
        } else {
            String dataUrl = bFile1.getFileUrl();
            if (StringUtils.isNotEmpty(dataUrl)) {
                String[] urlArray = dataUrl.split(","); // 使用逗号分割字符串
                ArrayList<OssInfo> ossInfos = new ArrayList<>();
                for (String url : urlArray) {
                    OssInfo ossInfo = ossInfoRepository.selectById(url);
                    if (ossInfo != null) {
                        ossInfo.setUrl(null);
                        ossInfo.setPath(null); // 可能需要设置其他字段
                        ossInfos.add(ossInfo);
                    }
                }
                bFile.setOssInfoList(ossInfos);
            }

        }
        return bFile;
    }

    /**
     * 删除课程文件
     *
     * @param bFile
     * @param ossId
     * @return
     */
    @SneakyThrows
    @Override
    public BFile removeDataFile(BFile bFile, String ossId) {
        //根据条件查询bFile对象
        bFile = bFileRepository.selectOne(new QueryWrapper<BFile>()
                .eq("lesson_id", bFile.getLessonId())
                .eq("chapter_id", "-1"));
        OssInfo ossInfo = ossInfoRepository.selectById(ossId);
        //路径list
        List<String> tempPathList = new ArrayList<>();
        //pdf路径
        tempPathList.add(ossInfo.getPath());
        //删除 可能存在包含或者不包含的关系
        String fileUrl = bFile.getFileUrl();
        if (fileUrl != null && fileUrl.contains(",")) {
            String[] ossIdList = fileUrl.split(",");
            List<String> ossIdAllList = new ArrayList<>(Arrays.stream(ossIdList).toList());
            ossIdAllList.remove(ossId);
            bFile.setFileUrl(StringUtils.strip(ossIdAllList.toString(), "[]"));
        } else {
            bFile.setFileUrl(null);
        }
        UpdateWrapper<BFile> up = new UpdateWrapper<>();
        up.eq("lesson_id", bFile.getLessonId())
                .set("file_url", bFile.getFileUrl());
        bFileRepository.update(null, up);
        ossInfoRepository.deleteById(ossId);

        //删除
        if (!CollectionUtils.isEmpty(tempPathList)) {
            for (String tempPath : tempPathList) {
                File tempFilePath = new File(tempPath);
                if (tempFilePath.exists()) {
                    FileUtils.deleteDirectory(tempFilePath);
                }
                //移动文件
                String realFilePath = global.getTEMP_LOCATION() + tempFilePath;
                File directory = new File(realFilePath);
                if (directory.exists()) {
                    FileUtils.moveDirectory(directory, tempFilePath);
                }
            }
        }
        return bFile;
    }

    /**
     * 下载课程文件
     *
     * @param bFile
     * @param token
     * @return
     */
    @SneakyThrows
    @Override
    public String download(BFile bFile, HttpServletResponse response, String token) {
        //权限判断是否拥有当前的课程
        Boolean auth = lessonPermission(bFile, token);
        if (auth) {
            if (StringUtils.isNotEmpty(bFile.getFileUrl())) {
                //解密信息
                String s = RSAUtil.decryptByPrivateKey(null, bFile.getFileUrl());
                //剔除字符串前六位
                String ossInfoId = s.substring(5);
                OssInfo ossInfo1 = ossInfoRepository.selectById(ossInfoId);
                //如果当前文件在云
                if (ossInfo1 != null && StringUtils.isNotEmpty(ossInfo1.getBucket())) {
                    //因为url 是 https -》 .mp4 结束  所以需要去掉头
                    String replace = ossInfo1.getPath().replace(ossGlobal.getRequest() + ossGlobal.getEndpoint(), "");
                    // 创建 OSS 客户端
                    OSS ossClient = new OSSClientBuilder().build(ossGlobal.getRequest() + ossGlobal.getEndpoint(), ossGlobal.getReadAcessKey(), ossGlobal.getReadSecretKey());
                    // 设置 URL 的过期时间
                    Date expiration = new Date(System.currentTimeMillis() + ossGlobal.getReadTime()); // 5 分钟后过期
                    // 生成签名 URL 请求
                    GeneratePresignedUrlRequest req = new GeneratePresignedUrlRequest(ossGlobal.getBucket(), replace, HttpMethod.GET);
                    req.setExpiration(expiration);
                    // 生成签名 URL
                    URL signedUrl = ossClient.generatePresignedUrl(req);
                    // 关闭客户端
                    ossClient.shutdown();
                    ossInfo1.setUrl(signedUrl.toString());
                    return RSAUtil.encryptByPublicKey(null, ossInfo1.getUrl());
                }
                if (ossInfo1 != null) {
                    //返回加密后的url地址
                    return RSAUtil.encryptByPublicKey(null, global.getBase_Discovery() + ossInfo1.getUrl());
                }
            }
        }
        return null;
    }

    /**
     * 下载课程文件 权限校验
     *
     * @return
     */
    @Override
    public Boolean lessonPermission(BFile bFile, String token) {
        //查询当前用户会否有权限可以看当前课程
        //是否是ip用户
        //获取身份字段
        Object uesr = CyUserUtil.getUserInfoObjProp(token, "username:" + CyUserUtil.getAuthenUsername());
        SysUser sysUser = null;
        if (uesr != null) {
            //将object 转换为 user对象
            sysUser = JSON.parseObject(JSON.toJSONString(uesr), SysUser.class);
        }
        //获取当前用户的id
        String authenBusinessId = CyUserUtil.getAuthenBusinessId();
        if (StringUtils.isBlank(authenBusinessId) && sysUser == null) {
            // 如果未登录直接返回无权限
            return false;
        }
        //查询当前课程
        BLesson bLesson = bLessonService.findById(bFile.getLessonId());

        //判断当前课程的价格是否为0  免费课程
        if (bLesson.getLessonPrice() == null || bLesson.getLessonPrice().compareTo(BigDecimal.ZERO) == 0) {
            return true;
        } else {
            //判断是个人用户还是企业用户
//            QueryWrapper<SysUser> userQw = new QueryWrapper<>();
//            userQw.eq("business_id", authenBusinessId)
//                    .eq("del_flag", 0)
//                    .eq("flag", 1);
//            SysUser sysUser = pcSysUserRepository.selectOne(userQw);
            if (sysUser == null) {
                return false;
            }
            //如果个人用户判断当前用户是否有该课程的权限 以及课程时间是否过期
            if (IdentityStaCons.INDIVIDUAL.getStatus().equals(sysUser.getIdentity())) {
                List<TrialCourseDto> list = teaTrialCourseRepository
                        .selectByUserIdAndLessonId(sysUser.getBusinessId(), bFile.getLessonId());
                if (CollectionUtils.isEmpty(list)) {
                    //没有拥有当前课程,查询当前课程章节是否试听
                    return hasAuditionChapter(bFile);
                }
                //过期
                if (list.get(0).getTimeResult() == null || list.get(0).getTimeResult() == 0) {
                    //当前课程已过期
                    return false;
                }
                return true;
            }
            //如果企业用户判断该登录人的角色 是否可以查看当前课程 以及课程时间是否过期
            if (IdentityStaCons.UNIT_USER.getStatus().equals(sysUser.getIdentity())) {
                //当前登录是否是单位管理员
                List<TrialCourseDto> adminList
                        = teaTrialCourseRepository.findByAdmin(sysUser.getBusinessId(), bFile.getLessonId());
                if (!CollectionUtils.isEmpty(adminList)) {
                    return true;
                } else {
                    //当前登录用户不是单位管理员
//                    List<TrialCourseDto> list = teaTrialCourseRepository
//                            .selectByUNITUserIdAndLessonId(sysUser.getBusinessId(), bFile.getLessonId());
                    List<BLesson> list = bChapterRepository.selectLessonsByLessonIdAndUserId(bFile.getLessonId(),sysUser.getBusinessId());
                    if (CollectionUtils.isEmpty(list)) {
                        //没有拥有当前课程,查询当前课程章节是否试听
                        return hasAuditionChapter(bFile);
                    }
                    //找出当前课程的最小开始时间和最大结束时间
                    BLesson one = new BLesson();
                    BeanUtils.copyProperties(list.get(0), one);
                    if (!list.isEmpty()) {
                        // 找出具有最小startTime的BLesson
                        Optional<BLesson> minStartTime = list.stream()
                                .min(Comparator.comparing(BLesson::getStartTime));
                        Optional<BLesson> maxEndTime = list.stream()
                                .max(Comparator.comparing(BLesson::getEndTime));
                        Date startTime = minStartTime.map(BLesson::getStartTime).orElse(null);
                        Date endTime = maxEndTime.map(BLesson::getEndTime).orElse(null);
                        one.setStartTime(startTime);
                        one.setEndTime(endTime);
                        // 使用 Calendar 让endTime 增加 23 小时 59 分钟 59 秒
                        Calendar calendar = Calendar.getInstance();
                        calendar.setTime(endTime);
                        calendar.add(Calendar.HOUR_OF_DAY, 23);
                        calendar.add(Calendar.MINUTE, 59);
                        calendar.add(Calendar.SECOND, 59);

                        Date newEndTime = calendar.getTime();
                        //与当前时间进行比对 如果过期，就把blesson.isExpired设置为1
                        if (new Date().after(newEndTime)) {
                            one.setIsExpired("1");
                        } else {
                            one.setIsExpired("0");
                        }
                    }
                    if (CollectionUtils.isEmpty(list)) {
                        //没有拥有当前课程,查询当前课程章节是否试听
                        return hasAuditionChapter(bFile);
                    }
                    //过期
                    if (one.getIsExpired() == null || one.getIsExpired() == "1") {
                        //当前课程已过期
                        return false;
                    }
                    return true;
                }
            }
            //ip用户
            if (IdentityStaCons.IP_USER.getStatus().equals(sysUser.getIdentity())) {
                List<TrialCourseDto> ipList = teaTrialCourseRepository.selectByIpUser(sysUser.getDeptId().toString(), bLesson.getBusinessId());
                if (!CollectionUtils.isEmpty(ipList)) {
                    return true;
                } else {
                    //当前登录用户不是单位管理员
                    List<TrialCourseDto> list = teaTrialCourseRepository
                            .selectByUNITUserIdAndLessonId(sysUser.getBusinessId(), bFile.getLessonId());
                    if (CollectionUtils.isEmpty(list)) {
                        //没有拥有当前课程,查询当前课程章节是否试听
                        return hasAuditionChapter(bFile);
                    }
                    if (list.get(0).getTimeResult() == null || list.get(0).getTimeResult() == 0) {
                        //当前课程已过期
                        return false;
                    }
                    return true;
                }
            }
            //用户如果是超级管理员
            if (IdentityStaCons.ADMIN.getStatus().equals(sysUser.getIdentity())) {
                return true;
            }
        }
        return false;
    }

    @Override
    public BFile findVideoUrlTeacher(BFile bFile, String token) throws Exception {
        if (bFile.getType().equals("0")) {
            //视频路径
            String videoUrl = bFile.getVideoUrl();
            //根据ossId查询上传文件信息以及url
            if (StringUtils.isNotEmpty(videoUrl)) {
                OssInfo ossInfo = ossInfoRepository.selectById(videoUrl);
                if (ossInfo != null) {
                    if (StringUtils.isNotEmpty(ossInfo.getBucket())){
                        //获取ossinfo正确访问路径
                        //因为url 是 https -》 .mp4 结束  所以需要去掉头
                        String replace = ossInfo.getPath().replace(ossGlobal.getRequest() + ossGlobal.getEndpoint() + "/", "");
                        // 创建 OSS 客户端
                        OSS ossClient = new OSSClientBuilder().build(ossGlobal.getRequest() + ossGlobal.getEndpoint(), ossGlobal.getReadAcessKey(), ossGlobal.getReadSecretKey());
                        // 设置 URL 的过期时间
                        Date expiration = new Date(System.currentTimeMillis() + (ossGlobal.getReadTime())); // 5 分钟后过期
                        // 生成签名 URL 请求
                        GeneratePresignedUrlRequest req = new GeneratePresignedUrlRequest(ossGlobal.getBucket(), replace, HttpMethod.GET);
                        req.setExpiration(expiration);
                        // 生成签名 URL
                        URL signedUrl = ossClient.generatePresignedUrl(req);
                        // 关闭客户端
                        ossClient.shutdown();
                        bFile.setVideoUrl(signedUrl.toString().replace("%2F", "/"));

                    } else {
                        bFile.setVideoUrl(global.getBase_Discovery() + ossInfo.getUrl());
                    }
                } else {
                    return null;
                }
                ArrayList<OssInfo> ossInfos = new ArrayList<>();
                //url加密
                if (StringUtils.isNotEmpty(ossInfo.getUrl()) && StringUtils.isNotEmpty(ossInfo.getPath())) {
                    ossInfo.setUrl(RSAUtil.encryptByPublicKey(null, ossInfo.getUrl()));
                    ossInfo.setPath(RSAUtil.encryptByPublicKey(null, ossInfo.getPath()));
                }
                ossInfo.setPath("");
                ossInfo.setUrl("");
                ossInfos.add(ossInfo);
                bFile.setOssInfoList(ossInfos);
            }
        }
        bFile.setVideoUrl(RSAUtil.encryptByPublicKey(null, bFile.getVideoUrl()));
        return bFile;
    }

    // 判断课程是否有试听章节
    private boolean hasAuditionChapter(BFile bFile) {
        BChapter bChapter = bChapterRepository.selectOne(new QueryWrapper<BChapter>()
                .eq("lesson_id", bFile.getLessonId())
                .eq("business_id", bFile.getChapterId())
                .eq("del_flag", 0)
                .eq("flag", 1));
        return bChapter != null && "1".equals(bChapter.getIsAudition());
    }


    /**
     * 上传课程文件
     *
     * @param list
     * @param bFile
     * @param temp
     * @return
     */
    private BFile uploadLesson(List<MultipartFile> list, BFile bFile, String temp) {
        ArrayList<String> ossInfos = new ArrayList<>();
        for (MultipartFile file : list) {
            //保存文件
            CyResult cyResult = cyCommonController.comFileUpload(file,
                    temp + File.separator + bFile.getLessonId() + File.separator + UUID.randomUUID());
            if (cyResult.getCode().equals(ResultServiceEnums.CYRESULT_SUCCESS.getCode())) {
                OssInfo ossInfo = new ObjectMapper().convertValue(cyResult.getData(), OssInfo.class);
                ossInfos.add(String.valueOf(ossInfo.getBusinessId()));
            }
        }

        if (!CollectionUtils.isEmpty(ossInfos)) {
            //涉及多次上传文件
            if (StringUtils.isEmpty(bFile.getFileUrl())) {
                bFile.setFileUrl(StringUtils.strip(ossInfos.toString(), "[]"));
            } else {
                bFile.setFileUrl(bFile.getFileUrl() + "," + StringUtils.strip(ossInfos.toString(), "[]"));
            }
        }
        return bFile;
    }

    /**
     * 将原视频复制到temp/video文件下，并删除原视频
     *
     * @param bFile
     */
    private void removeVideoToTemp(BFile bFile) throws Exception {
        List<String> tempPathList = new ArrayList<>();
        if (bFile.getType().equals("0")) {
            //视频路径
            String videoUrl = bFile.getVideoUrl();
            //根据ossId查询上传文件信息以及url
            if (videoUrl != null && videoUrl.contains(",")) {
                String[] ossIdList = videoUrl.split(",");
                List<OssInfo> ossInfos = ossInfoRepository.selectBatchIds(Arrays.stream(ossIdList).toList());
                for (OssInfo ossInfo : ossInfos) {
                    if (ossInfo.getPath() != null) {
                        tempPathList.add(ossInfo.getPath());
                    }
                }
                ossInfoRepository.deleteBatchIds(Arrays.stream(ossIdList).toList());
            } else if (videoUrl != null) {
                OssInfo ossInfo = ossInfoRepository.selectById(videoUrl);
                if (ossInfo.getPath() != null) {
                    tempPathList.add(ossInfo.getPath());
                }
                ossInfoRepository.deleteById(videoUrl);
            }
        } else if (bFile.getType().equals("1")) {
            //pdf路径
            String pdfUrl = bFile.getPdfUrl();
            if (pdfUrl != null && pdfUrl.contains(",")) {
                String[] ossIdList = pdfUrl.split(",");
                List<OssInfo> ossInfos = ossInfoRepository.selectBatchIds(Arrays.stream(ossIdList).toList());
                for (OssInfo ossInfo : ossInfos) {
                    if (ossInfo.getPath() != null) {
                        tempPathList.add(ossInfo.getPath());
                    }
                }
                ossInfoRepository.deleteBatchIds(Arrays.stream(ossIdList).toList());
            } else if (pdfUrl != null) {
                OssInfo ossInfo = ossInfoRepository.selectById(pdfUrl);
                if (ossInfo.getPath() != null) {
                    tempPathList.add(ossInfo.getPath());
                }
                ossInfoRepository.deleteById(pdfUrl);
            }
        }
        //删除
        if (!CollectionUtils.isEmpty(tempPathList)) {
            for (String tempPath : tempPathList) {
                File tempFilePath = new File(tempPath);
                if (tempFilePath.exists()) {
                    FileUtils.deleteDirectory(tempFilePath);
                }
                //移动文件
                String realFilePath = global.getTEMP_LOCATION() + tempFilePath;
                File directory = new File(realFilePath);
                if (directory.exists()) {
                    FileUtils.moveDirectory(directory, tempFilePath);
                }
            }
        }
    }

    /**
     * 上传视频到video目录
     *
     * @param fileList
     * @param bFile
     * @return
     * @throws IOException
     */
    private BFile uploadVideo(List<MultipartFile> fileList, BFile bFile, String temp) throws IOException {
        ArrayList<String> ossInfos = new ArrayList<>();
        for (MultipartFile file : fileList) {
            String s = CyIdGenUtil.generateShortUUID();
            //保存文件
            CyResult cyResult = cyCommonController.comFileUpload(file,
                    temp + File.separator + bFile.getChapterId() + File.separator + UUID.randomUUID());
            if (cyResult.getCode().equals(ResultServiceEnums.CYRESULT_SUCCESS.getCode())) {
                OssInfo ossInfo = new ObjectMapper().convertValue(cyResult.getData(), OssInfo.class);
                ossInfos.add(String.valueOf(ossInfo.getBusinessId()));
            }
        }

        if (!CollectionUtils.isEmpty(ossInfos)) {
            if (bFile.getType().equals("0")) {
                //上传文件id
                bFile.setVideoUrl(StringUtils.strip(ossInfos.toString(), "[]"));
            } else if (bFile.getType().equals("1")) {
                //pdf涉及多次上传文件
                if (StringUtils.isEmpty(bFile.getPdfUrl())) {
                    //pdf路径
                    bFile.setPdfUrl(StringUtils.strip(ossInfos.toString(), "[]"));
                } else {
                    bFile.setPdfUrl(bFile.getPdfUrl() + "," + StringUtils.strip(ossInfos.toString(), "[]"));
                }
            }
        }
        return bFile;
    }
}
