package org.rcisoft.business.blesson.controller;


/*固定导入*/

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.fasterxml.jackson.databind.ObjectMapper;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.collections4.map.HashedMap;
import org.rcisoft.business.auditlogs.entity.AuditLogs;
import org.rcisoft.business.blesson.dto.*;
import org.rcisoft.business.blesson.entity.*;
import org.rcisoft.business.blesson.service.BLessonService;
import org.rcisoft.business.cmsbanner.entity.CmsBanner;
import org.rcisoft.business.ossinfo.entity.OssInfo;
import org.rcisoft.common.component.Global;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyCommonController;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.converter.MultipartFile2HSSFWorkbookConverter;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.util.UploadUtil;
import org.rcisoft.pc.statistics.lessonStatistics.dto.LessonStudyDTO;
import org.rcisoft.result.ResultServiceEnums;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.util.List;
import java.util.Map;
import java.util.concurrent.atomic.AtomicInteger;

/**
 * Created by cy on 2024年3月23日 上午9:54:37.
 */
@RestController
@RequestMapping("/blesson")
public class BLessonController extends CyPaginationController<BLesson> {


    @Autowired
    private BLessonService bLessonServiceImpl;

    @Autowired
    private Global global;

    @Autowired
    private CyCommonController cyCommonController;

    @PreAuthorize("@cyPerm.hasPerm('opm:lesson:removing')")
    @CyOpeLogAnno(title = "system-BLesson管理-删除BLesson", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value = "逻辑删除BLesson", notes = "逻辑删除BLesson")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable String businessId, BLesson bLesson) {
        bLesson.setBusinessId(businessId);
        CyPersistModel data = bLessonServiceImpl.removeLogical(bLesson);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:sson:delete')")
    @CyOpeLogAnno(title = "system-BLesson管理-删除BLesson", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value = "删除BLesson", notes = "删除BLesson")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable String businessId, BLesson bLesson) {
        bLesson.setBusinessId(businessId);
        CyPersistModel data = bLessonServiceImpl.remove(bLesson);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:lesson:modifications')")
    @CyOpeLogAnno(title = "system-BLesson管理-修改BLesson", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value = "修改BLesson", notes = "修改BLesson")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable String businessId, @Valid BLesson bLesson, BindingResult bindingResult) {
        bLesson.setBusinessId(businessId);
        CyPersistModel data = bLessonServiceImpl.merge(bLesson);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLesson);
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:lesson:singleSearch')")
    @CyOpeLogAnno(title = "system-BLesson管理-查询BLesson", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询单一BLesson", notes = "查询单一BLesson")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable String businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLessonServiceImpl.findById(businessId));
    }


    @PreAuthorize("@cyPerm.hasPerm('opm:lesson:increase')")
    @ApiOperation(value = "添加/编辑课程", notes = "businessId为空时是添加方法，不为空时是修改方法")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar"),
//            @ApiImplicitParam(name = "code", value = "课程编号(1-100)", required = true, dataType = "varchar"),
            @ApiImplicitParam(name = "lessonName", value = "课程名称（1-150）", required = true, dataType = "varchar"),
            @ApiImplicitParam(name = "classHour", value = "课时（1-5）", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "credits", value = "学分（1-5）", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "directionId", value = "课程方向ID", required = false, dataType = "varchar")})
    @PostMapping(value = "/add")
    public CyResult add(@Valid BLesson bLesson, BindingResult bindingResult) {

        CyPersistModel data = bLessonServiceImpl.persist(bLesson, getToken());
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLesson);
    }


    @PreAuthorize("@cyPerm.hasPerm('opm:lesson:remove')")
    @ApiOperation(value = "删除课程", notes = "根据ID删除一条记录")
    @ApiImplicitParam(name = "id", value = "businessId", required = true, dataType = "varchar")
    @PostMapping(value = "/remove")
    public CyResult remove(String id) {
        CyPersistModel data = bLessonServiceImpl.removeBLesson(id);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                id);
    }

    //    @PreAuthorize("@cyPerm.hasPerm('opm:lesson:pageSearch')")
    @ApiOperation(value = "根据条件分页查询", notes = "根据URL中的参数分页查询")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "code", value = "课程编号", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "condition", value = "模糊查询条件", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "classHour", value = "课时", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "credits", value = "学分", required = false, dataType = "varchar")})
    @GetMapping(value = "/queryBLessonByPagination")
    public CyGridModel queryBLessonsByPagination(BLesson param) {
        IPage<BLesson> bLessonIPage = bLessonServiceImpl.queryBLessonsByPagination(getPaginationUtility(), param, getToken());
        return getGridModelResponse();
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:lesson:pageDateSearch')")
    @ApiOperation(value = "根据条件分页查询日期升序", notes = "根据URL中的参数分页查询")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "code", value = "课程编号", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "condition", value = "模糊查询条件", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "classHour", value = "课时", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "credits", value = "学分", required = false, dataType = "varchar")})
    @GetMapping(value = "/queryBLessonByPaginationByDateAsc")
    public CyGridModel queryBLessonByPaginationByDateAsc(BLesson param) {
        bLessonServiceImpl.queryBLessonByPaginationByDateAsc(getPaginationUtility(), param, getToken());
        return getGridModelResponse();
    }

    /**
     * pc端分页查询
     */
//    @PreAuthorize("@cyPerm.hasPerm('opm:lesson:pagingBLesson')")
    @ApiOperation(value = "根据条件分页查询", notes = "根据URL中的参数分页查询")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "code", value = "课程编号", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "condition", value = "模糊查询条件", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "classHour", value = "课时", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "credits", value = "学分", required = false, dataType = "varchar")})
    @GetMapping("/queryPcBLessonByPagination")
    public CyGridModel queryPcBLessonsByPagination(BLesson bLesson) {
        bLessonServiceImpl.queryPcBLessonsByPagination(getPaginationUtility(), bLesson);
        return getGridModelResponse();
    }

    /**
     * 根据条件分页查询
     * 使用模块：
     * 学习中心-我的课程
     *
     * @param pcBLessonQuery 查询条件
     * @return
     */
//    @PreAuthorize("@cyPerm.hasPerm('opm:lesson:pagingBLesson')")
    @ApiOperation(value = "学习中心-我的课程|根据条件分页查询", notes = "根据URL中的参数分页查询")
    @ApiImplicitParams({@ApiImplicitParam(name = "lessonName", value = "课程名称", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "isCompleteLearned", value = "是否完成课程学习(0: 未完成; 1: 已完成; )", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "isObligatory", value = "是否必修(0: 否; 1: 是)", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "userId", value = "用户id", required = false, dataType = "varchar")})
    @GetMapping("/pagingBLesson")
    public CyResult pagingBLesson(PcBLessonQuery pcBLessonQuery) {
        Map<String, Object> map = new HashedMap();
        IPage<BLesson> dataList = bLessonServiceImpl.pagingBLesson(getPaginationUtility(), pcBLessonQuery, getToken());
        List<BLesson> allBLessons = bLessonServiceImpl.getAllBLessonByUserId(pcBLessonQuery.getUserId());
        // 必修未完成数量
        AtomicInteger obligatoryIncompleteCount = new AtomicInteger();
        // 必修已完成数量
        AtomicInteger obligatoryCompleteCount = new AtomicInteger();
        // 选修未完成数量
        AtomicInteger electiveIncompleteCount = new AtomicInteger();
        // 选修已完成数量
        AtomicInteger electiveCompleteCount = new AtomicInteger();
        allBLessons.forEach(bLesson -> {
            String isObligatory = bLesson.getIsObligatory();
            String isCompleteLearned = bLesson.getIsCompleteLearned();
            if ("1".equals(isObligatory)) {
                // 必修
                if ("0".equals(isCompleteLearned)) {
                    // 未完成
                    obligatoryIncompleteCount.incrementAndGet();
                } else if ("1".equals(isCompleteLearned)) {
                    // 已完成
                    obligatoryCompleteCount.incrementAndGet();
                }
            } else if ("0".equals(isObligatory)) {
                // 选修
                if ("0".equals(isCompleteLearned)) {
                    // 未完成
                    electiveIncompleteCount.incrementAndGet();
                } else if ("1".equals(isCompleteLearned)) {
                    // 已完成
                    electiveCompleteCount.incrementAndGet();
                }
            }
        });

        // 将AtomicInteger类型的计数器转换为Integer数组
        Integer[] courseStatisticsArray = {
                obligatoryIncompleteCount.get(),
                obligatoryCompleteCount.get(),
                electiveIncompleteCount.get(),
                electiveCompleteCount.get()
        };
        map.put("dataList", dataList);
        map.put("courseStatisticsArray", courseStatisticsArray);
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                map);
    }

    /**
     * 根据条件分页查询
     * 使用模块：
     * 学习中心-我的课程（ip登录用户）
     *
     * @param pcBLessonQuery 查询条件
     * @return
     */
    @PreAuthorize("@cyPerm.hasPerm('opm:lesson:pagingBLessonForIP')")
    @ApiOperation(value = "学习中心-我的课程|根据条件分页查询（ip登录用户）", notes = "根据URL中的参数分页查询")
    @ApiImplicitParams({@ApiImplicitParam(name = "lessonName", value = "课程名称", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "isCompleteLearned", value = "是否完成课程学习(0: 未完成; 1: 已完成; )", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "isObligatory", value = "是否必修(0: 否; 1: 是)", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "userId", value = "用户id", required = false, dataType = "varchar")})
    @GetMapping("/pagingBLessonForIP")
    public CyResult pagingBLessonForIP(PcBLessonQuery pcBLessonQuery) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLessonServiceImpl.pagingBLessonForIP(getPaginationUtility(), pcBLessonQuery));
    }

    /**
     * 根据条件分页查询
     * 使用模块：
     * 学习中心-我的小组
     *
     * @param pcBLessonQuery 查询条件
     * @return
     */
//    @PreAuthorize("@cyPerm.hasPerm('opm:lesson:pagingMyGroupStatistics')")
    @ApiOperation(value = "学习中心-我的小组|根据条件分页查询", notes = "根据URL中的参数分页查询")
    @ApiImplicitParams({@ApiImplicitParam(name = "groupId", value = "小组id", required = true, dataType = "varchar"),
            @ApiImplicitParam(name = "viewType", value = "视图类型", required = true, dataType = "varchar")})
    @GetMapping("/pagingMyGroupStatistics")
    public CyResult pagingMyGroupStatistics(PcBLessonQuery pcBLessonQuery) {
        CyPageInfo<MyGroupStatisticsVO> paginationUtility = new CyPageInfo<>();
        paginationUtility.setCurrent(pcBLessonQuery.getPage());
        paginationUtility.setSize(pcBLessonQuery.getRows());
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLessonServiceImpl.pagingMyGroupStatistics(paginationUtility, pcBLessonQuery));
    }

    /**
     * 根据条件分页查询
     * 使用模块：
     * 学习中心-我的小组
     * 学员视图统计详情
     *
     * @param pcBLessonQuery 查询条件
     * @return
     */
    @PreAuthorize("@cyPerm.hasPerm('opm:lesson:pagingStatisticsDetail')")
    @ApiOperation(value = "学习中心-我的小组|根据条件分页查询", notes = "根据URL中的参数分页查询")
    @ApiImplicitParams({@ApiImplicitParam(name = "userId", value = "用户id", required = true, dataType = "varchar"),
            @ApiImplicitParam(name = "viewType", value = "视图类型", required = true, dataType = "varchar"),
            @ApiImplicitParam(name = "statisticalType", value = "统计类型", required = true, dataType = "varchar")})
    @GetMapping("/pagingStatisticsDetail")
    public CyResult pagingStatisticsDetail(PcBLessonQuery pcBLessonQuery) {
        CyPageInfo<StatisticsDetailVO> paginationUtility = new CyPageInfo<>();
        paginationUtility.setCurrent(pcBLessonQuery.getCurrent());
        paginationUtility.setSize(pcBLessonQuery.getSize());
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLessonServiceImpl.pagingStatisticsDetail(paginationUtility, pcBLessonQuery));
    }

    /**
     * 导入数据excel
     *
     * @param importFile
     * @return
     * @throws Exception
     */

    @PreAuthorize("@cyPerm.hasPerm('opm:lesson:derive')")
    @ApiOperation(value = "excel导入", notes = "上传excel到服务器")
    @ApiImplicitParam(name = "importFile", value = "excel文件", required = true, dataType = "MultipartFile")
    @PostMapping(value = "excelImport")
    public CyResult excelImport(MultipartFile importFile) throws Exception {
        CyPersistModel data = bLessonServiceImpl.importExcel(MultipartFile2HSSFWorkbookConverter.convert(importFile), getToken());
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                data.getInfluenceReason());
    }


    //    @PreAuthorize("@cyPerm.hasPerm('opm:sson:picImport')")
    @ApiOperation(value = "上传图片", notes = "上传图片到服务器")
    @ApiImplicitParams({@ApiImplicitParam(name = "importFile", value = "图片文件", required = true, dataType = "MultipartFile"),
            @ApiImplicitParam(name = "code", value = "课程编号", required = true, dataType = "varchar")})
    @PostMapping(value = "picImportOld")
    public CyResult picImport(MultipartFile importFile, String code) throws Exception {
        String path = global.getBASE_UPLOAD_SERVER_LOCATION();
        String course_logo_path = global.getIMAGE_LOCATION() + global.getCOURSE_LOGO_LOCATION();
        boolean type = false;
        if ("1".equals(global.getIS_SERVER_LINUX())) {
            type = true;
        }
        Map<String, Object> map = UploadUtil.picImport(path, course_logo_path, importFile, type);
        if (map.get(UploadUtil.IS_SUCCESSS).equals(true)) {
            BLesson bL = new BLesson();
            bL.setCode(code);
            BLesson bLesson = bLessonServiceImpl.selectOne(bL);
            if (bLesson != null) {
                bLesson.setDefaultUrl(map.get(UploadUtil.URL).toString());
                CyUserUtil.setCurrentMergeOperation(bLesson);
                int line = bLessonServiceImpl.updateByPrimaryKeySelective(bLesson);
                return CyResultGenUtil.builder(new CyPersistModel(line),
                        CyMessCons.MESSAGE_ALERT_SUCCESS,
                        CyMessCons.MESSAGE_ALERT_ERROR,
                        bLessonServiceImpl.selectOne(code, null, getToken()));
            } else {
                throw new CyServiceException(ResultServiceEnums.UPLOAD_FILE_ERROR.getCode(),
                        ResultServiceEnums.UPLOAD_FILE_ERROR.getMessage());
            }
        } else {
            throw new CyServiceException(ResultServiceEnums.ADD_ERROR.getCode(),
                    ResultServiceEnums.ADD_ERROR.getMessage());
        }
    }


    @PreAuthorize("@cyPerm.hasPerm('opm:lesson:picImport')")
    @ApiOperation(value = "上传图片", notes = "上传图片到服务器")
    @ApiImplicitParams({@ApiImplicitParam(name = "importFile", value = "图片文件", required = true, dataType = "MultipartFile"),
            @ApiImplicitParam(name = "code", value = "课程编号", required = true, dataType = "varchar")})
    @PostMapping(value = "picImport")
    public CyResult picImportNew(MultipartFile importFile, String temp, String code) throws Exception {
        CyResult cyResult = cyCommonController.comFileUpload(importFile, temp);
        if (cyResult.getCode().equals(ResultServiceEnums.CYRESULT_SUCCESS.getCode())) {
            BLesson bL = new BLesson();
            bL.setBusinessId(code);
            BLesson bLesson = bLessonServiceImpl.selectOne(bL);
            if (bLesson != null) {
                OssInfo ossInfo = new ObjectMapper().convertValue(cyResult.getData(), OssInfo.class);
                bLesson.setDefaultUrl(global.getBase_Discovery() + ossInfo.getPath());
                CyUserUtil.setCurrentMergeOperation(bLesson);
                int line = bLessonServiceImpl.updateByPrimaryKeySelective(bLesson);
                return CyResultGenUtil.builder(new CyPersistModel(line),
                        CyMessCons.MESSAGE_ALERT_SUCCESS,
                        CyMessCons.MESSAGE_ALERT_ERROR,
                        bLessonServiceImpl.selectOne(code, null, getToken()));
            } else {

                throw new CyServiceException(ResultServiceEnums.UPLOAD_FILE_ERROR.getCode(),
                        ResultServiceEnums.UPLOAD_FILE_ERROR.getMessage());
            }
        } else {
            throw new CyServiceException(ResultServiceEnums.ADD_ERROR.getCode(),
                    ResultServiceEnums.ADD_ERROR.getMessage());
        }
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:lesson:defaultUrl')")
    @ApiOperation(value = "恢复默认", notes = "恢复默认封面图片")
    @ApiImplicitParam(name = "code", value = "课程编号", required = true, dataType = "varchar")
    @PostMapping(value = "defaultUrl")
    public CyResult defaultUrl(String code) throws Exception {
        String path = global.getDEFAULT_COURSE_LOCATION();
        BLesson bL = new BLesson();
        bL.setCode(code);
        BLesson bLesson = bLessonServiceImpl.selectOne(bL);
        if (bLesson != null) {
            bLesson.setDefaultUrl(path);
            CyUserUtil.setCurrentMergeOperation(bLesson);
            int line = bLessonServiceImpl.updateByPrimaryKeySelective(bLesson);
            return CyResultGenUtil.builder(new CyPersistModel(line),
                    CyMessCons.MESSAGE_ALERT_SUCCESS,
                    CyMessCons.MESSAGE_ALERT_ERROR,
                    path);
        } else {
            throw new CyServiceException(ResultServiceEnums.UPLOAD_FILE_ERROR.getCode(),
                    ResultServiceEnums.UPLOAD_FILE_ERROR.getMessage());
        }
    }


    /**
     * 查询课程 详情
     *
     * @param businessId
     * @return
     */
//    @PreAuthorize("@cyPerm.hasPerm('opm:lesson:one')")
    @ApiOperation(value = "唯一查找", notes = "根据ID查找一条记录")
    @ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")
    @GetMapping(value = "/one")
    public CyResult queryOne(String businessId, String userId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLessonServiceImpl.selectOne(businessId, userId, getToken()));
    }


    /**
     * @description: 查询所有课程信息(前端下拉列表使用)
     * @author: gaoyu
     * @param:
     * @return:
     **/
    @PreAuthorize("@cyPerm.hasPerm('opm:lesson:teaLess')")
    @ApiOperation(value = "唯一查找", notes = "根据ID查找一条记录")
    @ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")
    @GetMapping(value = "/teaLess")
    public CyResult queryTeaLess(BLesson bLesson) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLessonServiceImpl.findAll(bLesson));
    }

    /**
     * 修改状态
     */
    @PreAuthorize("@cyPerm.hasPerm('opm:lesson:updateStatus')")
    @ApiOperation(value = "修改状态", notes = "修改状态")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @PutMapping("/updateStatus")
    public CyResult updateStatus(BLesson bLesson) {
        CyPersistModel data = bLessonServiceImpl.updateStatus(bLesson);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLesson);
    }


    /**
     * 批量修改课程状态
     */
    @PreAuthorize("@cyPerm.hasPerm('opm:lesson:updateStatus')")
    @ApiOperation(value = "批量修改状态", notes = "批量修改状态")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @PutMapping("/updateBatchStatus")
    public CyResult updateBatchStatus(BLesson bLesson) {
        CyPersistModel data = bLessonServiceImpl.updateBatchStatus(bLesson);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLesson);
    }


    /**
     * 精品课程查询
     */
//    @PreAuthorize("@cyPerm.hasPerm('opm:lesson:qualityLesson')")
    @ApiOperation(value = "精品课程查询", notes = "精品课程查询")
    @ApiImplicitParams({@ApiImplicitParam(name = "pageNum", value = "pageNum", required = true, dataType = "int"),
            @ApiImplicitParam(name = "rows", value = "rows", required = true, dataType = "int")})
    @GetMapping("/qualityLesson")
    public CyResult qualityLesson(BLesson bLesson) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLessonServiceImpl.findByqualityLesson(bLesson, getToken()));
    }

    /**
     * 推荐课程
     * 同岗位或者同技术方向的课程 显示3个
     */
//    @PreAuthorize("@cyPerm.hasPerm('opm:lesson:recommendLesson')")
    @ApiOperation(value = "推荐课程", notes = "推荐课程")
    @ApiImplicitParams({@ApiImplicitParam(name = "pageNum", value = "pageNum", required = true, dataType = "int"),
            @ApiImplicitParam(name = "rows", value = "rows", required = true, dataType = "int")})
    @GetMapping("/recommendLesson")
    public CyResult recommendLesson(BLesson bLesson) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLessonServiceImpl.recommendLesson(bLesson));
    }

    /**
     * 根据课程id修改角色
     */
    @CyOpeLogAnno(title = "system-课程表管理-修改课程角色表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value = "修改课程角色表", notes = "修改课程角色表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/updateRole/{businessId:\\w+}")
    public CyResult updateUserRole(@PathVariable String businessId, @RequestBody BLesson bLesson, BindingResult bindingResult) {
        bLesson.setBusinessId(businessId);
        CyPersistModel data = bLessonServiceImpl.updateRole(bLesson);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLesson);
    }

    /**
     * 课程难度统计
     */
    @ApiOperation(value = "课程统计", notes = "课程统计")
    @GetMapping("/lessonCount")
    public CyResult lessonDifficultyCount(difficultyCountDTO difficultyCountDTO) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLessonServiceImpl.lessonCount(difficultyCountDTO));
    }


    /**
     * pc 课程申请列表
     * 当前用户未拥有的课程信息
     * 已提交申请的课程信息
     */
    @PreAuthorize("@cyPerm.hasPerm('opm:lesson:pcLessonApplication')")
    @ApiOperation(value = "pc 课程申请列表", notes = "当前用户未拥有的课程信息")
    @ApiImplicitParams({@ApiImplicitParam(name = "pageNum", value = "pageNum", required = true, dataType = "int"),
            @ApiImplicitParam(name = "rows", value = "rows", required = true, dataType = "int")})
    @GetMapping("/pcLessonApplication")
    public CyResult pcLessonApplication() {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLessonServiceImpl.pcLessonApplication());
    }

    /**
     * 查询收藏的课程
     */
    @PreAuthorize("@cyPerm.hasPerm('opm:lesson:findByFavorites')")
    @CyOpeLogAnno(title = "system-pc_用户收藏课程表管理-查询pc_用户收藏课程表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "分页查询pc_用户收藏课程表集合", notes = "分页查询pc_用户收藏课程表集合")
    @GetMapping(value = "/findByFavorites")
    public CyResult findByFavorites(BLesson bLesson) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLessonServiceImpl.findByFavorites(getPaginationUtility(), bLesson));
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:lesson:getDifficultyLevel')")
    @CyOpeLogAnno(title = "查询所有课程难度等级列表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询所有课程难度等级列表", notes = "查询所有课程难度等级列表")
    @GetMapping(value = "/getDifficultyLevel")
    public CyResult getDifficultyLevel() {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLessonServiceImpl.getDifficultyLevel());
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:lesson:getClassPlan')")
    @CyOpeLogAnno(title = "查询所有课程方案列表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询所有课程方案列表", notes = "查询所有课程方案列表")
    @GetMapping(value = "/getClassPlan")
    public CyResult getClassPlan(ClassPlanDTO classPlanDTO) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLessonServiceImpl.getClassPlan(classPlanDTO));
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:lesson:getTecClassify')")
    @CyOpeLogAnno(title = "查询所有课程技术分布", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询所有课程技术分布", notes = "查询所有课程技术分布")
    @GetMapping(value = "/getTecClassify")
    public CyResult getTecClassify(TecClassifyDTO tecClassifyDTO) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLessonServiceImpl.getTecClassify(tecClassifyDTO));
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:lesson:getJobClassify')")
    @CyOpeLogAnno(title = "查询所有课程岗位分布", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询所有课程岗位分布", notes = "查询所有课程岗位分布")
    @GetMapping(value = "/getJobClassify")
    public CyResult getJobClassify() {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLessonServiceImpl.getJobClassify());
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:lesson:getCourseView')")
    @CyOpeLogAnno(title = "查询所有课程统计列表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询所有课程统计列表", notes = "查询所有课程统计列表")
    @GetMapping(value = "/getCourseView")
    public CyResult getCourseView() {
        CyPageInfo<CourseView> paginationUtility = new CyPageInfo<>();
        paginationUtility.setCurrent(getPaginationUtility().getCurrent());
        paginationUtility.setSize(getPaginationUtility().getSize());
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLessonServiceImpl.getCourseView(paginationUtility));
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:lesson:getTotalLearn')")
    @CyOpeLogAnno(title = "查询学习总人数", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询学习总人数", notes = "查询学习总人数")
    @GetMapping(value = "/getTotalLearn")
    public CyResult getTotalLearn(BLesson bLesson) {
        CyPageInfo<TotalLearn> paginationUtility = new CyPageInfo<>();
        paginationUtility.setCurrent(getPaginationUtility().getCurrent());
        paginationUtility.setSize(getPaginationUtility().getSize());
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLessonServiceImpl.getTotalLearn(paginationUtility, bLesson));
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:lesson:getNotStart')")
    @CyOpeLogAnno(title = "查询未开始学习总人数", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询未开始学习总人数", notes = "查询未开始学习总人数")
    @GetMapping(value = "/getNotStart")
    public CyResult getNotStart(BLesson bLesson) {
        CyPageInfo<TotalLearn> paginationUtility = new CyPageInfo<>();
        paginationUtility.setCurrent(getPaginationUtility().getCurrent());
        paginationUtility.setSize(getPaginationUtility().getSize());
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLessonServiceImpl.getNotStart(paginationUtility, bLesson));
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:lesson:getLearning')")
    @CyOpeLogAnno(title = "查询学习中总人数", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询学习中总人数", notes = "查询学习中总人数")
    @GetMapping(value = "/getLearning")
    public CyResult getLearning(BLesson bLesson) {
        CyPageInfo<TotalLearn> paginationUtility = new CyPageInfo<>();
        paginationUtility.setCurrent(getPaginationUtility().getCurrent());
        paginationUtility.setSize(getPaginationUtility().getSize());
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLessonServiceImpl.getLearning(paginationUtility, bLesson));
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:lesson:getFinish')")
    @CyOpeLogAnno(title = "查询学习完成总人数", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询学习完成总人数", notes = "查询学习完成总人数")
    @GetMapping(value = "/getFinish")
    public CyResult getFinish(BLesson bLesson) {
        CyPageInfo<TotalLearn> paginationUtility = new CyPageInfo<>();
        paginationUtility.setCurrent(getPaginationUtility().getCurrent());
        paginationUtility.setSize(getPaginationUtility().getSize());
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLessonServiceImpl.getFinish(paginationUtility, bLesson));
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:lesson:getExamed')")
    @CyOpeLogAnno(title = "查参与考核总人数", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查参与考核总人数", notes = "查参与考核总人数")
    @GetMapping(value = "/getExamed")
    public CyResult getExamed(BLesson bLesson) {
        CyPageInfo<LessonStudyDTO> paginationUtility = new CyPageInfo<>();
        paginationUtility.setCurrent(getPaginationUtility().getCurrent());
        paginationUtility.setSize(getPaginationUtility().getSize());
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLessonServiceImpl.getExamed(paginationUtility, bLesson));
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:lesson:getExamineList')")
    @CyOpeLogAnno(title = "数据统计-考核视图-统计列表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "数据统计-考核视图-统计列表", notes = "数据统计-考核视图-统计列表")
    @GetMapping(value = "/getExamineList")
    public CyResult getExamineList(ExamListDTO examListDTO) {
        CyPageInfo<Examine> paginationUtility = new CyPageInfo<>();
        paginationUtility.setCurrent(getPaginationUtility().getCurrent());
        paginationUtility.setSize(getPaginationUtility().getSize());
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLessonServiceImpl.getExamineList(paginationUtility, examListDTO));
    }

    @CyOpeLogAnno(title = "数据统计-考核视图-参与考核人数", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "数据统计-考核视图-参与考核人数", notes = "数据统计-考核视图-参与考核人数")
    @GetMapping(value = "/getExamineParticipant")
    public CyResult getExamineParticipant(ListDetailDTO listDetailDTO) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLessonServiceImpl.getExamineParticipant(listDetailDTO));
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:lesson:getFullMark')")
    @CyOpeLogAnno(title = "数据统计-考核视图-满分人数", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "数据统计-考核视图-满分人数", notes = "数据统计-考核视图-满分人数")
    @GetMapping(value = "/getFullMark")
    public CyResult getFullMark(ListDetailDTO listDetailDTO) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLessonServiceImpl.getFullMark(listDetailDTO));
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:lesson:getPassNumber')")
    @CyOpeLogAnno(title = "数据统计-考核视图-及格人数", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "数据统计-考核视图-及格人数", notes = "数据统计-考核视图-及格人数")
    @GetMapping(value = "/getPassNumber")
    public CyResult getPassNumber(ListDetailDTO listDetailDTO) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLessonServiceImpl.getPassNumber(listDetailDTO));
    }

    /**
     * 查询用户是否为企业还是院校
     */
//    @PreAuthorize("@cyPerm.hasPerm('opm:lesson:getUserType')")
    @CyOpeLogAnno(title = "查询用户是否为企业还是院校", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询用户是否为企业还是院校", notes = "查询用户是否为企业还是院校")
    @GetMapping(value = "/getUserType")
    public CyResult getUserType(String userId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLessonServiceImpl.getUserType(userId));
    }

    //分页查询当前讲师的课程状态
//    @PreAuthorize("@cyPerm.hasPerm('opm:lesson:getLessonStatus')")
    @CyOpeLogAnno(title = "分页查询当前讲师的课程状态", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "分页查询当前讲师的课程状态", notes = "分页查询当前讲师的课程状态")
    @GetMapping(value = "/getLessonStatus")
    public CyResult getLessonStatus(BLesson bLesson) {
        CyPageInfo<BLesson> paginationUtility = new CyPageInfo<>();
        paginationUtility.setCurrent(getPaginationUtility().getCurrent());
        paginationUtility.setSize(getPaginationUtility().getSize());
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLessonServiceImpl.getLessonStatus(paginationUtility, bLesson));
    }

    //查询讲师的 创建课程数量 和学习数量
    @CyOpeLogAnno(title = "查询讲师的 创建课程数量 和学习数量", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询讲师的 创建课程数量 和学习数量", notes = "查询讲师的 创建课程数量 和学习数量")
    @GetMapping(value = "/getLessonCount")
    public CyResult getLessonCount() {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLessonServiceImpl.getLessonCount());
    }

    //查询当前讲师课程未通过的记录
    @CyOpeLogAnno(title = "查询当前讲师课程未通过的记录", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询当前讲师课程未通过的记录", notes = "查询当前讲师课程未通过的记录")
    @GetMapping(value = "/getLessonFail")
    public CyResult getLessonFail(BLesson bLesson) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLessonServiceImpl.getLessonFail(getPaginationUtility(), bLesson));
    }

    //查询当前讲师课程未通过的记录历史
    @CyOpeLogAnno(title = "查询当前讲师课程审核记录", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询当前讲师课程审核记录", notes = "查询当前讲师课程审核记录")
    @GetMapping(value = "/getLessonFailHistory")
    public CyResult getLessonFailHistory(BLesson bLesson) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLessonServiceImpl.getLessonFailHistory(getPaginationUtility(), bLesson));
    }

    //讲师创建课程时返回讲师的 id
    @CyOpeLogAnno(title = "讲师创建课程时返回讲师的 id", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "讲师创建课程时返回讲师的 id", notes = "讲师创建课程时返回讲师的 id")
    @GetMapping(value = "/getLessonTeacherId")
    public CyResult getLessonTeacherId() {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLessonServiceImpl.getLessonTeacherId());
    }


    //后台以及审核员查看提交审核课程
    @CyOpeLogAnno(title = "后台以及审核员查看提交审核课程", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "后台以及审核员查看提交审核课程", notes = "后台以及审核员查看提交审核课程")
    @GetMapping(value = "/getLessonAuditPrimary")
    public CyResult getLessonAuditPrimary(BLesson bLesson) {
        CyPageInfo<BLesson> paginationUtility = new CyPageInfo<>();
        paginationUtility.setCurrent(getPaginationUtility().getCurrent());
        paginationUtility.setSize(getPaginationUtility().getSize());
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLessonServiceImpl.getLessonAuditPrimary(paginationUtility, bLesson));
    }

    //后台审核员获取审核数量情况统计
    @CyOpeLogAnno(title = "后台审核员获取审核数量情况统计", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "后台审核员获取审核数量情况统计", notes = "后台审核员获取审核数量情况统计")
    @GetMapping(value = "/getLessonAuditCount")
    public CyResult getLessonAuditCount() {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLessonServiceImpl.getLessonAuditCount());
    }

    //后台审核按钮
    @CyOpeLogAnno(title = "后台审核按钮", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value = "后台审核按钮", notes = "后台审核按钮")
    @PostMapping(value = "/updateLessonAudit")
    public CyResult updateLessonAudit(@Valid AuditLogs auditLogs) {
        bLessonServiceImpl.updateLessonAudit(auditLogs);
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                null);
    }

    //讲师提交审核
    @CyOpeLogAnno(title = "讲师提交审核", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value = "讲师提交审核", notes = "讲师提交审核")
    @PostMapping(value = "/updateLessonAuditPrimary")
    public CyResult updateLessonAuditPrimary(BLesson bLesson) {
        bLessonServiceImpl.updateLessonAuditPrimary(bLesson);
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                null);
    }


    @PreAuthorize("@cyPerm.hasPerm('cms:lesson:export')")
    @CyOpeLogAnno(title = "system-课程管理-查询课程管理列表管理", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出课程管理列表信息", notes = "导出课程管理列表信息")
    @GetMapping(value = "/export")
    public void outCmsBanner(HttpServletResponse response, BLesson bLesson, @PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="课程管理信息.xls";break;
            case "1": excelName="课程管理信息.xlsx";break;
            case "2": excelName="课程管理信息.csv";break;
        }
        List<ExportBLesson> blessonsList = bLessonServiceImpl.export(bLesson);
        CyEpExcelUtil.exportExcel(blessonsList, "课程管理列表信息", "课程管理列表信息", ExportBLesson.class, excelName, response);
    }
}
