package org.rcisoft.business.blesson.dao;

import com.baomidou.mybatisplus.core.metadata.IPage;
import org.apache.ibatis.annotations.*;
import org.rcisoft.business.blesson.dto.*;
import org.rcisoft.business.blesson.entity.*;
import org.rcisoft.business.blesson.vo.DifficultyCountVO;
import org.rcisoft.core.mapper.CyBaseMapper;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.pc.pcrolelesson.entity.PcRoleLesson;
import org.rcisoft.pc.statistics.lessonStatistics.dto.LessonStudyDTO;

import java.util.List;

/**
 * Created with cy on 2024年3月23日 上午9:54:37.
 */

public interface BLessonRepository extends CyBaseMapper<BLesson> {


//    List<BLesson> queryBLessons(@Param("entity") BLesson bLesson);

    List<BLesson> queryAllBusson(@Param("entity") BLesson bLesson);

    IPage<BLesson> queryBLessons(CyPageInfo cyPageInfo, @Param("entity") BLesson param);

    List<ExportBLesson> exportBlessonList(@Param("entity") BLesson param);

    IPage<BLesson> queryPcBLessons(CyPageInfo cyPageInfo, @Param("entity") BLesson bLesson);

    /**
     * 分页查询用户必修课程
     *
     * @param cyPageInfo
     * @param pcBLessonQuery
     * @return
     */
    IPage<BLesson> pagingBLessonObligatory(CyPageInfo cyPageInfo, @Param("pcBLessonQuery") PcBLessonQuery pcBLessonQuery);

    /**
     * 分页查询用户选修课程
     *
     * @param cyPageInfo
     * @param pcBLessonQuery
     * @param list
     * @return
     */
    IPage<BLesson> pagingBLessonElective(CyPageInfo cyPageInfo, @Param("pcBLessonQuery") PcBLessonQuery pcBLessonQuery,
                                         @Param("entity") List<String> list);

    /**
     * 分页查询ip登录用户课程
     *
     * @param cyPageInfo
     * @param pcBLessonQuery
     * @return
     */
    IPage<BLesson> pagingBLessonForIP(CyPageInfo cyPageInfo, @Param("pcBLessonQuery") PcBLessonQuery pcBLessonQuery);

    /**
     * 根据用户id查询全部用户课程
     *
     * @param userId
     * @return
     */
    List<BLesson> getAllBLessonByUserId(@Param("userId") String userId);

    IPage<BLesson> getAllBLessonByUserIdNew(CyPageInfo cyPageInfo, @Param("userId") String userId);

    /**
     * 学习中心 - 我的小组 - 学员统计视图
     *
     * @param cyPageInfo
     * @param pcBLessonQuery
     * @return
     */
    IPage<MyGroupStatisticsVO> pagingStudentStatistics(CyPageInfo<MyGroupStatisticsVO> cyPageInfo, @Param("pcBLessonQuery") PcBLessonQuery pcBLessonQuery);

    /**
     * 学习中心 - 我的小组
     * 学员/课程统计视图明细
     *
     * @param cyPageInfo
     * @param pcBLessonQuery
     * @return
     */
    IPage<StatisticsDetailVO> pagingStudentStatisticsDetail(CyPageInfo<StatisticsDetailVO> cyPageInfo, @Param("pcBLessonQuery") PcBLessonQuery pcBLessonQuery);

    /**
     * 学习中心 - 我的小组 - 课程视图
     *
     * @param cyPageInfo
     * @param pcBLessonQuery
     * @return
     */
    IPage<MyGroupStatisticsVO> pagingLessonStatistics(CyPageInfo<MyGroupStatisticsVO> cyPageInfo, @Param("pcBLessonQuery") PcBLessonQuery pcBLessonQuery);

    /**
     * 学习中心 - 我的小组 - 课程视图明细
     *
     * @param cyPageInfo
     * @param pcBLessonQuery
     * @return
     */
    IPage<StatisticsDetailVO> pagingLessonStatisticsDetail(CyPageInfo<StatisticsDetailVO> cyPageInfo, @Param("pcBLessonQuery") PcBLessonQuery pcBLessonQuery);

    //批量删除课程角色中间表
    int deleteRoleLessons(List<PcRoleLesson> pcRoleLessonList);


    @Select("<script>select bl.*,bld.lecturer_id as lecturerId from tea_lesson_new bl " +
            "left join tea_lesson_direction bld on bl.business_id = bld.lession_id " +
            "where bl.code = #{code} and bl.del_flag != 1 and bl.flag = 1 </script>")
    @ResultMap(value = "BaseResultMap")
    BLesson queryBLessonByCode(String code);

    //    @Insert("<script>INSERT INTO tea_lesson_direction (business_id,lession_id,lecturer_id,sl_id) VALUES " +
//            "(#{businessId},#{lessionId},#{lecturerId},#{slId})</script>")
//    int insertLessonDirection(BLessonDirection model);
    @Insert("<script>INSERT INTO tea_lesson_direction (business_id,lession_id,lecturer_id) VALUES " +
            "(#{businessId},#{lessionId},#{lecturerId})</script>")
    int insertLessonDirection(BLessonDirection model);

    @Select("SELECT COALESCE(SUM(class_hour),0) classHour FROM tea_lesson_direction where lesson_id = #{businessId} and pid != '-1'")
    int queryClassHourByLessonId(String businessId);

    @Update("<script>update tea_lesson_direction set lecturer_id = #{lecturerId} where lession_id = #{lessionId}</script>")
    int updateDirectionByLessonId(BLessonDirection direction);


    @Insert("<script>INSERT INTO tea_lesson_new (" +
            "business_id, lesson_name, class_hour, class_plan,class_plan_school, job_classify, tec_classify, tec_classify_school,difficulty_classify, lesson_brief, lesson_tea_name, lesson_price, home_display, ent_quality_lesson, school_quality_lesson, lesson_description, default_url, create_by, update_by, del_flag, flag, remarks, update_date, create_date,quality_lesson,lesson_type,lesson_type_school,course_type,course_type_c,enterprise_course_dimensions,is_appraisal,audit_state,lecturer_id,intelligent_classroom ) " +
            "VALUES" +
            "<foreach collection=\"list\" item=\"item\" separator=\",\">" +
            "( #{item.businessId}, #{item.lessonName}, #{item.classHour}, #{item.classPlan}, #{item.classPlanSchool}, #{item.jobClassify}, #{item.tecClassify}, #{item.tecClassifySchool}, #{item.difficultyClassify}, #{item.lessonBrief}, #{item.lessonTeaName}, #{item.lessonPrice}, #{item.homeDisplay}, #{item.entQualityLesson}, #{item.schoolQualityLesson}, #{item.lessonDescription}, #{item.defaultUrl}, #{item.createBy}, #{item.updateBy}, #{item.delFlag}, #{item.flag}, #{item.remarks}, #{item.updateDate}, #{item.createDate},#{item.qualityLesson},#{item.lessonType},#{item.lessonTypeSchool},#{item.courseType},#{item.courseTypeC},#{item.enterpriseCourseDimensions},#{item.isAppraisal},#{item.auditState},#{item.lecturerId},#{item.intelligentClassroom})" +
            "</foreach></script>")
    int insertList(List<BLesson> bLessons);


    /**
     * 根据code查询对象
     *
     * @param bLesson
     * @return
     */
    BLesson selectOneByCode(@Param("entity") BLesson bLesson);

    //修改状态
    int updateStatus(@Param("entity") BLesson bLesson);

    //查询id课程详情
    BLesson queryLessonDetail(String id);

    /**
     * 查询精品课
     *
     * @param bLesson
     * @return
     */
    List<BLesson> findByqualityLesson(@Param("bLesson") BLesson bLesson);

    /**
     * 查询推荐课程
     *
     * @param bLesson
     * @return
     */
    List<BLesson> recommendLesson(@Param("bLesson") BLesson bLesson);

    //统计课程难度
    int lessonCount(@Param("entity") difficultyCountDTO difficultyCountDTO);

    difficultyCountDTO lessonDifficultyCount(@Param("entity") difficultyCountDTO difficultyCountDTO);

    /**
     * 查询所有课程信息以及讲师名称
     *
     * @return
     */
    List<BLesson> findAllAndTeaName();

    /**
     * 查询用户收藏列表
     *
     * @param paginationUtility
     * @return
     */
    IPage<BLesson> findByFavorites(CyPageInfo<BLesson> paginationUtility, @Param("userId") String userId);

    DifficultyCountVO getDifficultyLevel();

    List<String> getClassPlan(@Param("entity") ClassPlanDTO classPlanDTO);

    List<String> getTecClassify(@Param("entity") TecClassifyDTO tecClassifyDTO);

    List<String> getJobClassify();

    /**
     * 查询所有的课程信息
     *
     * @param model
     * @return
     */
    List<BLesson> queryAllBLessons(@Param("entity") BLesson model);

    Integer getLessonTotalRecords();

    IPage<CourseView> getCourseViewByPage(CyPageInfo<CourseView> paginationUtility);

    Integer getTotalLearnNumber();

    IPage<TotalLearn> getTotalLearnRecords(CyPageInfo<TotalLearn> paginationUtility, @Param("entity") BLesson bLesson);

    Integer getNotStartNumber(String businessId);

    IPage<TotalLearn> getNotStartRecords(CyPageInfo<TotalLearn> paginationUtility, @Param("entity") BLesson bLesson);

    Integer getLearnNumber(String businessId);

    IPage<TotalLearn> getLearnRecords(CyPageInfo<TotalLearn> paginationUtility, @Param("entity") BLesson bLesson);

    Integer getFinishNumber(String businessId);

    IPage<TotalLearn> getFinishRecords(CyPageInfo<TotalLearn> paginationUtility, @Param("entity") BLesson bLesson);


    Integer getExamedNumber(String businessId);

    IPage<LessonStudyDTO> getExamedRecords(CyPageInfo<LessonStudyDTO> paginationUtility, @Param("entity") BLesson bLesson);

    Integer getExamineListNumber(@Param("entity") ExamListDTO examListDTO);

    IPage<Examine> getExamineListRecords(CyPageInfo<Examine> paginationUtility, @Param("entity") ExamListDTO examListDTO);

    Integer getExamineParticipantNumber(@Param("entity") String businessId);

    List<ListDetail> getExamineParticipantRecords(@Param("entity") ListDetailDTO listDetailDTO, @Param("offset") Integer i);

    Integer getFullMarkNumber(@Param("entity") String businessId);

    List<ListDetail> getFullMarkRecords(@Param("entity") ListDetailDTO listDetailDTO, @Param("offset") Integer i);


    Integer getPassNumberNumber(@Param("entity") String businessId);

    List<ListDetail> getPassNumberRecords(@Param("entity") ListDetailDTO listDetailDTO, @Param("offset") Integer i);

    String tryout(@Param("businessId") String businessId, @Param("userId") String userId);

    IPage<BLesson> queryBLessonByPaginationByDateAsc(CyPageInfo cyPageInfo, @Param("entity") BLesson param);

    List<ElectiveCourses> getCourseViewWithNotRole(List<String> list);

    List<UserRoleLesson> getCourseViewWithRole(List<String> list);

    List<UserRoleLesson> getRoleLesson(@Param("entity") List<UserRoleLesson> listRole);

    IPage<BLesson> freeAndPurchased(CyPageInfo<BLesson> paginationUtility, @Param("entity") BLesson model);

    List<StatisticsDetailVO> pagingStudentStatisticsDetailAll(String userIds);

    String getUserType(@Param("userId") String userId);

    String tryoutPerson(@Param("businessId") String businessId, @Param("userId") String userId);

    String tryoutAdmin(String businessId, String userId);

    MyGroupStatisticsVO queryStudentStatistics(@Param("userId") String userId);


    IPage<StatisticsDetailVO> totalLearnerNum(IPage<StatisticsDetailVO> statisticsDetailVOIPage, @Param("pcBLessonQuery") PcBLessonQuery pcBLessonQuery);

    IPage<StatisticsDetailVO> numberOfPeopleWhoDidNotStart(IPage<StatisticsDetailVO> statisticsDetailVOIPage, @Param("pcBLessonQuery") PcBLessonQuery pcBLessonQuery);

    IPage<StatisticsDetailVO> numberOfStudentsInTheStudy(IPage<StatisticsDetailVO> statisticsDetailVOIPage, @Param("pcBLessonQuery") PcBLessonQuery pcBLessonQuery);

    IPage<StatisticsDetailVO> numberOfStudyCompletions(IPage<StatisticsDetailVO> statisticsDetailVOIPage, @Param("pcBLessonQuery") PcBLessonQuery pcBLessonQuery);

    IPage<StatisticsDetailVO> theNumberOfParticipantsInTheAssessment(IPage<StatisticsDetailVO> statisticsDetailVOIPage, @Param("pcBLessonQuery") PcBLessonQuery pcBLessonQuery);

    IPage<BLesson> tryItQueryBLessons(CyPageInfo<BLesson> paginationUtility, @Param("entity") BLesson model, @Param("authenDept") String authenDept, @Param("authenBusinessId") String authenBusinessId);

    Integer inquireForAFullScore(@Param("entity") MyGroupStatisticsVO myGroupStatisticsVO);

    List<BLesson> getAllBLessonByUserIdPersonal(String loginUserId);

    IPage<BLesson> getLessonStatus(CyPageInfo<BLesson> paginationUtility, @Param("entity") BLesson entity);

    Integer getLessonCount(String authenBusinessId);

    IPage<BLesson> getLessonAuditPrimary(CyPageInfo<BLesson> paginationUtility, @Param("entity") BLesson entity);

    List<Integer> getLessonAuditCount();

    List<BLesson> getAllBeginBLessonByUserId(String userId);

    /**
     * 批量修改状态
     */
    Integer updateBatchStatus(BLesson bLesson);

    /**
     * 导出课程列表信息
     */
    List<ExportBLesson> exportBlessons();
}

