package org.rcisoft.business.blesson.entity;

import cn.afterturn.easypoi.excel.annotation.Excel;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonFormat;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.hibernate.validator.constraints.Length;
import org.rcisoft.business.bchapter.entity.BChapter;
import org.rcisoft.business.pclessonevaluation.entity.PcLessonEvaluation;
import org.rcisoft.core.entity.CyIdEntity;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * Created with cy on 2024年3月23日 上午9:54:37.
 */
@Data
@TableName("tea_lesson_new")
@NoArgsConstructor
@AllArgsConstructor
public class BLesson extends CyIdEntity<BLesson> {

    private static final long serialVersionUID = -4327021174023243830L;


    /**
     * @desc 课程名称
     * @column lesson_name
     * @default
     */
    @Excel(name = "课程名称", orderNum = "0", width = 20)
    private String lessonName;

    /**
     * @desc 课时
     * @column class_hour
     * @default
     */
    @Excel(name = "课时", orderNum = "1", width = 20)
    private String classHour;

    /**
     * @desc 课程方案
     * @column class_plan
     * @default
     */
    @Excel(name = "课程方案", orderNum = "2", width = 20)
    private String classPlan;
    /**
     * @desc 院校课程方案
     * @column class_plan
     * @default
     */
    private String classPlanSchool;

    /**
     * @desc 岗位分类
     * @column job_classify
     * @default
     */
    @Excel(name = "岗位分类", orderNum = "3", width = 20)
    private String jobClassify;
    /**
     * 企业课程分类
     */
    private String courseType;
    /**
     * 院校课程分类
     */
    private String courseTypeC;


    /**
     * @desc 技术分类
     * @column tec_classify
     * @default
     */
    @Excel(name = "技术分类", orderNum = "4", width = 20)
    private String tecClassify;
    /**
     * @desc 院校技术分类
     * @column tec_classify_school
     * @default
     */
    @Excel(name = "院校技术分类", orderNum = "4", width = 20)
    private String tecClassifySchool;

    /**
     * @desc 难度等级
     * @column difficulty_classify
     * @default
     */
    @Excel(name = "难度等级", orderNum = "5", width = 20)
    private String difficultyClassify;

    /**
     * @desc 课程简介
     * @column lesson_brief
     * @default
     */
    @Excel(name = "课程简介", orderNum = "6", width = 20)
    private String lessonBrief;

    /**
     * @desc 课程讲师
     * @column lesson_tea_name
     * @default
     */
    @Excel(name = "课程讲师", orderNum = "7", width = 20)
    private Integer lessonTeaName;

    /**
     * @desc 价格(元)
     * @column lesson_price
     * @default
     */
    @Excel(name = "价格(元)", orderNum = "8", width = 20)
    private BigDecimal lessonPrice;

    @Excel(name = "首页显示(0:不显示; 1: 显示)", orderNum = "9", width = 20)
    private String homeDisplay;

    /**
     * @desc 企业精品课(0 : 否 ; 1 : 是)
     * @column ent_quality_lesson
     * @default
     */
    @Excel(name = "企业精品课(0:否 ; 1 :是)", orderNum = "10", width = 20)
    private String entQualityLesson;

    /**
     * @desc 院校精品课(0 : 否 ; 1 : 是)
     * @column school_quality_lesson
     * @default
     */
    @Excel(name = "院校精品课(0:否 ; 1 : 是)", orderNum = "11", width = 20)
    private String schoolQualityLesson;

    /**
     * 精品课(0:否 ; 1 :是)
     **/
    @TableField("quality_lesson")
    private String qualityLesson;

    /**
     * 企业课程（0：未选择，1：已选择）
     **/
    @TableField(value = "lesson_type")
    private String lessonType;
    /**
     * 院校课程（0：未选择，1：已选择）
     **/
    @TableField(value = "lesson_type_school")
    private String lessonTypeSchool;
    /**
     * 企业课程维度
     */
    @TableField(value = "enterprise_course_dimensions")
    private String enterpriseCourseDimensions;

    /**
     * @desc 课程介绍
     * @column lesson_description
     * @default
     */
    @Excel(name = "课程介绍", orderNum = "12", width = 20)
    private String lessonDescription;

    /**
     * 是否考核
     */
    @TableField(value = "is_appraisal")
    private String isAppraisal;
    /**
     * 审核状态
     */
    @TableField(value = "audit_state")
    private String auditState;
    /**
     * 绑定讲师id
     */
    @TableField(value = "lecturer_id")
    private String lecturerId;

    /**
     * 智联课堂分类
     */
    @TableField(value = "intelligent_classroom")
    private String intelligentClassroom;
    /**
     * @desc 默认封面图片url
     * @column default_url
     * @default
     */
    @Excel(name = "默认封面图片url", orderNum = "13", width = 20)
    private String defaultUrl;
    //课程讲师
    @TableField(exist = false)
    private String teacherName;


    //     /*课程编号*/
//     //@NotBlank
    @Length(min = 1, max = 64, message = "长度最小为1,最大为50")
    @TableField(exist = false)
    private String code;

    /**
     * 申请id
     */
    @TableField(exist = false)
    private Integer applicationId;
//     /*课程名称*/
//     @NotBlank
//     @Length(min = 1,max = 200,message = "长度最小为1,最大为150")
//     private String lessonName;
//     /*默认封面图片url*/
//     private String defaultUrl;
//
//     @Length(min = 1,max = 8,message = "长度最小为1,最大为5")
//     private String classHour;//课时

    @Length(min = 1, max = 8, message = "长度最小为1,最大为5")
    @TableField(exist = false)
    private String credits;//学分

    @TableField(exist = false)
    private BigDecimal courseGrad;//课程评分

    @TableField(exist = false)
    private List<PcLessonEvaluation> evaluationList;//课程评论列表

    private transient String directionId;//课程方向ID

    private transient String directionName;//课程方向名称

    private transient String directionCode;//课程方向编号

    private transient String chapterClassHour;//目前已添加总学时

    //pc端字段
    //角色名称集合
    @TableField(exist = false)
    private String roleNames;
    //角色id集合
    @TableField(exist = false)
    private String roleIds;
    //到期日期
    @TableField(exist = false)
    private Integer remainingDate;
    //单位id
    @TableField(exist = false)
    private Integer unitId;
    //单位类型(1:企业;2:院校)
    @TableField(exist = false)
    private String unitType;
    //是否付费(0:否;1:是)
    @TableField(exist = false)
    private String isPay;
    //学员统计
    @TableField(exist = false)
    private Integer userCount;
    //角色idlist
    @TableField(exist = false)
    private List<Integer> roleIdsList;
    //技术分类标签
    @TableField(exist = false)
    private String tecClassifyLabels;
    //岗位分类标签
    @TableField(exist = false)
    private String jobClassifyLabels;
    //难度标签
    @TableField(exist = false)
    private String difficultyClassifyLabels;
    //课程维度标签
    @TableField(exist = false)
    private String courseDimensionsLabels;
    //智联课堂标签
    @TableField(exist = false)
    private String intelligentClassroomLabels;
    //前沿课堂分类标签
    @TableField(exist = false)
    private String courseTypeLabels;
    //前沿课堂分类标签
    @TableField(exist = false)
    private String courseTypeCLabels;
    @TableField(exist = false)
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date beginTime;
    @TableField(exist = false)
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date expireTime;

    @TableField(exist = false)
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date startTime;
    @TableField(exist = false)
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date endTime;

    @TableField(exist = false)
    /**
     * 判断是前端开始学习和继续学习的切换
     */
    private Integer isStudy;

    /**
     * 课程浏览量
     */
    private transient int lessonViews;

    /**
     * 是否购买, 0 未付费(试用) 1 已付费
     */
    private transient int lessonIsPay;

    /**
     * 是否收藏, 0/null 未收藏, 1 收藏, 2 用户未登录
     */
    private transient int lessonIsFavorite;

    /**
     * 开始试用时间
     */
    private transient Date beginTrialTime;

    /**
     * 结束试用时间
     */
    private transient Date endTrialTime;

    /**
     * 剩余有效天数
     */
    @TableField(exist = false)
    private Integer availableTrialTime;

    /**
     * 课程是否过期（0：未过期；1已过期）
     */
    @TableField(exist = false)
    private String isExpired;

    /**
     * 全部可学习的课程节点数量
     */
    @TableField(exist = false)
    private Integer allChapterNum;

    /**
     * 已经学习完成的课程节点数量
     */
    @TableField(exist = false)
    private Integer learnedChapterNum;

    /**
     * 是否完成课程学习(0: 未完成; 1: 已完成; )
     */
    @TableField(exist = false)
    private String isCompleteLearned;

    /**
     * 是否必修(0: 否; 1: 是)
     */
    @TableField(exist = false)
    private String isObligatory;

    /**
     * 是否完成课程考核(0: 未完成; 1: 已完成; )
     */
    @TableField(exist = false)
    private String isCompleteExam;

    /**
     * 上次学习的课程节点信息
     */
    @TableField(exist = false)
    private BChapter lastTimeChapter;

    /**
     * 上次学习的课程节点名称
     */
    @TableField(exist = false)
    private String chapterName;
    /**
     * 上次学习的课程节点编号
     */
    @TableField(exist = false)
    private String chapterNum;
    /**
     * 开课时教师的名称
     **/
    @TableField(exist = false)
    private String sTeachName;

    /**
     * 课程得分
     */
    @TableField(exist = false)
    private Double lessonScore;

    /**
     * 必修未完成数量、必修已完成数量、选修课数量
     */
    @TableField(exist = false)
    private Integer[] courseStatisticsList;

    /**
     * 图面路径
     */
    @TableField(exist = false)
    private String path;

    @Excel(name = "及格分数", width = 20)
    private String passingGrade;

    @Excel(name = "总分", width = 21)
    @TableField(exist = false)
    private String totalScore;
    @TableField(value = "`condition`")
    private transient String condition;//模糊查询条件
    @TableField(exist = false)
    private String tryout;
    @TableField(exist = false)
    private Date createTime;
    //时间排序 0正序 1倒叙
    @TableField(exist = false)
    private Integer chronologicalOrdering;
    //标签集合
    @TableField(exist = false)
    private transient List<String> labelList;

    @TableField(exist = false)
    private List<String> lessonIdList;

    /**
     * 从免费变为收费
     */
    private String priceTrend;

    /**
     * 创建人
     */
    @TableField(exist = false)
    private String createName;

    public BLesson(String code) {
        this.code = code;
    }

    public BLesson(String code, String lessonName, String classHour, String credits) {
        this.code = code;
        this.lessonName = lessonName;
        this.classHour = classHour;
        this.credits = credits;
    }
}

