package org.rcisoft.business.blesson.service;

import com.baomidou.mybatisplus.core.metadata.IPage;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.rcisoft.business.auditlogs.entity.AuditLogs;
import org.rcisoft.business.blesson.dto.*;
import org.rcisoft.business.blesson.entity.*;
import org.rcisoft.business.blesson.vo.DifficultyCountVO;
import org.rcisoft.business.blesson.vo.ExamineInfoVO;
import org.rcisoft.business.cmsbanner.entity.CmsBanner;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.pc.statistics.lessonStatistics.dto.LessonStudyDTO;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Created by cy on 2024年3月23日 上午9:54:37.
 */
public interface BLessonService {

    /**
     * 保存
     *
     * @param bLesson
     * @return
     */
    CyPersistModel persist(BLesson bLesson, String token);

    /**
     * 删除
     *
     * @param bLesson
     * @return
     */
    CyPersistModel remove(BLesson bLesson);

    /**
     * 逻辑删除
     *
     * @param bLesson
     * @return
     */
    CyPersistModel removeLogical(BLesson bLesson);

    /**
     * 修改
     *
     * @param bLesson
     * @return
     */
    CyPersistModel merge(BLesson bLesson);

    CyPersistModel updateRole(BLesson bLesson);

    /**
     * 根据id查询
     *
     * @param id
     * @return
     */
    BLesson findById(String id);


    /**
     * 查询list
     *
     * @param bLesson
     * @return
     */
    List<BLesson> findAll(BLesson bLesson);


//    /**
//    * 导出
//    * @return
//    */
//    List<BLesson> export(BLesson bLesson);

    /**
     * 根据条件分页查询
     *
     * @param paginationUtility
     * @param param
     * @return
     */
    IPage<BLesson> queryBLessonsByPagination(CyPageInfo<BLesson> paginationUtility, BLesson param, String token);

    /**
     * 根据条件分页查询pc端
     *
     * @param paginationUtility
     * @param bLesson
     * @return
     */
    IPage<BLesson> queryPcBLessonsByPagination(CyPageInfo<BLesson> paginationUtility, BLesson bLesson);

    /**
     * 根据条件分页查询
     * 使用模块：
     * 学习中心-我的课程
     *
     * @param paginationUtility 分页参数
     * @param pcBLessonQuery    查询条件
     * @param token
     * @return
     */
    IPage<BLesson> pagingBLesson(CyPageInfo<BLesson> paginationUtility, PcBLessonQuery pcBLessonQuery, String token);

    /**
     * 根据条件分页查询
     * 使用模块：
     * 学习中心-我的课程（ip登录用户）
     *
     * @param paginationUtility 分页参数
     * @param pcBLessonQuery    查询条件
     * @return
     */
    IPage<BLesson> pagingBLessonForIP(CyPageInfo<BLesson> paginationUtility, PcBLessonQuery pcBLessonQuery);

    List<BLesson> getAllBLessonByUserId(String userId);

    /**
     * 根据条件分页查询
     * 使用模块：
     * 学习中心-我的小组
     * 学员视图 / 课程视图
     *
     * @param paginationUtility 分页参数
     * @param pcBLessonQuery    查询条件
     * @return
     */
    IPage<MyGroupStatisticsVO> pagingMyGroupStatistics(CyPageInfo<MyGroupStatisticsVO> paginationUtility, PcBLessonQuery pcBLessonQuery);

    /**
     * 根据条件分页查询
     * 使用模块：
     * 学习中心-我的小组
     * 学员视图 / 课程视图
     * 统计详情
     *
     * @param paginationUtility 分页参数
     * @param pcBLessonQuery    查询条件
     * @return
     */
    IPage<StatisticsDetailVO> pagingStatisticsDetail(CyPageInfo<StatisticsDetailVO> paginationUtility, PcBLessonQuery pcBLessonQuery);

//    IPage<BLesson> queryBLessons(BLesson model);

    CyPersistModel removeBLesson(String id);

    /**
     * 课程信息导入
     *
     * @param convert
     * @param token
     * @return
     */
    CyPersistModel importExcel(HSSFWorkbook convert, String token);

    /**
     * 根据主键唯一查找
     *
     * @param businessId
     * @return
     */
    BLesson selectOne(String businessId, String userId, String token);

    /**
     * 根据bLesson对象查询
     */
    BLesson selectOne(BLesson bLesson);

    /**
     * 根据bLesson对象更新
     */
    int updateByPrimaryKeySelective(BLesson bLesson);

    //修改状态
    CyPersistModel updateStatus(BLesson bLesson);

    /**
     * @param bLesson
     * @param token
     * @return
     */
    List<BLesson> findByqualityLesson(BLesson bLesson, String token);

    List<BLesson> recommendLesson(BLesson bLesson);

    //课程难度统计
    difficultyCountDTO lessonCount(difficultyCountDTO difficultyCountDTO);

    /**
     * pc 课程申请列表
     * 当前用户未拥有的课程信息
     */
    Map<String, List<BLesson>> pcLessonApplication();

    /**
     * 查询用户收藏列表
     *
     * @param paginationUtility
     * @param pcLessonFavorite
     */
    IPage<BLesson> findByFavorites(CyPageInfo<BLesson> paginationUtility, BLesson pcLessonFavorite);

    DifficultyCountVO getDifficultyLevel();

    ClassPlanDTO getClassPlan(ClassPlanDTO classPlanDTO);

    Map<String, Integer> getTecClassify(TecClassifyDTO tecClassifyDTO);

    Map<String, Integer> getJobClassify();


    IPage<CourseView> getCourseView(CyPageInfo<CourseView> paginationUtility);

    IPage<TotalLearn> getTotalLearn(CyPageInfo<TotalLearn> paginationUtility, BLesson bLesson);

    IPage<TotalLearn> getNotStart(CyPageInfo<TotalLearn> paginationUtility, BLesson bLesson);

    IPage<TotalLearn> getLearning(CyPageInfo<TotalLearn> paginationUtility, BLesson bLesson);

    IPage<TotalLearn> getFinish(CyPageInfo<TotalLearn> paginationUtility, BLesson bLesson);

    IPage<LessonStudyDTO> getExamed(CyPageInfo<LessonStudyDTO> paginationUtility, BLesson bLesson);

    IPage<Examine> getExamineList(CyPageInfo<Examine> paginationUtility, ExamListDTO examListDTO);

    ExamineInfoVO getExamineParticipant(ListDetailDTO listDetailDTO);

    ExamineInfoVO getFullMark(ListDetailDTO listDetailDTO);

    ExamineInfoVO getPassNumber(ListDetailDTO listDetailDTO);

    IPage<BLesson> queryBLessonByPaginationByDateAsc(CyPageInfo<BLesson> paginationUtility, BLesson param, String token);

    String getUserType(String userId);

    IPage<BLesson> getLessonStatus(CyPageInfo<BLesson> paginationUtility, BLesson bLesson);

    HashMap<String, String> getLessonCount();

    IPage<AuditLogs> getLessonFail(CyPageInfo<BLesson> paginationUtility, BLesson bLesson);

    IPage<AuditLogs> getLessonFailHistory(CyPageInfo<BLesson> paginationUtility, BLesson bLesson);

    IPage<BLesson> getLessonAuditPrimary(CyPageInfo<BLesson> paginationUtility, BLesson param);

    HashMap<String, Integer> getLessonAuditCount();


    String getLessonTeacherId();

    void updateLessonAudit(AuditLogs auditLogs);

    void updateLessonAuditPrimary(BLesson bLesson);

    CyPersistModel updateBatchStatus(BLesson bLesson);

    List<ExportBLesson> export(BLesson bLesson);
}
