package org.rcisoft.business.blesson.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.jetbrains.annotations.NotNull;
import org.rcisoft.business.auditlogs.dao.AuditLogsRepository;
import org.rcisoft.business.auditlogs.entity.AuditLogs;
import org.rcisoft.business.bchapter.entity.BChapter;
import org.rcisoft.business.bchapter.service.impl.BChapterServiceImpl;
import org.rcisoft.business.bdirection.dao.BDirectionRepository;
import org.rcisoft.business.bdirection.entity.BDirection;
import org.rcisoft.business.bfile.service.impl.BFileServiceImpl;
import org.rcisoft.business.blesson.dao.BLessonRepository;
import org.rcisoft.business.blesson.dto.*;
import org.rcisoft.business.blesson.entity.*;
import org.rcisoft.business.blesson.service.BLessonService;
import org.rcisoft.business.blesson.util.TecClassifyString;
import org.rcisoft.business.blesson.vo.DifficultyCountVO;
import org.rcisoft.business.blesson.vo.ExamineInfoVO;
import org.rcisoft.business.ossinfo.dao.OssInfoRepository;
import org.rcisoft.business.pclessonbrowse.entity.PcLessonBrowse;
import org.rcisoft.business.pclessonbrowse.service.PcLessonBrowseService;
import org.rcisoft.business.pclessonevaluation.dao.PcLessonEvaluationRepository;
import org.rcisoft.business.pclessonevaluation.entity.PcLessonEvaluation;
import org.rcisoft.business.pclessonfavorite.dao.PcLessonFavoriteRepository;
import org.rcisoft.business.pclessonfavorite.entity.PcLessonFavorite;
import org.rcisoft.business.sysLecturer.dao.CmsLecturerRepository;
import org.rcisoft.business.sysLecturer.entity.CmsLecturer;
import org.rcisoft.business.sysunitlesson.dao.SysUnitLessonRepository;
import org.rcisoft.business.sysuser.dao.PCSysUserRepository;
import org.rcisoft.business.sysuser.entity.SysUser;
import org.rcisoft.business.sysuser.enums.IdentityStaCons;
import org.rcisoft.business.tealessonandapplication.dao.TeaLessonAndApplicationRepository;
import org.rcisoft.business.teatrialcourse.dao.TeaTrialCourseRepository;
import org.rcisoft.business.teatrialcourse.dto.TrialCourseDto;
import org.rcisoft.business.teatrialcourse.entity.TeaTrialCourse;
import org.rcisoft.common.component.Global;
import org.rcisoft.core.component.CyInitComp;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyIdGenUtil;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.util.ExcelUtil;
import org.rcisoft.core.util.TestChinese;
import org.rcisoft.pc.pcgroupuser.service.impl.PcGroupUserServiceImpl;
import org.rcisoft.pc.pcrolelesson.entity.PcRoleLesson;
import org.rcisoft.pc.pcrolelesson.service.PcRoleLessonService;
import org.rcisoft.pc.statistics.lessonStatistics.dto.LessonStudyDTO;
import org.rcisoft.result.ResultServiceEnums;
import org.rcisoft.sys.dictionary.entity.DictData;
import org.rcisoft.sys.dictionary.service.DictionaryService;
import org.rcisoft.sys.wbac.user.dao.SysUserRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;
import org.springframework.util.ObjectUtils;

import java.io.IOException;
import java.math.BigDecimal;
import java.math.BigInteger;
import java.math.RoundingMode;
import java.util.*;
import java.util.stream.Collectors;

/**
 * Created by cy on 2024年3月23日 上午9:54:37.
 */
@Service
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class BLessonServiceImpl extends ServiceImpl<BLessonRepository, BLesson> implements BLessonService {


    @Autowired
    private BLessonRepository bLessonRepository;
    @Autowired
    private PcRoleLessonService pcRoleLessonService;
    @Autowired
    private PcLessonEvaluationRepository pcLessonEvaluationRepository;

    @Autowired
    private PCSysUserRepository sysUserRepository;
    @Autowired
    private Global global;

    @Autowired
    private BDirectionRepository bDirectionRepository;

    @Autowired
    private PCSysUserRepository pcSysUserRepository;

    @Autowired
    private TeaTrialCourseRepository teaTrialCourseRepository;

    @Autowired
    private CyInitComp cyInitComp;

    @Autowired
    private PcLessonFavoriteRepository pcLessonFavoriteRepository;

    @Autowired
    private OssInfoRepository ossInfoRepository;
    @Autowired
    private DictionaryService dictionaryServiceImpl;

    @Autowired
    private BChapterServiceImpl bChapterService;

    @Autowired
    private PcGroupUserServiceImpl pcGroupUserService;

    @Autowired
    private SysUnitLessonRepository sysUnitLessonRepository;

    @Autowired
    private TeaLessonAndApplicationRepository teaLessonAndApplicationRepository;

    @Autowired
    private BFileServiceImpl bFileService;

    @Autowired
    private PcLessonBrowseService pcLessonBrowseServiceImpl;

    @Autowired
    private AuditLogsRepository auditLogsRepository;
    @Autowired
    private CmsLecturerRepository cmsLecturerRepository;

    @NotNull
    private static List<String> getStrings(String tecClassify, List<DictData> tecClassifyList) {
        String[] tecClassifyValues = tecClassify.split(",");  // 将逗号分隔的多个值分割成数组
        List<String> tecClassifyLabels = new ArrayList<>();
        for (String value : tecClassifyValues) {
            for (DictData dictData : tecClassifyList) {
                if (dictData.getDictValue().equals(value.trim())) {
                    tecClassifyLabels.add(dictData.getDictLabel());  // 将找到的名称添加到集合中
                    break;  // 找到一个匹配即可跳出内层循环
                }
            }
        }
        return tecClassifyLabels;
    }

    @Override
    @Transactional(propagation = Propagation.REQUIRED, readOnly = false)
    public CyPersistModel persist(BLesson model, String token) {
        int line = 0;
        BLessonDirection direction = new BLessonDirection();
        direction.setLecturerId(model.getLessonTeaName());
        if (model.getBusinessId() == null) {
            if (StringUtils.isEmpty(model.getDefaultUrl())) {
                model.setDefaultUrl(global.getDEFAULT_COURSE_LOCATION());
            }
            if ("0".equals(model.getFlag())) {
                CyUserUtil.setCurrentPersistOperation(model);
                model.setFlag("0");
            } else {
                CyUserUtil.setCurrentPersistOperation(model);
            }
            ArrayList<BLesson> bLessons = new ArrayList<>();
            bLessons.add(model);
            line = bLessonRepository.insertList(bLessons);
            //添加课程方向信息
            direction.setBusinessId(CyIdGenUtil.uuid());
            direction.setLessionId(model.getBusinessId());
            bLessonRepository.insertLessonDirection(direction);
        } else {
            CyUserUtil.setCurrentMergeOperation(model);
            // 处理前端将非空字段置空后端不修改问题
            nonNullValidation(model);
            //从免费变为收费
            BLesson bLesson1 = new BLesson();
            bLesson1.setBusinessId(model.getBusinessId());
            BLesson bLesson = baseMapper.selectById(bLesson1);
            if (bLesson != null) {
                if (bLesson.getLessonPrice().compareTo(BigDecimal.ZERO) == 0 &&
                        model.getLessonPrice().compareTo(BigDecimal.ZERO) != 0) {
                    //添加收费课程记录
                    model.setPriceTrend("1");
                }
                //从收费变免费
                if (bLesson.getLessonPrice().compareTo(BigDecimal.ZERO) != 0 &&
                        model.getLessonPrice().compareTo(BigDecimal.ZERO) == 0) {
                    //添加收费课程记录
                    model.setPriceTrend("0");
                }
            }
            line = bLessonRepository.updateById(model);
            direction.setLessionId(model.getBusinessId());
            bLessonRepository.updateDirectionByLessonId(direction);
        }
        return new CyPersistModel(line);
    }

    private void nonNullValidation(BLesson model) {
        if (StringUtils.isBlank(model.getJobClassify())) {
            model.setJobClassify("");
        }
        if (StringUtils.isBlank(model.getTecClassify())) {
            model.setTecClassify("");
        }
        if (StringUtils.isBlank(model.getTecClassifySchool())) {
            model.setTecClassifySchool("");
        }
        if (StringUtils.isBlank(model.getLessonDescription())) {
            model.setLessonDescription("");
        }
        if ("0".equals(model.getLessonType())) {
            model.setClassPlan("");
        }
        if ("0".equals(model.getLessonTypeSchool())) {
            model.setClassPlanSchool("");
        }
    }

    /**
     * 删除
     *
     * @param bLesson
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(BLesson bLesson) {
        int line = baseMapper.realDelete(bLesson);
        log.debug(CyUserUtil.getAuthenUsername() + "删除了ID为" +
                bLesson.getBusinessId() + "的信息");
        return new CyPersistModel(line);
    }

    /**
     * 逻辑删除
     *
     * @param bLesson
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(BLesson bLesson) {
        bLesson.setDeleted();
        int line = baseMapper.deleteById(bLesson);
        log.debug(CyUserUtil.getAuthenUsername() + "逻辑删除了ID为" +
                bLesson.getBusinessId() + "的信息");
        return new CyPersistModel(line);
    }

    /**
     * 修改
     *
     * @param bLesson
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(BLesson bLesson) {
        int line = baseMapper.updateById(bLesson);
        log.debug(CyUserUtil.getAuthenUsername() + "修改了ID为" + bLesson.getBusinessId() + "的信息");
        return new CyPersistModel(line);
    }

    /**
     * 根据课程id修改角色
     *
     * @param bLesson
     * @return
     */

    @Override
    public CyPersistModel updateRole(BLesson bLesson) {
        //根据课程id查询全部课程角色关联表
        PcRoleLesson pcRoleLesson = new PcRoleLesson();
        pcRoleLesson.setLessonId(bLesson.getBusinessId());
        List<PcRoleLesson> pcRoleLessons = pcRoleLessonService.findAll(pcRoleLesson);
        if (pcRoleLessons != null && !pcRoleLessons.isEmpty()) {
            //删除全部课程角色关联表
            baseMapper.deleteRoleLessons(pcRoleLessons);
        }
        //如果角色idList为空 则不插入
        if (bLesson.getRoleIdsList() == null || bLesson.getRoleIdsList().isEmpty()) {
//            throw new CyServiceException(CyResSysExcEnum.ERROR);
        } else {
            //在中间表中添加数据
            List<Integer> roleIdsList = bLesson.getRoleIdsList();
            if (roleIdsList != null && !roleIdsList.isEmpty()) {
                for (Integer roleId : roleIdsList) {
                    PcRoleLesson pcRoleLesson1 = new PcRoleLesson();
                    pcRoleLesson1.setPcRoleId(roleId);
                    pcRoleLesson1.setLessonId(bLesson.getBusinessId());
                    pcRoleLessonService.persist(pcRoleLesson1);
                }
            }
        }
        return new CyPersistModel(1);
    }

    /**
     * 根据id查询
     *
     * @param id
     * @return
     */
    @Override
    public BLesson findById(String id) {
        BLesson bLesson = baseMapper.queryLessonDetail(id);
        if (bLesson != null) {
            bLesson.setPath(global.getBase_Discovery() + bLesson.getPath());
        }
        return bLesson;
    }

    /**
     * @description: 查询所有课程信息
     * @author: gaoyu
     * @param:
     * @return:
     **/
    @Override
    public List<BLesson> findAll(BLesson bLesson) {
        return baseMapper.queryAllBusson(bLesson);
    }

    /**
     * 导出
     *
     * @return
     */
//    @Override
//    public List<BLesson> export(BLesson bLesson) {
//        //List<BLesson> bLessonList = baseMapper.queryBLessons(bLesson);
//        return bLessonList;
//    }
    @Override
    public IPage<BLesson> queryBLessonsByPagination(CyPageInfo<BLesson> paginationUtility, BLesson model, String token) {
        IPage<BLesson> bLessonIPage = null;
        if ("0".equals(model.getLessonType())) {
            model.setLessonType("1");
        } else if ("1".equals(model.getLessonType())) {
            model.setLessonType(null);
            model.setLessonTypeSchool("1");
//            //将课程类型给学校
//            model.setCourseTypeC(model.getCourseType());
//            model.setCourseType(model.getCourseType());
        } else if ("2".equals(model.getLessonType())) {
            model.setLessonType("1");
            model.setLessonTypeSchool("1");
        }

        if (model.getLessonIsPay() == 0) {
            bLessonIPage = baseMapper.queryBLessons(paginationUtility, model);
            List<BLesson> records = bLessonIPage.getRecords();
            //添加标签
            for (BLesson bLesson : records) {
                List<String> labelList = new ArrayList<>();
                List<DictData> tecClassifyList = dictionaryServiceImpl.selectByTypes("tec_classify");//技术分类
                List<DictData> jobClassifyList = dictionaryServiceImpl.selectByTypes("job_classify");//岗位分类
                List<DictData> difficultyGradeList = dictionaryServiceImpl.selectByTypes("difficulty_grade");//难度等级
                List<DictData> courseTypeList = dictionaryServiceImpl.selectByTypes("course_type");//前沿讲堂
                List<DictData> courseDimensionsList = dictionaryServiceImpl.selectByTypes("course_dimensions");//课程维度
                List<DictData> intelligentClassroomList = dictionaryServiceImpl.selectByTypes("intelligent_classroom");//智联课堂

                // 标签转化
                String tecClassify = bLesson.getTecClassifySchool();
                if (tecClassify != null && !tecClassify.isEmpty()) {
                    List<String> tecClassifyLabels = getStrings(tecClassify, tecClassifyList);
                    bLesson.setTecClassifyLabels(String.join(",", tecClassifyLabels));  // 将名称集合拼接成逗号分隔的字符串，设置到 bLesson 对象中
                    for (String tecClassifyLabel : tecClassifyLabels) {
                        labelList.add(tecClassifyLabel);
                    }
                }
                String jobClassify = bLesson.getJobClassify();
                if (jobClassify != null && !jobClassify.isEmpty()) {
                    List<String> jobClassifyLabels = getStrings(jobClassify, jobClassifyList);
                    bLesson.setJobClassifyLabels(String.join(",", jobClassifyLabels));  // 将名称集合拼接成逗号分隔的字符串，设置到 bLesson 对象中
                    for (String jobClassifyLabel : jobClassifyLabels) {
                        labelList.add(jobClassifyLabel);
                    }
                }
                String difficultyClassify = bLesson.getDifficultyClassify();
                if (difficultyClassify != null && !difficultyClassify.isEmpty()) {
                    List<String> difficultyClassifyLabels = getStrings(difficultyClassify, difficultyGradeList);
                    bLesson.setDifficultyClassifyLabels(String.join(",", difficultyClassifyLabels));  // 将名称集合拼接成逗号分隔的字符串，设置到 bLesson 对象中
                    for (String difficultyClassifyLabel : difficultyClassifyLabels) {
                        labelList.add(difficultyClassifyLabel);
                    }
                }
                String courseType = bLesson.getCourseType();
                if (courseType != null && !courseType.isEmpty()) {
                    List<String> courseTypeLabels = getStrings(courseType, courseTypeList);
                    bLesson.setCourseTypeLabels(String.join(",", courseTypeLabels));  // 将名称集合拼接成逗号分隔的字符串，设置到 bLesson 对象中
                    for (String courseTypeLabel : courseTypeLabels) {
                        labelList.add(courseTypeLabel);
                    }
                }
                String courseTypeC = bLesson.getCourseTypeC();
                if (courseTypeC != null && !courseTypeC.isEmpty()) {
                    List<String> courseTypeCLabels = getStrings(courseTypeC, courseTypeList);
                    bLesson.setCourseTypeCLabels(String.join(",", courseTypeCLabels));  // 将名称集合拼接成逗号分隔的字符串，设置到 bLesson 对象中
                    for (String courseTypeCLabel : courseTypeCLabels) {
                        labelList.add(courseTypeCLabel);
                    }
                }
                String courseDimensions = bLesson.getEnterpriseCourseDimensions();
                if (courseDimensions != null && !courseDimensions.isEmpty()) {
                    List<String> courseDimensionsLabels = getStrings(courseDimensions, courseDimensionsList);
                    bLesson.setCourseDimensionsLabels(String.join(",", courseDimensionsLabels));  // 将名称集合拼接成逗号分隔的字符串，设置到 bLesson 对象中
                    for (String courseDimensionsLabel : courseDimensionsLabels) {
                        labelList.add(courseDimensionsLabel);
                    }
                }
                String intelligentClassroom = bLesson.getIntelligentClassroom();
                if (intelligentClassroom != null && !intelligentClassroom.isEmpty()) {
                    List<String> intelligentClassroomLabels = getStrings(intelligentClassroom, intelligentClassroomList);
                    bLesson.setIntelligentClassroomLabels(String.join(",", intelligentClassroomLabels));  // 将名称集合拼接成逗号分隔的字符串，设置到 bLesson 对象中
                    for (String intelligentClassroomLabel : intelligentClassroomLabels) {
                        labelList.add(intelligentClassroomLabel);
                    }
                }
                bLesson.setLabelList(labelList);
            }
            if (!CollectionUtils.isEmpty(records)) {
                for (BLesson bLesson : records) {
                    getBeginCourseInfoByUserType(bLesson, token);
                    configBLessonInfo(bLesson);
                }
            }
            return bLessonIPage;
        }
        if (model.getLessonIsPay() == 1) {//查看已购
            paginationUtility.setSize(1000);
            bLessonIPage = baseMapper.queryBLessons(paginationUtility, model);
            List<BLesson> list = bLessonIPage.getRecords();
            if (!CollectionUtils.isEmpty(list)) {
                ArrayList<BLesson> freeLessonList = new ArrayList<>();
                for (BLesson bLesson : list) {
                    getBeginCourseInfoByUserType(bLesson, token);
                    configBLessonInfo(bLesson);
                    if (model.getLessonIsPay() == bLesson.getLessonIsPay()) {
                        freeLessonList.add(bLesson);
                    }
                }
                bLessonIPage.setCurrent(paginationUtility.getCurrent());
                bLessonIPage.setCurrent(paginationUtility.getCurrent());
                bLessonIPage.setRecords(freeLessonList);
                bLessonIPage.setTotal(freeLessonList.size());
                bLessonIPage.setPages(paginationUtility.getPages());
                bLessonIPage.setSize(paginationUtility.getSize());
                return bLessonIPage;
            }
        }
        if (model.getLessonIsPay() == 2) {//免费和已购
            model.setIsPay("0");
            //免费
            bLessonIPage = baseMapper.queryBLessons(paginationUtility, model);
            List<BLesson> records = bLessonIPage.getRecords();
            if (!CollectionUtils.isEmpty(records)) {
                for (BLesson bLesson : records) {
                    getBeginCourseInfoByUserType(bLesson, token);
                    configBLessonInfo(bLesson);
                }
            }
            ArrayList<BLesson> freeLessonList = new ArrayList<>();
            //拷贝
            records.forEach(bLesson -> {
                freeLessonList.add(bLesson);
            });
            model.setIsPay("1");
            model.setLessonIsPay(1);
            bLessonIPage = baseMapper.queryBLessons(paginationUtility, model);
            List<BLesson> list = bLessonIPage.getRecords();
            for (BLesson bLesson : list) {
                getBeginCourseInfoByUserType(bLesson, token);
                configBLessonInfo(bLesson);
                if (model.getLessonIsPay() == bLesson.getLessonIsPay()) {
                    freeLessonList.add(bLesson);
                }
            }
            bLessonIPage.setCurrent(paginationUtility.getCurrent());
            bLessonIPage.setCurrent(paginationUtility.getCurrent());
            bLessonIPage.setRecords(freeLessonList);
            bLessonIPage.setTotal(freeLessonList.size());
            bLessonIPage.setPages(paginationUtility.getPages());
            bLessonIPage.setSize(paginationUtility.getSize());
        }
        if (model.getLessonIsPay() == 3) {//试用
            //获得当前用户的id
            String authenDept = CyUserUtil.getAuthenDept();
            String authenBusinessId = null;
            if (authenDept == null) {
                authenBusinessId = CyUserUtil.getAuthenBusinessId();
                authenDept = null;
            }
            bLessonIPage = baseMapper.tryItQueryBLessons(paginationUtility, model, authenDept, authenBusinessId);
            List<BLesson> records = bLessonIPage.getRecords();
            if (!CollectionUtils.isEmpty(records)) {
                for (BLesson bLesson : records) {
                    getBeginCourseInfoByUserType(bLesson, token);
                    configBLessonInfo(bLesson);
                }
            }
        }
        return bLessonIPage;
    }

    /**
     * 配置课程信息
     *
     * @param bLesson
     */
    private void configBLessonInfo(BLesson bLesson) {
        //配置返回图片路径
        bLesson.setPath(global.getBase_Discovery() + bLesson.getPath());
        //查询课程评论列表
        List<PcLessonEvaluation> evaluationList = pcLessonEvaluationRepository.queryPcLessonEvaluationsById(bLesson.getBusinessId());
        bLesson.setEvaluationList(evaluationList);
        if (!CollectionUtils.isEmpty(evaluationList)) {
            //计算平均分
            BigDecimal averageLessonRate = BigDecimal.valueOf(evaluationList.stream()
                    .map(PcLessonEvaluation::getLessonRate) // 提取每个PcLessonEvaluation中的Integer lessonRate
                    .filter(Objects::nonNull) // 排除可能存在的null值
                    .mapToDouble(Double::doubleValue) // 将Integer转换为int基本类型
                    .average() // 计算平均值作为Double返回
                    .orElse(0.0)); // 若列表为空，返回0.0
            // 保留一位小数
            bLesson.setCourseGrad(averageLessonRate.setScale(1, RoundingMode.HALF_UP));
        }
    }

    @Override
    public IPage<BLesson> queryPcBLessonsByPagination(CyPageInfo<BLesson> paginationUtility, BLesson bLesson) {
        // 获取当前登录人单位id
//        bLesson.setUnitId(Integer.valueOf(CyUserUtil.getAuthenDept()));
        String currentUserId = CyUserUtil.getAuthenBusinessId();
        SysUser user = sysUserRepository.selectById(currentUserId);
        IPage<BLesson> bLessonIPage = new Page<>();
        if (user.getDeptId() != null){
            int intVal = user.getDeptId().intValueExact();
            bLesson.setUnitId(intVal);
            //分页查询
            bLessonIPage = baseMapper.queryPcBLessons(paginationUtility, bLesson);
            dictionaryConfig(bLessonIPage);
        }else {
            bLessonIPage.setTotal(0);
            bLessonIPage.setRecords(null);
        }
        return bLessonIPage;
    }

    private void dictionaryConfig(IPage<BLesson> bLessonIPage) {
        //获取所有所需的数据字典
        List<DictData> tecClassifyList = dictionaryServiceImpl.selectByTypes("tec_classify");
        List<DictData> jobClassifyList = dictionaryServiceImpl.selectByTypes("job_classify");
        List<DictData> dictDataList = dictionaryServiceImpl.selectByTypes("difficulty_grade");
        //根据字典值获取字典名称 并拼接成字符串
        for (BLesson bLesson1 : bLessonIPage.getRecords()) {
            String tecClassify = bLesson1.getTecClassify();
            if (tecClassify != null && !tecClassify.isEmpty()) {
                List<String> tecClassifyLabels = getStrings(tecClassify, tecClassifyList);
                bLesson1.setTecClassifyLabels(String.join(",", tecClassifyLabels));  // 将名称集合拼接成逗号分隔的字符串，设置到 bLesson 对象中
            }
            String jobClassify = bLesson1.getJobClassify();
            if (jobClassify != null && !jobClassify.isEmpty()) {
                List<String> jobClassifyLabels = getStrings(jobClassify, jobClassifyList);
                bLesson1.setJobClassifyLabels(String.join(",", jobClassifyLabels));  // 将名称集合拼接成逗号分隔的字符串，设置到 bLesson 对象中
            }
            String difficultyClassify = bLesson1.getDifficultyClassify();
            if (difficultyClassify != null && !difficultyClassify.isEmpty()) {
                List<String> difficultyClassifyLabels = getStrings(difficultyClassify, dictDataList);
                bLesson1.setDifficultyClassifyLabels(String.join(",", difficultyClassifyLabels));  // 将名称集合拼接成逗号分隔的字符串，设置到 bLesson 对象中
            }
            bLesson1.setPath(global.getBase_Discovery() + bLesson1.getPath());
        }
    }

    /**
     * 根据条件分页查询
     * 使用模块：
     * 学习中心-我的课程
     *
     * @param paginationUtility 分页参数
     * @param pcBLessonQuery    查询条件
     * @param token
     * @return
     */
    @Override
    public IPage<BLesson> pagingBLesson(CyPageInfo<BLesson> paginationUtility, PcBLessonQuery pcBLessonQuery, String token) {
        paginationUtility.setCurrent(pcBLessonQuery.getCurrent());
        paginationUtility.setSize(pcBLessonQuery.getSize());
        List<String> list = null;
        if (StringUtils.isNotBlank(pcBLessonQuery.getLessonIsPay())) {
            list = Arrays.asList(pcBLessonQuery.getLessonIsPay().split(","));
        }
        // 获取当前登录人id
        String loginUserId = CyUserUtil.getAuthenBusinessId();
        // 获取当前登录人用户信息
//        SysUser sysUser = pcSysUserRepository.selectById(loginUserId);
        if (StringUtils.isBlank(pcBLessonQuery.getUserId())) {
            pcBLessonQuery.setUserId(loginUserId);
        }
        IPage<BLesson> bLessonIPage = null;
        if (pcBLessonQuery.getIsObligatory().equals("1")) {
            // 必修
            bLessonIPage = baseMapper.pagingBLessonObligatory(paginationUtility, pcBLessonQuery);
        } else {
            //选修
            bLessonIPage = baseMapper.pagingBLessonElective(paginationUtility, pcBLessonQuery, list);
        }
        //查询当前登录用户的角色下的课程，和分页查询的records里的课程id进行比对，如果相等，进行比对时间
        List<BLesson> bLessonList = bLessonIPage.getRecords();
        List<BLesson>  bLessons = baseMapper.getAllBeginBLessonByUserId(loginUserId);
        //比对blessonList和blessons的lessonId,找出相同的id 修改startTime和endTime
        bLessonList.forEach(bLesson -> {
            //在bLessons找出和bLessonList中相同id的课程
            List<BLesson> sameLessonList = bLessons.stream()
                    .filter(bLesson1 -> bLesson.getBusinessId().equals(bLesson1.getBusinessId()))
                    .collect(Collectors.toList());

            if (!sameLessonList.isEmpty()) {
                // 找出具有最小startTime的BLesson
                Optional<BLesson> minStartTime = sameLessonList.stream()
                        .min(Comparator.comparing(BLesson::getStartTime));
                Optional<BLesson> maxEndTime = sameLessonList.stream()
                        .max(Comparator.comparing(BLesson::getEndTime));
                Date startTime = minStartTime.map(BLesson::getStartTime).orElse(null);
                Date endTime = maxEndTime.map(BLesson::getEndTime).orElse(null);
                bLesson.setStartTime(startTime);
                bLesson.setEndTime(endTime);
                // 使用 Calendar 让endTime 增加 23 小时 59 分钟 59 秒
                Calendar calendar = Calendar.getInstance();
                calendar.setTime(endTime);
                calendar.add(Calendar.HOUR_OF_DAY, 23);
                calendar.add(Calendar.MINUTE, 59);
                calendar.add(Calendar.SECOND, 59);

                Date newEndTime = calendar.getTime();
                //与当前时间进行比对 如果过期，就把blesson.isExpired设置为1
                if (new Date().after(newEndTime)) {
                    bLesson.setIsExpired("1");
                }
            }
        });
        bLessonIPage.setRecords(bLessonList);
        List<DictData> tecClassifyList = dictionaryServiceImpl.selectByTypes("tec_classify");
        List<DictData> jobClassifyList = dictionaryServiceImpl.selectByTypes("job_classify");
        List<DictData> dictDataList = dictionaryServiceImpl.selectByTypes("difficulty_grade");
        // 获取用户全部课程全部章节的最后一条学习记录
        List<BChapter> latestLearnRecordList = bChapterService.getLatestLearnRecord(pcBLessonQuery.getUserId());
        // 按照课程id 为 key 分组成map
        Map<String, List<BChapter>> latestLearnRecordMap = latestLearnRecordList.stream()
                .collect(Collectors.groupingBy(BChapter::getLessonId));
        // 查询当前用户是那种类型
        Object user = CyUserUtil.getUserInfoObjProp(token, "username:" + CyUserUtil.getAuthenUsername());
        SysUser sysUser = null;
        boolean isIndividual = false;
        if (user != null) {
            sysUser = JSON.parseObject(JSON.toJSONString(user), SysUser.class);
        }
        if (sysUser != null) {
            if (IdentityStaCons.INDIVIDUAL.getStatus().equals(sysUser.getIdentity())) {
                //个人用户 则将所有选修字段修改为必修
                isIndividual = true;
            }
        }
        for (BLesson bLesson1 : bLessonIPage.getRecords()) {
            String tecClassify = bLesson1.getTecClassify();
            if (tecClassify != null && !tecClassify.isEmpty()) {
                List<String> tecClassifyLabels = getStrings(tecClassify, tecClassifyList);
                bLesson1.setTecClassifyLabels(String.join(",", tecClassifyLabels));  // 将名称集合拼接成逗号分隔的字符串，设置到 bLesson 对象中
            }
            String jobClassify = bLesson1.getJobClassify();
            if (jobClassify != null && !jobClassify.isEmpty()) {
                List<String> jobClassifyLabels = getStrings(jobClassify, jobClassifyList);
                bLesson1.setJobClassifyLabels(String.join(",", jobClassifyLabels));  // 将名称集合拼接成逗号分隔的字符串，设置到 bLesson 对象中
            }
            String difficultyClassify = bLesson1.getDifficultyClassify();
            if (difficultyClassify != null && !difficultyClassify.isEmpty()) {
                List<String> difficultyClassifyLabels = getStrings(difficultyClassify, dictDataList);
                bLesson1.setDifficultyClassifyLabels(String.join(",", difficultyClassifyLabels));  // 将名称集合拼接成逗号分隔的字符串，设置到 bLesson 对象中
            }
            if (isIndividual) {
                //查询是否有该用户的开课记录 有 1 / 否 0
                List<TrialCourseDto> trialCourseDtos = teaTrialCourseRepository.selectByUserIdAndLessonId(sysUser.getBusinessId(), bLesson1.getBusinessId());
                if (CollectionUtils.isEmpty(trialCourseDtos)) {
                    bLesson1.setIsObligatory("0");
                } else {
                    bLesson1.setIsObligatory("1");
                }
            } else {
                bLesson1.setIsObligatory(pcBLessonQuery.getIsObligatory());
            }

            // 配置完整图片路径
            bLesson1.setPath(global.getBase_Discovery() + bLesson1.getPath());
            if (latestLearnRecordMap.containsKey(bLesson1.getBusinessId()) && !latestLearnRecordMap.get(bLesson1.getBusinessId()).isEmpty()) {
                List<BChapter> tempList = latestLearnRecordMap.get(bLesson1.getBusinessId());
                tempList.sort(Comparator.comparing(BChapter::getUTime).reversed());

                BChapter bChapter = tempList.get(0);
                bLesson1.setLastTimeChapter(bChapter);
                bLesson1.setChapterName(bChapter.getChapterName());
                String chapterSort = "";
                if (!"-1".equals(bChapter.getPid())) {
                    //根据课程ID查询课程章节
                    List<BChapter> bChapters = bChapterService.getBaseMapper()
                            .selectList(new LambdaQueryWrapper<BChapter>()
                                    .eq(BChapter::getLessonId, bLesson1.getBusinessId())
                                    .eq(BChapter::getDelFlag, 0));
                    // 查询bChapters中businessId等于bChapter.getPid()的章节
                    BChapter bChapter1 = bChapters.stream().filter(bChapter2 -> bChapter2.getBusinessId().equals(bChapter.getPid())).findFirst().orElse(new BChapter());
                    chapterSort = bChapter1.getSort() + "." + bChapter.getSort();
                    if (!"-1".equals(bChapter1.getPid())) {
                        BChapter bChapter3 = bChapters.stream().filter(bChapter2 -> bChapter2.getBusinessId().equals(bChapter1.getPid())).findFirst().orElse(new BChapter());
                        chapterSort = bChapter3.getSort() + "." + bChapter1.getSort() + "." + bChapter.getSort();
                    }
                }
                bLesson1.setChapterNum(chapterSort);
            }
        }
        return bLessonIPage;
    }

    /**
     * 根据条件分页查询
     * 使用模块：
     * 学习中心-我的课程（ip登录用户）
     *
     * @param paginationUtility 分页参数
     * @param pcBLessonQuery    查询条件
     * @return
     */
    @Override
    public IPage<BLesson> pagingBLessonForIP(CyPageInfo<BLesson> paginationUtility, PcBLessonQuery pcBLessonQuery) {
        // 获取当前ip登录用户单位id
        String unitId = CyUserUtil.getAuthenDept();
        // 获取当前登录人id
        String loginUserId = CyUserUtil.getAuthenBusinessId();
        // TODO 临时测试用的id
        pcBLessonQuery.setUnitId(unitId);
//        pcBLessonQuery.setUnitId("6");
        IPage<BLesson> bLessonIPage = baseMapper.pagingBLessonForIP(paginationUtility, pcBLessonQuery);
        List<DictData> tecClassifyList = dictionaryServiceImpl.selectByTypes("tec_classify");
        List<DictData> dictDataList = dictionaryServiceImpl.selectByTypes("difficulty_grade");
        // 获取用户全部课程全部章节的最后一条学习记录
//        List<BChapter> latestLearnRecordList = bChapterService.getLatestLearnRecord(loginUserId);
        // 按照课程id 为 key 分组成map
//        Map<String, List<BChapter>> latestLearnRecordMap = latestLearnRecordList.stream()
//                .collect(Collectors.groupingBy(BChapter::getLessonId));
        for (BLesson bLesson1 : bLessonIPage.getRecords()) {
            String tecClassify = bLesson1.getTecClassify();
            if (tecClassify != null && !tecClassify.isEmpty()) {
                List<String> tecClassifyLabels = getStrings(tecClassify, tecClassifyList);
                bLesson1.setTecClassifyLabels(String.join(",", tecClassifyLabels));  // 将名称集合拼接成逗号分隔的字符串，设置到 bLesson 对象中
            }
            String difficultyClassify = bLesson1.getDifficultyClassify();
            if (difficultyClassify != null && !difficultyClassify.isEmpty()) {
                List<String> difficultyClassifyLabels = getStrings(difficultyClassify, dictDataList);
                bLesson1.setDifficultyClassifyLabels(String.join(",", difficultyClassifyLabels));  // 将名称集合拼接成逗号分隔的字符串，设置到 bLesson 对象中
            }
//            if (latestLearnRecordMap.containsKey(bLesson1.getBusinessId()) && latestLearnRecordMap.get(bLesson1.getBusinessId()).size() > 0) {
//                List<BChapter> tempList = latestLearnRecordMap.get(bLesson1.getBusinessId());
//                bLesson1.setLastTimeChapter(tempList.get(0));
//                bLesson1.setChapterName(tempList.get(0).getChapterName());
//            }
            bLesson1.setPath(global.getBase_Discovery() + bLesson1.getPath());
        }
        return bLessonIPage;
    }

    /**
     * 根据用户id查询全部用户课程
     *
     * @param userId
     * @return
     */
    @Override
    public List<BLesson> getAllBLessonByUserId(String userId) {
        // 获取当前登录人id
        String loginUserId = CyUserUtil.getAuthenBusinessId();
        //获取当前用户
        SysUser sysUser = pcSysUserRepository.selectById(loginUserId);
        if ("2".equals(sysUser.getIdentity())) {
            //单位用户
            return baseMapper.getAllBLessonByUserId(StringUtils.isBlank(userId) ? loginUserId : userId);
        } else {
            //个人用户
            return baseMapper.getAllBLessonByUserIdPersonal(loginUserId);
        }
    }

    /**
     * 根据条件分页查询
     * 使用模块：
     * 学习中心-我的小组
     * 学员视图 / 课程视图
     *
     * @param paginationUtility 分页参数
     * @param pcBLessonQuery    查询条件
     * @return
     */
    @Override
    public IPage<MyGroupStatisticsVO> pagingMyGroupStatistics(CyPageInfo<MyGroupStatisticsVO> paginationUtility, PcBLessonQuery pcBLessonQuery) {
        // 获取当前登录人id
        String loginId = CyUserUtil.getAuthenBusinessId();
        // 获取当前登录人用户信息
        SysUser sysUser = pcSysUserRepository.selectById(loginId);
        IPage<MyGroupStatisticsVO> myGroupStatisticsVOIPage = null;
        CyPageInfo<StatisticsDetailVO> pagin = new CyPageInfo<>();
        pagin.setCurrent(1);
        pagin.setSize(-1);
        PcBLessonQuery queryDetail = new PcBLessonQuery();
        if (StringUtils.isNotBlank(pcBLessonQuery.getViewType()) && StringUtils.isNotBlank(pcBLessonQuery.getGroupId())) {
            List<StatisticsDetailVO> statisticsDetailVOList = new ArrayList<>();
            if (pcBLessonQuery.getViewType().equals("0")) {
                // 通过小组 找到 数据
                myGroupStatisticsVOIPage = baseMapper.pagingLessonStatistics(paginationUtility, pcBLessonQuery);
                //myGroupStatisticsVOIPage 循环查询课程满分
                for (MyGroupStatisticsVO myGroupStatisticsVO : myGroupStatisticsVOIPage.getRecords()) {
                    myGroupStatisticsVO.setFullGrade(String.valueOf(baseMapper.inquireForAFullScore(myGroupStatisticsVO)));
                }
//                // 获取当前分页中的课程id
//                String lessonIds = myGroupStatisticsVOIPage.getRecords().stream()
//                        .map(MyGroupStatisticsVO::getLessonId)
//                        .distinct()
//                        .collect(Collectors.joining(","));
//                queryDetail.setGroupId(pcBLessonQuery.getGroupId());
//                queryDetail.setLessonId(lessonIds);
               /* statisticsDetailVOList = baseMapper.pagingLessonStatisticsDetail(pagin, queryDetail).getRecords();
                // 将全部统计详情数据按照 lessonId 分组
                Map<String, List<StatisticsDetailVO>> statisticsDetailVOMap = statisticsDetailVOList.stream().collect(Collectors.groupingBy(StatisticsDetailVO::getLessonId));
                if (!myGroupStatisticsVOIPage.getRecords().isEmpty()) {
                    for (MyGroupStatisticsVO myGroupStatisticsVO : myGroupStatisticsVOIPage.getRecords()) {
                        if (statisticsDetailVOMap.containsKey(myGroupStatisticsVO.getLessonId())) {
                            // 如果存在该课程的统计详情数据
                            List<StatisticsDetailVO> statisticsDetailList = statisticsDetailVOMap.get(myGroupStatisticsVO.getLessonId());
                            // 根据学习状态进行分组
                            Map<String, Long> learningStateCounts = statisticsDetailList.stream()
                                    .collect(Collectors.groupingBy(
                                            StatisticsDetailVO::getLearningState,
                                            Collectors.counting()
                                    ));
                            // 根据考核状态进行分组
                            Map<String, Long> isCompleteExamCounts = statisticsDetailList.stream()
                                    .collect(Collectors.groupingBy(
                                            StatisticsDetailVO::getIsCompleteExam,
                                            Collectors.counting()
                                    ));
                            //根据考试状态分组
                            Map<String, Long> examStateCounts = statisticsDetailList.stream()
                                    .collect(Collectors.groupingBy(
                                            StatisticsDetailVO::getExamState,
                                            Collectors.counting()
                                    ));

                            // 学习总人数
                            myGroupStatisticsVO.setTotalLearnerNum(String.valueOf(statisticsDetailList.size()));
                            // 未开始人数
                            myGroupStatisticsVO.setNoLearnedNum(String.valueOf(learningStateCounts.getOrDefault("未开始", 0L)));
                            // 学习中人数
                            myGroupStatisticsVO.setLearningNum(String.valueOf(learningStateCounts.getOrDefault("学习中", 0L)));
                            // 学习完成人数
                            myGroupStatisticsVO.setLearnedNum(String.valueOf(learningStateCounts.getOrDefault("已完成", 0L)));
                            // 参与考核人数
                            myGroupStatisticsVO.setBeAssessingNum(String.valueOf(examStateCounts.getOrDefault("2", 0L)));
                        } else {
                            // 如果不存在该课程的统计详情数据 全部赋 0
                            // 学习总人数
                            myGroupStatisticsVO.setTotalLearnerNum("0");
                            // 未开始人数
                            myGroupStatisticsVO.setNoLearnedNum("0");
                            // 学习中人数
                            myGroupStatisticsVO.setLearningNum("0");
                            // 学习完成人数
                            myGroupStatisticsVO.setLearnedNum("0");
                            // 参与考核人数
                            myGroupStatisticsVO.setBeAssessingNum("0");
                        }
                    }
                }*/


            } else if (pcBLessonQuery.getViewType().equals("1")) {
                // 学员视图
                myGroupStatisticsVOIPage = baseMapper.pagingStudentStatistics(paginationUtility, pcBLessonQuery);
                // 获取当前分页中的组员id
                String userIds = myGroupStatisticsVOIPage.getRecords().stream()
                        .map(MyGroupStatisticsVO::getUserId)
                        .distinct()
                        .collect(Collectors.joining(","));
                queryDetail.setUserId(userIds);
                statisticsDetailVOList = baseMapper.pagingStudentStatisticsDetail(pagin, queryDetail).getRecords();
                // 将全部统计详情数据按照 userId 分组
               /* Map<String, List<StatisticsDetailVO>> statisticsDetailVOMap = statisticsDetailVOList.stream()
                        .collect(Collectors.groupingBy(StatisticsDetailVO::getUserId));
                if (!myGroupStatisticsVOIPage.getRecords().isEmpty()) {
                    for (MyGroupStatisticsVO myGroupStatisticsVO : myGroupStatisticsVOIPage.getRecords()) {
                        if (statisticsDetailVOMap.containsKey(myGroupStatisticsVO.getUserId())) {
                            // 如果存在该用户的统计详情数据
                            List<StatisticsDetailVO> statisticsDetailList = statisticsDetailVOMap.get(myGroupStatisticsVO.getUserId());
                            // 根据学习状态进行分组
                            Map<String, Long> learningStateCounts = statisticsDetailList.stream()
                                    .collect(Collectors.groupingBy(
                                            StatisticsDetailVO::getLearningState,
                                            Collectors.counting()
                                    ));
                            // 根据考核状态进行分组
                            Map<String, Long> isCompleteExamCounts = statisticsDetailList.stream()
                                    .collect(Collectors.groupingBy(
                                            StatisticsDetailVO::getIsCompleteExam,
                                            Collectors.counting()
                                    ));
                            // 计划课程总数
                            myGroupStatisticsVO.setPlannedCourseNum(String.valueOf(statisticsDetailList.size()));
                            // 学习中课程数
                            myGroupStatisticsVO.setLearningCourseNum(String.valueOf(learningStateCounts.getOrDefault("学习中", 0L)));
                            // 已完成课程数
                            myGroupStatisticsVO.setLearnedCourseNum(String.valueOf(learningStateCounts.getOrDefault("已完成", 0L)));
                            // 未开始课程数
                            myGroupStatisticsVO.setNoStartedCourseNum(String.valueOf(learningStateCounts.getOrDefault("未开始", 0L)));
                            // 参与考核课程数
//                            myGroupStatisticsVO.setBeAssessingCourseNum(String.valueOf(isCompleteExamCounts.getOrDefault("1", 0L)));
                            // 未考核课程数
//                            myGroupStatisticsVO.setNoAssessedCourseNum(String.valueOf(isCompleteExamCounts.getOrDefault("0", 0L)));
                            //考核完成人数

                        } else {
                            // 如果不存在该用户的统计详情数据 全部赋 0
                            // 计划课程总数
                            myGroupStatisticsVO.setPlannedCourseNum("0");
                            // 学习中课程数
                            myGroupStatisticsVO.setLearningCourseNum("0");
                            // 已完成课程数
                            myGroupStatisticsVO.setLearnedCourseNum("0");
                            // 未开始课程数
                            myGroupStatisticsVO.setNoStartedCourseNum("0");
                            // 参与考核课程数
                            myGroupStatisticsVO.setBeAssessingCourseNum("0");
                            // 未考核课程数
                            myGroupStatisticsVO.setNoAssessedCourseNum("0");
                        }
                    }
                }*/
                myGroupStatisticsVOIPage.getRecords().forEach(myGroupStatisticsVO -> {
                    MyGroupStatisticsVO myGroupStatisticsVO1 = baseMapper.queryStudentStatistics(myGroupStatisticsVO.getUserId());
                    //复制值
                    myGroupStatisticsVO.setPlannedCourseNum(myGroupStatisticsVO1.getPlannedCourseNum());
                    myGroupStatisticsVO.setLearningCourseNum(myGroupStatisticsVO1.getLearningCourseNum());
                    myGroupStatisticsVO.setLearnedCourseNum(myGroupStatisticsVO1.getLearnedCourseNum());
                    myGroupStatisticsVO.setNoStartedCourseNum(myGroupStatisticsVO1.getNoStartedCourseNum());
                    myGroupStatisticsVO.setBeAssessingCourseNum(myGroupStatisticsVO1.getBeAssessingCourseNum());
                    myGroupStatisticsVO.setNoAssessedCourseNum(myGroupStatisticsVO1.getNoAssessedCourseNum());
                });
            }
        }
        return myGroupStatisticsVOIPage;
    }

    /**
     * 根据条件分页查询
     * 使用模块：
     * 学习中心-我的小组
     * 学员视图 / 课程视图
     * 统计详情
     *
     * @param paginationUtility 分页参数
     * @param pcBLessonQuery    查询条件
     * @return
     */
    @Override
    public IPage<StatisticsDetailVO> pagingStatisticsDetail(CyPageInfo<StatisticsDetailVO> paginationUtility, PcBLessonQuery pcBLessonQuery) {
        // 获取当前登录人id
        String loginId = CyUserUtil.getAuthenBusinessId();
        // 获取当前登录人用户信息
        SysUser sysUser = pcSysUserRepository.selectById(loginId);
        if (StringUtils.isBlank(pcBLessonQuery.getUserId())) {
            pcBLessonQuery.setUserId(loginId);
        }
        IPage<StatisticsDetailVO> statisticsDetailVOIPage = new CyPageInfo<>();
        statisticsDetailVOIPage.setSize(pcBLessonQuery.getRows());
        statisticsDetailVOIPage.setCurrent(pcBLessonQuery.getPage());
        paginationUtility.setSize(pcBLessonQuery.getRows());
        paginationUtility.setCurrent(pcBLessonQuery.getPage());
        if (StringUtils.isNotBlank(pcBLessonQuery.getViewType()) && StringUtils.isNotBlank(pcBLessonQuery.getStatisticalType())) {
            if (pcBLessonQuery.getViewType().equals("0") && StringUtils.isNotBlank(pcBLessonQuery.getGroupId())) {
                // 课程视图详情
                switch (pcBLessonQuery.getStatisticalType()) {
                    case "totalLearnerNum" -> {
                        // 学习总人数
                        statisticsDetailVOIPage = baseMapper.totalLearnerNum(statisticsDetailVOIPage, pcBLessonQuery);
                    }
                    case "noLearnedNum" -> {
                        // 未开始人数
                        statisticsDetailVOIPage = baseMapper.numberOfPeopleWhoDidNotStart(statisticsDetailVOIPage, pcBLessonQuery);

                    }
                    case "learningNum" -> {
                        // 学习中人数
                        statisticsDetailVOIPage = baseMapper.numberOfStudentsInTheStudy(statisticsDetailVOIPage, pcBLessonQuery);
                    }
                    case "learnedNum" -> {
                        // 学习完成人数
                        statisticsDetailVOIPage = baseMapper.numberOfStudyCompletions(statisticsDetailVOIPage, pcBLessonQuery);
                    }
                    case "beAssessingNum" -> {
                        // 参与考核人数
                        statisticsDetailVOIPage = baseMapper.theNumberOfParticipantsInTheAssessment(statisticsDetailVOIPage, pcBLessonQuery);
                    }
                }
//                statisticsDetailVOIPage = baseMapper.pagingLessonStatisticsDetail(paginationUtility, pcBLessonQuery);
            } else if (pcBLessonQuery.getViewType().equals("1")) {
                // 学员视图详情
                switch (pcBLessonQuery.getStatisticalType()) {
                    case "plannedCourseNum" -> {
                        // 计划课程总数
                        pcBLessonQuery.setLearningState(null);
                        pcBLessonQuery.setIsCompleteExam(null);
                    }
                    case "learningCourseNum" -> {
                        // 学习中课程数
                        pcBLessonQuery.setLearningState("学习中");
                        pcBLessonQuery.setIsCompleteExam(null);
                    }
                    case "learnedCourseNum" -> {
                        // 已完成课程数
                        pcBLessonQuery.setLearningState("已完成");
                        pcBLessonQuery.setIsCompleteExam(null);
                    }
                    case "noStartedCourseNum" -> {
                        // 未开始课程数
                        pcBLessonQuery.setLearningState("未开始");
                        pcBLessonQuery.setIsCompleteExam(null);
                    }
                    case "beAssessingCourseNum" -> {
                        // 参与考核课程数
                        pcBLessonQuery.setLearningState(null);
                        pcBLessonQuery.setIsCompleteExam("1");
                    }
                    case "noAssessedCourseNum" -> {
                        // 未考核课程数
                        pcBLessonQuery.setLearningState(null);
                        pcBLessonQuery.setIsCompleteExam("0");
                        pcBLessonQuery.setIsAppraisal("0");
                    }
                }
                statisticsDetailVOIPage = baseMapper.pagingStudentStatisticsDetail(paginationUtility, pcBLessonQuery);
            }
        }
        return statisticsDetailVOIPage;
    }


    @Transactional(propagation = Propagation.REQUIRED, readOnly = false)
    @Override
    public CyPersistModel removeBLesson(String id) {
        BLesson bLesson = new BLesson();
        bLesson.setBusinessId(id);
        bLesson.setDeleted();
        CyUserUtil.setCurrentMergeOperation(bLesson);
        return removeLogical(bLesson);

    }


    /**
     * 课程信息导入
     *
     * @param hwb
     * @param token
     * @return
     * @throws IOException
     */
    @Transactional(propagation = Propagation.REQUIRED, readOnly = false)
    @Override
    public CyPersistModel importExcel(HSSFWorkbook hwb, String token) {
        ArrayList<BLesson> lessons = new ArrayList<BLesson>();
        ArrayList<String> repeatCode = new ArrayList<String>();
        List<String> errorCode = new ArrayList<>();
        ArrayList<String> direction = new ArrayList<String>();
        List<String> isChinese = new ArrayList<>();
        List<String> isNegative = new ArrayList<>();
        List<String> currentlyCode = new ArrayList<>();
        String innerRepeatResult = "";
        String[] headers = {"课程编号", "课程名称", "课程方向编号", "学时", "学分"};
        ArrayList<String[]> values = ExcelUtil.importExcel(hwb, headers, false, 1);  //获取excel数据


        if (values.size() < 1) {
            throw new CyServiceException(ResultServiceEnums.EXCEL_IMPORT_DATA_NOT_EXIST.getCode()
                    , ResultServiceEnums.EXCEL_IMPORT_DATA_NOT_EXIST.getMessage());
        }

        for (String[] value : values) {   //将数据封装到entity
            BLesson bLesson = null;
            String classCode = value[0];

            //判断编号是否含有中文
            if (TestChinese.isChinese(classCode)) {
                isChinese.add(value[0]);
                continue;
            }

            //判断1:班级编号是否满足<15位；
            if (classCode.length() > 15) {
                //该用户不满足要求，记入valuesShort中
                errorCode.add(value[0]);
                continue;
            }

            if (Integer.parseInt(value[4]) < 0 || Integer.parseInt(value[3]) < 0) {
                //该用户不满足要求，记入valuesShort中
                isNegative.add(value[0]);
                continue;
            }
            if ((bLesson = bLessonRepository.queryBLessonByCode(value[0])) != null) {
                repeatCode.add(value[0]);
                continue;
            }
            BDirection b_direction = bDirectionRepository.selectOne(new QueryWrapper<BDirection>().eq("code", value[2]));
            if (b_direction == null) {
                if (!direction.contains(value[2]))
                    direction.add(value[2]);
                continue;
            }
            bLesson = new BLesson(value[0], value[1], value[3], value[4]);
            bLesson.setDefaultUrl(global.getDEFAULT_COURSE_LOCATION());
            CyUserUtil.setCurrentPersistOperation(bLesson);
            //表中去重
            if (currentlyCode.contains(bLesson.getCode())) {
                innerRepeatResult += "编号 " + value[1] + " 在Excel中重复出现，除第一条以外的数据插入失败 \n";
                continue;
            }
            if (!lessons.contains(bLesson)) {
                currentlyCode.add(bLesson.getCode());
                lessons.add(bLesson);

                BLessonDirection bDirection = new BLessonDirection();
//                bDirection.setLecturerId(b_direction.getBusinessId());
                bDirection.setBusinessId(CyIdGenUtil.uuid());
                bDirection.setLessionId(bLesson.getBusinessId());
                bDirectionRepository.insertBLessonDirection(bDirection);
            }
        }

        String result = "";
        if (lessons.size() > 0) {
            int line = bLessonRepository.insertList(lessons);

            if (line > 0) {
                result += "成功导入" + lessons.size() + "门课程。";
            } else {
                throw new CyServiceException(ResultServiceEnums.EXCEL_IMPORT_DB_INSERT_ERROR.getCode()
                        , ResultServiceEnums.EXCEL_IMPORT_DB_INSERT_ERROR.getMessage());

            }
        }


        if (isNegative.size() > 0) {
            result += "以下课程的学时或学分不能为负数：" + JSON.toJSONString(isNegative) + "。";
        }
        if (isChinese.size() > 0) {
            result += "以下编号格式不正确：" + JSON.toJSONString(isChinese) + "。";
        }
        if (repeatCode.size() > 0) {
            result += "以下课程编号存在重复：" + JSON.toJSONString(repeatCode) + "。";
        }
        if (errorCode.size() > 0) {
            result += "以下课程编号超过15位：" + JSON.toJSONString(errorCode) + "。";
        }
        if (direction.size() > 0) {
            result += "以下课程方向编号不存在：" + JSON.toJSONString(direction) + "。";
        }
        if (lessons.size() < 1) {
            throw new CyServiceException(ResultServiceEnums.EXCEL_IMPORT_DATA_NOT_EXIST.getCode(), result);
        }

        return new CyPersistModel(1, result + innerRepeatResult);


    }


    @Override
    public BLesson selectOne(String businessId, String userId, String token) {
//        String roleIds = CyUserUtil.getAuthenRoleIds();
//        CyUserUtil.getAuthenBusinessId()
//        BLesson bLesson = bLessonRepository.queryLessonDetailWithTime(businessId,roleIds);
        BLesson bLesson = bLessonRepository.queryLessonDetail(businessId);
        //是否该用户在试用中
        if (userId != null) {
            String tryout = null;
            //单位用户
            tryout = bLessonRepository.tryout(businessId, userId);
//            //单位管理员
//            if (tryout == null) {
//                tryout = bLessonRepository.tryoutAdmin(businessId, userId);
//            }
            //个人用户
            if (tryout == null) {
                tryout = bLessonRepository.tryoutPerson(businessId, userId);
            }
            if (tryout != null) {
                bLesson.setTryout("1");
            }
        }
        //是否收藏
        String authenBusinessId = CyUserUtil.getAuthenBusinessId();
        if (StringUtils.isBlank(authenBusinessId)) {
            //如果用户未登录
            bLesson.setLessonIsFavorite(2);
        } else {
            PcLessonFavorite favorite = pcLessonFavoriteRepository.selectOne(new QueryWrapper<PcLessonFavorite>()
                    .eq("lesson_id", businessId)
                    .eq("user_id", authenBusinessId)
                    .eq("del_flag", 0));
            if (ObjectUtils.isEmpty(favorite)) {
                bLesson.setLessonIsFavorite(0);
            } else {
                bLesson.setLessonIsFavorite(1);
            }
        }
        //浏览记录
        if (StringUtils.isNotEmpty(authenBusinessId) && !"null".equals(authenBusinessId)) {
            PcLessonBrowse pcLessonBrowse = new PcLessonBrowse();
            pcLessonBrowse.setLessonId(businessId);
            pcLessonBrowse.setUserId(Integer.parseInt(authenBusinessId));
            pcLessonBrowseServiceImpl.persistOne(pcLessonBrowse);
        }
        // 路径拼接
        bLesson.setPath(global.getBase_Discovery() + bLesson.getPath());
        List<DictData> tecClassifyList = dictionaryServiceImpl.selectByTypes("tec_classify");//技术分类
        List<DictData> jobClassifyList = dictionaryServiceImpl.selectByTypes("job_classify");//岗位分类
        List<DictData> difficultyGradeList = dictionaryServiceImpl.selectByTypes("difficulty_grade");//难度等级
        List<DictData> courseTypeList = dictionaryServiceImpl.selectByTypes("course_type");//前沿讲堂
        List<DictData> courseDimensionsList = dictionaryServiceImpl.selectByTypes("course_dimensions");//课程维度
        List<DictData> intelligentClassroomList = dictionaryServiceImpl.selectByTypes("intelligent_classroom");//智联课堂

        // 标签转化
        String tecClassify = bLesson.getTecClassifySchool();
        if (tecClassify != null && !tecClassify.isEmpty()) {
            List<String> tecClassifyLabels = getStrings(tecClassify, tecClassifyList);
            bLesson.setTecClassifyLabels(String.join(",", tecClassifyLabels));  // 将名称集合拼接成逗号分隔的字符串，设置到 bLesson 对象中
        }
        String jobClassify = bLesson.getJobClassify();
        if (jobClassify != null && !jobClassify.isEmpty()) {
            List<String> jobClassifyLabels = getStrings(jobClassify, jobClassifyList);
            bLesson.setJobClassifyLabels(String.join(",", jobClassifyLabels));  // 将名称集合拼接成逗号分隔的字符串，设置到 bLesson 对象中
        }
        String difficultyClassify = bLesson.getDifficultyClassify();
        if (difficultyClassify != null && !difficultyClassify.isEmpty()) {
            List<String> difficultyClassifyLabels = getStrings(difficultyClassify, difficultyGradeList);
            bLesson.setDifficultyClassifyLabels(String.join(",", difficultyClassifyLabels));  // 将名称集合拼接成逗号分隔的字符串，设置到 bLesson 对象中
        }
        String courseType = bLesson.getCourseType();
        if (courseType != null && !courseType.isEmpty()) {
            List<String> courseTypeLabels = getStrings(courseType, courseTypeList);
            bLesson.setCourseTypeLabels(String.join(",", courseTypeLabels));  // 将名称集合拼接成逗号分隔的字符串，设置到 bLesson 对象中
        }
        String courseTypeC = bLesson.getCourseTypeC();
        if (courseTypeC != null && !courseTypeC.isEmpty()) {
            List<String> courseTypeCLabels = getStrings(courseTypeC, courseTypeList);
            bLesson.setCourseTypeCLabels(String.join(",", courseTypeCLabels));  // 将名称集合拼接成逗号分隔的字符串，设置到 bLesson 对象中
        }
        String courseDimensions = bLesson.getEnterpriseCourseDimensions();
        if (courseDimensions != null && !courseDimensions.isEmpty()) {
            List<String> courseDimensionsLabels = getStrings(courseDimensions, courseDimensionsList);
            bLesson.setCourseDimensionsLabels(String.join(",", courseDimensionsLabels));  // 将名称集合拼接成逗号分隔的字符串，设置到 bLesson 对象中
        }
        String intelligentClassroom = bLesson.getIntelligentClassroom();
        if (intelligentClassroom != null && !intelligentClassroom.isEmpty()) {
            List<String> intelligentClassroomLabels = getStrings(intelligentClassroom, intelligentClassroomList);
            bLesson.setIntelligentClassroomLabels(String.join(",", intelligentClassroomLabels));  // 将名称集合拼接成逗号分隔的字符串，设置到 bLesson 对象中
        }
        // 计算评分
        //查询课程评论列表
        List<PcLessonEvaluation> evaluationList = pcLessonEvaluationRepository.queryPcLessonEvaluationsById(bLesson.getBusinessId());
        if (!CollectionUtils.isEmpty(evaluationList)) {
            //计算平均分
            BigDecimal averageLessonRate = BigDecimal.valueOf(evaluationList.stream()
                    .map(PcLessonEvaluation::getLessonRate) // 提取每个PcLessonEvaluation中的Integer lessonRate
                    .filter(Objects::nonNull) // 排除可能存在的null值
                    .mapToDouble(Double::doubleValue) // 将Integer转换为int基本类型
                    .average() // 计算平均值作为Double返回
                    .orElse(0.0)); // 若列表为空，返回0.0
            // 保留一位小数
            bLesson.setCourseGrad(averageLessonRate.setScale(1, RoundingMode.HALF_UP));
        }
        // 根据用户类型获取对应开课信息
        getBeginCourseInfoByUserType(bLesson, token);
        return bLesson;
    }

    /**
     * 根据用户类型获取对应开课信息
     */
    private void getBeginCourseInfoByUserType(BLesson bLesson, String token) {
        //获取身份字段
        Object uesr = CyUserUtil.getUserInfoObjProp(token, "username:" + CyUserUtil.getAuthenUsername());
        SysUser sysUser = null;
        if (uesr != null) {
            //将object 转换为 user对象
            sysUser = JSON.parseObject(JSON.toJSONString(uesr), SysUser.class);
        }
        // 当前登录人id
        String loginId = CyUserUtil.getAuthenBusinessId();
        if (StringUtils.isBlank(loginId) && sysUser == null) {
            // 如果用户未登录
            bLesson.setLessonIsPay(0);
        } else {
            // 如果用户已登录
            // 获取当前登录人用户信息
            sysUser = pcSysUserRepository.selectById(loginId);
            if (IdentityStaCons.INDIVIDUAL.getStatus().equals(sysUser.getIdentity())) {
                // 个人用户
                // 查询开课信息
                List<TrialCourseDto> list = teaTrialCourseRepository
                        .selectByUserIdAndLessonId(Integer.valueOf(loginId), bLesson.getBusinessId());
                if (CollectionUtils.isEmpty(list) || ObjectUtil.isEmpty(list.get(0))) {
                    // 如果无开课信息
                    if (bLesson.getIsPay() != null) {
                        if (bLesson.getIsPay().equals("1")) {
                            // 如果是付费课程
                            bLesson.setLessonIsPay(0); // 未付费
                            bLesson.setIsExpired("1"); // 已过期
                        } else {
                            // 如果是免费课程
                            bLesson.setLessonIsPay(1); // 已付费
                            bLesson.setIsExpired("0"); // 未过期
                        }
                    }
                } else {
                    TrialCourseDto trialCourseDto = list.get(0);
                    // 如果有开课信息
                    countCourseBeginInformation(bLesson, trialCourseDto);
                }
            } else if (IdentityStaCons.UNIT_USER.getStatus().equals(sysUser.getIdentity())) {
                // 企业用户，判断是否为单位管理员
                List<TrialCourseDto> adminList
                        = teaTrialCourseRepository.findByAdmin(sysUser.getBusinessId(), bLesson.getBusinessId());
                if (!CollectionUtils.isEmpty(adminList)) {
                    // 如果是单位管理员
                    if (!ObjectUtil.isEmpty(adminList.get(0))) {
                        // 如果有开课信息
                        TrialCourseDto trialCourseDto = adminList.get(0);
                        countCourseBeginInformation(bLesson, trialCourseDto);
                    } else {
                        // 如果无开课信息
                        if (bLesson.getIsPay().equals("1")) {
                            // 如果是付费课程
                            bLesson.setLessonIsPay(0); // 未付费
                            bLesson.setIsExpired("1"); // 已过期
                        } else {
                            // 如果是免费课程
                            bLesson.setLessonIsPay(1); // 已付费
                            bLesson.setIsExpired("0"); // 未过期
                        }
                    }
                } else {
                    // 如果非单位管理员
                    List<TrialCourseDto> list = teaTrialCourseRepository
                            .selectByUNITUserIdAndLessonId(sysUser.getBusinessId(), bLesson.getBusinessId());
                    if (!CollectionUtils.isEmpty(list) && !ObjectUtil.isEmpty(list.get(0))) {
                        // 如果有开课信息
                        TrialCourseDto trialCourseDto = list.get(0);
                        countCourseBeginInformation(bLesson, trialCourseDto);
                    } else {
                        if (bLesson.getIsPay() != null) {
                            // 如果无开课信息
                            if (bLesson.getIsPay().equals("1")) {
                                // 如果是付费课程
                                bLesson.setLessonIsPay(0); // 未付费
                                bLesson.setIsExpired("1"); // 已过期
                            } else {
                                // 如果是免费课程
                                bLesson.setLessonIsPay(1); // 已付费
                                bLesson.setIsExpired("0"); // 未过期
                            }
                        }
                    }
                }
            } else if (IdentityStaCons.IP_USER.getStatus().equals(sysUser.getIdentity())) {
                //ip 登录用户
                // 如果非单位管理员
                List<TrialCourseDto> list = teaTrialCourseRepository.selectByIpUser(sysUser.getDeptId().toString(), bLesson.getBusinessId());
                if (!CollectionUtils.isEmpty(list) && !ObjectUtil.isEmpty(list.get(0))) {
                    // 如果有开课信息
                    TrialCourseDto trialCourseDto = list.get(0);
                    countCourseBeginInformation(bLesson, trialCourseDto);
                } else {
                    if (bLesson.getIsPay() != null) {
                        // 如果无开课信息
                        if (bLesson.getIsPay().equals("1")) {
                            // 如果是付费课程
                            bLesson.setLessonIsPay(0); // 未付费
                            bLesson.setIsExpired("1"); // 已过期
                        } else {
                            // 如果是免费课程
                            bLesson.setLessonIsPay(1); // 已付费
                            bLesson.setIsExpired("0"); // 未过期
                        }
                    }
                }
            } else if (IdentityStaCons.ADMIN.getStatus().equals(sysUser.getIdentity())) {
                // 超级管理员
                bLesson.setAvailableTrialTime(-1); // 无限期
                bLesson.setLessonIsPay(1); // 已付费
                bLesson.setIsExpired("0"); // 未过期
            }
        }
    }

    /**
     * 计算课程开课信息
     *
     * @return
     */
    private void countCourseBeginInformation(BLesson bLesson, TrialCourseDto trialCourseDto) {
        if (trialCourseDto.getBeginTrialTime() != null) {
            bLesson.setBeginTrialTime(trialCourseDto.getBeginTrialTime());
        }
        if (trialCourseDto.getEndTrialTime() != null) {
            bLesson.setEndTrialTime(trialCourseDto.getEndTrialTime());
        }
        if (trialCourseDto.getIsPay() != null) {
            // 课程是否付费
            bLesson.setLessonIsPay(trialCourseDto.getIsPay());
        }
        if (trialCourseDto.getBeginTrialTime() == null || trialCourseDto.getEndTrialTime() == null) {
            bLesson.setIsExpired("1"); // 已过期
        } else {
            // 获取当前日期
            long nowTime = new Date().getTime();
            // 结束时间
            long endTime = trialCourseDto.getEndTrialTime().getTime();
            // 计算结束试用时间和当前时间之间的天数差，不足一天按一天计算
            long lookTime = endTime - nowTime;
            if (lookTime > 0) {
                int l = (int) (lookTime / (1000 * 60 * 60 * 24));
                if (l == 0) {
                    l = 1;
                }
                bLesson.setAvailableTrialTime(l);
                bLesson.setRemainingDate(l);
                bLesson.setIsExpired("0"); // 未过期
            } else {
                bLesson.setAvailableTrialTime(0);
                bLesson.setIsExpired("1"); // 已过期
            }
        }
    }

    @Override
    public BLesson selectOne(BLesson bLesson) {
        return bLessonRepository.selectOneByCode(bLesson);
    }

    @Transactional(propagation = Propagation.REQUIRED, readOnly = false)
    @Override
    public int updateByPrimaryKeySelective(BLesson bLesson) {
        return bLessonRepository.updateById(bLesson);
    }

    @Override
    public CyPersistModel updateStatus(BLesson bLesson) {
        int line = baseMapper.updateById(bLesson);
        log.debug(CyUserUtil.getAuthenUsername() + "修改了ID为" + bLesson.getBusinessId() + "的课程信息状态");
        return new CyPersistModel(line);
    }

    @Override
    public CyPersistModel updateBatchStatus(BLesson bLesson) {
        int line = baseMapper.updateBatchStatus(bLesson);
        return new CyPersistModel(line);
    }

    /**
     * 查询精品课 Views
     *
     * @param bLesson
     * @param token
     * @return
     */
    @Override
    public List<BLesson> findByqualityLesson(BLesson bLesson, String token) {
        List<BLesson> lessonList = bLessonRepository.findByqualityLesson(bLesson);
        // 只取最多8条数据
        return findByUsersLessonList(lessonList.stream().limit(8).collect(Collectors.toList()), token);
    }

    /**
     * 推荐课程
     *
     * @param bLesson
     * @return
     */
    @Override
    public List<BLesson> recommendLesson(BLesson bLesson) {
        List<BLesson> bLessons = bLessonRepository.recommendLesson(bLesson);
        if (!CollectionUtils.isEmpty(bLessons)) {
            for (BLesson bLesson1 : bLessons) {
                // 配置完整图片路径
                if (bLesson1.getPath() != null) {
                    bLesson1.setPath(global.getBase_Discovery() + bLesson1.getPath());
                }
            }
            if (bLessons.size() > 3) {
                List<BLesson> lessons = bLessons.subList(0, 3);
                return lessons;
            }
        }
        return bLessons;
    }

    @Override
    public difficultyCountDTO lessonCount(difficultyCountDTO difficultyCountDTO) {
        difficultyCountDTO.setUnit(CyUserUtil.getAuthenDept());
//        difficultyCountDTO.setUnit("6");
        difficultyCountDTO = baseMapper.lessonDifficultyCount(difficultyCountDTO);
//        difficultyCountDTO.setUnit("6");
        if (difficultyCountDTO != null) {
            difficultyCountDTO.setUnit(CyUserUtil.getAuthenDept());
            difficultyCountDTO.setTotal(baseMapper.lessonCount(difficultyCountDTO));
            return difficultyCountDTO;
        }
        return null;
    }

    /**
     * pc 课程申请列表
     * 当前用户未拥有的课程信息
     */
    @Override
    public Map<String, List<BLesson>> pcLessonApplication() {
        Map<String, List<BLesson>> map = new HashMap<>();
        //查询所有的课程信息
        List<BLesson> allbLessons = bLessonRepository.findAllAndTeaName();
        String authenBusinessId = CyUserUtil.getAuthenBusinessId();
        if (StringUtils.isNotBlank(authenBusinessId)) {
            SysUser sysUser = pcSysUserRepository.
                    selectOne(new QueryWrapper<SysUser>().eq("business_id", authenBusinessId)
                            .eq("del_flag", 0)
                            .eq("flag", 1));
            //如果登录用户是个人用户
            if (cyInitComp.getIndividual()[0].equals(sysUser.getIdentity())) {
                //查询当前用户申请过的课程
                List<BLesson> bLessons = teaLessonAndApplicationRepository.selectsubmitByUser(sysUser);
                if (!CollectionUtils.isEmpty(bLessons)) {
                    //根据id删除当前数据
                    bLessons.forEach(bLesson -> {
                        allbLessons.removeIf(bLesson1 -> bLesson1.getBusinessId().equals(bLesson.getBusinessId()));
                    });
                }
            }
            //如果登录用户是公司用户
            if (cyInitComp.getUnit()[0].equals(sysUser.getIdentity())) {
                //查询当前用户申请过的课程
                List<BLesson> bLessons = teaLessonAndApplicationRepository.selectsubmitByUser(sysUser);
                if (!CollectionUtils.isEmpty(bLessons)) {
                    bLessons.forEach(bLesson -> {
                        allbLessons.removeIf(bLesson1 -> bLesson1.getBusinessId().equals(bLesson.getBusinessId()));
                    });
                }
            }
            //查询所有的课程信息
            map.put("allbLessons", allbLessons);
        } else {
            throw new CyServiceException(ResultServiceEnums.COMPANY_NOT_EXISTS.getCode()
                    , ResultServiceEnums.COMPANY_NOT_EXISTS.getMessage());
        }
        return map;
    }

    /**
     * 查询用户收藏列表
     *
     * @param paginationUtility
     */
    @Override
    public IPage<BLesson> findByFavorites(CyPageInfo<BLesson> paginationUtility, BLesson bLesson) {
        String authenBusinessId = CyUserUtil.getAuthenBusinessId();
        if (StringUtils.isEmpty(authenBusinessId)) {
            return null;
        }
        IPage<BLesson> byFavorites = baseMapper.findByFavorites(paginationUtility, authenBusinessId);
        dictionaryConfig(byFavorites);
        return byFavorites;
    }

    /**
     * 用户是否拥有该课程信息
     *
     * @return
     */
    public List<BLesson> findByUsersLessonList(List<BLesson> lessonList, String token) {
        String authenBusinessId = CyUserUtil.getAuthenBusinessId();
        Object uesr = CyUserUtil.getUserInfoObjProp(token, "username:" + CyUserUtil.getAuthenUsername());
        SysUser sysUser = null;
        if (uesr != null) {
            //将object 转换为 user对象
            sysUser = JSON.parseObject(JSON.toJSONString(uesr), SysUser.class);
        }
        if (ObjectUtil.isNotEmpty(sysUser)) {
//            SysUser sysUser = pcSysUserRepository.
//                    selectOne(new QueryWrapper<SysUser>().eq("business_id", authenBusinessId)
//                            .eq("del_flag", 0)
//                            .eq("flag", 1));
            //如果登录用户是个人用户
            if (IdentityStaCons.INDIVIDUAL.getStatus().equals(sysUser.getIdentity())) {
                //查询当前用户拥有的课程
                List<TeaTrialCourse> teaTrialCourses = teaTrialCourseRepository.selectList(new QueryWrapper<TeaTrialCourse>()
                        .eq("applicant", sysUser.getBusinessId())
                        //个人用户
                        .eq("applicant_type", 1)
                        .eq("del_flag", 0));
//                        .eq("flag", 1));
                if (!CollectionUtils.isEmpty(teaTrialCourses)) {
                    for (TeaTrialCourse teaTrialCourse : teaTrialCourses) {
                        for (BLesson lesson : lessonList) {
                            if (teaTrialCourse.getLessonId().equals(lesson.getBusinessId())) {
                                lesson.setLessonIsPay(teaTrialCourse.getIsPay());
                                lesson.setBeginTrialTime(teaTrialCourse.getBeginTrialTime());
                                lesson.setEndTrialTime(teaTrialCourse.getEndTrialTime());
                            }
                        }
                    }
                }
            } else if (IdentityStaCons.UNIT_USER.getStatus().equals(sysUser.getIdentity())) {
                //单位用户
                //查询当前用户拥有的课程
                List<TeaTrialCourse> teaTrialCourses = teaTrialCourseRepository.selectListByUserId(sysUser.getBusinessId());
                if (!CollectionUtils.isEmpty(teaTrialCourses)) {
                    for (TeaTrialCourse teaTrialCourse : teaTrialCourses) {
                        for (BLesson lesson : lessonList) {
                            if (teaTrialCourse.getLessonId().equals(lesson.getBusinessId())) {
                                lesson.setLessonIsPay(teaTrialCourse.getIsPay());
                                lesson.setBeginTrialTime(teaTrialCourse.getBeginTrialTime());
                                lesson.setEndTrialTime(teaTrialCourse.getEndTrialTime());
                            }
                        }
                    }
                }
            } else if (IdentityStaCons.IP_USER.getStatus().equals(sysUser.getIdentity())) {
                List<TrialCourseDto> trialCourseDtos = teaTrialCourseRepository.selectByIpUser(sysUser.getDeptId().toString(), null);
                for (TeaTrialCourse teaTrialCourse : trialCourseDtos) {
                    for (BLesson lesson : lessonList) {
                        if (teaTrialCourse.getLessonId().equals(lesson.getBusinessId())) {
                            lesson.setLessonIsPay(teaTrialCourse.getIsPay());
                            lesson.setBeginTrialTime(teaTrialCourse.getBeginTrialTime());
                            lesson.setEndTrialTime(teaTrialCourse.getEndTrialTime());
                        }
                    }
                }
            }
        }
        if (lessonList.size() > 0) {
            for (BLesson lesson : lessonList) {
                //配置全称url
                if (lesson.getPath() != null) {
                    lesson.setPath(global.getBase_Discovery() + lesson.getPath());
                }
            }
        }
        return lessonList;
    }

    @Override
    public DifficultyCountVO getDifficultyLevel() {
        return bLessonRepository.getDifficultyLevel();
    }

    @Override
    public ClassPlanDTO getClassPlan(ClassPlanDTO classPlanDTO) {
        List<String> classPlan = bLessonRepository.getClassPlan(classPlanDTO);
        if (!CollectionUtils.isEmpty(classPlan)) {
            //使用工具类转换为map
            //去除classPlan中为空字符串的
            classPlan.removeAll(Collections.singleton(""));
            Map map = TecClassifyString.stringToMap(classPlan);
            //使用工具类转为VO
            //标签转化
            List<DictData> classPlanList = null;
            //院校‘
            if (classPlanDTO.getFlag() == 0) {
                classPlanList = dictionaryServiceImpl.selectByTypes("class_plan_c");
            } else if (classPlanDTO.getFlag() == 1) { //企业
                classPlanList = dictionaryServiceImpl.selectByTypes("class_plan");
            }
            //使用工具类转为VO
            Map<String, Integer> hashMap = TecClassifyString.mapToJobClassifyVO(map, classPlanList);
            //获取map中value值的和
            classPlanDTO.setTotal(hashMap.values().stream().mapToInt(Integer::intValue).sum());
            classPlanDTO.setDataMap(hashMap);
            return classPlanDTO;
        }
        return null;
    }

    @Override
    public Map<String, Integer> getTecClassify(TecClassifyDTO tecClassifyDTO) {
        //查表获得技术分布
        List<String> temp = bLessonRepository.getTecClassify(tecClassifyDTO);
        if (!CollectionUtils.isEmpty(temp)) {
            //使用工具类转换为map
            Map map = TecClassifyString.stringToMap(temp);
            //使用工具类转为VO
            //标签转化
            List<DictData> tecClassifyList = dictionaryServiceImpl.selectByTypes("tec_classify");
            //使用工具类转为VO
            Map<String, Integer> hashMap = TecClassifyString.mapToJobClassifyVO(map, tecClassifyList);
            return hashMap;
        }
        return null;
    }

    @Override
    public Map<String, Integer> getJobClassify() {
        //查表获得岗位分布
        List<String> temp = bLessonRepository.getJobClassify();
        if (!CollectionUtils.isEmpty(temp)) {
            //使用工具类转换为map
            Map map = TecClassifyString.stringToMap(temp);
            //标签转化
            List<DictData> jobClassifyList = dictionaryServiceImpl.selectByTypes("job_classify");
            //使用工具类转为VO
            Map hashMap = TecClassifyString.mapToJobClassifyVO(map, jobClassifyList);
            return hashMap;
        }
        return null;
    }

    @Override
    public IPage<CourseView> getCourseView(CyPageInfo<CourseView> paginationUtility) {
        return bLessonRepository.getCourseViewByPage(paginationUtility);
    }

    @Override
    public IPage<TotalLearn> getTotalLearn(CyPageInfo<TotalLearn> paginationUtility, BLesson bLesson) {
        IPage<TotalLearn> records = bLessonRepository.getTotalLearnRecords(paginationUtility, bLesson);
        //数据处理
        //个人用户 院校企业类型为null 修改'--'
        records.getRecords().stream().forEach(totalLearn -> {
            if ("个人用户".equals(totalLearn.getUserType())) {
                totalLearn.setUnitType(totalLearn.getUnitType() == null ? "--" : totalLearn.getUnitType());
                totalLearn.setUnitName(totalLearn.getUnitName() == null ? "--" : totalLearn.getUnitName());
            }
        });
        return records;
    }

    @Override
    public IPage<TotalLearn> getNotStart(CyPageInfo<TotalLearn> paginationUtility, BLesson bLesson) {
        //查询记录
        IPage<TotalLearn> records = bLessonRepository.getNotStartRecords(paginationUtility, bLesson);
        //数据处理
        //个人用户 院校企业类型为null 修改'--'
        records.getRecords().stream().forEach(totalLearn -> {
            if ("个人用户".equals(totalLearn.getUserType())) {
                totalLearn.setUnitType(totalLearn.getUnitType() == null ? "--" : totalLearn.getUnitType());
                totalLearn.setUnitName(totalLearn.getUnitName() == null ? "--" : totalLearn.getUnitName());
            }
        });
        return records;
    }

    @Override
    public IPage<TotalLearn> getLearning(CyPageInfo<TotalLearn> paginationUtility, BLesson bLesson) {
        //查询记录
        IPage<TotalLearn> records = bLessonRepository.getLearnRecords(paginationUtility, bLesson);
        records.getRecords().stream().forEach(totalLearn -> {
            if ("个人用户".equals(totalLearn.getUserType())) {
                totalLearn.setUnitType(totalLearn.getUnitType() == null ? "--" : totalLearn.getUnitType());
                totalLearn.setUnitName(totalLearn.getUnitName() == null ? "--" : totalLearn.getUnitName());
            }
        });
        return records;
    }

    @Override
    public IPage<TotalLearn> getFinish(CyPageInfo<TotalLearn> paginationUtility, BLesson bLesson) {
        //查询记录
        IPage<TotalLearn> records = bLessonRepository.getFinishRecords(paginationUtility, bLesson);
        records.getRecords().stream().forEach(totalLearn -> {
            if ("个人用户".equals(totalLearn.getUserType())) {
                totalLearn.setUnitType(totalLearn.getUnitType() == null ? "--" : totalLearn.getUnitType());
                totalLearn.setUnitName(totalLearn.getUnitName() == null ? "--" : totalLearn.getUnitName());
            }
        });
        return records;
    }

    @Override
    public IPage<LessonStudyDTO> getExamed(CyPageInfo<LessonStudyDTO> paginationUtility, BLesson bLesson) {
        //查询记录
        IPage<LessonStudyDTO> records = bLessonRepository.getExamedRecords(paginationUtility, bLesson);
        records.getRecords().stream().forEach(totalLearn -> {
            if ("个人用户".equals(totalLearn.getUserType())) {
                totalLearn.setUnitType(totalLearn.getUnitType() == null ? "--" : totalLearn.getUnitType());
                totalLearn.setUnit(totalLearn.getUnit() == null ? "--" : totalLearn.getUnit());
            }
        });
        return records;
    }

    @Override
    public IPage<Examine> getExamineList(CyPageInfo<Examine> paginationUtility, ExamListDTO examListDTO) {
        //查询记录
        IPage<Examine> res = baseMapper.getExamineListRecords(paginationUtility, examListDTO);

        //填充满分人数占比
        List<Examine> records = res.getRecords();
        for (Examine record : records) {
            Integer fullNumber = record.getFullNumber() == null ? 0 : record.getFullNumber();
            Integer testNumber = record.getTestNumber() == null ? 0 : record.getTestNumber();
            Integer participant = record.getParticipant() == null ? 0 : record.getParticipant();
            Integer passNumber = record.getPassNumber() == null ? 0 : record.getPassNumber();

            if (testNumber != 0) {
                record.setFullScale((double) fullNumber / (double) testNumber);
                record.setPassScale((double) passNumber / (double) participant);
            } else {
                record.setFullScale(0d);
                record.setPassScale(0d);
            }
        }

        return res;
    }

    @Override
    public ExamineInfoVO getExamineParticipant(ListDetailDTO listDetailDTO) {

        //创建返回对象
        ExamineInfoVO res = new ExamineInfoVO();

        //查询总记录数
        res.setTotal(baseMapper.getExamineParticipantNumber(listDetailDTO.getBusinessId()));

        //健壮性判断
        if (listDetailDTO.getPage() == null) {
            listDetailDTO.setPage(1);
        }
        if (listDetailDTO.getRows() == null) {
            listDetailDTO.setRows(10);
        }

        //查询记录
        res.setRecords(baseMapper.getExamineParticipantRecords(listDetailDTO, (listDetailDTO.getPage() - 1) * listDetailDTO.getRows()));


        return res;
    }

    @Override
    public ExamineInfoVO getFullMark(ListDetailDTO listDetailDTO) {
        //创建返回对象
        ExamineInfoVO res = new ExamineInfoVO();

        //查询总记录数
        res.setTotal(baseMapper.getFullMarkNumber(listDetailDTO.getBusinessId()));

        //健壮性判断
        if (listDetailDTO.getPage() == null) {
            listDetailDTO.setPage(1);
        }
        if (listDetailDTO.getRows() == null) {
            listDetailDTO.setRows(10);
        }

        //查询记录
        res.setRecords(baseMapper.getFullMarkRecords(listDetailDTO, (listDetailDTO.getPage() - 1) * listDetailDTO.getRows()));

        return res;
    }

    @Override
    public ExamineInfoVO getPassNumber(ListDetailDTO listDetailDTO) {
        //创建返回对象
        ExamineInfoVO res = new ExamineInfoVO();

        //查询总记录数
        res.setTotal(baseMapper.getPassNumberNumber(listDetailDTO.getBusinessId()));

        //健壮性判断
        if (listDetailDTO.getPage() == null) {
            listDetailDTO.setPage(1);
        }
        if (listDetailDTO.getRows() == null) {
            listDetailDTO.setRows(10);
        }

        //查询记录
        res.setRecords(baseMapper.getPassNumberRecords(listDetailDTO, (listDetailDTO.getPage() - 1) * listDetailDTO.getRows()));

        return res;
    }

    @Override
    public IPage<BLesson> queryBLessonByPaginationByDateAsc(CyPageInfo<BLesson> paginationUtility, BLesson model, String token) {
        IPage<BLesson> bLessonIPage = null;
        if ("0".equals(model.getLessonType())) {
            model.setLessonType("1");
        } else if ("1".equals(model.getLessonType())) {
//            model.setLessonType("");
            model.setLessonTypeSchool("1");
        }
        if (model.getLessonIsPay() == 0) {
            bLessonIPage = baseMapper.queryBLessonByPaginationByDateAsc(paginationUtility, model);
            List<BLesson> records = bLessonIPage.getRecords();
            if (!CollectionUtils.isEmpty(records)) {
                for (BLesson bLesson : records) {
                    getBeginCourseInfoByUserType(bLesson, token);
                    configBLessonInfo(bLesson);
                }
            }
            return bLessonIPage;
        } else if (model.getLessonIsPay() == 1) {//查看已购
            paginationUtility.setSize(1000);
            bLessonIPage = baseMapper.queryBLessonByPaginationByDateAsc(paginationUtility, model);
            List<BLesson> list = bLessonIPage.getRecords();
            if (!CollectionUtils.isEmpty(list)) {
                ArrayList<BLesson> freeLessonList = new ArrayList<>();
                for (BLesson bLesson : list) {
                    getBeginCourseInfoByUserType(bLesson, token);
                    configBLessonInfo(bLesson);
                    if (model.getLessonIsPay() == bLesson.getLessonIsPay()) {
                        freeLessonList.add(bLesson);
                    }
                }
                if (!CollectionUtils.isEmpty(freeLessonList) && model.getLessonIsPay() == 1) {
                    // 更新分页信息
                    if (!CollectionUtils.isEmpty(freeLessonList)) {
                        bLessonIPage.setCurrent(paginationUtility.getCurrent());
                        bLessonIPage.setCurrent(paginationUtility.getCurrent());
                        bLessonIPage.setRecords(freeLessonList);
                        bLessonIPage.setTotal(freeLessonList.size());
                        bLessonIPage.setPages(paginationUtility.getPages());
                        bLessonIPage.setSize(paginationUtility.getSize());
                        return bLessonIPage;
                    }
                }
            }
        }
        return bLessonIPage;
    }

    @Override
    public String getUserType(String userId) {
        if (StringUtils.isNotEmpty(userId)) {
            //返回用户类型 null 无   0 企业 1 学院
            return baseMapper.getUserType(userId);
        }
        return null;
    }

    @Override
    public IPage<BLesson> getLessonStatus(CyPageInfo<BLesson> paginationUtility, BLesson bLesson) {
        //当前用户id
        String authenBusinessId = CyUserUtil.getAuthenBusinessId();
        bLesson.setLecturerId(authenBusinessId);
        //查询当前用户的课程信息
        if (StringUtils.isNotEmpty(authenBusinessId)) {
            //查询当前用户的课程信息
            IPage<BLesson> bLessonIPage = baseMapper.getLessonStatus(paginationUtility, bLesson);
            List<BLesson> records = bLessonIPage.getRecords();
            if (!CollectionUtils.isEmpty(records)) {
                for (BLesson bLesson1 : records) {
                    bLesson1.setPath(global.getBase_Discovery() + bLesson1.getPath());
                }
            }
            return bLessonIPage;
        }
        return null;
    }

    @Override
    public HashMap<String, String> getLessonCount() {
        HashMap<String, String> stringStringHashMap = new HashMap<>();
        //讲师id
        String authenBusinessId = CyUserUtil.getAuthenBusinessId();
        //讲师创建课程但没有删除的课程
        Integer lessonCount = baseMapper.getLessonCount(authenBusinessId);
        stringStringHashMap.put("lesson", String.valueOf(lessonCount));
        //个人开课给讲师的所有课程
        lessonCount = teaTrialCourseRepository.getLessonCount(authenBusinessId);
        stringStringHashMap.put("lessonStart", String.valueOf(lessonCount));
        return stringStringHashMap;
    }

    @Override
    public IPage<AuditLogs> getLessonFail(CyPageInfo<BLesson> paginationUtility, BLesson bLesson) {
        //通过课程id查询出当前课程的审核状态
        return auditLogsRepository.selectByLessonId(paginationUtility, bLesson.getBusinessId());
    }

    @Override
    public IPage<AuditLogs> getLessonFailHistory(CyPageInfo<BLesson> paginationUtility, BLesson bLesson) {
        //通过课程id查询出当前课程的审核状态
        IPage<AuditLogs> auditLogsIPage = auditLogsRepository.selectByLessonId(paginationUtility, bLesson.getBusinessId());
        return auditLogsIPage;
    }

    @Override
    public IPage<BLesson> getLessonAuditPrimary(CyPageInfo<BLesson> paginationUtility, BLesson param) {
        //分页查询当前课程
        IPage<BLesson> lessonAuditPrimary = baseMapper.getLessonAuditPrimary(paginationUtility, param);
        //循环插入图片完整路径
        lessonAuditPrimary.getRecords().forEach(lesson -> {
            // 配置完整图片路径
            if (lesson.getPath() != null) {
                lesson.setPath(global.getBase_Discovery() + lesson.getPath());
            }
        });
        return lessonAuditPrimary;
    }

    @Override
    public HashMap<String, Integer> getLessonAuditCount() {
        List<Integer> lessonAuditCount = baseMapper.getLessonAuditCount();
        HashMap<String, Integer> stringStringHashMap = new HashMap<>();
        //统计list 不同的数字的数量
        if (!CollectionUtils.isEmpty(lessonAuditCount)) {
            // 1，2，3，4，5
            stringStringHashMap.put("ONE", (int) lessonAuditCount.stream().filter(x -> x == 1).count());
            stringStringHashMap.put("TWO", (int) lessonAuditCount.stream().filter(x -> x == 2).count());
            stringStringHashMap.put("THREE", (int) lessonAuditCount.stream().filter(x -> x == 3).count());
            stringStringHashMap.put("FOUR", (int) lessonAuditCount.stream().filter(x -> x == 4).count());
            stringStringHashMap.put("FIVE", (int) lessonAuditCount.stream().filter(x -> x == 5).count());
        }
        return stringStringHashMap;
    }

    @Override
    public String getLessonTeacherId() {
        String authenBusinessId = CyUserUtil.getAuthenBusinessId();
        if (StringUtils.isNotEmpty(authenBusinessId)) {
            CmsLecturer cmsLecturer = cmsLecturerRepository.selectByUserId(Integer.parseInt(authenBusinessId));
            if (cmsLecturer != null){
                return String.valueOf(cmsLecturer.getBusinessId());
            }
        }
        return "";
    }

    @Override
    public void updateLessonAudit(AuditLogs auditLogs) {
        //添加
        auditLogs.setAuditTime(new Date());
        auditLogsRepository.insert(auditLogs);
    }

    @Override
    public void updateLessonAuditPrimary(BLesson bLesson) {
        String auditState = bLesson.getAuditState();
        if (auditState.equals("6")) {
            //一级审核通过 二级审核未通过  直接转成3 提交审核时直接进入二级审核
            bLesson.setAuditState("3");
            //修改课程
            bLessonRepository.updateById(bLesson);
        } else {
            //修改课程
            bLessonRepository.updateById(bLesson);
            //添加记录
            AuditLogs auditLogs = new AuditLogs();
            //添加课程id
            auditLogs.setLessonId(bLesson.getBusinessId());
            //审核时间
            auditLogs.setAuditTime(new Date());
            //审核结果
            auditLogs.setAuditState(bLesson.getAuditState());
            //审核意见
            if ("1".equals(bLesson.getAuditState())) {
                auditLogs.setAuditOpinion("提交审核申请");
            } else {
                auditLogs.setAuditOpinion("撤销提交审核申请");
            }
            //提交人id
            auditLogs.setAuditUserId(Integer.valueOf(CyUserUtil.getAuthenBusinessId()));
            auditLogsRepository.insert(auditLogs);
        }
    }

    @Override
    public List<ExportBLesson> export(BLesson model) {
        if ("0".equals(model.getLessonType())) {
            model.setLessonType("1");
        } else if ("1".equals(model.getLessonType())) {
            model.setLessonType(null);
            model.setLessonTypeSchool("1");
        } else if ("2".equals(model.getLessonType())) {
            model.setLessonType("1");
            model.setLessonTypeSchool("1");
        }
        List<ExportBLesson> records = null;
        records = baseMapper.exportBlessonList(model);
        //添加标签
        for (ExportBLesson bLesson : records) {
            List<DictData> lessonTypeList = dictionaryServiceImpl.selectByTypes("lesson_type");//课程类型
            List<DictData> tecClassifyList = dictionaryServiceImpl.selectByTypes("tec_classify");//技术分类
            List<DictData> jobClassifyList = dictionaryServiceImpl.selectByTypes("job_classify");//岗位分类
            List<DictData> difficultyGradeList = dictionaryServiceImpl.selectByTypes("difficulty_grade");//难度等级
            List<DictData> courseTypeList = dictionaryServiceImpl.selectByTypes("course_type");//前沿讲堂
            List<DictData> courseDimensionsList = dictionaryServiceImpl.selectByTypes("course_dimensions");//课程维度
            List<DictData> intelligentClassroomList = dictionaryServiceImpl.selectByTypes("intelligent_classroom");//智联课堂
            List<DictData> classPlanList = dictionaryServiceImpl.selectByTypes("class_plan");//技术端课程方案
            List<DictData> classPlanSchoolList = dictionaryServiceImpl.selectByTypes("class_plan_c");//技能端课程方案
            // 标签转化
            //技术端课程方案
            String classPlan = bLesson.getClassPlan();
            if (classPlan != null && !classPlan.isEmpty()) {
                List<String> classPlanLabels = getStrings(classPlan, classPlanList);
                bLesson.setClassPlanLabels(String.join(",", classPlanLabels));  // 将名称集合拼接成逗号分隔的字符串，设置到 bLesson 对象中

            }
            //技能端课程方案
            String classPlanSchool = bLesson.getClassPlanSchool();
            if (classPlanSchool != null && !classPlanSchool.isEmpty()) {
                List<String> classPlanSchoolLabels = getStrings(classPlanSchool, classPlanSchoolList);
                bLesson.setClassPlanCSchoolLabels(String.join(",", classPlanSchoolLabels));  // 将名称集合拼接成逗号分隔的字符串，设置到 bLesson 对象中

            }
            //课程类型
            String lessonType = bLesson.getLessonType();
            String lessonTypeSchool = bLesson.getLessonTypeSchool();
            if (lessonType != null && lessonTypeSchool != null) {
                if (lessonType.equals("1") && lessonTypeSchool.equals("1")){
                    List<String> lessonTypeLabels = getStrings("0,1", lessonTypeList);
                    bLesson.setLessonTypeLabels(String.join(",", lessonTypeLabels));
                } else if (lessonType.equals("1")) {
                    //技术端
                    List<String> lessonTypeLabels = getStrings("0", lessonTypeList);
                    bLesson.setLessonTypeLabels(String.join(",", lessonTypeLabels));
                } else if (lessonTypeSchool.equals("1")){
                    //技能端
                    List<String> lessonTypeLabels = getStrings("1", lessonTypeList);
                    bLesson.setLessonTypeLabels(String.join(",", lessonTypeLabels));
                }
            }
            //技术分类
            String tecClassify = bLesson.getTecClassifySchool();
            if (tecClassify != null && !tecClassify.isEmpty()) {
                List<String> tecClassifyLabels = getStrings(tecClassify, tecClassifyList);
                bLesson.setTecClassifyLabels(String.join(",", tecClassifyLabels));  // 将名称集合拼接成逗号分隔的字符串，设置到 bLesson 对象中

            }
            //岗位分类
            String jobClassify = bLesson.getJobClassify();
            if (jobClassify != null && !jobClassify.isEmpty()) {
                List<String> jobClassifyLabels = getStrings(jobClassify, jobClassifyList);
                bLesson.setJobClassifyLabels(String.join(",", jobClassifyLabels));  // 将名称集合拼接成逗号分隔的字符串，设置到 bLesson 对象中

            }
            //难度等级
            String difficultyClassify = bLesson.getDifficultyClassify();
            if (difficultyClassify != null && !difficultyClassify.isEmpty()) {
                List<String> difficultyClassifyLabels = getStrings(difficultyClassify, difficultyGradeList);
                bLesson.setDifficultyClassifyLabels(String.join(",", difficultyClassifyLabels));  // 将名称集合拼接成逗号分隔的字符串，设置到 bLesson 对象中

            }
            //技术端课程分类
            String courseType = bLesson.getCourseType();
            if (courseType != null && !courseType.isEmpty()) {
                List<String> courseTypeLabels = getStrings(courseType, courseTypeList);
                bLesson.setCourseTypeLabels(String.join(",", courseTypeLabels));  // 将名称集合拼接成逗号分隔的字符串，设置到 bLesson 对象中

            }
            //课程维度
            String courseDimensions = bLesson.getEnterpriseCourseDimensions();
            if (courseDimensions != null && !courseDimensions.isEmpty()) {
                List<String> courseDimensionsLabels = getStrings(courseDimensions, courseDimensionsList);
                bLesson.setCourseDimensionsLabels(String.join(",", courseDimensionsLabels));  // 将名称集合拼接成逗号分隔的字符串，设置到 bLesson 对象中

            }
            //智联课堂
            String intelligentClassroom = bLesson.getIntelligentClassroom();
            if (intelligentClassroom != null && !intelligentClassroom.isEmpty()) {
                List<String> intelligentClassroomLabels = getStrings(intelligentClassroom, intelligentClassroomList);
                bLesson.setIntelligentClassroomLabels(String.join(",", intelligentClassroomLabels));  // 将名称集合拼接成逗号分隔的字符串，设置到 bLesson 对象中
            }

        }
        return records;
    }
}
