package org.rcisoft.business.cmsdevelopment.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.business.cmsdevelopment.entity.CmsDevelopment;
import org.rcisoft.business.cmsdevelopment.service.CmsDevelopmentService;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;

import org.rcisoft.core.model.CyGridModel;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;



import java.util.List;

/**
* Created by cy on 2024年3月25日 下午7:55:33.
*/
@RestController
@RequestMapping("/cmsdevelopment")
public class CmsDevelopmentController extends CyPaginationController<CmsDevelopment> {


    @Autowired
    private CmsDevelopmentService cmsDevelopmentServiceImpl;

    @PreAuthorize("@cyPerm.hasPerm('cms:milestones:increase')")
    @CyOpeLogAnno(title = "system-发展表管理-新增发展表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="添加发展表", notes="添加发展表")
    @PostMapping(value = "/add")
    public CyResult add(@Valid CmsDevelopment cmsDevelopment, BindingResult bindingResult) {
        CyPersistModel data = cmsDevelopmentServiceImpl.persist(cmsDevelopment);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        cmsDevelopment);
    }
    @PreAuthorize("@cyPerm.hasPerm('cms:milestones:removing')")
    @CyOpeLogAnno(title = "system-发展表管理-删除发展表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="逻辑删除发展表", notes="逻辑删除发展表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable int businessId,CmsDevelopment cmsDevelopment) {
        cmsDevelopment.setBusinessId(businessId);
        CyPersistModel data = cmsDevelopmentServiceImpl.removeLogical(cmsDevelopment);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }
    @PreAuthorize("@cyPerm.hasPerm('cms:milestones:kill')")
    @CyOpeLogAnno(title = "system-发展表管理-删除发展表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="删除发展表", notes="删除发展表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable int businessId,CmsDevelopment cmsDevelopment) {
        cmsDevelopment.setBusinessId(businessId);
        CyPersistModel data = cmsDevelopmentServiceImpl.remove(cmsDevelopment);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    @PreAuthorize("@cyPerm.hasPerm('cms:milestones:modifications')")
    @CyOpeLogAnno(title = "system-发展表管理-修改发展表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改发展表", notes="修改发展表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable int businessId, @Valid CmsDevelopment cmsDevelopment, BindingResult bindingResult) {
        cmsDevelopment.setBusinessId(businessId);
        CyPersistModel data = cmsDevelopmentServiceImpl.merge(cmsDevelopment);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        cmsDevelopment);
    }

    @PreAuthorize("@cyPerm.hasPerm('cms:milestones:singleSearch')")
    @CyOpeLogAnno(title = "system-发展表管理-查询发展表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单一发展表", notes="查询单一发展表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable int businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        cmsDevelopmentServiceImpl.findByIdWithUrl(businessId));
    }

//    @PreAuthorize("@cyPerm.hasPerm('sys:development:list')")
    @CyOpeLogAnno(title = "system-发展表管理-查询发展表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询发展表集合", notes="查询发展表集合")
    @GetMapping(value = "/queryCmsDevelopments")
    public CyResult queryCmsDevelopments(CmsDevelopment cmsDevelopment) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            cmsDevelopmentServiceImpl.findAll(cmsDevelopment));
    }

//    @PreAuthorize("@cyPerm.hasPerm('cms:milestones:pageSearch')")
    @CyOpeLogAnno(title = "system-发展表管理-查询发展表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="分页查询发展表集合", notes="分页查询发展表集合")
    @GetMapping(value = "/queryCmsDevelopmentByPagination")
    public CyGridModel listByPagination(CmsDevelopment cmsDevelopment) {
        cmsDevelopmentServiceImpl.findAllByPagination(getPaginationUtility(), cmsDevelopment);
        return getGridModelResponse();
    }

    @PreAuthorize("@cyPerm.hasPerm('cms:milestones:derive')")
    @CyOpeLogAnno(title = "system-发展表管理-查询发展表", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出发展表信息", notes = "导出发展表信息")
    @GetMapping(value = "/export")
    public void outCmsDevelopment(HttpServletResponse response,CmsDevelopment cmsDevelopment,@PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="发展表信息.xls";break;
            case "1": excelName="发展表信息.xlsx";break;
            case "2": excelName="发展表信息.csv";break;
        }
        List<CmsDevelopment> cmsDevelopmentList = cmsDevelopmentServiceImpl.export(cmsDevelopment);
        CyEpExcelUtil.exportExcel(cmsDevelopmentList, "发展表信息", "发展表信息", CmsDevelopment.class, excelName, response);
    }
}
