package org.rcisoft.business.cmsdevelopment.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.rcisoft.business.cmsdevelopment.dao.CmsDevelopmentRepository;
import org.rcisoft.business.cmsdevelopment.entity.CmsDevelopment;
import org.rcisoft.business.cmsdevelopment.service.CmsDevelopmentService;
import org.rcisoft.common.component.Global;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyPersistModel;


import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.rcisoft.core.model.CyPageInfo;

import java.util.List;
import lombok.extern.slf4j.Slf4j;

/**
 * Created by cy on 2024年3月25日 下午7:55:33.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class CmsDevelopmentServiceImpl extends ServiceImpl<CmsDevelopmentRepository, CmsDevelopment>  implements CmsDevelopmentService {

    @Autowired
    private Global global;
    /**
    * 保存 发展表
    * @param cmsDevelopment
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(CmsDevelopment cmsDevelopment){
        //增加操作
        int line = baseMapper.insert(cmsDevelopment);
        log.debug(CyUserUtil.getAuthenUsername()+"新增了ID为"+
            cmsDevelopment.getBusinessId()+"的发展表信息");
        return new CyPersistModel(line);
    }

    /**
    * 删除 发展表
    * @param cmsDevelopment
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(CmsDevelopment cmsDevelopment){
        int line = baseMapper.realDelete(cmsDevelopment);
        log.debug(CyUserUtil.getAuthenUsername()+"删除了ID为"+
            cmsDevelopment.getBusinessId()+"的发展表信息");
        return new CyPersistModel(line);
    }

    /**
    * 逻辑删除 发展表
    * @param cmsDevelopment
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(CmsDevelopment cmsDevelopment){
        cmsDevelopment.setDeleted();
        int line = baseMapper.deleteById(cmsDevelopment);
            log.debug(CyUserUtil.getAuthenUsername()+"逻辑删除了ID为"+
                cmsDevelopment.getBusinessId()+"的发展表信息");
            return new CyPersistModel(line);
    }

    /**
    * 修改 发展表
    * @param cmsDevelopment
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(CmsDevelopment cmsDevelopment){
        int line = baseMapper.updateById(cmsDevelopment);
        log.debug(CyUserUtil.getAuthenUsername()+"修改了ID为"+ cmsDevelopment.getBusinessId()+"的发展表信息");
        return new CyPersistModel(line);
    }

    /**
    * 根据id查询 发展表
    * @param id
    * @return
    */
    @Override
    public CmsDevelopment findById(int id){
        return baseMapper.selectById(id);
    }

    @Override
    public CmsDevelopment findByIdWithUrl(int id){

      CmsDevelopment cmsDevelopment = baseMapper.selectByIdWithUrl(id);
       String url = cmsDevelopment.getUrl();
       if (url != null){
           cmsDevelopment.setUrl(global.getBase_Discovery()+url);
       }

        return cmsDevelopment;
    }

    /**
    * 分页查询 发展表
    * @param cmsDevelopment
    * @return
    */
    @Override
    public IPage<CmsDevelopment> findAllByPagination(CyPageInfo<CmsDevelopment> paginationUtility,
        CmsDevelopment cmsDevelopment){
        IPage<CmsDevelopment>  result = baseMapper.queryCmsDevelopmentsPaged(paginationUtility,cmsDevelopment);
        // 获取 IPage 中的 CmsDevelopment 列表
        List<CmsDevelopment> cmsDevelopmentsList = result.getRecords();

// 遍历列表中的每个 CmsDevelopment 实例并进行修改
        for (CmsDevelopment dev : cmsDevelopmentsList) {
            if (dev.getUrl() != null){
                // 在这里修改每个 CmsDevelopment 对象的属性
                dev.setUrl(global.getBase_Discovery()+dev.getUrl());
            }
        }

        result.setRecords(cmsDevelopmentsList);

        return result;

    }




    /**
    * 查询list 发展表
    * @param cmsDevelopment
    * @return
    */
    @Override
    public List<CmsDevelopment> findAll(CmsDevelopment cmsDevelopment){
        return baseMapper.queryCmsDevelopments(cmsDevelopment);

    }

    /**
    * 导出发展表
    * @return
    */
    @Override
    public List<CmsDevelopment> export(CmsDevelopment cmsDevelopment) {
        List<CmsDevelopment> cmsDevelopmentList = baseMapper.queryCmsDevelopments(cmsDevelopment);
        return cmsDevelopmentList;
    }

}
