package org.rcisoft.business.cmsproject.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.business.cmsproject.entity.CmsProject;
import org.rcisoft.business.cmsproject.service.CmsProjectService;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.exception.CyServiceException;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;

import java.util.List;

/**
* Created by cy on 2024年3月25日 下午5:57:59.
*/
@RestController
@RequestMapping("/cmsproject")
public class CmsProjectController extends CyPaginationController<CmsProject> {


    @Autowired
    private CmsProjectService cmsProjectServiceImpl;

    @PreAuthorize("@cyPerm.hasPerm('cms:estateMake:increase')")
    @CyOpeLogAnno(title = "system-项目案例管理-新增项目案例", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="添加项目案例", notes="添加项目案例")
    @PostMapping(value = "/add")
    public CyResult add(@Valid CmsProject cmsProject, BindingResult bindingResult) {
        CyPersistModel data = cmsProjectServiceImpl.persist(cmsProject);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        cmsProject);
    }
    @PreAuthorize("@cyPerm.hasPerm('cms:estateMake:removing')")
    @CyOpeLogAnno(title = "system-项目案例管理-删除项目案例", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="逻辑删除项目案例", notes="逻辑删除项目案例")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable Integer businessId,CmsProject cmsProject) {
        cmsProject.setBusinessId(businessId);
        CyPersistModel data = cmsProjectServiceImpl.removeLogical(cmsProject);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:project:delete')")
    @CyOpeLogAnno(title = "system-项目案例管理-删除项目案例", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="删除项目案例", notes="删除项目案例")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable Integer businessId,CmsProject cmsProject) {
        cmsProject.setBusinessId(businessId);
        CyPersistModel data = cmsProjectServiceImpl.remove(cmsProject);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    @PreAuthorize("@cyPerm.hasPerm('cms:estateMake:modifications')")
    @CyOpeLogAnno(title = "system-项目案例管理-修改项目案例", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改项目案例", notes="修改项目案例")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable Integer businessId, @Valid CmsProject cmsProject, BindingResult bindingResult) {
        cmsProject.setBusinessId(businessId);
        CyPersistModel data = cmsProjectServiceImpl.merge(cmsProject);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        cmsProject);
    }

//    @PreAuthorize("@cyPerm.hasPerm('cms:estateMake:singleSearch')")
    @CyOpeLogAnno(title = "system-项目案例管理-查询项目案例", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单一项目案例", notes="查询单一项目案例")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable Integer businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        cmsProjectServiceImpl.findById(businessId));
    }

//    @PreAuthorize("@cyPerm.hasPerm('cms:estateMake:singleSearch')")
    @CyOpeLogAnno(title = "system-项目案例管理-查询项目案例", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询项目案例集合", notes="查询项目案例集合")
    @GetMapping(value = "/queryCmsProjects")
    public CyResult queryCmsProjects(CmsProject cmsProject) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            cmsProjectServiceImpl.findAll(cmsProject));
    }
    //修改状态
    @PreAuthorize("@cyPerm.hasPerm('cms:estateMake:removingStatus')")
    @CyOpeLogAnno(title = "system-项目案例管理-修改项目案例状态", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改项目案例状态", notes="修改项目案例状态")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @PutMapping("/updateStatus/{businessId:\\w+}")
    public CyResult updateStatus(@PathVariable Integer businessId, CmsProject cmsProject) {
        cmsProject.setBusinessId(businessId);
        CyPersistModel data = cmsProjectServiceImpl.updateStatus(cmsProject);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

//    @PreAuthorize("@cyPerm.hasPerm('cms:estateMake:pageSearch')")
    @CyOpeLogAnno(title = "system-项目案例管理-查询项目案例", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="分页查询项目案例集合", notes="分页查询项目案例集合")
    @GetMapping(value = "/queryCmsProjectByPagination")
    public CyGridModel listByPagination(CmsProject cmsProject) {
        cmsProjectServiceImpl.findAllByPagination(getPaginationUtility(), cmsProject);
        return getGridModelResponse();
    }
    @PreAuthorize("@cyPerm.hasPerm('cms:estateMake:derive')")
    @CyOpeLogAnno(title = "system-项目案例管理-查询项目案例", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出项目案例信息", notes = "导出项目案例信息")
    @GetMapping(value = "/export")
    public void outCmsProject(HttpServletResponse response,CmsProject cmsProject,@PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="项目案例信息.xls";break;
            case "1": excelName="项目案例信息.xlsx";break;
            case "2": excelName="项目案例信息.csv";break;
        }
        List<CmsProject> cmsProjectList = cmsProjectServiceImpl.export(cmsProject);
        CyEpExcelUtil.exportExcel(cmsProjectList, "项目案例信息", "项目案例信息", CmsProject.class, excelName, response);
    }
}
