package org.rcisoft.business.cmsproject.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.apache.fop.fo.FOText;
import org.rcisoft.business.cmsproject.dao.CmsProjectRepository;
import org.rcisoft.business.cmsproject.entity.CmsProject;
import org.rcisoft.business.cmsproject.service.CmsProjectService;
import org.rcisoft.common.component.Global;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.result.enums.CyResSysExcEnum;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.aop.CyPageUtilAsp;
import org.rcisoft.core.model.CyPersistModel;


import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.rcisoft.core.model.CyPageInfo;

import java.util.List;

import lombok.extern.slf4j.Slf4j;

/**
 * Created by cy on 2024年3月25日 下午5:57:59.
 */
@Service
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class CmsProjectServiceImpl extends ServiceImpl<CmsProjectRepository, CmsProject> implements CmsProjectService {

    @Autowired
    private Global global;


    /**
     * 保存 项目案例
     *
     * @param cmsProject
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(CmsProject cmsProject) {
        CmsProject check = baseMapper.checkWeight(cmsProject.getWeight());
        if (ObjectUtil.isNotNull(check)) {
            throw new CyServiceException(500, "排序已存在");
        } else {
            //增加操作
            int line = baseMapper.insert(cmsProject);
            log.debug(CyUserUtil.getAuthenUsername() + "新增了ID为" +
                    cmsProject.getBusinessId() + "的项目案例信息");
            return new CyPersistModel(line);
        }


    }

    /**
     * 删除 项目案例
     *
     * @param cmsProject
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(CmsProject cmsProject) {
        int line = baseMapper.realDelete(cmsProject);
        log.debug(CyUserUtil.getAuthenUsername() + "删除了ID为" +
                cmsProject.getBusinessId() + "的项目案例信息");
        return new CyPersistModel(line);
    }

    /**
     * 逻辑删除 项目案例
     *
     * @param cmsProject
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(CmsProject cmsProject) {
        cmsProject.setDeleted();
        int line = baseMapper.deleteCmsProject(cmsProject.getBusinessId());
        log.debug(CyUserUtil.getAuthenUsername() + "逻辑删除了ID为" +
                cmsProject.getBusinessId() + "的项目案例信息");
        return new CyPersistModel(line);
    }

    /**
     * 修改 项目案例
     *
     * @param cmsProject
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(CmsProject cmsProject) {
        //判断富文本中是否有 #image
        if (cmsProject.getDetails().contains("#image")) {
            //将所有 #image替换成 data:imagge
            cmsProject.setDetails(cmsProject.getDetails().replaceAll("#image", "data:image"));
        }


        CmsProject check = baseMapper.checkWeight(cmsProject.getWeight());
        if (ObjectUtil.isNotNull(check) && !check.getBusinessId().equals(cmsProject.getBusinessId())) {
            throw new CyServiceException(500, "排序已存在");
        } else {
            int line = baseMapper.updateById(cmsProject);
            log.debug(CyUserUtil.getAuthenUsername() + "修改了ID为" + cmsProject.getBusinessId() + "的项目案例信息");
            return new CyPersistModel(line);
        }
    }

    /**
     * 根据id查询 项目案例
     *
     * @param id
     * @return
     */
    @Override
    public CmsProject findById(Integer id) {
        CmsProject cmsProject = baseMapper.selectById(id);
        if (cmsProject.getPath() != null) {
            cmsProject.setPath(global.getBase_Discovery() + cmsProject.getPath());
        }
        return cmsProject;
    }

    /**
     * 分页查询 项目案例
     *
     * @param cmsProject
     * @return
     */
    @Override
    public IPage<CmsProject> findAllByPagination(CyPageInfo<CmsProject> paginationUtility,
                                                 CmsProject cmsProject) {
        IPage<CmsProject> result = baseMapper.queryCmsProjectsPaged(paginationUtility, cmsProject);
        List<CmsProject> cmsProjectList = result.getRecords();
        for (CmsProject project : cmsProjectList) {
            if (project.getPath() != null) {
                project.setPath(global.getBase_Discovery() + project.getPath());
            }
        }
        result.setRecords(cmsProjectList);
        return result;

    }

    /**
     * 查询list 项目案例
     *
     * @param cmsProject
     * @return
     */
    @Override
    public List<CmsProject> findAll(CmsProject cmsProject) {
        return baseMapper.queryCmsProjects(cmsProject);

    }

    /**
     * 导出项目案例
     *
     * @return
     */
    @Override
    public List<CmsProject> export(CmsProject cmsProject) {
        List<CmsProject> cmsProjectList = baseMapper.queryCmsProjects(cmsProject);
        return cmsProjectList;
    }

    @Override
    public CyPersistModel updateStatus(CmsProject cmsProject) {
        int line = baseMapper.updateStatus(cmsProject);
        log.debug(CyUserUtil.getAuthenUsername() + "修改了ID为" + cmsProject.getBusinessId() + "的项目案例状态");
        return new CyPersistModel(line);
    }

}
