package org.rcisoft.business.ossinfo.controller;


/*固定导入*/

import com.aliyuncs.exceptions.ClientException;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.business.bfile.entity.BFile;
import org.rcisoft.business.ossinfo.entity.OssInfo;
import org.rcisoft.business.ossinfo.service.OssInfoService;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.core.util.CyResultGenUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.IOException;
import java.util.List;

/**
 * Created by cy on 2024年3月26日 下午5:06:30.
 */
@RestController
@RequestMapping("/ossinfo")
public class OssInfoController extends CyPaginationController<OssInfo> {


    @Autowired
    private OssInfoService ossInfoServiceImpl;

    //@PreAuthorize("@cyPerm.hasPerm('sys:info:add')")
    @CyOpeLogAnno(title = "system-OssInfo管理-新增OssInfo", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value = "添加OssInfo", notes = "添加OssInfo")
    @PostMapping(value = "/add")
    public CyResult add(@Valid OssInfo ossInfo, BindingResult bindingResult) {
        CyPersistModel data = ossInfoServiceImpl.persist(ossInfo);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                ossInfo);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:info:delete')")
    @CyOpeLogAnno(title = "system-OssInfo管理-删除OssInfo", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value = "删除OssInfo", notes = "删除OssInfo")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable Integer businessId, OssInfo ossInfo) {
        ossInfo.setBusinessId(businessId);
        CyPersistModel data = ossInfoServiceImpl.remove(ossInfo);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:info:update')")
    @CyOpeLogAnno(title = "system-OssInfo管理-修改OssInfo", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value = "修改OssInfo", notes = "修改OssInfo")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable Integer businessId, @Valid OssInfo ossInfo, BindingResult bindingResult) {
        ossInfo.setBusinessId(businessId);
        CyPersistModel data = ossInfoServiceImpl.merge(ossInfo);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                ossInfo);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:info:query')")
    @CyOpeLogAnno(title = "system-OssInfo管理-查询OssInfo", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询单一OssInfo", notes = "查询单一OssInfo")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable String businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                ossInfoServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:info:list')")
    @CyOpeLogAnno(title = "system-OssInfo管理-查询OssInfo", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询OssInfo集合", notes = "查询OssInfo集合")
    @GetMapping(value = "/queryOssInfos")
    public CyResult queryOssInfos(OssInfo ossInfo) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                ossInfoServiceImpl.findAll(ossInfo));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:info:list')")
    @CyOpeLogAnno(title = "system-OssInfo管理-查询OssInfo", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "分页查询OssInfo集合", notes = "分页查询OssInfo集合")
    @GetMapping(value = "/queryOssInfoByPagination")
    public CyGridModel listByPagination(OssInfo ossInfo) {
        ossInfoServiceImpl.findAllByPagination(getPaginationUtility(), ossInfo);
        return getGridModelResponse();
    }

    @CyOpeLogAnno(title = "system-OssInfo管理-查询OssInfo", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出OssInfo信息", notes = "导出OssInfo信息")
    @GetMapping(value = "/export")
    public void outOssInfo(HttpServletResponse response, OssInfo ossInfo, @PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName = "";
        switch (excelId) {
            case "0":
                excelName = "OssInfo信息.xls";
                break;
            case "1":
                excelName = "OssInfo信息.xlsx";
                break;
            case "2":
                excelName = "OssInfo信息.csv";
                break;
        }
        List<OssInfo> ossInfoList = ossInfoServiceImpl.export(ossInfo);
        CyEpExcelUtil.exportExcel(ossInfoList, "OssInfo信息", "OssInfo信息", OssInfo.class, excelName, response);
    }

    //阿里云视频上传
    @CyOpeLogAnno(title = "system-OssInfo管理-上传文件", businessType = CyLogTypeEnum.IMPORT)
    @ApiOperation(value = "上传文件", notes = "上传文件")
    @PostMapping(value = "/upload")
    public CyResult upload(BFile bFile, String temp, String videoType) throws IOException, ClientException {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                ossInfoServiceImpl.upload(bFile, temp, videoType)
        );
    }

    //视频上传完成后保存
    @CyOpeLogAnno(title = "system-OssInfo管理-上传文件", businessType = CyLogTypeEnum.IMPORT)
    @ApiOperation(value = "上传文件", notes = "上传文件")
    @PostMapping(value = "/updateVideo")
    public CyResult uploadVideo(BFile bFile, String temp) throws IOException, ClientException {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                ossInfoServiceImpl.uploadVideo(bFile, temp)
        );
    }

    //阿里云课程文件上传
    @CyOpeLogAnno(title = "system-OssInfo管理-上传文件", businessType = CyLogTypeEnum.IMPORT)
    @ApiOperation(value = "上传文件", notes = "上传文件")
    @PostMapping(value = "/uploadCourse")
    public CyResult uploadCourse(BFile bFile, String temp, HttpServletRequest request) throws IOException {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                ossInfoServiceImpl.uploadCourse(bFile, temp, request)
        );
    }

    //上传本地视频文件到oss
    @CyOpeLogAnno(title = "system-OssInfo管理-上传视频文件", businessType = CyLogTypeEnum.IMPORT)
    @ApiOperation(value = "上传视频文件到OSS", notes = "上传视频文件到OSS")
    @PostMapping(value = "/uploadVideoToOss")
    public CyResult uploadVideoToOss(String lessonId, String chapterId) throws IOException {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                ossInfoServiceImpl.uploadVideoToOss(lessonId, chapterId,"classVideo")
        );
    }

    //上传课程资料文件到oss
    @CyOpeLogAnno(title = "system-OssInfo管理-上传课程资料", businessType = CyLogTypeEnum.IMPORT)
    @ApiOperation(value = "上传课程资料到OSS", notes = "上传课程资料到OSS")
    @PostMapping(value = "/uploadZipToOss")
    public CyResult uploadZipToOss(String lessonId, String chapterId) throws IOException {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                ossInfoServiceImpl.uploadZipToOss(lessonId, chapterId,"classZip")
        );
    }
}
