package org.rcisoft.business.ossinfo.service.impl;

import cn.hutool.core.date.DateUtil;
import com.aliyun.oss.ClientBuilderConfiguration;
import com.aliyun.oss.HttpMethod;
import com.aliyun.oss.OSS;
import com.aliyun.oss.OSSClientBuilder;
import com.aliyun.oss.common.auth.CredentialsProviderFactory;
import com.aliyun.oss.common.auth.STSAssumeRoleSessionCredentialsProvider;
import com.aliyun.oss.common.comm.Protocol;
import com.aliyun.oss.internal.OSSHeaders;
import com.aliyun.oss.model.GeneratePresignedUrlRequest;
import com.aliyun.oss.model.PutObjectRequest;
import com.aliyuncs.exceptions.ClientException;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import io.swagger.models.auth.In;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.io.FileUtils;
import org.apache.commons.lang3.StringUtils;
import org.apache.http.entity.ContentType;
import org.rcisoft.business.bfile.dao.BFileRepository;
import org.rcisoft.business.bfile.entity.BFile;
import org.rcisoft.business.ossinfo.dao.OssInfoRepository;
import org.rcisoft.business.ossinfo.entity.OssInfo;
import org.rcisoft.business.ossinfo.service.OssInfoService;
import org.rcisoft.common.component.Global;
import org.rcisoft.common.component.OssGlobal;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.result.ResultServiceEnums;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.mock.web.MockMultipartFile;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;

import javax.servlet.http.HttpServletRequest;
import java.io.*;
import java.net.HttpURLConnection;
import java.net.URL;
import java.net.URLConnection;
import java.nio.ByteBuffer;
import java.nio.channels.Channels;
import java.nio.channels.ReadableByteChannel;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.nio.file.StandardCopyOption;
import java.text.SimpleDateFormat;
import java.util.*;

/**
 * Created by cy on 2024年3月26日 下午5:06:30.
 */
@Service
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class OssInfoServiceImpl extends ServiceImpl<OssInfoRepository, OssInfo> implements OssInfoService {

    @Autowired
    private BFileRepository bFileRepository;
    @Autowired
    private OssInfoRepository ossInfoRepository;
    @Autowired
    private OssGlobal ossGlobal;
    @Autowired
    private Global global;

    /**
     * 保存
     *
     * @param ossInfo
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(OssInfo ossInfo) {
        //增加操作
        int line = baseMapper.insert(ossInfo);
        log.debug(CyUserUtil.getAuthenUsername() + "新增了ID为" +
                ossInfo.getBusinessId() + "的信息");
        return new CyPersistModel(line);
    }

    /**
     * 删除
     *
     * @param ossInfo
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(OssInfo ossInfo) {
        int line = baseMapper.realDelete(ossInfo);
        log.debug(CyUserUtil.getAuthenUsername() + "删除了ID为" +
                ossInfo.getBusinessId() + "的信息");
        return new CyPersistModel(line);
    }

    /**
     * 修改
     *
     * @param ossInfo
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(OssInfo ossInfo) {
        int line = baseMapper.updateById(ossInfo);
        log.debug(CyUserUtil.getAuthenUsername() + "修改了ID为" + ossInfo.getBusinessId() + "的信息");
        return new CyPersistModel(line);
    }

    /**
     * 根据id查询
     *
     * @param id
     * @return
     */
    @Override
    public OssInfo findById(String id) {
        return baseMapper.selectById(id);
    }

    /**
     * 分页查询
     *
     * @param ossInfo
     * @return
     */
    @Override
    public IPage<OssInfo> findAllByPagination(CyPageInfo<OssInfo> paginationUtility,
                                              OssInfo ossInfo) {
        return baseMapper.queryOssInfosPaged(paginationUtility, ossInfo);

    }

    /**
     * 查询list
     *
     * @param ossInfo
     * @return
     */
    @Override
    public List<OssInfo> findAll(OssInfo ossInfo) {
        return baseMapper.queryOssInfos(ossInfo);

    }

    /**
     * 导出
     *
     * @return
     */
    @Override
    public List<OssInfo> export(OssInfo ossInfo) {
        List<OssInfo> ossInfoList = baseMapper.queryOssInfos(ossInfo);
        return ossInfoList;
    }

    //阿里云私有桶上传
    @Override
    public Object upload(BFile bFile, String temp, String videoType) throws ClientException {
        String endPoint = ossGlobal.getEndpoint();
        String accessKeyId = ossGlobal.getPutAcessKey();
        String accessKeySecret = ossGlobal.getPutSecretKey();
        String bucketName = ossGlobal.getBucket();
        String roleArn = ossGlobal.getPutRam();
//        String urlOss = "https://catarc-res.oss-cn-beijing.aliyuncs.com/";
        String urlOss = ossGlobal.getRequest() + ossGlobal.getBucket() + "." + ossGlobal.getEndpoint() + "/";
        String objectName = temp + "/" + new SimpleDateFormat("yyyy-MM-dd").format(new Date()) + "/";
        String regionId = ossGlobal.getRegionId();
        //uuid 生成随机文件名 去掉所有的“-”
        String uuid = UUID.randomUUID().toString().replaceAll("-", "");
        //获取文件名
        String fileName = bFile.getVideoName();
        //获取文件名称后缀
        String suffix = fileName.substring(fileName.lastIndexOf("."));
        try {
            //STS 创建链接
            STSAssumeRoleSessionCredentialsProvider stsAssumeRoleSessionCredentialsProvider = CredentialsProviderFactory
                    .newSTSAssumeRoleSessionCredentialsProvider(regionId, accessKeyId, accessKeySecret, roleArn);
            //创建链接
            ClientBuilderConfiguration clientConfig = new ClientBuilderConfiguration();
            clientConfig.setProtocol(Protocol.HTTPS); // 设置使用 HTTPS 协议
            OSS ossClient = new OSSClientBuilder().build(endPoint, stsAssumeRoleSessionCredentialsProvider, clientConfig);
            // 设置请求头。
            Map<String, String> headers = new HashMap<String, String>();
            headers.put(OSSHeaders.CONTENT_TYPE, videoType);
            long expireTime = 30;
            long expireEndTime = System.currentTimeMillis() + expireTime * 1000;
            Date expiration = new Date(expireEndTime);
            // 指定生成的签名URL过期时间，单位为毫秒。本示例以设置过期时间为1小时为例。
            // 生成签名URL。
//            GeneratePresignedUrlRequest request = new GeneratePresignedUrlRequest(bucketName, objectName + uuid + "." + suffix, HttpMethod.PUT);
            GeneratePresignedUrlRequest request = new GeneratePresignedUrlRequest(bucketName, objectName + uuid + suffix, HttpMethod.PUT);
            request.setExpiration(expiration);
            // 将请求头加入到request中。
            request.setHeaders(headers);
            // 通过HTTP PUT请求生成签名URL。
            URL url = ossClient.generatePresignedUrl(request);
            Map<String, String> map = new HashMap<>();
            map.put("url", url.toString());
            map.put("objectName", urlOss + objectName);
            map.put("uuidVideoName", uuid + suffix);
            // ossInfo存储
            OssInfo ossInfo = new OssInfo();
            //桶名称
            ossInfo.setBucket(ossGlobal.getBucket());
            //文件夹路径
            ossInfo.setPath(objectName + uuid + suffix);
            //当前文件名
            ossInfo.setOssKey(uuid + "." + suffix);
            //url
            ossInfo.setUrl(ossGlobal.getRequest() + ossGlobal.getEndpoint() + "/" + objectName + uuid + suffix);
            //文件大小
            ossInfo.setFileSize(bFile.getFileSize());
            //文件类型
            ossInfo.setFileType(suffix);
            //文件真实名称
            ossInfo.setOriginalName(fileName);
            //flag
            ossInfo.setFlag(String.valueOf(1));
            baseMapper.insert(ossInfo);
            map.put("ossInfoId", String.valueOf(ossInfo.getBusinessId()));
            return map;
        } catch (ClientException e) {
            throw new RuntimeException(e);
        }
    }

    @Override
    public Object uploadCourse(BFile bFile, String temp, HttpServletRequest request) {
        List<MultipartFile> list = ((MultipartHttpServletRequest) request).getFiles("file");
        String dataUrl = "";
        if (list.size() > 0) {
            try {
                //查询此课程是否有课程文件
                BFile dataFile = bFileRepository.selectInfoByBLessonId(bFile.getLessonId());
                //此课程下是有课程文件
                if (dataFile != null) {
                    //上传课程资料并保存
                    BFile newVideo = this.uploadVideoToServer(list, dataFile, temp);
                    newVideo.setBusinessId(dataFile.getBusinessId());
                    CyUserUtil.setCurrentMergeOperation(newVideo);
                    bFileRepository.updateById(newVideo);//更新表中信息
                    dataUrl = newVideo.getFileUrl();
                } else {
                    //上传文件
                    BFile newFile = this.uploadVideoToServer(list, bFile, temp);
                    //如果上传课程资料，插入章节id为-1
                    newFile.setChapterId("-1");
                    //插入表信息
                    bFileRepository.insert(newFile);
                    dataUrl = newFile.getFileUrl();
                }
            } catch (Exception e) {
                e.printStackTrace();
                throw new CyServiceException(ResultServiceEnums.UPLOAD_ERROR.getCode()
                        , ResultServiceEnums.UPLOAD_ERROR.getMessage());
            }
        }
        return dataUrl;
    }

    @Override
    public Object uploadVideo(BFile bFile, String temp) {
        BFile video = bFileRepository.selectInfoByChapterIdAndLessonId(bFile.getChapterId(), bFile.getLessonId());
        //没有新增  有修改
        if (video == null) {
            //判断是视频还是资料
            if (bFile.getType().equals("0")) {
                BFile newVideo = new BFile();
                newVideo.setLessonId(bFile.getLessonId());
                newVideo.setChapterId(bFile.getChapterId());
                newVideo.setVideoUrl(bFile.getVideoUrl());
                newVideo.setType("0");
                CyUserUtil.setCurrentMergeOperation(newVideo);
                bFileRepository.insert(bFile);
                return newVideo.getVideoUrl();
            } else if (bFile.getType().equals("1")) {
                BFile newVideo = new BFile();
                newVideo.setLessonId(bFile.getLessonId());
                newVideo.setChapterId("-1");
                newVideo.setType("0");
                CyUserUtil.setCurrentMergeOperation(newVideo);
                bFileRepository.insert(bFile);
                return newVideo.getVideoUrl();
            }
        } else {
            //判断是视频还是资料
            if (bFile.getType().equals("0")) {
                video.setVideoUrl(bFile.getVideoUrl());
                bFileRepository.updateById(video);
                return video.getVideoUrl();
            } else if (bFile.getType().equals("1")) {
                //拼接字符串
                video.setFileUrl(video.getFileUrl() + "," + bFile.getFileUrl());
                bFileRepository.updateById(video);
                return video.getFileUrl();
            }
        }
        return null;
    }


    private BFile uploadVideoToServer(List<MultipartFile> fileList, BFile bFile, String temp) {
        ArrayList<String> ossInfos = new ArrayList<>();
        //批量文件上传，可能会用在学习资料中 视频还一个
        for (MultipartFile file : fileList) {
            //将当前时间转化为 年月日
            String date = DateUtil.format(new Date(), "yyyyMMdd");
            //uuid 生成随机文件名 去掉所有的“-”
            String uuid = UUID.randomUUID().toString().replaceAll("-", "");
            //获取文件名
            String fileName = file.getOriginalFilename();
            //获取文件名称后缀
            String suffix = fileName.substring(fileName.lastIndexOf(".") + 1);
            //组装url
            //url 前
            String urlHead = ossGlobal.getRequest() + ossGlobal.getEndpoint();
            //url 后  文件夹/日期（yyyyMMDD）/文件名
            String urlTail = temp + "/" + date + "/" + uuid + "." + suffix;
            // 创建 OSSClient 实例
            OSS ossClient = new OSSClientBuilder().build(urlHead, ossGlobal.getPutAcessKey(), ossGlobal.getPutSecretKey());
            try {
                // 创建 PutObjectRequest 对象
                PutObjectRequest putObjectRequest = new PutObjectRequest(ossGlobal.getBucket(), urlTail, file.getInputStream());
                // 上传文件
                ossClient.putObject(putObjectRequest);
            } catch (IOException e) {
                throw new CyServiceException(ResultServiceEnums.UPLOAD_ERROR.getCode(), ResultServiceEnums.UPLOAD_ERROR.getMessage());
            } finally {
                // 关闭 OSSClient 实例
                ossClient.shutdown();
            }
            //创建oss info 存储
            OssInfo ossInfo = new OssInfo();
            //桶名称
            ossInfo.setBucket(ossGlobal.getBucket());
            //文件夹路径
            ossInfo.setPath(urlTail);
            //当前文件名
            ossInfo.setOssKey(uuid + "." + suffix);
            //url
            ossInfo.setUrl(urlHead + "/" + urlTail);
            //文件大小
            ossInfo.setFileSize((int) file.getSize());
            //文件类型
            ossInfo.setFileType(suffix);
            //文件真实名称
            ossInfo.setOriginalName(fileName);
            //flag
            ossInfo.setFlag(String.valueOf(1));
            baseMapper.insert(ossInfo);
            ossInfos.add(String.valueOf(ossInfo.getBusinessId()));
        }
        if (!CollectionUtils.isEmpty(ossInfos)) {
            if (bFile.getType().equals("0")) {
                //上传文件id
                bFile.setVideoUrl(StringUtils.strip(ossInfos.toString(), "[]"));
            } else if (bFile.getType().equals("1")) {

                //涉及多次上传文件
                if (StringUtils.isEmpty(bFile.getFileUrl())) {
                    bFile.setFileUrl(StringUtils.strip(ossInfos.toString(), "[]"));
                } else {
                    bFile.setFileUrl(bFile.getFileUrl() + "," + StringUtils.strip(ossInfos.toString(), "[]"));
                }
//                //pdf涉及多次上传文件
//                if (StringUtils.isEmpty(bFile.getPdfUrl())) {
//                    //pdf路径
//                    bFile.setPdfUrl(StringUtils.strip(ossInfos.toString(), "[]"));
//                } else {
//                    bFile.setPdfUrl(bFile.getPdfUrl() + "," + StringUtils.strip(ossInfos.toString(), "[]"));
//                }
            }
        }
        return bFile;
    }

    /**
     * 将网络文件转换为文件流
     * @param imageUrl
     * @return
     */
    public static MultipartFile fileUrlConvertToMultipartFile(String imageUrl) {
        try {
            // 将在线图片地址转换为URL对象
            URL url = new URL(imageUrl);
            // 打开URL连接
            URLConnection connection = url.openConnection();
            // 转换为HttpURLConnection对象
            HttpURLConnection httpURLConnection = (HttpURLConnection) connection;
            // 获取输入流
            InputStream inputStream = httpURLConnection.getInputStream();
            // 读取输入流中的数据，并保存到字节数组中
            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
            byte[] buffer = new byte[1024];
            int bytesRead;
            while ((bytesRead = inputStream.read(buffer)) != -1) {
                byteArrayOutputStream.write(buffer, 0, bytesRead);
            }
            // 将字节数组转换为字节数组
            byte[] bytes = byteArrayOutputStream.toByteArray();
            // 创建ByteArrayInputStream对象，将字节数组传递给它
            ByteArrayInputStream byteArrayInputStream = new ByteArrayInputStream(bytes);
            // 创建MultipartFile对象，将ByteArrayInputStream对象作为构造函数的参数
            MultipartFile multipartFile = new MockMultipartFile("file", "filename.mp4", "video/mp4", byteArrayInputStream);
            return multipartFile;
        }catch (IOException ex){
            ex.printStackTrace();
        }
        return null;
    }

    public BFile uploadZipToOss(String lessonId, String chapterId, String temp) {
        BFile bFile = bFileRepository.selectOne(new QueryWrapper<BFile>()
                .eq("lesson_id", lessonId)
                .eq("chapter_id", "-1"));
        if (Objects.isNull(bFile)) {
            return null;
        } else {
            String fileUrl = bFile.getFileUrl();
            String[] urlArray = fileUrl.split(","); // 使用逗号分割字符串
            ArrayList<OssInfo> ossInfos = new ArrayList<>();
            for (String url : urlArray) {
                OssInfo ossInfo = ossInfoRepository.selectById(url);
                if (ossInfo != null) {
                    if (ossInfo.getBucket() != null) {
                        //桶不为空 证明上传到oss了
                        break;
                    } else {
                        String filePath = global.getBase_Discovery() + ossInfo.getPath();
                        MultipartFile multipartFile = fileUrlConvertToMultipartFile(filePath);
                        File file = new File(filePath);
                        InputStream stream = null;
                        try {
                            stream = multipartFile.getInputStream();
                        } catch (IOException e) {
                            e.printStackTrace();
                        }
                        //将当前时间转化为 年月日
                        String date = DateUtil.format(new Date(), "yyyy-MM-dd");
                        //uuid 生成随机文件名 去掉所有的“-”
                        String uuid = UUID.randomUUID().toString().replaceAll("-", "");
                        //获取文件名
                        String fileName = file.getName();
                        //获取文件名称后缀
                        String suffix = fileName.substring(fileName.lastIndexOf(".") + 1);
                        //组装url
                        //url 前
                        String urlHead = ossGlobal.getRequest() + ossGlobal.getEndpoint();
                        //url 后  文件夹/日期（yyyyMMDD）/文件名
//            String urlTail = temp + "/" + date + "/" + uuid + "." + suffix;
                        String urlTail = temp + "/" + date + "/" + uuid + "." + suffix;
                        // 创建 OSSClient 实例
                        OSS ossClient = new OSSClientBuilder().build(urlHead, ossGlobal.getPutAcessKey(), ossGlobal.getPutSecretKey());
                        try {
                            // 创建 PutObjectRequest 对象
                            PutObjectRequest putObjectRequest = new PutObjectRequest(ossGlobal.getBucket(), urlTail, stream);
                            // 上传文件
                            ossClient.putObject(putObjectRequest);
                        } finally {
                            // 关闭 OSSClient 实例
                            ossClient.shutdown();
                        }
                        //桶名称
                        ossInfo.setBucket(ossGlobal.getBucket());
                        //文件夹路径
                        ossInfo.setPath(urlTail);
                        ossInfo.setUrl(ossGlobal.getRequest() + ossGlobal.getEndpoint() + "/" + urlTail);
                        baseMapper.updateById(ossInfo);
                    }
                }
            }
        }
        return null;
    }


    public BFile uploadVideoToOss(String lessonId, String chapterId, String temp) {
        List<OssInfo> bFiles = ossInfoRepository.selectInfoAllPath(lessonId, chapterId);
        //如果bFiles的长度大于0
        if (bFiles.size() > 0) {
            for (OssInfo ossInfo : bFiles) {
                if (ossInfo.getBucket() != null) {
                    //桶不为空 证明上传到oss了
                    continue;
                } else {
                    String filePath = global.getBase_Discovery() + ossInfo.getPath();
                    MultipartFile multipartFile = fileUrlConvertToMultipartFile(filePath);
                    File file = new File(filePath);
                    InputStream stream = null;
                    try {
                        stream = multipartFile.getInputStream();
                    } catch (IOException e) {
                        e.printStackTrace();
                    }
                    //将当前时间转化为 年月日
                    String date = DateUtil.format(new Date(), "yyyy-MM-dd");
                    //uuid 生成随机文件名 去掉所有的“-”
                    String uuid = UUID.randomUUID().toString().replaceAll("-", "");
                    //获取文件名
                    String fileName = file.getName();
                    //获取文件名称后缀
                    String suffix = fileName.substring(fileName.lastIndexOf(".") + 1);
                    //组装url
                    //url 前
                    String urlHead = ossGlobal.getRequest() + ossGlobal.getEndpoint();
                    //url 后  文件夹/日期（yyyyMMDD）/文件名
//            String urlTail = temp + "/" + date + "/" + uuid + "." + suffix;
                    String urlTail = temp + "/" + date + "/" + uuid + "." + suffix;
                    // 创建 OSSClient 实例
                    OSS ossClient = new OSSClientBuilder().build(urlHead, ossGlobal.getPutAcessKey(), ossGlobal.getPutSecretKey());
                    try {
                        // 创建 PutObjectRequest 对象
                        PutObjectRequest putObjectRequest = new PutObjectRequest(ossGlobal.getBucket(), urlTail, stream);
                        // 上传文件
                        ossClient.putObject(putObjectRequest);
                    } finally {
                        // 关闭 OSSClient 实例
                        ossClient.shutdown();
                    }
                    //桶名称
                    ossInfo.setBucket(ossGlobal.getBucket());
                    //文件夹路径
                    ossInfo.setPath(urlTail);
                    ossInfo.setUrl(ossGlobal.getRequest() + ossGlobal.getEndpoint() + "/" + urlTail);
                    baseMapper.updateById(ossInfo);
                }
            }
        }
        return null;
    }
}
