package org.rcisoft.business.pcfeedexamflag.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.rcisoft.business.pcfeedexamflag.dao.PcFeedExamFlagRepository;
import org.rcisoft.business.pcfeedexamflag.entity.PcFeedExamFlag;
import org.rcisoft.business.pcfeedexamflag.service.PcFeedExamFlagService;
import org.rcisoft.business.teaexamexaminationpaper.entity.TeaExamExaminationPaper;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyUserUtil;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.ObjectUtils;

import java.util.List;

/**
 * Created by cy on 2024年4月13日 下午4:05:03.
 */
@Service
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class PcFeedExamFlagServiceImpl extends ServiceImpl<PcFeedExamFlagRepository, PcFeedExamFlag> implements PcFeedExamFlagService {


    /**
     * 保存 课程学习完成意见,考核提示标识表
     *
     * @param pcFeedExamFlag
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(PcFeedExamFlag pcFeedExamFlag) {
        //增加操作
        int line = baseMapper.insert(pcFeedExamFlag);
        log.debug(CyUserUtil.getAuthenUsername() + "新增了ID为" +
                pcFeedExamFlag.getBusinessId() + "的课程学习完成意见,考核提示标识表信息");
        return new CyPersistModel(line);
    }

    /**
     * 删除 课程学习完成意见,考核提示标识表
     *
     * @param pcFeedExamFlag
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(PcFeedExamFlag pcFeedExamFlag) {
        int line = baseMapper.realDelete(pcFeedExamFlag);
        log.debug(CyUserUtil.getAuthenUsername() + "删除了ID为" +
                pcFeedExamFlag.getBusinessId() + "的课程学习完成意见,考核提示标识表信息");
        return new CyPersistModel(line);
    }

    /**
     * 逻辑删除 课程学习完成意见,考核提示标识表
     *
     * @param pcFeedExamFlag
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(PcFeedExamFlag pcFeedExamFlag) {
        pcFeedExamFlag.setDeleted();
        int line = baseMapper.deleteById(pcFeedExamFlag);
        log.debug(CyUserUtil.getAuthenUsername() + "逻辑删除了ID为" +
                pcFeedExamFlag.getBusinessId() + "的课程学习完成意见,考核提示标识表信息");
        return new CyPersistModel(line);
    }

    /**
     * 修改 课程学习完成意见,考核提示标识表
     *
     * @param pcFeedExamFlag
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(PcFeedExamFlag pcFeedExamFlag) {
        int line = baseMapper.updateById(pcFeedExamFlag);
        log.debug(CyUserUtil.getAuthenUsername() + "修改了ID为" + pcFeedExamFlag.getBusinessId() + "的课程学习完成意见,考核提示标识表信息");
        return new CyPersistModel(line);
    }

    /**
     * 根据id查询 课程学习完成意见,考核提示标识表
     *
     * @param id
     * @return
     */
    @Override
    public PcFeedExamFlag findById(String id) {
        return baseMapper.selectById(id);
    }

    /**
     * 分页查询 课程学习完成意见,考核提示标识表
     *
     * @param pcFeedExamFlag
     * @return
     */
    @Override
    public IPage<PcFeedExamFlag> findAllByPagination(CyPageInfo<PcFeedExamFlag> paginationUtility,
                                                     PcFeedExamFlag pcFeedExamFlag) {
        return baseMapper.queryPcFeedExamFlagsPaged(paginationUtility, pcFeedExamFlag);

    }

    /**
     * 查询list 课程学习完成意见,考核提示标识表
     *
     * @param pcFeedExamFlag
     * @return
     */
    @Override
    public List<PcFeedExamFlag> findAll(PcFeedExamFlag pcFeedExamFlag) {
        return baseMapper.queryPcFeedExamFlags(pcFeedExamFlag);

    }

    /**
     * 导出课程学习完成意见,考核提示标识表
     *
     * @return
     */
    @Override
    public List<PcFeedExamFlag> export(PcFeedExamFlag pcFeedExamFlag) {
        List<PcFeedExamFlag> pcFeedExamFlagList = baseMapper.queryPcFeedExamFlags(pcFeedExamFlag);
        return pcFeedExamFlagList;
    }

    /**
     * 添加/修改课程学习完成意见,考核提示标识表
     *
     * @param pcFeedExamFlag
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel addOrUpdate(PcFeedExamFlag pcFeedExamFlag) {
        //查询是否存在
        QueryWrapper<PcFeedExamFlag> qw = new QueryWrapper<>();
        qw.eq("user_id", pcFeedExamFlag.getUserId())
                .eq("lesson_id", pcFeedExamFlag.getLessonId());
        PcFeedExamFlag pcFeedExamFlagNew = baseMapper.selectOne(qw);

        if (ObjectUtils.isEmpty(pcFeedExamFlagNew)) {
            //增加
            return persist(pcFeedExamFlag);
        } else {
            //修改
            pcFeedExamFlag.setBusinessId(pcFeedExamFlagNew.getBusinessId());
            return merge(pcFeedExamFlag);
        }
    }

    /**
     * 根据用户id以及课程id查询课程学习完成意见,考核提示标识表
     *
     * @param pcFeedExamFlag
     * @return
     */
    @Override
    public PcFeedExamFlag findByOne(PcFeedExamFlag pcFeedExamFlag) {
        pcFeedExamFlag = baseMapper.selectOne(
                new QueryWrapper<PcFeedExamFlag>()
                        .eq(pcFeedExamFlag.getUserId() != null, "user_id", pcFeedExamFlag.getUserId())
                        .eq(pcFeedExamFlag.getLessonId() != null, "lesson_id", pcFeedExamFlag.getLessonId())
                        .eq("del_flag", 0));
        return pcFeedExamFlag;
    }

    /**
     * 在用户保存试卷的时候，将学习状态修改成为已经考完试的状态
     */
    @Override
    public void examCompleted(TeaExamExaminationPaper paperQueryWrapper) {
        baseMapper.examCompleted(paperQueryWrapper);
    }

}
