package org.rcisoft.business.pclessonbrowse.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.business.blesson.entity.BLesson;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.core.util.PageUtil;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.exception.CyServiceException;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;


import org.rcisoft.business.pclessonbrowse.entity.PcLessonBrowse;
import org.rcisoft.business.pclessonbrowse.service.PcLessonBrowseService;

import java.util.List;

/**
* Created by cy on 2024年4月13日 下午1:12:55.
*/
@RestController
@RequestMapping("/pclessonbrowse")
public class PcLessonBrowseController extends CyPaginationController<PcLessonBrowse> {


    @Autowired
    private PcLessonBrowseService pcLessonBrowseServiceImpl;

    /**
     * 进入课程详情添加课程浏览记录
     * @param pcLessonBrowse
     * @param bindingResult
     * @return
     */
    //@PreAuthorize("@cyPerm.hasPerm('sys:essonBrowse:add')")
    @CyOpeLogAnno(title = "system-课程浏览记录表管理-新增课程浏览记录表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="添加课程浏览记录表", notes="添加课程浏览记录表")
    @PostMapping(value = "/add")
    public CyResult add(@Valid PcLessonBrowse pcLessonBrowse, BindingResult bindingResult) {
        CyPersistModel data = pcLessonBrowseServiceImpl.persist(pcLessonBrowse);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        pcLessonBrowse);
    }

    /**
     * 查询用户的浏览记录
     * @param pcLessonBrowse
     * @return
     */
    //@PreAuthorize("@cyPerm.hasPerm('sys:essonBrowse:list')")
    @CyOpeLogAnno(title = "system-课程浏览记录表管理-查询课程浏览记录表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="分页查询课程浏览记录表集合", notes="分页查询课程浏览记录表集合")
    @GetMapping(value = "/list")
    public CyGridModel listByPagination(PcLessonBrowse pcLessonBrowse) {
//        CyPageInfo<BLesson> pageInfo = PageUtil.getPageInfo(request);
        pcLessonBrowseServiceImpl.findAllByPagination(getPaginationUtility(), pcLessonBrowse);
        return getGridModelResponse();
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:essonBrowse:list')")
    @CyOpeLogAnno(title = "system-课程浏览记录表管理-查询课程浏览记录表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询课程浏览记录表集合", notes="查询课程浏览记录表集合")
    @GetMapping(value = "/listAll")
    public CyResult listAll(PcLessonBrowse pcLessonBrowse) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                pcLessonBrowseServiceImpl.findAll(pcLessonBrowse));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:essonBrowse:delete')")
    @CyOpeLogAnno(title = "system-课程浏览记录表管理-删除课程浏览记录表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="逻辑删除课程浏览记录表", notes="逻辑删除课程浏览记录表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable Integer businessId,PcLessonBrowse pcLessonBrowse) {
        pcLessonBrowse.setBusinessId(businessId);
        CyPersistModel data = pcLessonBrowseServiceImpl.removeLogical(pcLessonBrowse);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:essonBrowse:delete')")
    @CyOpeLogAnno(title = "system-课程浏览记录表管理-删除课程浏览记录表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="删除课程浏览记录表", notes="删除课程浏览记录表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable Integer businessId,PcLessonBrowse pcLessonBrowse) {
        pcLessonBrowse.setBusinessId(businessId);
        CyPersistModel data = pcLessonBrowseServiceImpl.remove(pcLessonBrowse);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:essonBrowse:update')")
    @CyOpeLogAnno(title = "system-课程浏览记录表管理-修改课程浏览记录表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改课程浏览记录表", notes="修改课程浏览记录表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable Integer businessId, @Valid PcLessonBrowse pcLessonBrowse, BindingResult bindingResult) {
        pcLessonBrowse.setBusinessId(businessId);
        CyPersistModel data = pcLessonBrowseServiceImpl.merge(pcLessonBrowse);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        pcLessonBrowse);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:essonBrowse:query')")
    @CyOpeLogAnno(title = "system-课程浏览记录表管理-查询课程浏览记录表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单一课程浏览记录表", notes="查询单一课程浏览记录表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable String businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        pcLessonBrowseServiceImpl.findById(businessId));
    }

    @CyOpeLogAnno(title = "system-课程浏览记录表管理-查询课程浏览记录表", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出课程浏览记录表信息", notes = "导出课程浏览记录表信息")
    @GetMapping(value = "/export")
    public void outPcLessonBrowse(HttpServletResponse response,PcLessonBrowse pcLessonBrowse,@PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="课程浏览记录表信息.xls";break;
            case "1": excelName="课程浏览记录表信息.xlsx";break;
            case "2": excelName="课程浏览记录表信息.csv";break;
        }
        List<PcLessonBrowse> pcLessonBrowseList = pcLessonBrowseServiceImpl.export(pcLessonBrowse);
        CyEpExcelUtil.exportExcel(pcLessonBrowseList, "课程浏览记录表信息", "课程浏览记录表信息", PcLessonBrowse.class, excelName, response);
    }
}
