package org.rcisoft.business.pclessonbrowse.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.rcisoft.business.blesson.entity.BLesson;
import org.rcisoft.business.pclessonbrowse.dao.PcLessonBrowseRepository;
import org.rcisoft.business.pclessonbrowse.entity.PcLessonBrowse;
import org.rcisoft.business.pclessonbrowse.service.PcLessonBrowseService;
import org.rcisoft.common.component.Global;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyUserUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * Created by cy on 2024年4月13日 下午1:12:55.
 */
@Service
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class PcLessonBrowseServiceImpl extends ServiceImpl<PcLessonBrowseRepository, PcLessonBrowse> implements PcLessonBrowseService {

    @Autowired
    private Global global;

    /**
     * 保存 课程浏览记录表
     *
     * @param pcLessonBrowse
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(PcLessonBrowse pcLessonBrowse) {
        //最多只有12条浏览记录
        List<PcLessonBrowse> pcLessonBrowseList = baseMapper.selectList(
                new QueryWrapper<PcLessonBrowse>()
                        .eq("user_id", pcLessonBrowse.getUserId())
                        .orderByDesc("update_date")
        );

        if (CollectionUtils.isNotEmpty(pcLessonBrowseList)) {
            //根据id直接物理删除数据
            if (pcLessonBrowseList.size() > 12) {
                baseMapper.deleteById(pcLessonBrowseList.get(0).getBusinessId());
            }
            //重复数据修改  不重复 添加
//            for (PcLessonBrowse lessonBrowse : pcLessonBrowseList) {
//                if (pcLessonBrowse.getLessonId().equals(lessonBrowse.getLessonId())
//                && pcLessonBrowse.getUserId().equals(lessonBrowse.getUserId())){
//                    baseMapper.updateById(pcLessonBrowse);
//                }else {
//                    //增加操作
//                    int line = baseMapper.insert(pcLessonBrowse);
//                    log.debug(CyUserUtil.getAuthenUsername() + "新增了ID为" +
//                            pcLessonBrowse.getBusinessId() + "的课程浏览记录表信息");
//                }
//            }
        } else {
            //增加操作
            int line = baseMapper.insert(pcLessonBrowse);
            log.debug(CyUserUtil.getAuthenUsername() + "新增了ID为" +
                    pcLessonBrowse.getBusinessId() + "的课程浏览记录表信息");
        }
        return new CyPersistModel(1);
    }

    @Override
    @Async
    public void persistOne(PcLessonBrowse pcLessonBrowse) {
        //最多只有12条浏览记录
        List<PcLessonBrowse> pcLessonBrowseList = baseMapper.selectList(
                new QueryWrapper<PcLessonBrowse>()
                        .eq("user_id", pcLessonBrowse.getUserId())
                        .eq("lesson_id", pcLessonBrowse.getLessonId())
                        .orderByDesc("update_date")
        );

        if (CollectionUtils.isNotEmpty(pcLessonBrowseList)) {
            //根据id直接物理删除数据
            if (pcLessonBrowseList.size() > 12) {
                baseMapper.deleteById(pcLessonBrowseList.get(0).getBusinessId());
            }
//            //重复数据修改  不重复 添加
//            for (PcLessonBrowse lessonBrowse : pcLessonBrowseList) {
//                if (pcLessonBrowse.getLessonId().equals(lessonBrowse.getLessonId())
//                        && pcLessonBrowse.getUserId().equals(lessonBrowse.getUserId())) {
//                    baseMapper.updateById(pcLessonBrowse);
//                } else {
//                    //增加操作
//                    int line = baseMapper.insert(pcLessonBrowse);
//                    log.debug(CyUserUtil.getAuthenUsername() + "新增了ID为" +
//                            pcLessonBrowse.getBusinessId() + "的课程浏览记录表信息");
//                }
//            }
            baseMapper.insert(pcLessonBrowse);
        } else {
            //增加操作
            int line = baseMapper.insert(pcLessonBrowse);
            log.debug(CyUserUtil.getAuthenUsername() + "新增了ID为" +
                    pcLessonBrowse.getBusinessId() + "的课程浏览记录表信息");
        }
    }


    /**
     * 删除 课程浏览记录表
     *
     * @param pcLessonBrowse
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(PcLessonBrowse pcLessonBrowse) {
        int line = baseMapper.realDelete(pcLessonBrowse);
        log.debug(CyUserUtil.getAuthenUsername() + "删除了ID为" +
                pcLessonBrowse.getBusinessId() + "的课程浏览记录表信息");
        return new CyPersistModel(line);
    }

    /**
     * 逻辑删除 课程浏览记录表
     *
     * @param pcLessonBrowse
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(PcLessonBrowse pcLessonBrowse) {
        pcLessonBrowse.setDeleted();
        int line = baseMapper.deleteById(pcLessonBrowse);
        log.debug(CyUserUtil.getAuthenUsername() + "逻辑删除了ID为" +
                pcLessonBrowse.getBusinessId() + "的课程浏览记录表信息");
        return new CyPersistModel(line);
    }

    /**
     * 修改 课程浏览记录表
     *
     * @param pcLessonBrowse
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(PcLessonBrowse pcLessonBrowse) {
        int line = baseMapper.updateById(pcLessonBrowse);
        log.debug(CyUserUtil.getAuthenUsername() + "修改了ID为" + pcLessonBrowse.getBusinessId() + "的课程浏览记录表信息");
        return new CyPersistModel(line);
    }

    /**
     * 根据id查询 课程浏览记录表
     *
     * @param id
     * @return
     */
    @Override
    public PcLessonBrowse findById(String id) {
        return baseMapper.selectById(id);
    }

    /**
     * 分页查询 课程浏览记录表
     *
     * @param pcLessonBrowse
     * @return
     */
    @Override
    public IPage<BLesson> findAllByPagination(CyPageInfo<PcLessonBrowse> paginationUtility,
                                              PcLessonBrowse pcLessonBrowse) {
        paginationUtility.setSize(pcLessonBrowse.getPageSize());
        paginationUtility.setCurrent(pcLessonBrowse.getPage());
        IPage<BLesson> bLessonIPage = baseMapper.queryPcLessonBrowsesPaged(paginationUtility, pcLessonBrowse);
        if (bLessonIPage.getRecords() != null) {
            List<BLesson> records = bLessonIPage.getRecords();
            for (BLesson bLesson : records) {
                if (StringUtils.isNotEmpty(bLesson.getPath())) {
                    // 配置完整图片路径
                    bLesson.setPath(global.getBase_Discovery() + bLesson.getPath());
                }
            }
        }
        return bLessonIPage;
    }

    /**
     * 查询list 课程浏览记录表
     * 根据当前登录用户 查询浏览过的课程信息
     *
     * @param pcLessonBrowse
     * @return
     */
    @Override
    public List<PcLessonBrowse> findAll(PcLessonBrowse pcLessonBrowse) {
        return baseMapper.queryPcLessonBrowses(pcLessonBrowse);
    }

    /**
     * 导出课程浏览记录表
     *
     * @return
     */
    @Override
    public List<PcLessonBrowse> export(PcLessonBrowse pcLessonBrowse) {
        List<PcLessonBrowse> pcLessonBrowseList = baseMapper.queryPcLessonBrowses(pcLessonBrowse);
        return pcLessonBrowseList;
    }

    /**
     * 用户添加题库
     */

    @Override
    public Boolean addSystemQuestion(List<PcLessonBrowse> pcLessonBrowseList) {
        return this.saveBatch(pcLessonBrowseList);
    }

}
