package org.rcisoft.business.pclessonevaluation.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.exception.CyServiceException;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;


import org.rcisoft.business.pclessonevaluation.entity.PcLessonEvaluation;
import org.rcisoft.business.pclessonevaluation.service.PcLessonEvaluationService;

import java.util.List;

/**
* Created by cy on 2024年4月17日 下午8:36:05.
*/
@RestController
@RequestMapping("/pclessonevaluation")
public class PcLessonEvaluationController extends CyPaginationController<PcLessonEvaluation> {


    @Autowired
    private PcLessonEvaluationService pcLessonEvaluationServiceImpl;

    //@PreAuthorize("@cyPerm.hasPerm('sys:essonEvaluation:add')")
    @CyOpeLogAnno(title = "system-pc课程评价表管理-新增pc课程评价表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="添加pc课程评价表", notes="添加pc课程评价表")
    @PostMapping(value = "/add")
    public CyResult add(@Valid PcLessonEvaluation pcLessonEvaluation, BindingResult bindingResult) {
        CyPersistModel data = pcLessonEvaluationServiceImpl.persist(pcLessonEvaluation);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        pcLessonEvaluation);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:essonEvaluation:delete')")
    @CyOpeLogAnno(title = "system-pc课程评价表管理-删除pc课程评价表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="逻辑删除pc课程评价表", notes="逻辑删除pc课程评价表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable int businessId,PcLessonEvaluation pcLessonEvaluation) {
        pcLessonEvaluation.setBusinessId(businessId);
        CyPersistModel data = pcLessonEvaluationServiceImpl.removeLogical(pcLessonEvaluation);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:essonEvaluation:delete')")
    @CyOpeLogAnno(title = "system-pc课程评价表管理-删除pc课程评价表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="删除pc课程评价表", notes="删除pc课程评价表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable int businessId,PcLessonEvaluation pcLessonEvaluation) {
        pcLessonEvaluation.setBusinessId(businessId);
        CyPersistModel data = pcLessonEvaluationServiceImpl.remove(pcLessonEvaluation);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:essonEvaluation:update')")
    @CyOpeLogAnno(title = "system-pc课程评价表管理-修改pc课程评价表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改pc课程评价表", notes="修改pc课程评价表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable int businessId, @Valid PcLessonEvaluation pcLessonEvaluation, BindingResult bindingResult) {
        pcLessonEvaluation.setBusinessId(businessId);
        CyPersistModel data = pcLessonEvaluationServiceImpl.merge(pcLessonEvaluation);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        pcLessonEvaluation);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:essonEvaluation:query')")
    @CyOpeLogAnno(title = "system-pc课程评价表管理-查询pc课程评价表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单一pc课程评价表", notes="查询单一pc课程评价表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable int businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        pcLessonEvaluationServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:essonEvaluation:list')")
    @CyOpeLogAnno(title = "system-pc课程评价表管理-查询pc课程评价表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询pc课程评价表集合", notes="查询pc课程评价表集合")
    @GetMapping(value = "/listAll")
    public CyResult listAll(PcLessonEvaluation pcLessonEvaluation) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            pcLessonEvaluationServiceImpl.findAll(pcLessonEvaluation));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:essonEvaluation:list')")
    @CyOpeLogAnno(title = "system-pc课程评价表管理-查询pc课程评价表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="分页查询pc课程评价表集合", notes="分页查询pc课程评价表集合")
    @GetMapping(value = "/list")
    public CyGridModel listByPagination(PcLessonEvaluation pcLessonEvaluation) {
        pcLessonEvaluationServiceImpl.findAllByPagination(getPaginationUtility(), pcLessonEvaluation);
        return getGridModelResponse();
    }


    @CyOpeLogAnno(title = "system-课程管理-查询评价表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="分页查询评价表集合", notes="分页查询评价表集合（匿名）")
    @GetMapping(value = "/evaluationList")
    public CyGridModel evaluationListByPagination(PcLessonEvaluation pcLessonEvaluation) {
        pcLessonEvaluationServiceImpl.findEvaluationByPagination(getPaginationUtility(), pcLessonEvaluation);
        return getGridModelResponse();
    }





    @CyOpeLogAnno(title = "system-pc课程评价表管理-查询pc课程评价表", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出pc课程评价表信息", notes = "导出pc课程评价表信息")
    @GetMapping(value = "/export")
    public void outPcLessonEvaluation(HttpServletResponse response,PcLessonEvaluation pcLessonEvaluation,@PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="pc课程评价表信息.xls";break;
            case "1": excelName="pc课程评价表信息.xlsx";break;
            case "2": excelName="pc课程评价表信息.csv";break;
        }
        List<PcLessonEvaluation> pcLessonEvaluationList = pcLessonEvaluationServiceImpl.export(pcLessonEvaluation);
        CyEpExcelUtil.exportExcel(pcLessonEvaluationList, "pc课程评价表信息", "pc课程评价表信息", PcLessonEvaluation.class, excelName, response);
    }
}
