package org.rcisoft.business.pclessonevaluation.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.aop.CyPageUtilAsp;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.business.pclessonevaluation.dao.PcLessonEvaluationRepository;
import org.rcisoft.business.pclessonevaluation.entity.PcLessonEvaluation;
import org.rcisoft.business.pclessonevaluation.service.PcLessonEvaluationService;
import org.rcisoft.core.service.CyBaseService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.rcisoft.core.model.CyPageInfo;

import java.util.Date;
import java.util.List;
import lombok.extern.slf4j.Slf4j;

/**
 * Created by cy on 2024年4月17日 下午8:36:05.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class PcLessonEvaluationServiceImpl extends ServiceImpl<PcLessonEvaluationRepository,PcLessonEvaluation>  implements PcLessonEvaluationService {


    /**
    * 保存 pc课程评价表
    * @param pcLessonEvaluation
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(PcLessonEvaluation pcLessonEvaluation){
        if (pcLessonEvaluation!=null){
            pcLessonEvaluation.setSubmissionTime(new Date());
        }
        //增加操作
        int line = baseMapper.insert(pcLessonEvaluation);
        log.debug(CyUserUtil.getAuthenUsername()+"新增了ID为"+
            pcLessonEvaluation.getBusinessId()+"的pc课程评价表信息");
        return new CyPersistModel(line);
    }

    /**
    * 删除 pc课程评价表
    * @param pcLessonEvaluation
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(PcLessonEvaluation pcLessonEvaluation){
        int line = baseMapper.realDelete(pcLessonEvaluation);
        log.debug(CyUserUtil.getAuthenUsername()+"删除了ID为"+
            pcLessonEvaluation.getBusinessId()+"的pc课程评价表信息");
        return new CyPersistModel(line);
    }

    /**
    * 逻辑删除 pc课程评价表
    * @param pcLessonEvaluation
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(PcLessonEvaluation pcLessonEvaluation){
        pcLessonEvaluation.setDeleted();
        int line = baseMapper.deleteById(pcLessonEvaluation);
            log.debug(CyUserUtil.getAuthenUsername()+"逻辑删除了ID为"+
                pcLessonEvaluation.getBusinessId()+"的pc课程评价表信息");
            return new CyPersistModel(line);
    }

    /**
    * 修改 pc课程评价表
    * @param pcLessonEvaluation
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(PcLessonEvaluation pcLessonEvaluation){
        int line = baseMapper.updateById(pcLessonEvaluation);
        log.debug(CyUserUtil.getAuthenUsername()+"修改了ID为"+ pcLessonEvaluation.getBusinessId()+"的pc课程评价表信息");
        return new CyPersistModel(line);
    }

    /**
    * 根据id查询 pc课程评价表
    * @param id
    * @return
    */
    @Override
    public PcLessonEvaluation findById(int id){
        return baseMapper.selectById(id);
    }

    /**
    * 分页查询 pc课程评价表
    * @param pcLessonEvaluation
    * @return
    */
    @Override
    public IPage<PcLessonEvaluation> findEvaluationByPagination(CyPageInfo<PcLessonEvaluation> paginationUtility,
        PcLessonEvaluation pcLessonEvaluation){
        IPage<PcLessonEvaluation> pcLessonEvaluationIPage = baseMapper.queryLessonEvaluationsPaged(paginationUtility, pcLessonEvaluation);
        List<PcLessonEvaluation> records = pcLessonEvaluationIPage.getRecords();
        records.forEach(evaluation -> {
            if (evaluation.getAnonymousFlag().equals("0")){
                evaluation.setUserName("匿名用户");
            }
        });
        pcLessonEvaluationIPage.setRecords(records);
        return pcLessonEvaluationIPage;

    }

    /**
     * 分页查询 课程评价表
     * @param pcLessonEvaluation
     * @return
     */
    @Override
    public IPage<PcLessonEvaluation> findAllByPagination(CyPageInfo<PcLessonEvaluation> paginationUtility,
                                                         PcLessonEvaluation pcLessonEvaluation){
        return baseMapper.queryPcLessonEvaluationsPaged(paginationUtility,pcLessonEvaluation);

    }



    /**
    * 查询list pc课程评价表
    * @param pcLessonEvaluation
    * @return
    */
    @Override
    public List<PcLessonEvaluation> findAll(PcLessonEvaluation pcLessonEvaluation){
        return baseMapper.queryPcLessonEvaluations(pcLessonEvaluation);

    }

    /**
    * 导出pc课程评价表
    * @return
    */
    @Override
    public List<PcLessonEvaluation> export(PcLessonEvaluation pcLessonEvaluation) {
        List<PcLessonEvaluation> pcLessonEvaluationList = baseMapper.queryPcLessonEvaluations(pcLessonEvaluation);
        return pcLessonEvaluationList;
    }

}
