package org.rcisoft.business.pclessonfavorite.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.exception.CyServiceException;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;


import org.rcisoft.business.pclessonfavorite.entity.PcLessonFavorite;
import org.rcisoft.business.pclessonfavorite.service.PcLessonFavoriteService;

import java.util.List;

/**
* Created by cy on 2024年4月12日 下午1:09:06.
*/
@RestController
@RequestMapping("/pclessonfavorite")
public class PcLessonFavoriteController extends CyPaginationController<PcLessonFavorite> {


    @Autowired
    private PcLessonFavoriteService pcLessonFavoriteServiceImpl;

    //@PreAuthorize("@cyPerm.hasPerm('sys:essonFavorite:delete')")
    @CyOpeLogAnno(title = "system-pc_用户收藏课程表管理-删除pc_用户收藏课程表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="删除pc_用户收藏课程表", notes="删除pc_用户收藏课程表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable Integer businessId,PcLessonFavorite pcLessonFavorite) {
        pcLessonFavorite.setBusinessId(businessId);
        CyPersistModel data = pcLessonFavoriteServiceImpl.remove(pcLessonFavorite);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:essonFavorite:update')")
    @CyOpeLogAnno(title = "system-pc_用户收藏课程表管理-修改pc_用户收藏课程表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改pc_用户收藏课程表", notes="修改pc_用户收藏课程表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable int businessId, @Valid PcLessonFavorite pcLessonFavorite, BindingResult bindingResult) {
        pcLessonFavorite.setBusinessId(businessId);
        CyPersistModel data = pcLessonFavoriteServiceImpl.merge(pcLessonFavorite);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        pcLessonFavorite);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:essonFavorite:query')")
    @CyOpeLogAnno(title = "system-pc_用户收藏课程表管理-查询pc_用户收藏课程表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单一pc_用户收藏课程表", notes="查询单一pc_用户收藏课程表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable int businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        pcLessonFavoriteServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:essonFavorite:list')")
    @CyOpeLogAnno(title = "system-pc_用户收藏课程表管理-查询pc_用户收藏课程表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询pc_用户收藏课程表集合", notes="查询pc_用户收藏课程表集合")
    @GetMapping(value = "/listAll")
    public CyResult listAll(PcLessonFavorite pcLessonFavorite) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            pcLessonFavoriteServiceImpl.findAll(pcLessonFavorite));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:essonFavorite:list')")
    @CyOpeLogAnno(title = "system-pc_用户收藏课程表管理-查询pc_用户收藏课程表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="分页查询pc_用户收藏课程表集合", notes="分页查询pc_用户收藏课程表集合")
    @GetMapping(value = "/list")
    public CyGridModel listByPagination(PcLessonFavorite pcLessonFavorite) {
        pcLessonFavoriteServiceImpl.findAllByPagination(getPaginationUtility(), pcLessonFavorite);
        return getGridModelResponse();
    }

    @CyOpeLogAnno(title = "system-pc_用户收藏课程表管理-查询pc_用户收藏课程表", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出pc_用户收藏课程表信息", notes = "导出pc_用户收藏课程表信息")
    @GetMapping(value = "/export")
    public void outPcLessonFavorite(HttpServletResponse response,PcLessonFavorite pcLessonFavorite,@PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="pc_用户收藏课程表信息.xls";break;
            case "1": excelName="pc_用户收藏课程表信息.xlsx";break;
            case "2": excelName="pc_用户收藏课程表信息.csv";break;
        }
        List<PcLessonFavorite> pcLessonFavoriteList = pcLessonFavoriteServiceImpl.export(pcLessonFavorite);
        CyEpExcelUtil.exportExcel(pcLessonFavoriteList, "pc_用户收藏课程表信息息", "pc_用户收藏课程表信息", PcLessonFavorite.class, excelName, response);
    }

    //pc端
    /**
     * 用户收藏取消收藏课程信息
     */
    //@PreAuthorize("@cyPerm.hasPerm('sys:essonFavorite:add')")
    @CyOpeLogAnno(title = "system-pc_用户收藏课程表管理-新增/删除pc_用户收藏课程表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="添加/删除pc_用户收藏课程表", notes="添加/删除pc_用户收藏课程表")
    @PostMapping(value = "/addOrDelete")
    public CyResult add(@Valid PcLessonFavorite pcLessonFavorite, BindingResult bindingResult) {
        CyPersistModel data = pcLessonFavoriteServiceImpl.addOrDelete(pcLessonFavorite);
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                pcLessonFavorite);
    }

}
