package org.rcisoft.business.pclessonfavorite.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.rcisoft.business.blesson.entity.BLesson;
import org.rcisoft.business.pclessonfavorite.dao.PcLessonFavoriteRepository;
import org.rcisoft.business.pclessonfavorite.entity.PcLessonFavorite;
import org.rcisoft.business.pclessonfavorite.service.PcLessonFavoriteService;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyUserUtil;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;

import java.util.List;

/**
 * Created by cy on 2024年4月12日 下午1:09:06.
 */
@Service
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class PcLessonFavoriteServiceImpl extends ServiceImpl<PcLessonFavoriteRepository, PcLessonFavorite> implements PcLessonFavoriteService {


    /**
     * 保存 pc_用户收藏课程表
     *
     * @param pcLessonFavorite
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(PcLessonFavorite pcLessonFavorite) {
        QueryWrapper<PcLessonFavorite> qw = new QueryWrapper<>();
        qw.eq("user_id", pcLessonFavorite.getUserId())
                .eq("lesson_id", pcLessonFavorite.getLessonId())
                .eq("del_flag", 0);
        List<PcLessonFavorite> pcLessonFavorites = baseMapper.selectList(qw);
        if (pcLessonFavorites.size() >= 100) {
            //删除最前面的一条数据
            PcLessonFavorite favorite = pcLessonFavorites.get(0);
            favorite.setDelFlag("1");
            baseMapper.updateById(favorite);
        }
        //增加操作
        int line = baseMapper.insert(pcLessonFavorite);
        log.debug(CyUserUtil.getAuthenUsername() + "新增了ID为" +
                pcLessonFavorite.getBusinessId() + "的pc_用户收藏课程表信息");
        return new CyPersistModel(line);
    }

    /**
     * 删除 pc_用户收藏课程表
     *
     * @param pcLessonFavorite
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(PcLessonFavorite pcLessonFavorite) {
        QueryWrapper<PcLessonFavorite> qw = new QueryWrapper<>();
        qw.eq("user_id", pcLessonFavorite.getUserId())
                .eq("lesson_id", pcLessonFavorite.getLessonId());
        pcLessonFavorite = baseMapper.selectOne(qw);
        pcLessonFavorite.setDelFlag("1");
        //逻辑删除
        int line = baseMapper.updateById(pcLessonFavorite);
        log.debug(CyUserUtil.getAuthenUsername() + "删除了ID为" +
                pcLessonFavorite.getBusinessId() + "的pc_用户收藏课程表信息");
        return new CyPersistModel(line);
    }

    /**
     * 修改 pc_用户收藏课程表
     *
     * @param pcLessonFavorite
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(PcLessonFavorite pcLessonFavorite) {
        int line = baseMapper.updateById(pcLessonFavorite);
        log.debug(CyUserUtil.getAuthenUsername() + "修改了ID为" + pcLessonFavorite.getBusinessId() + "的pc_用户收藏课程表信息");
        return new CyPersistModel(line);
    }

    /**
     * 根据id查询 pc_用户收藏课程表
     *
     * @param id
     * @return
     */
    @Override
    public PcLessonFavorite findById(int id) {
        return baseMapper.selectById(id);
    }

    /**
     * 分页查询 pc_用户收藏课程表
     *
     * @param pcLessonFavorite
     * @return
     */
    @Override
    public IPage<BLesson> findAllByPagination(CyPageInfo<PcLessonFavorite> paginationUtility,
                                              PcLessonFavorite pcLessonFavorite) {
        return baseMapper.queryPcLessonFavoritesPaged(paginationUtility, pcLessonFavorite);

    }

    /**
     * 查询list pc_用户收藏课程表
     *
     * @param pcLessonFavorite
     * @return
     */
    @Override
    public List<PcLessonFavorite> findAll(PcLessonFavorite pcLessonFavorite) {
        return baseMapper.queryPcLessonFavorites(pcLessonFavorite);

    }

    /**
     * 导出pc_用户收藏课程表
     *
     * @return
     */
    @Override
    public List<PcLessonFavorite> export(PcLessonFavorite pcLessonFavorite) {
        List<PcLessonFavorite> pcLessonFavoriteList = baseMapper.queryPcLessonFavorites(pcLessonFavorite);
        return pcLessonFavoriteList;
    }

    @Override
    public CyPersistModel addOrDelete(PcLessonFavorite pcLessonFavorite) {
        String authenBusinessId = CyUserUtil.getAuthenBusinessId();
        if (authenBusinessId != null) {
            QueryWrapper<PcLessonFavorite> qw = new QueryWrapper<>();
            qw.eq("user_id", authenBusinessId)
                    .eq("lesson_id", pcLessonFavorite.getLessonId());
            List<PcLessonFavorite> pcLessonFavorites = baseMapper.selectList(qw);
            if (!CollectionUtils.isEmpty(pcLessonFavorites)){
                if ("0".equals(pcLessonFavorites.get(0).getDelFlag())) {
                    //取消收藏
                    pcLessonFavorites.get(0).setDelFlag("1");
                } else {
                    //收藏
                    pcLessonFavorites.get(0).setDelFlag("0");
                }
                baseMapper.updateById(pcLessonFavorites.get(0));
            }else {
                //新增收藏
                PcLessonFavorite favorite = new PcLessonFavorite();
                favorite.setUserId(Integer.parseInt(authenBusinessId));
                favorite.setLessonId(pcLessonFavorite.getLessonId());
                favorite.setDelFlag("0");
                baseMapper.insert(favorite);
            }
        }
        return null;
    }

}
