package org.rcisoft.business.pclessonlearntime.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.exception.CyServiceException;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;


import org.rcisoft.business.pclessonlearntime.entity.PcLessonLearntime;
import org.rcisoft.business.pclessonlearntime.service.PcLessonLearntimeService;

import java.util.List;

/**
* Created by cy on 2024年4月13日 下午3:14:16.
*/
@RestController
@RequestMapping("/pclessonlearntime")
public class PcLessonLearntimeController extends CyPaginationController<PcLessonLearntime> {


    @Autowired
    private PcLessonLearntimeService pcLessonLearntimeServiceImpl;

    //@PreAuthorize("@cyPerm.hasPerm('sys:essonLearntime:add')")
    @CyOpeLogAnno(title = "system-课程学习时长表管理-新增/修改课程学习时长表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value = "新增/修改课程学习时长表", notes = "新增/修改课程学习时长表")
    @PostMapping(value = "/addOrUpdate")
    public CyResult addOrUpdate(@Valid PcLessonLearntime pcLessonLearntime, BindingResult bindingResult) {
        CyPersistModel data = pcLessonLearntimeServiceImpl.addOrUpdate(pcLessonLearntime);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                pcLessonLearntime);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:essonLearntime:delete')")
    @CyOpeLogAnno(title = "system-课程学习时长表管理-删除课程学习时长表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value = "逻辑删除课程学习时长表", notes = "逻辑删除课程学习时长表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable Integer businessId, PcLessonLearntime pcLessonLearntime) {
        pcLessonLearntime.setBusinessId(businessId);
        CyPersistModel data = pcLessonLearntimeServiceImpl.removeLogical(pcLessonLearntime);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:essonLearntime:delete')")
    @CyOpeLogAnno(title = "system-课程学习时长表管理-删除课程学习时长表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value = "删除课程学习时长表", notes = "删除课程学习时长表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable Integer businessId, PcLessonLearntime pcLessonLearntime) {
        pcLessonLearntime.setBusinessId(businessId);
        CyPersistModel data = pcLessonLearntimeServiceImpl.remove(pcLessonLearntime);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:essonLearntime:update')")
    @CyOpeLogAnno(title = "system-课程学习时长表管理-修改课程学习时长表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value = "修改课程学习时长表", notes = "修改课程学习时长表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable Integer businessId, @Valid PcLessonLearntime pcLessonLearntime, BindingResult bindingResult) {
        pcLessonLearntime.setBusinessId(businessId);
        CyPersistModel data = pcLessonLearntimeServiceImpl.merge(pcLessonLearntime);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                pcLessonLearntime);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:essonLearntime:query')")
    @CyOpeLogAnno(title = "system-课程学习时长表管理-查询课程学习时长表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询单一课程学习时长表", notes = "查询单一课程学习时长表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable String businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                pcLessonLearntimeServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:essonLearntime:list')")
    @CyOpeLogAnno(title = "system-课程学习时长表管理-查询课程学习时长表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询课程学习时长表集合", notes = "查询课程学习时长表集合")
    @GetMapping(value = "/listAll")
    public CyResult listAll(PcLessonLearntime pcLessonLearntime) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                pcLessonLearntimeServiceImpl.findAll(pcLessonLearntime));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:essonLearntime:list')")
    @CyOpeLogAnno(title = "system-课程学习时长表管理-查询课程学习时长表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "分页查询课程学习时长表集合", notes = "分页查询课程学习时长表集合")
    @GetMapping(value = "/list")
    public CyGridModel listByPagination(PcLessonLearntime pcLessonLearntime) {
        pcLessonLearntimeServiceImpl.findAllByPagination(getPaginationUtility(), pcLessonLearntime);
        return getGridModelResponse();
    }

    @CyOpeLogAnno(title = "system-课程学习时长表管理-查询课程学习时长表", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出课程学习时长表信息", notes = "导出课程学习时长表信息")
    @GetMapping(value = "/export")
    public void outPcLessonLearntime(HttpServletResponse response, PcLessonLearntime pcLessonLearntime, @PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName = "";
        switch (excelId) {
            case "0":
                excelName = "课程学习时长表信息.xls";
                break;
            case "1":
                excelName = "课程学习时长表信息.xlsx";
                break;
            case "2":
                excelName = "课程学习时长表信息.csv";
                break;
        }
        List<PcLessonLearntime> pcLessonLearntimeList = pcLessonLearntimeServiceImpl.export(pcLessonLearntime);
        CyEpExcelUtil.exportExcel(pcLessonLearntimeList, "课程学习时长表信息", "课程学习时长表信息", PcLessonLearntime.class, excelName, response);
    }

    /**
     * 当前用户是否将此课程学习全部学习完成
     */
    @ApiOperation(value = "当前用户是否将此课程学习全部学习完成", notes = "当前用户是否将此课程学习全部学习完成")
    @GetMapping(value = "/isComplete")
    public CyResult isComplete(PcLessonLearntime pcLessonLearntime) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                pcLessonLearntimeServiceImpl.isComplete(pcLessonLearntime));
    }


    /**
     * 根据条件查询单个课程学习时长表
     */
    @CyOpeLogAnno(title = "system-课程学习时长表管理-查询课程学习时长表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "根据条件查询单个课程学习时长表", notes = "根据条件查询单个课程学习时长表")
    @GetMapping(value = "/findOne")
    public CyResult findOne(PcLessonLearntime pcLessonLearntime) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                pcLessonLearntimeServiceImpl.findOne(pcLessonLearntime)
        );
    }

}
