package org.rcisoft.business.pclessonlearntime.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.rcisoft.business.blesson.entity.BLesson;
import org.rcisoft.business.pcfeedexamflag.entity.PcFeedExamFlag;
import org.rcisoft.business.pcfeedexamflag.service.impl.PcFeedExamFlagServiceImpl;
import org.rcisoft.business.pclessonlearntime.dao.PcLessonLearntimeRepository;
import org.rcisoft.business.pclessonlearntime.entity.PcLessonLearntime;
import org.rcisoft.business.pclessonlearntime.service.PcLessonLearntimeService;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyUserUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;
import org.springframework.util.ObjectUtils;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

/**
 * Created by cy on 2024年4月13日 下午3:14:16.
 */
@Service
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class PcLessonLearntimeServiceImpl extends ServiceImpl<PcLessonLearntimeRepository, PcLessonLearntime> implements PcLessonLearntimeService {

    @Autowired
    private PcFeedExamFlagServiceImpl pcFeedExamFlagServiceImpl;

    @Autowired
    private PcLessonLearntimeRepository pcLessonLearntimeRepository;

    /**
     * 保存 课程学习时长表
     *
     * @param pcLessonLearntime
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel addOrUpdate(PcLessonLearntime pcLessonLearntime) {
        //添加标识
        QueryWrapper<PcLessonLearntime> flagQw = new QueryWrapper<>();
        flagQw.eq("user_id", pcLessonLearntime.getUserId())
                .eq("lesson_id", pcLessonLearntime.getLessonId())
                .eq("del_flag", 0);
        List<PcLessonLearntime> pcLessonLearntimes = baseMapper.selectList(flagQw);
        if (CollectionUtils.isEmpty(pcLessonLearntimes)) {
            //添加学习标识
            PcFeedExamFlag pcFeedExamFlag = new PcFeedExamFlag();
            pcFeedExamFlag.setLessonId(pcLessonLearntime.getLessonId());
            pcFeedExamFlag.setUserId(Integer.valueOf(pcLessonLearntime.getUserId()));
            pcFeedExamFlag.setFeedbackFlag("0");
            pcFeedExamFlag.setExamFlag("0");
            pcFeedExamFlagServiceImpl.addOrUpdate(pcFeedExamFlag);
        }

        //根据条件查询
        QueryWrapper<PcLessonLearntime> qw = new QueryWrapper<>();
        qw.eq("user_id", pcLessonLearntime.getUserId())
                .eq("lesson_id", pcLessonLearntime.getLessonId())
                .eq("chapter_id", pcLessonLearntime.getChapterId())
                .eq("del_flag", 0);
        PcLessonLearntime lessonLearntime = baseMapper.selectOne(qw);

        //查询剩余课程量
        //1. 从课程中查询所有的章节包含url地址
        //如果为空添加
        int line = 0;
        if (ObjectUtils.isEmpty(lessonLearntime)) {
            line = baseMapper.insert(pcLessonLearntime);
            log.debug(CyUserUtil.getAuthenUsername() + "新增了ID为" +
                    pcLessonLearntime.getBusinessId() + "的课程学习时长表信息");
        } else {
            pcLessonLearntime.setBusinessId(lessonLearntime.getBusinessId());
            line = baseMapper.updateById(pcLessonLearntime);
            log.debug(CyUserUtil.getAuthenUsername() + "修改了ID为" + pcLessonLearntime.getBusinessId() + "的课程学习时长表信息");
        }
        return new CyPersistModel(line);
    }

    /**
     * 删除 课程学习时长表
     *
     * @param pcLessonLearntime
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(PcLessonLearntime pcLessonLearntime) {
        int line = baseMapper.realDelete(pcLessonLearntime);
        log.debug(CyUserUtil.getAuthenUsername() + "删除了ID为" +
                pcLessonLearntime.getBusinessId() + "的课程学习时长表信息");
        return new CyPersistModel(line);
    }

    /**
     * 逻辑删除 课程学习时长表
     *
     * @param pcLessonLearntime
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(PcLessonLearntime pcLessonLearntime) {
        pcLessonLearntime.setDeleted();
        int line = baseMapper.deleteById(pcLessonLearntime);
        log.debug(CyUserUtil.getAuthenUsername() + "逻辑删除了ID为" +
                pcLessonLearntime.getBusinessId() + "的课程学习时长表信息");
        return new CyPersistModel(line);
    }

    /**
     * 修改 课程学习时长表
     *
     * @param pcLessonLearntime
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(PcLessonLearntime pcLessonLearntime) {
        int line = baseMapper.updateById(pcLessonLearntime);
        log.debug(CyUserUtil.getAuthenUsername() + "修改了ID为" + pcLessonLearntime.getBusinessId() + "的课程学习时长表信息");
        return new CyPersistModel(line);
    }

    /**
     * 根据id查询 课程学习时长表
     *
     * @param id
     * @return
     */
    @Override
    public PcLessonLearntime findById(String id) {
        return baseMapper.selectById(id);
    }

    /**
     * 分页查询 课程学习时长表
     *
     * @param pcLessonLearntime
     * @return
     */
    @Override
    public IPage<PcLessonLearntime> findAllByPagination(CyPageInfo<PcLessonLearntime> paginationUtility,
                                                        PcLessonLearntime pcLessonLearntime) {
        return baseMapper.queryPcLessonLearntimesPaged(paginationUtility, pcLessonLearntime);

    }

    /**
     * 查询list 课程学习时长表
     *
     * @param pcLessonLearntime
     * @return
     */
    @Override
    public List<PcLessonLearntime> findAll(PcLessonLearntime pcLessonLearntime) {
        return baseMapper.queryPcLessonLearntimes(pcLessonLearntime);

    }

    /**
     * 导出课程学习时长表   courseEvaluation   anonymous_flag
     *
     * @return
     */
    @Override
    public List<PcLessonLearntime> export(PcLessonLearntime pcLessonLearntime) {
        List<PcLessonLearntime> pcLessonLearntimeList = baseMapper.queryPcLessonLearntimes(pcLessonLearntime);
        return pcLessonLearntimeList;
    }

    /**
     * 课程是否学习完成
     *
     * @param pcLessonLearntime
     * @return
     */
    @Override
    public Boolean isComplete(PcLessonLearntime pcLessonLearntime) {
        //课程是否学习完成
        ArrayList<BLesson> bLessons = pcLessonLearntimeRepository.isComplete(pcLessonLearntime);
        for (BLesson bLesson : bLessons) {
            if (!Objects.isNull(bLesson)) {
                //未学完
                if ("1".equals(bLesson.getIsCompleteLearned())) {
                    //修改学习的进度字段
                    pcLessonLearntimeRepository.learningProgress(pcLessonLearntime);
                    return true;
                } else {
                    return false;
                }
            }
        }
        return false;
    }

    /**
     * @param pcLessonLearntime
     * @return
     */
    @Override
    public PcLessonLearntime findOne(PcLessonLearntime pcLessonLearntime) {
        QueryWrapper<PcLessonLearntime> qw = new QueryWrapper<>();
        qw.eq("user_id", pcLessonLearntime.getUserId())
                .eq("lesson_id", pcLessonLearntime.getLessonId())
                .eq("chapter_id", pcLessonLearntime.getChapterId())
                .eq("del_flag", 0);
        pcLessonLearntime = baseMapper.selectOne(qw);
        return pcLessonLearntime;
    }

}
