package org.rcisoft.business.pclessonviews.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.business.blesson.entity.BLesson;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.exception.CyServiceException;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;


import org.rcisoft.business.pclessonviews.entity.PcLessonViews;
import org.rcisoft.business.pclessonviews.service.PcLessonViewsService;

import java.util.List;

/**
* Created by cy on 2024年4月12日 下午1:09:06.
*/
@RestController
@RequestMapping("/pclessonviews")
public class PcLessonViewsController extends CyPaginationController<PcLessonViews> {


    @Autowired
    private PcLessonViewsService pcLessonViewsServiceImpl;

    //@PreAuthorize("@cyPerm.hasPerm('sys:essonViews:add')")
    @CyOpeLogAnno(title = "system-课程浏览次数表管理-新增课程浏览次数表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="添加课程浏览次数表", notes="添加课程浏览次数表")
    @PostMapping(value = "/add")
    public CyResult add(@Valid PcLessonViews pcLessonViews, BindingResult bindingResult) {
        CyPersistModel data = pcLessonViewsServiceImpl.persist(pcLessonViews);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        pcLessonViews);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:essonViews:delete')")
    @CyOpeLogAnno(title = "system-课程浏览次数表管理-删除课程浏览次数表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="删除课程浏览次数表", notes="删除课程浏览次数表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable int businessId,PcLessonViews pcLessonViews) {
        pcLessonViews.setBusinessId(businessId);
        CyPersistModel data = pcLessonViewsServiceImpl.remove(pcLessonViews);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:essonViews:update')")
    @CyOpeLogAnno(title = "system-课程浏览次数表管理-修改课程浏览次数表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改课程浏览次数表", notes="修改课程浏览次数表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable int businessId, @Valid PcLessonViews pcLessonViews, BindingResult bindingResult) {
        pcLessonViews.setBusinessId(businessId);
        CyPersistModel data = pcLessonViewsServiceImpl.merge(pcLessonViews);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        pcLessonViews);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:essonViews:query')")
    @CyOpeLogAnno(title = "system-课程浏览次数表管理-查询课程浏览次数表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单一课程浏览次数表", notes="查询单一课程浏览次数表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable int businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        pcLessonViewsServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:essonViews:list')")
    @CyOpeLogAnno(title = "system-课程浏览次数表管理-查询课程浏览次数表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询课程浏览次数表集合", notes="查询课程浏览次数表集合")
    @GetMapping(value = "/listAll")
    public CyResult listAll(PcLessonViews pcLessonViews) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            pcLessonViewsServiceImpl.findAll(pcLessonViews));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:essonViews:list')")
    @CyOpeLogAnno(title = "system-课程浏览次数表管理-查询课程浏览次数表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="分页查询课程浏览次数表集合", notes="分页查询课程浏览次数表集合")
    @GetMapping(value = "/list")
    public CyGridModel listByPagination(PcLessonViews pcLessonViews) {
        pcLessonViewsServiceImpl.findAllByPagination(getPaginationUtility(), pcLessonViews);
        return getGridModelResponse();
    }

    @CyOpeLogAnno(title = "system-课程浏览次数表管理-查询课程浏览次数表", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出课程浏览次数表信息", notes = "导出课程浏览次数表信息")
    @GetMapping(value = "/export")
    public void outPcLessonViews(HttpServletResponse response,PcLessonViews pcLessonViews,@PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="课程浏览次数表信息.xls";break;
            case "1": excelName="课程浏览次数表信息.xlsx";break;
            case "2": excelName="课程浏览次数表信息.csv";break;
        }
        List<PcLessonViews> pcLessonViewsList = pcLessonViewsServiceImpl.export(pcLessonViews);
        CyEpExcelUtil.exportExcel(pcLessonViewsList, "课程浏览次数表信息", "课程浏览次数表信息", PcLessonViews.class, excelName, response);
    }

    /**
     * 根据课程id查询浏览次数
     * 有 +1
     * 无 创建为1
     * @param bindingResult
     * @return
     */
    @CyOpeLogAnno(title = "system-课程浏览次数表管理-查询浏览课程次数,添加修改", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="查询浏览课程次数,添加修改", notes="查询浏览课程次数,添加修改")
    @PostMapping(value = "/addViewsByLessonId")
    public CyResult addViewsByLessonId(PcLessonViews pcLessonViews, BindingResult bindingResult) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                pcLessonViewsServiceImpl.addViewsByLessonId(pcLessonViews));
    }
}
