package org.rcisoft.business.pclessonviews.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.aop.CyPageUtilAsp;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.business.pclessonviews.dao.PcLessonViewsRepository;
import org.rcisoft.business.pclessonviews.entity.PcLessonViews;
import org.rcisoft.business.pclessonviews.service.PcLessonViewsService;
import org.rcisoft.core.service.CyBaseService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.rcisoft.core.model.CyPageInfo;

import java.util.List;
import lombok.extern.slf4j.Slf4j;

/**
 * Created by cy on 2024年4月12日 下午1:09:06.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class PcLessonViewsServiceImpl extends ServiceImpl<PcLessonViewsRepository,PcLessonViews>  implements PcLessonViewsService {


    /**
    * 保存 课程浏览次数表
    * @param pcLessonViews
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(PcLessonViews pcLessonViews){
        //增加操作
        int line = baseMapper.insert(pcLessonViews);
        log.debug(CyUserUtil.getAuthenUsername()+"新增了ID为"+
            pcLessonViews.getBusinessId()+"的课程浏览次数表信息");
        return new CyPersistModel(line);
    }

    /**
    * 删除 课程浏览次数表
    * @param pcLessonViews
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(PcLessonViews pcLessonViews){
        int line = baseMapper.realDelete(pcLessonViews);
        log.debug(CyUserUtil.getAuthenUsername()+"删除了ID为"+
            pcLessonViews.getBusinessId()+"的课程浏览次数表信息");
        return new CyPersistModel(line);
    }

    /**
    * 修改 课程浏览次数表
    * @param pcLessonViews
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(PcLessonViews pcLessonViews){
        int line = baseMapper.updateById(pcLessonViews);
        log.debug(CyUserUtil.getAuthenUsername()+"修改了ID为"+ pcLessonViews.getBusinessId()+"的课程浏览次数表信息");
        return new CyPersistModel(line);
    }

    /**
    * 根据id查询 课程浏览次数表
    * @param id
    * @return
    */
    @Override
    public PcLessonViews findById(int id){
        return baseMapper.selectById(id);
    }

    /**
    * 分页查询 课程浏览次数表
    * @param pcLessonViews
    * @return
    */
    @Override
    public IPage<PcLessonViews> findAllByPagination(CyPageInfo<PcLessonViews> paginationUtility,
        PcLessonViews pcLessonViews){
        return baseMapper.queryPcLessonViewssPaged(paginationUtility,pcLessonViews);

    }

    /**
    * 查询list 课程浏览次数表
    * @param pcLessonViews
    * @return
    */
    @Override
    public List<PcLessonViews> findAll(PcLessonViews pcLessonViews){
        return baseMapper.queryPcLessonViewss(pcLessonViews);

    }

    /**
    * 导出课程浏览次数表
    * @return
    */
    @Override
    public List<PcLessonViews> export(PcLessonViews pcLessonViews) {
        List<PcLessonViews> pcLessonViewsList = baseMapper.queryPcLessonViewss(pcLessonViews);
        return pcLessonViewsList;
    }

    /**
     * 根据课程id查询浏览次数
     * @param pcLessonViews
     * @return
     */
    @Override
    public PcLessonViews addViewsByLessonId(PcLessonViews pcLessonViews) {
        QueryWrapper<PcLessonViews> qw = new QueryWrapper<>();
        qw.eq("lesson_id",pcLessonViews.getLessonId())
                .eq("type",pcLessonViews.getType());
        PcLessonViews pcLessonViewsNew = baseMapper.selectOne(qw);
        if (pcLessonViewsNew != null){
            //有 +1
            pcLessonViewsNew.setLessonViews(pcLessonViewsNew.getLessonViews()+1);
            baseMapper.updateById(pcLessonViewsNew);
        }else {
            //无 创建
            pcLessonViews.setLessonId(pcLessonViews.getLessonId());
            pcLessonViews.setType(pcLessonViews.getType());
            pcLessonViews.setLessonViews(1);
            baseMapper.insert(pcLessonViews);
        }
        return pcLessonViews;
    }

}
