package org.rcisoft.business.pcmanage.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.business.teatrialcourse.entity.TeaTrialCourse;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.exception.CyServiceException;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;


import org.rcisoft.business.pcmanage.entity.PcManage;
import org.rcisoft.business.pcmanage.service.PcManageService;

import java.util.List;

/**
* Created by cy on 2024年4月19日 下午3:46:44.
*/
@RestController
@RequestMapping("/pcmanage")
public class PcManageController extends CyPaginationController<PcManage> {


    @Autowired
    private PcManageService pcManageServiceImpl;

    //@PreAuthorize("@cyPerm.hasPerm('sys:anage:delete')")
    @CyOpeLogAnno(title = "system-PcManage管理-删除PcManage", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="逻辑删除PcManage", notes="逻辑删除PcManage")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable String businessId,PcManage pcManage) {
        pcManage.setBusinessId(Integer.valueOf(businessId));
        CyPersistModel data = pcManageServiceImpl.removeLogical(pcManage);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:anage:delete')")
    @CyOpeLogAnno(title = "system-PcManage管理-删除PcManage", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="删除PcManage", notes="删除PcManage")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable String businessId,PcManage pcManage) {
        pcManage.setBusinessId(Integer.valueOf(businessId));
        CyPersistModel data = pcManageServiceImpl.remove(pcManage);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:anage:query')")
    @CyOpeLogAnno(title = "system-PcManage管理-查询PcManage", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单一PcManage", notes="查询单一PcManage")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable String businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        pcManageServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:anage:list')")
    @CyOpeLogAnno(title = "system-PcManage管理-查询PcManage", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询PcManage集合", notes="查询PcManage集合")
    @GetMapping(value = "/listAll")
    public CyResult listAll(PcManage pcManage) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            pcManageServiceImpl.findAll(pcManage));
    }


    @CyOpeLogAnno(title = "system-PcManage管理-查询PcManage", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出PcManage信息", notes = "导出PcManage信息")
    @GetMapping(value = "/export")
    public void outPcManage(HttpServletResponse response,PcManage pcManage,@PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="PcManage信息.xls";break;
            case "1": excelName="PcManage信息.xlsx";break;
            case "2": excelName="PcManage信息.csv";break;
        }
        List<PcManage> pcManageList = pcManageServiceImpl.export(pcManage);
        CyEpExcelUtil.exportExcel(pcManageList, "PcManage信息", "PcManage信息", PcManage.class, excelName, response);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:anage:list')")
    @CyOpeLogAnno(title = "system-PcManage管理-查询PcManage", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="分页查询PcManage集合", notes="分页查询PcManage集合")
    @GetMapping(value = "/list")
    public CyGridModel listByPagination(PcManage pcManage) {
        pcManageServiceImpl.findAllByPagination(getPaginationUtility(), pcManage);
        return getGridModelResponse();
    }


    /**
     * 修改 ,
     * 已读, state 状态 0:未读 , 1:已读
     * 全部已读,
     * 全部修改
     * 删 除    del_flag 0:未删除 , 1:已删除
     * 全部删除
     * @param pcManageListJson
     * @return
     */
    //@PreAuthorize("@cyPerm.hasPerm('sys:anage:update')")
    @CyOpeLogAnno(title = "system-PcManage管理-修改PcManage", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改PcManage", notes="修改PcManage")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PostMapping("/update")
    public CyResult update(String pcManageListJson) {
        CyPersistModel data = pcManageServiceImpl.merge(pcManageListJson);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                pcManageListJson);
    }


    //@PreAuthorize("@cyPerm.hasPerm('sys:anage:add')")
    @CyOpeLogAnno(title = "system-PcManage管理-新增PcManage", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="添加PcManage", notes="添加PcManage")
    @PostMapping(value = "/add")
    public CyResult add(List<TeaTrialCourse> teaTrialCourses,Integer type) {
        CyPersistModel data = pcManageServiceImpl.persist(teaTrialCourses , type);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                teaTrialCourses);
    }

}

