package org.rcisoft.business.pcmanage.service.impl;

import cn.afterturn.easypoi.cache.manager.IFileLoader;
import com.alibaba.fastjson.JSON;
import com.anji.captcha.util.JsonUtil;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.rcisoft.business.blesson.dao.BLessonRepository;
import org.rcisoft.business.blesson.entity.BLesson;
import org.rcisoft.business.blesson.service.impl.BLessonServiceImpl;
import org.rcisoft.business.pcmanage.enums.PCManageTypeEnums;
import org.rcisoft.business.sysunit.dao.UnitRepository;
import org.rcisoft.business.sysunit.entity.SysUnit;
import org.rcisoft.business.sysunit.service.impl.UnitServiceImpl;
import org.rcisoft.business.teatrialcourse.entity.TeaTrialCourse;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.aop.CyPageUtilAsp;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.business.pcmanage.dao.PcManageRepository;
import org.rcisoft.business.pcmanage.entity.PcManage;
import org.rcisoft.business.pcmanage.service.PcManageService;
import org.rcisoft.core.service.CyBaseService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.rcisoft.core.model.CyPageInfo;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Date;
import java.util.List;
import lombok.extern.slf4j.Slf4j;
import org.springframework.util.CollectionUtils;

/**
 * Created by cy on 2024年4月19日 下午3:46:44.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class PcManageServiceImpl extends ServiceImpl<PcManageRepository,PcManage>  implements PcManageService {

    @Autowired
    private UnitRepository unitRepository;

    @Autowired
    private BLessonRepository bLessonRepository;

    /**
    * 保存
    * @param teaTrialCourses
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(List<TeaTrialCourse> teaTrialCourses,Integer type){
        List<PcManage> pcManages = new ArrayList<>();
        //试用提示
        if (PCManageTypeEnums.TRIAL_TIPS.getCode().equals(type)) {
            for (TeaTrialCourse trialCourse : teaTrialCourses) {
                //根据课程id查询课程信息
                BLesson bLesson = bLessonRepository.selectById(trialCourse.getLessonId());
                //数据预处理
                if (trialCourse.getApplicant() != null){
                    trialCourse.setUserId(trialCourse.getApplicant());
                }else {
                    SysUnit sysUnit = unitRepository.selectById(trialCourse.getApplicantUnit());
                    trialCourse.setUserId(sysUnit.getUserId());
                }
                PcManage pcManage = new PcManage();
                //用户id
                pcManage.setUserId(trialCourse.getUserId());
                //课程id
                pcManage.setLessonId(trialCourse.getLessonId());
                //标题
                pcManage.setTiltle("课程开通试用提醒");
                //消息内容
                SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd");
                pcManage.setDetails("尊敬的用户，已为您开通" + bLesson.getLessonName() + "课程，试用周期为"
                        +dateFormat.format(trialCourse.getBeginTrialTime())
                        +"至"+dateFormat.format(trialCourse.getEndTrialTime())+"，请尽快安排学习。");
                //状态
                pcManage.setState("0");
                pcManage.setType("系统消息");
                //发布时间
                pcManage.setReleaseTime(new Date());
                pcManages.add(pcManage);
            }
        }
        //到期提示
        if (PCManageTypeEnums.EXPIRATION_REMINDER.getCode().equals(type)) {
            for (TeaTrialCourse trialCourse : teaTrialCourses) {
                //数据预处理
                if (trialCourse.getApplicant() != null){
                    trialCourse.setUserId(trialCourse.getApplicant());
                }else {
                    SysUnit sysUnit = unitRepository.selectById(trialCourse.getApplicantUnit());
                    trialCourse.setUserId(sysUnit.getUserId());
                }
                PcManage pcManage = new PcManage();
                //用户id
                pcManage.setUserId(trialCourse.getUserId());
                //课程id
                pcManage.setLessonId(trialCourse.getLessonId());
                //标题
                pcManage.setTiltle("课程即将到期提醒");
                //消息内容
                pcManage.setDetails("《" + trialCourse.getLessonName() + "》课程还有"+trialCourse.getRemainingDays()
                        +"天到期，请尽快学习或续期。");
                //状态
                pcManage.setState("0");
                //类型
                pcManage.setType("系统消息");
                pcManage.setReleaseTime(new Date());
                pcManages.add(pcManage);
            }
        }
        //增加操作
        if (!CollectionUtils.isEmpty(pcManages)){
            pcManages.forEach(pcManage -> {
                baseMapper.insert(pcManage);
            });
        }
        return new CyPersistModel(1);
    }

    /**
    * 删除
    * @param pcManage
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(PcManage pcManage){
        int line = baseMapper.realDelete(pcManage);
        log.debug(CyUserUtil.getAuthenUsername()+"删除了ID为"+
            pcManage.getBusinessId()+"的信息");
        return new CyPersistModel(line);
    }

    /**
    * 逻辑删除
    * @param pcManage
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(PcManage pcManage){
        pcManage.setDeleted();
        int line = baseMapper.deleteById(pcManage);
            log.debug(CyUserUtil.getAuthenUsername()+"逻辑删除了ID为"+
                pcManage.getBusinessId()+"的信息");
            return new CyPersistModel(line);
    }

    /**
    * 修改
    * @param pcManageListJson
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(String pcManageListJson){
//        List<PcManage> pcManages = JSON.parseArray(pcManageListJson, PcManage.class);
//        if (!CollectionUtils.isEmpty(pcManages)){
//            pcManages.forEach(pcManage -> {
//                baseMapper.updateById(pcManage);
//            });
//        }
        String userId = CyUserUtil.getAuthenBusinessId();
        PcManage pcManage = new PcManage();
        pcManage.setUserId(Integer.valueOf(userId));
        List<PcManage> pcManages = baseMapper.queryPcManages(pcManage);
        pcManages.forEach(pcManage1 -> {
            pcManage1.setState(String.valueOf(1));
            baseMapper.updateById(pcManage1);
        });
        return new CyPersistModel(1);
    }

    /**
    * 根据id查询
    * @param id
    * @return
    */
    @Override
    public PcManage findById(String id){
        return baseMapper.selectById(id);
    }

    /**
    * 分页查询
    * @param pcManage
    * @return
    */
    @Override
    public IPage<PcManage> findAllByPagination(CyPageInfo<PcManage> paginationUtility,
        PcManage pcManage){
        paginationUtility.setSize(pcManage.getPageSize());
        paginationUtility.setCurrent(pcManage.getPageNum());
        IPage<PcManage> pcManageIPage = baseMapper.queryPcManagesPaged(paginationUtility, pcManage);
        return pcManageIPage;
    }

    /**
    * 查询list
    * @param pcManage
    * @return
    */
    @Override
    public List<PcManage> findAll(PcManage pcManage){
        return baseMapper.queryPcManages(pcManage);

    }

    /**
    * 导出
    * @return
    */
    @Override
    public List<PcManage> export(PcManage pcManage) {
        List<PcManage> pcManageList = baseMapper.queryPcManages(pcManage);
        return pcManageList;
    }

}
