package org.rcisoft.business.postblesson.controller;
//

import cn.afterturn.easypoi.excel.ExcelExportUtil;
import cn.afterturn.easypoi.excel.entity.ExportParams;
import cn.afterturn.easypoi.excel.entity.enmus.ExcelType;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.rcisoft.business.postblesson.dto.BLessonDTO;
import org.rcisoft.business.postblesson.dto.PostExamQuestionDto;
import org.rcisoft.business.postblesson.service.BLessonService;
import org.rcisoft.business.postblesson.vo.AddEnterpriseVO;
import org.rcisoft.business.postblesson.vo.ExcelPostTeaExamQuestionsVO;
import org.rcisoft.business.postblesson.vo.PostBLessonVO;
import org.rcisoft.business.teaexamquestions.dto.ExportExamQuestionDto;
import org.rcisoft.core.anno.CyEncryptSm4Anno;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.util.ExcelUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.IOException;
import java.io.OutputStream;
import java.net.URLEncoder;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;


/**
 * @FileName PostLessonController
 * @Description
 * @Author 牛虎林
 * @date 2024-05-13
 **/
@RestController
@RequestMapping("/post/blesson")
@Slf4j
public class PostLessonController extends CyPaginationController<BLessonDTO> {
    @Autowired
    private BLessonService bLessonServiceImpl;


    @PreAuthorize("@cyPerm.hasPerm('opm:postBlesson:add')")
    @ApiOperation(value = "添加/编辑课程", notes = "businessId为空时是添加方法，不为空时是修改方法")
    @PostMapping(value = "/add")
    public CyResult add(@Valid  PostBLessonVO postBLesson, BindingResult bindingResult) {
        CyPersistModel data = bLessonServiceImpl.postPersist(postBLesson, getToken());
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                postBLesson);
    }


    @PreAuthorize("@cyPerm.hasPerm('opm:postBlesson:update')")
    @ApiOperation(value = "添加/编辑课程", notes = "businessId为空时是添加方法，不为空时是修改方法")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar"),
//            @ApiImplicitParam(name = "code", value = "课程编号(1-100)", required = true, dataType = "varchar"),
            @ApiImplicitParam(name = "lessonName", value = "课程名称（1-150）", required = true, dataType = "varchar"),
            @ApiImplicitParam(name = "classHour", value = "课时（1-5）", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "credits", value = "学分（1-5）", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "directionId", value = "课程方向ID", required = false, dataType = "varchar")})
    @PostMapping(value = "/update")
    public CyResult update(@Valid PostBLessonVO postBLesson, BindingResult bindingResult) {
        CyPersistModel data = bLessonServiceImpl.update(postBLesson, getToken());
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                postBLesson);
    }

    /**
     * 根据id查询题库信息
     * @param
     * @param
     * @return
     */
    @ApiOperation(value = "根据条件查询", notes = "根据URL中的参数查询")
    @GetMapping(value = "/findById/{businessId:\\w+}")
    public CyResult findById(@PathVariable("businessId") String businessId) {

        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLessonServiceImpl.findById(businessId));
    }

    //删除题库
    @PreAuthorize("@cyPerm.hasPerm('opm:postBlesson:deleteLogical')")
    @CyOpeLogAnno(title = "system-BLesson管理-删除BLesson", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value = "逻辑删除BLesson", notes = "逻辑删除BLesson")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable String businessId) {
        CyPersistModel data = bLessonServiceImpl.removeLogical(businessId);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }

    @ApiOperation(value = "判断题库是否存在", notes = "businessId为空时是添加方法，不为空时是修改方法")
    @GetMapping(value = "/isrepeat/{jobClassify:\\w+}/{difficultyClassify:\\w+}")
    public CyResult isRepeat(@PathVariable("jobClassify") String jobClassify, @PathVariable("difficultyClassify") String difficultyClassify) {
        return CyResultGenUtil.builder(null,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLessonServiceImpl.isRepeat(jobClassify, difficultyClassify));
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:postBlesson:queryBLessonByPagination')")
    @ApiOperation(value = "根据条件分页查询", notes = "根据URL中的参数分页查询")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "code", value = "课程编号", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "condition", value = "模糊查询条件", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "classHour", value = "课时", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "credits", value = "学分", required = false, dataType = "varchar")})
    @GetMapping(value = "/queryBLessonByPagination")
    public CyGridModel queryBLessonsByPagination(BLessonDTO bLessonDTO) {
        bLessonServiceImpl.queryPcPostBLessonsByPagination(getPaginationUtility(), bLessonDTO);
        return getGridModelResponse();
    }

    /**
     * 添加企业
     */
    @PreAuthorize("@cyPerm.hasPerm('opm:postBlesson:addEnterprise')")
    @ApiOperation(value = "添加企业", notes = "添加企业")
    @PostMapping(value = "/addEnterprise")
    public CyResult addEnterprise(@Valid AddEnterpriseVO  aAddEnterpriseVO, BindingResult bindingResult) {
        CyPersistModel data = bLessonServiceImpl.addEnterprise(aAddEnterpriseVO, getToken());
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                aAddEnterpriseVO);
    }

    /**
     * 根据岗位题库id查询企业信息
     */

    @PreAuthorize("@cyPerm.hasPerm('opm:postBlesson:enterprise')")
    @ApiOperation(value = "根据岗位题库id查询企业信息", notes = "根据岗位题库id查询企业信息")
    @GetMapping(value = "/enterprise/{businessId}")
    public CyResult selectEnterprise(@PathVariable String businessId ,String unitName) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLessonServiceImpl.selectEnterprise(businessId, unitName));
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:postBlesson:addtopic')")
    @CyOpeLogAnno(title = "system-试题表管理-新增试题表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="添加试题表", notes="添加试题表")
    @PostMapping(value = "/addtopic")
    public CyResult addtopic(@Valid @RequestBody PostExamQuestionDto examQuestionDto, BindingResult bindingResult) {
        CyPersistModel data = bLessonServiceImpl.addPersist(examQuestionDto);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                examQuestionDto);
    }
    @PreAuthorize("@cyPerm.hasPerm('opm:postBlesson:updateStatus')")
    @CyOpeLogAnno(title = "system-试题表管理-修改试题状态", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改题库状态", notes="修改试题状态")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/updateStatus/{status}/{businessId}")
    public CyResult updateStatus(@PathVariable String status,@PathVariable String businessId) {
        CyPersistModel data = bLessonServiceImpl.changeStatusLesson(status,businessId);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                null);
    }

    /**
     * 根据企业id和题库id删除企业
     */
    @PreAuthorize("@cyPerm.hasPerm('opm:postBlesson:deleteEnterprise')")
    @CyOpeLogAnno(title = "system-试题表管理-删除试题表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value = "根据企业id和题库id删除企业", notes = "根据企业id和题库id删除企业")
    @DeleteMapping(value = "/deleteEnterprise/{businessId}/{enterpriseId}")
    public CyResult deleteEnterprise(@PathVariable String businessId, @PathVariable Integer enterpriseId) {
        CyPersistModel data = bLessonServiceImpl.deleteEnterprise(businessId, enterpriseId);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                null);
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:postBlesson:importTemplate')")
    @CyOpeLogAnno(
            title = "system-试题管理-导出试题数据空模板",
            businessType = CyLogTypeEnum.EXPORT
    )
    @ApiOperation(
            value = "导出试题数据空模板",
            notes = "导出试题数据空模板"
    )
    @GetMapping({"/importTemplate"})
    @CyEncryptSm4Anno
    public void importTemplate(HttpServletResponse response) {
        OutputStream outputStream = null;
        Workbook workbook = null;
        try {
            response.setCharacterEncoding("UTF-8");
            response.setHeader("content-Type", "application/vnd.ms-excel");
            response.setHeader("Content-Disposition", "attachment;filename=" + URLEncoder.encode("试题数据信息.xlsx", "UTF-8"));
            ExportParams exportParams = new ExportParams("试题数据信息", "试题数据");
            exportParams.setType(ExcelType.XSSF);
            List<ExportExamQuestionDto> exportList = new ArrayList();
            workbook = ExcelExportUtil.exportExcel(exportParams, ExcelPostTeaExamQuestionsVO.class, exportList);
            Sheet sheet = workbook.getSheetAt(0);
            // 获取 题型 下拉数据

            String[] typeStars = new String[]{"单选题", "多选题", "判断题"};
            // 获取 题目难度难度 下拉数据
            String[] difficultyStars = new String[]{"简单", "一般", "困难"};

            // 题型名称列 第二列
            ExcelUtil.XSSFSetDropDownAndHidden(typeStars, workbook, sheet, 2, 10000, 1, 1);
            // 题目难度难度名称列 第三列
            ExcelUtil.XSSFSetDropDownAndHidden(difficultyStars, workbook, sheet, 2, 10000, 2, 2);

            outputStream = response.getOutputStream();
            workbook.write(outputStream);
        } catch (IOException var12) {
            throw new CyServiceException(var12.getMessage());
        } finally {
            try {
                if (outputStream != null) {
                    outputStream.close();
                }
            } catch (IOException var11) {
                log.info("context:" + var11);
            }
        }
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:postBlesson:importDictData')")
    @CyOpeLogAnno(
            title = "system-单位开课数据管理-导入岗位课程",
            businessType = CyLogTypeEnum.IMPORT
    )
    @ApiOperation(
            value = "导入单位开课数据",
            notes = "导入单位开课数据"
    )
    @PostMapping("/importDictData/{courseId}")
    @CyEncryptSm4Anno
    public CyResult importDictData(MultipartFile file,@PathVariable("courseId") String courseId) {
        List<Integer> integers = bLessonServiceImpl.importDictData(file, courseId);
        return CyResultGenUtil.builder( new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                integers);
    }


    @CyOpeLogAnno(
            title = "system-岗位题库数据管理-导入岗位题库数据",
            businessType = CyLogTypeEnum.IMPORT
    )
    @ApiOperation(
            value = "导入岗位题库数据",
            notes = "导入岗位题库数据"
    )
    @PostMapping("/importPostQuestionData/{courseId}")
    @CyEncryptSm4Anno
    public CyResult importPostQuestionData(MultipartFile file,@PathVariable("courseId") String courseId) {
        List<Integer> integers = bLessonServiceImpl.importDictData(file, courseId);
        return CyResultGenUtil.builder( new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                integers);
    }
}
