package org.rcisoft.business.postblesson.controller;
//
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;


import org.rcisoft.business.postblesson.dto.PostExamQuestionResultDto;
import org.rcisoft.business.postblesson.dto.QuestionsExamination;
import org.rcisoft.business.postblesson.entity.QuestionBank;
import org.rcisoft.business.postblesson.service.BLessonService;
import org.rcisoft.business.postblesson.vo.AnswerVO;
import org.rcisoft.business.postblesson.vo.ExaminationPaperVO;
import org.rcisoft.business.postblesson.vo.QuestionBankVO;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

/**
 * @FileName PostLessonController
 * @Description
 * @Author 牛虎林
 * @date 2024-05-13
 **/
@RestController
@RequestMapping("/post/user/blesson")
public class PostLessonUserController extends CyPaginationController<QuestionsExamination> {
    @Autowired
    private BLessonService bLessonServiceImpl;


    /**
     * 查询自己题库
     */
    @ApiOperation(value = "查询自己题库", notes = "查询自己题库")
    @PostMapping(value = "/queryBLessonByPagination")
    public CyGridModel queryBLessonByPagination(@Valid QuestionBankVO questionBankVO, BindingResult bindingResult) {
        bLessonServiceImpl.queryBLessonByPagination(getPaginationUtility(), questionBankVO);
        return getGridModelResponse();
    }

    /**
     * 查询用户需要答题信息
     */
    @ApiOperation(value = "查询用户需要答题信息", notes = "查询用户需要答题信息")
    @PostMapping(value = "/queryAllExamQuestionDto")
    public CyResult queryAllExamQuestionDetail(@Valid QuestionBankVO questionBankVO,BindingResult bindingResult) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLessonServiceImpl.queryAllExamQuestionDetail(questionBankVO));
    }

    /**
     * 查询试卷接口
     */
    //先查询试题列表
    @CyOpeLogAnno(title = "system-试题表管理-查询试题表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="根据课程id查询试题", notes="根据课程id查询试题")
    @ApiImplicitParams({@ApiImplicitParam(name = "lessonId", value = "lessonId", required = true, dataType = "varchar")})
    @PostMapping("/findByLessonId")
    public CyResult findByLessonId(@Valid ExaminationPaperVO examPaperVO,BindingResult bindingResult) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLessonServiceImpl.findByLessonId(examPaperVO));
    }

    /**
     * 用户答题
     */
    @CyOpeLogAnno(title = "system-试题表管理-用户答题", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="用户答题", notes="用户答题")
    @PostMapping("/answer")
    public CyResult answer(@Valid AnswerVO answerVO, BindingResult bindingResult) {
        CyPersistModel data = bLessonServiceImpl.answer(answerVO);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                answerVO);
    }

    @CyOpeLogAnno(title = "system-试题表管理-用户答题", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="用户答题", notes="用户答题")
    @GetMapping("/submit")
    public CyResult submit( Integer businessId) {
        PostExamQuestionResultDto postExamQuestionResultDto = bLessonServiceImpl.selectByQuestionsId(businessId);
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                postExamQuestionResultDto);
    }


    /**
     * 删除答题记录
     */
    @CyOpeLogAnno(title = "system-试题表管理-删除答题记录", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="删除答题记录", notes="删除答题记录")
    @DeleteMapping("/removeLogical/{businessId:\\w+}")
    public CyResult removeLogical(@PathVariable Integer businessId) {
        CyPersistModel data = bLessonServiceImpl.deleteLogical(businessId);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }






}
