package org.rcisoft.business.postblesson.controller;
//

import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.business.postblesson.dto.PostExamQuestionDto;
import org.rcisoft.business.postblesson.dto.QuestionsList;
import org.rcisoft.business.postblesson.service.BLessonService;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

/**
 * @FileName QuestionsController
 * @Description
 * @Author 牛虎林
 * @date 2024-05-14
 **/

@RestController
@RequestMapping("/post/questions")
public class QuestionsController  extends CyPaginationController<QuestionsList> {

    @Autowired
    private BLessonService bLessonServiceImpl;
    @ApiOperation(value = "查询题库下面的题目", notes = "查询题库下面的题目")
    @GetMapping(value = "/questionList/{courseId}")
    public CyGridModel queryQuestionTypeByPagination(QuestionsList questionsList, @PathVariable String courseId) {
        bLessonServiceImpl.queryQuestionTypeByPagination(getPaginationUtility(), questionsList,courseId);
        return getGridModelResponse();
    }

    /**
     * 根据id查询试题详情
     * @param businessId
     * @return
     */

    @CyOpeLogAnno(title = "system-试题表管理-查询试题表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单一试题表", notes="查询单一试题表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable String businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                bLessonServiceImpl.queryAllExamQuestionDto(businessId));
    }
    /**
     * 修改试题
     */

    @CyOpeLogAnno(title = "system-试题表管理-修改试题表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改试题表", notes="修改试题表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update")
    public CyResult update(  @RequestBody @Valid PostExamQuestionDto examQuestionDto, BindingResult bindingResult) {
        CyPersistModel data = bLessonServiceImpl.merge(examQuestionDto);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                examQuestionDto);
    }

    @CyOpeLogAnno(title = "system-试题表管理-修改试题状态", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改试题状态", notes="修改试题状态")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/updateStatus/{status}/{businessId}")
    public CyResult updateStatus(@PathVariable String status,@PathVariable Integer businessId) {
        CyPersistModel data = bLessonServiceImpl.changeStatus(status,businessId);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                null);
    }

    /**
     * 删除题目
     */
    @CyOpeLogAnno(title = "system-试题表管理-删除试题表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="删除试题表", notes="删除试题表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId}")
    public CyResult delete(@PathVariable Integer businessId) {
        CyPersistModel data = bLessonServiceImpl.delete(businessId);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                null);
    }






}
