package org.rcisoft.business.postblesson.dao;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.ibatis.annotations.*;

import org.rcisoft.business.blesson.entity.BLessonDirection;
import org.rcisoft.business.postblesson.dto.*;

import org.rcisoft.business.postblesson.entity.PostBLesson;
import org.rcisoft.business.postblesson.entity.PostSysUnit;
import org.rcisoft.business.postblesson.entity.PostTeaExamQuestions;
import org.rcisoft.business.postblesson.entity.QuestionBank;
import org.rcisoft.business.postblesson.vo.QuestionBankVO;
import org.rcisoft.core.mapper.CyBaseMapper;
import org.rcisoft.core.model.CyPageInfo;

import java.util.List;


/**
 * Created with cy on 2024年3月23日 上午9:54:37.
 */

public interface PostBLessonRepository extends CyBaseMapper<PostBLesson> {




    @Select("<script>select bl.*,bld.lecturer_id as lecturerId from tea_post_lesson_new bl " +
            "left join tea_lesson_direction bld on bl.business_id = bld.lession_id " +
            "where bl.code = #{code} and bl.del_flag != 1 and bl.flag = 1 </script>")
    @ResultMap(value = "BaseResultMap")
    PostBLesson queryBLessonByCode(String code);

    //    @Insert("<script>INSERT INTO tea_lesson_direction (business_id,lession_id,lecturer_id,sl_id) VALUES " +
//            "(#{businessId},#{lessionId},#{lecturerId},#{slId})</script>")
//    int insertLessonDirection(BLessonDirection model);
    @Insert("<script>INSERT INTO tea_lesson_direction (business_id,lession_id,lecturer_id) VALUES " +
            "(#{businessId},#{lessionId},#{lecturerId})</script>")
    int insertLessonDirection(BLessonDirection model);

    @Select("SELECT COALESCE(SUM(class_hour),0) classHour FROM tea_lesson_direction where lesson_id = #{businessId} and pid != '-1'")
    int queryClassHourByLessonId(String businessId);

    @Update("<script>update tea_lesson_direction set lecturer_id = #{lecturerId} where lession_id = #{lessionId}</script>")
    int updateDirectionByLessonId(BLessonDirection direction);


    @Insert("<script>INSERT INTO tea_post_lesson_new (" +
            "business_id, lesson_name, class_hour, class_plan,class_plan_school, job_classify, tec_classify, tec_classify_school,difficulty_classify, lesson_brief, lesson_tea_name, lesson_price, home_display, ent_quality_lesson, school_quality_lesson, lesson_description, default_url, create_by, update_by, del_flag, flag, remarks, update_date, create_date,quality_lesson,lesson_type,lesson_type_school,passing_grade) " +
            "VALUES" +
            "<foreach collection=\"list\" item=\"item\" separator=\",\">" +
            "( #{item.businessId}, #{item.lessonName}, #{item.classHour}, #{item.classPlan}, #{item.classPlanSchool}, #{item.jobClassify}, #{item.tecClassify}, #{item.tecClassifySchool}, #{item.difficultyClassify}, #{item.lessonBrief}, #{item.lessonTeaName}, #{item.lessonPrice}, #{item.homeDisplay}, #{item.entQualityLesson}, #{item.schoolQualityLesson}, #{item.lessonDescription}, #{item.defaultUrl}, #{item.createBy}, #{item.updateBy}, #{item.delFlag}, #{item.flag}, #{item.remarks}, #{item.updateDate}, #{item.createDate},#{item.qualityLesson},#{item.lessonType},#{item.lessonTypeSchool},#{item.passingGrade})" +
            "</foreach></script>")
    int insertList(List<PostBLesson> bLessons);



    ;

    IPage<org.rcisoft.business.postblesson.dto.BLessonDTO> queryPcPostBLessonsByPagination(CyPageInfo<BLessonDTO> paginationUtility,@Param("bLessonDTO") BLessonDTO bLessonDTO);

    /**
     * 根据课程id查询题目类型统计
     * @Param 课程id
     * @return
     */
    org.rcisoft.business.postblesson.dto.QuestionsDTO getQuestionsDTO(@Param("courseId") String courseId);


    /**
     * 分数统计
     * @param courseId
     * @return
     */
    Integer  getScoreCount(@Param("courseId") String courseId);

    /**
     * 统计企业数目
     *
     */
    Integer  getCount(@Param("courseId") String courseId);


    /**
     * 批量插入课程和企业关联数据
     * @param addEnterprise
     * @return
     */
    Integer addEnterprise(@Param("addEnterprise") List<AddEnterpriseDTO> addEnterprise);


    /**
     * 根据岗位题库id查询企业信息
     *
     * @param lessonId
     * @param unitName
     * @return
     */
    List<EnterpriseDTO> getEnterprise(@Param("lessonId") String lessonId,@Param("unitName") String unitName);

    IPage<QuestionBank> queryBLessonByPagination(CyPageInfo<QuestionBank> paginationUtility, @Param("entity") QuestionBankVO questionBankVO);

    /**
     * 根据用户ID查询自己的题库
     * @param userId 用户id
     * @param  examinationId 试题id
     * @return
     */
    QuestionsExamination queryBLessonsByUserId(@Param("userId") Integer userId, @Param("examinationId") Integer examinationId);

    IPage<QuestionsList> queryQuestionTypeByPagination(CyPageInfo<QuestionsList> paginationUtility, @Param("questionsList") QuestionsList questionsList,
                                                       @Param("courseId") String courseId);

    /**
     * 查询同一课程下同一题目编号的个数
     * **/
    int queryNumbeSomeCourse(PostTeaExamQuestions teaExamQuestions);

    /**
     * 查询同一课程下同一权重的个数
     * **/
    int queryNumberSomeWeiht(PostTeaExamQuestions teaExamQuestions);

    int deleteEnterprise(@Param("businessId") String businessId,@Param("enterpriseId")  Integer enterpriseId);


    /**
     * 根据用户的id查询用户属于哪一个单位
     * @param userId
     * @return
     */
    PostSysUnit querySysUnit(@Param("userId") Integer userId);


    String queryTeaExamOptionss(@Param("questionBankVO") QuestionBankVO questionBankVO,
                                @Param("enterpriseId") Integer enterpriseId);
    //根据用户用户id和题目id 查询用户答题状态
    queryTeaExamOptionsDTO queryTeaExamOptions(@Param("courseId") String courseId ,
                               @Param("userId") Integer userId);

    /**
     * 查询已完成的题库
     */
    Page<QuestionsExamination> queryFinishCourse(CyPageInfo<QuestionsExamination> paginationUtility,@Param("courseId") String courseId, @Param("userId") Integer userId);

    String queryTeaExamOptionssStatus(@Param("courseId") String courseId, @Param("userId") Integer userId);
}

