package org.rcisoft.business.postblesson.service.impl;


import cn.hutool.core.collection.CollectionUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.rcisoft.business.blesson.entity.BLessonDirection;
import org.rcisoft.business.postblesson.dao.*;
import org.rcisoft.business.postblesson.dto.*;
import org.rcisoft.business.postblesson.entity.*;
import org.rcisoft.business.postblesson.enums.*;
import org.rcisoft.business.postblesson.service.BLessonService;
import org.rcisoft.business.postblesson.service.PostPcLessonBrowseService;
import org.rcisoft.business.postblesson.vo.*;
import org.rcisoft.business.sysunit.service.UnitService;
import org.rcisoft.common.component.Global;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.core.util.CyIdGenUtil;
import org.rcisoft.core.util.CyUserUtil;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;

import java.util.*;
import java.util.stream.Collectors;
import java.util.stream.IntStream;

/**
 * Created by cy on 2024年3月23日 上午9:54:37.
 */
@Service
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class PostBLessonServiceImpl extends ServiceImpl<PostBLessonRepository, PostBLesson> implements BLessonService {


    private static String lessonType = "1";
    private static String entQualityLesson = "1";
    /**
     * 题型 判断题
     */
    private static Integer questionType = 3;
    @Autowired
    private PostBLessonRepository bLessonRepository;
    @Autowired
    private Global global;
    /**
     * 企业服务
     */
    @Autowired
    private UnitService unitService;
    /**
     * 题库服务
     */
    @Autowired
    private PostPcLessonBrowseService pcLessonBrowseService;
    @Autowired
    private PostTeaExamOptionsRepository teaExamOptionsRepository;
    @Autowired
    private PostTeaExamQuestionsRepository teaExamQuestionsRepository;
    @Autowired
    private PostTeaExamExaminationPaperRepository teaExamExaminationPaperRepository;
    @Autowired
    private PostTeaExamQuestionsExaminationRepository teaExamQuestionsExaminationRepository;


    /**
     * 分页查询用户数据
     *
     * @param paginationUtility
     * @param
     * @return
     */
    @Override
    public IPage<BLessonDTO> queryPcPostBLessonsByPagination(CyPageInfo<BLessonDTO> paginationUtility, BLessonDTO bLessonDTO) {
        IPage<BLessonDTO> pagination = baseMapper.queryPcPostBLessonsByPagination(paginationUtility, bLessonDTO);
        List<BLessonDTO> records = pagination.getRecords();
        //根据id 统计题目数目
        records.stream().map(record -> {
            //统计题目数目
            QuestionsDTO questionsDTO = baseMapper.getQuestionsDTO(record.getBusinessId());
            record.setQuestionsDTO(questionsDTO);
            //分数统计
            record.setFullScore(baseMapper.getScoreCount(record.getBusinessId()));
            //企业数目
            record.setCompanyNum(baseMapper.getCount(record.getBusinessId()));
            return record;
        }).collect(Collectors.toList());
        pagination.setRecords(records);
        return pagination;
    }

    @Override
    public PostBLessonVO findById(String businessId) {
        PostBLesson postBLesson = baseMapper.selectById(businessId);

        PostBLessonVO pastBLessonVO = new PostBLessonVO();
        BeanUtils.copyProperties(postBLesson, pastBLessonVO);
        return pastBLessonVO;
    }

    @Override
    public CyPersistModel update(PostBLessonVO postBLesson, String token) {
        PostBLesson model = new PostBLesson();
        model.setLessonType(lessonType);
        model.setEntQualityLesson(entQualityLesson);
        BeanUtils.copyProperties(postBLesson, model);
//        if (isRepeat(model.getJobClassify(), model.getDifficultyClassify())) {
//            throw new CyServiceException(10001, "岗位分类和难度分类不能重复");
//        }
        int line = 0;
        BLessonDirection direction = new BLessonDirection();
        direction.setLecturerId(model.getLessonTeaName());
        if (model.getBusinessId() == null) {
            if (StringUtils.isEmpty(model.getDefaultUrl())) {
                model.setDefaultUrl(global.getDEFAULT_COURSE_LOCATION());
            }
            CyUserUtil.setCurrentPersistOperation(model);
            ArrayList<PostBLesson> bLessons = new ArrayList<>();
            bLessons.add(model);
            line = bLessonRepository.insertList(bLessons);
            //添加课程方向信息
            direction.setBusinessId(CyIdGenUtil.uuid());
            direction.setLessionId(model.getBusinessId());
            bLessonRepository.insertLessonDirection(direction);
        } else {
            CyUserUtil.setCurrentMergeOperation(model);
            // 处理前端将非空字段置空后端不修改问题
            nonNullValidation(model);
            line = bLessonRepository.updateById(model);
            direction.setLessionId(model.getBusinessId());
            bLessonRepository.updateDirectionByLessonId(direction);
        }
        return new CyPersistModel(line);
    }

    @Override
    public CyPersistModel removeLogical(String businessId) {
        PostBLesson bLesson = baseMapper.selectById(businessId);
        bLesson.setDeleted();
        int line = baseMapper.deleteById(bLesson);
        log.debug(CyUserUtil.getAuthenUsername() + "逻辑删除了ID为" +
                bLesson.getBusinessId() + "的信息");
        return new CyPersistModel(line);
    }


    /**
     * 岗位分类与题库难度的组合判断页有没有重复的数据
     *
     * @param jobClassify        岗位分类
     * @param difficultyClassify 难度分类
     * @return true:有重复数据
     */
    @Override
    public Boolean isRepeat(String jobClassify, String difficultyClassify) {
        LambdaQueryWrapper<PostBLesson> lambdaQueryWrapper = new LambdaQueryWrapper<>();
        lambdaQueryWrapper.eq(PostBLesson::getJobClassify, jobClassify);
        lambdaQueryWrapper.eq(PostBLesson::getDifficultyClassify, difficultyClassify);
        return bLessonRepository.selectCount(lambdaQueryWrapper) > 0;

    }

    @Transactional(propagation = Propagation.REQUIRED, readOnly = false)
    @Override
    public CyPersistModel addEnterprise(AddEnterpriseVO addEnterpriseVO, String token) {
        //根据id查询企业员工
        List<Integer> integerList = addEnterpriseVO.getIntegerList();
        List<AddEnterpriseDTO> addEnterprise = new ArrayList<>();
        if (integerList != null && integerList.size() > 0) {
            addEnterprise = integerList.stream().map(obj -> {
                AddEnterpriseDTO addEnterpriseDTO = new AddEnterpriseDTO();
                addEnterpriseDTO.setJobId(addEnterpriseVO.getLessonId());
                addEnterpriseDTO.setEnterpriseId(obj);
                //查询用户 id
                List<Integer> integers = unitService.SelectUserIdByEnterpriseId(obj);
                //写一个查询判断
                Boolean isExist = pcLessonBrowseService.isExist(integerList, addEnterpriseVO.getLessonId(), ItemStatus.DELETE.getStatus());
                if (isExist) {
                    Boolean isBoolean = pcLessonBrowseService.updateSystemQuestion(integers,
                            null, addEnterpriseVO.getLessonId());
                    if (!isBoolean) {
                        throw new CyServiceException(10001, "企业添加失败");
                    }
                }
                //用户批量添加课程
                if (integers.size() > 0) {
                    pcLessonBrowseService.addSystemQuestion(integers.stream().map(userId -> {
                        PostPcLessonBrowse pcLessonBrowse = new PostPcLessonBrowse();
                        pcLessonBrowse.setUserId(userId);
                        pcLessonBrowse.setStatus(ItemStatus.LEARNING.getStatus());
                        pcLessonBrowse.setFlag(ItemStatus.LEARNING.getStatus());
                        pcLessonBrowse.setLessonId(addEnterpriseVO.getLessonId());
                        return pcLessonBrowse;
                    }).toList());
                }
                return addEnterpriseDTO;
            }).toList();
        }
        //批量插入关联数据
        if (bLessonRepository.addEnterprise(addEnterprise) > 0) {
            log.info("添加成功");
            return new CyPersistModel(1);
        }
        throw new CyServiceException(10001, "添加失败");
    }

    @Override
    public List<EnterpriseDTO> selectEnterprise(String lessonId, String unitName) {
        return bLessonRepository.getEnterprise(lessonId, unitName);
    }


    /**
     * 用户查询自己的题目列表
     *
     * @param paginationUtility
     * @param questionBankVO
     * @return
     */
    @Override
    public IPage<QuestionsExamination> queryBLessonByPagination(CyPageInfo<QuestionsExamination> paginationUtility,
                                                                QuestionBankVO questionBankVO) {
        //查询用户的单位
        PostSysUnit postSysUnit = baseMapper.querySysUnit(questionBankVO.getUserId());
        if (postSysUnit == null) {
            return paginationUtility;
        }
        //企业id 和 试题分类   题目难度
        String courseId = baseMapper.queryTeaExamOptionss(questionBankVO, postSysUnit.getBusinessId());
        if (StringUtils.isBlank(courseId)) {
            return paginationUtility;
        }
        //查询试题状态
        String status = baseMapper.queryTeaExamOptionssStatus(courseId, questionBankVO.getUserId());
        if (StringUtils.isNotBlank(status)) {
            if (status.equals(ItemStatus.NOT_START.getStatus())) {
                return paginationUtility;
            }
        }
        Page<QuestionsExamination> questionsExaminationPage = baseMapper.queryFinishCourse
                (paginationUtility, courseId, questionBankVO.getUserId());
        return questionsExaminationPage;

    }

    //保存试题
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel addPersist(PostExamQuestionDto examQuestionDto) {
        PostTeaExamQuestions teaExamQuestions = new PostTeaExamQuestions();
//        //增加操作
        BeanUtils.copyProperties(examQuestionDto, teaExamQuestions);

        if (teaExamQuestionsRepository.queryNumbeSomeCourse(teaExamQuestions) > 0)
            throw new CyServiceException(1001, "同一岗位题库,该题目编号已存在");
        if (teaExamQuestionsRepository.queryNumberSomeWeiht(teaExamQuestions) > 0)
            throw new CyServiceException(1001, "同一岗位题库,该权重已存在");
        teaExamQuestions.setCreateBy("1");
        int line = teaExamQuestionsRepository.insert(teaExamQuestions);
        if (!examQuestionDto.getOptionsList().isEmpty()) {
            examQuestionDto.getOptionsList().stream().forEach(item -> {
                item.setQuestionsId(teaExamQuestions.getBusinessId());
                item.setFlag("1");
                teaExamOptionsRepository.insert(item);
            });
        }
        log.debug(CyUserUtil.getAuthenUsername() + "新增了ID为" +
                teaExamQuestions.getBusinessId() + "的试题表信息");
        return new CyPersistModel(line);
    }


    @Override
    public IPage<QuestionsList> queryQuestionTypeByPagination(CyPageInfo<QuestionsList> paginationUtility, QuestionsList questionsList, String courseId) {
        return baseMapper.queryQuestionTypeByPagination(paginationUtility, questionsList, courseId);
    }


    @Override
    @Transactional(propagation = Propagation.REQUIRED, readOnly = false)
    public CyPersistModel postPersist(PostBLessonVO postBLesson, String token) {
        PostBLesson model = new PostBLesson();
        model.setLessonType(lessonType);
        model.setEntQualityLesson(entQualityLesson);
        BeanUtils.copyProperties(postBLesson, model);
        if (isRepeat(model.getJobClassify(), model.getDifficultyClassify())) {
            throw new CyServiceException(10001, "岗位分类和难度分类不能重复");
        }
        int line = 0;
        BLessonDirection direction = new BLessonDirection();
        direction.setLecturerId(model.getLessonTeaName());
        if (model.getBusinessId() == null) {
            if (StringUtils.isEmpty(model.getDefaultUrl())) {
                model.setDefaultUrl(global.getDEFAULT_COURSE_LOCATION());
            }
            CyUserUtil.setCurrentPersistOperation(model);
            ArrayList<PostBLesson> bLessons = new ArrayList<>();
            bLessons.add(model);
            line = bLessonRepository.insertList(bLessons);
            //添加课程方向信息
            direction.setBusinessId(CyIdGenUtil.uuid());
            direction.setLessionId(model.getBusinessId());
            bLessonRepository.insertLessonDirection(direction);
        } else {
            CyUserUtil.setCurrentMergeOperation(model);
            // 处理前端将非空字段置空后端不修改问题
            nonNullValidation(model);
            line = bLessonRepository.updateById(model);
            direction.setLessionId(model.getBusinessId());
            bLessonRepository.updateDirectionByLessonId(direction);
        }
        return new CyPersistModel(line);
    }

    private void nonNullValidation(PostBLesson model) {
        if (StringUtils.isBlank(model.getJobClassify())) {
            model.setJobClassify("");
        }
        if (StringUtils.isBlank(model.getTecClassify())) {
            model.setTecClassify("");
        }
        if (StringUtils.isBlank(model.getTecClassifySchool())) {
            model.setTecClassifySchool("");
        }
        if (StringUtils.isBlank(model.getLessonDescription())) {
            model.setLessonDescription("");
        }
        if ("0".equals(model.getLessonType())) {
            model.setClassPlan("");
        }
        if ("0".equals(model.getLessonTypeSchool())) {
            model.setClassPlanSchool("");
        }
    }

    @Override
    public PostExamQuestionDto queryAllExamQuestionDto(String id) {
        PostTeaExamQuestions postTeaExamQuestions = teaExamQuestionsRepository.selectById(id);
        PostExamQuestionDto questionDto = new PostExamQuestionDto();
        BeanUtils.copyProperties(postTeaExamQuestions, questionDto);
        log.info("试提主表信息: {}", questionDto);
        //PostTeaExamOptions
        List<PostTeaExamOptions> postTeaExamOptions = teaExamOptionsRepository.queryTeaExamOptionById(Integer.valueOf(id));
        questionDto.setOptionsList(postTeaExamOptions);
        return questionDto;
    }


    /**
     * 修改试题
     *
     * @param examQuestionDto
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(PostExamQuestionDto examQuestionDto) {
        /**
         * 1.修改试题信息
         * 2.根据试题id修改与本试题有关的所有选项
         * **/
        PostTeaExamQuestions teaExamQuestions = new PostTeaExamQuestions();
        BeanUtils.copyProperties(examQuestionDto, teaExamQuestions);
        if (baseMapper.queryNumbeSomeCourse(teaExamQuestions) > 0)
            throw new CyServiceException(1001, "同一课程下,该题目编号已存在");
//        if (baseMapper.queryNumberSomeWeiht(teaExamQuestions) > 0)
//            throw new CyServiceException(1001, "同一课程下,该权重已存在");
        int line = teaExamQuestionsRepository.updateById(teaExamQuestions);
        teaExamOptionsRepository.deleteByQuestionsId(examQuestionDto.getBusinessId());
        if (!examQuestionDto.getOptionsList().isEmpty()) {
            examQuestionDto.getOptionsList().stream().forEach(item -> {
                item.setQuestionsId(examQuestionDto.getBusinessId());
                item.setFlag("1");
                teaExamOptionsRepository.insert(item);
            });
        }
        log.debug(CyUserUtil.getAuthenUsername() + "修改了ID为" + teaExamQuestions.getBusinessId() + "的试题表信息");
        return new CyPersistModel(line);
    }


    /**
     * 修改试题状态
     *
     * @param status
     * @param businessId
     * @return
     */
    @Override
    public CyPersistModel changeStatus(String status, Integer businessId) {
        PostTeaExamQuestions postTeaExamQuestions = teaExamQuestionsRepository.selectById(businessId);
        postTeaExamQuestions.setFlag(status);
        if (teaExamQuestionsRepository.updateById(postTeaExamQuestions) > 0) {
            return new CyPersistModel(1);
        }

        throw new CyServiceException(10001, "修改失败");
    }

    @Override
    public CyPersistModel changeStatusLesson(String status, String businessId) {
        PostBLesson postBLesson = baseMapper.selectById(businessId);
        postBLesson.setFlag(status);
        if (baseMapper.updateById(postBLesson) > 0) {
            return new CyPersistModel(1);
        }

        throw new CyServiceException(10001, "修改失败");
    }


    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel deleteEnterprise(String businessId, Integer enterpriseId) {
        //根据题库id和企业id查询用户题目表格
        List<Integer> integers = unitService.SelectUserIdByEnterpriseId(enterpriseId);
        Boolean isBoolean = pcLessonBrowseService.updateSystemQuestion(integers, ItemStatus.NOT_START.getStatus(), businessId);
        if (isBoolean) {
            int line = baseMapper.deleteEnterprise(businessId, enterpriseId);
            return new CyPersistModel(line);
        }
        throw new CyServiceException(10001, "企业删除失败");

    }

    @Override
    public AnswerStatus queryAllExamQuestionDetail(QuestionBankVO questionBankVO) {

        AnswerStatus answerStatus = new AnswerStatus();
        //查询用户的单位
        PostSysUnit postSysUnit = baseMapper.querySysUnit(questionBankVO.getUserId());
        if (postSysUnit == null) {
            return null;
        }
        //企业id 和 试题分类   题目难度
        String courseId = baseMapper.queryTeaExamOptionss(questionBankVO, postSysUnit.getBusinessId());
        //查询试题状态
        String status = baseMapper.queryTeaExamOptionssStatus(courseId, questionBankVO.getUserId());
        if (!StringUtils.isBlank(status)) {
            if (status.equals(ItemStatus.NOT_START.getStatus())) {
                return null;
            }
        }
        if (StringUtils.isBlank(courseId)) {
            return null;
        }
        if (StringUtils.isBlank(status)) {
            return null;
        }

        queryTeaExamOptionsDTO queryTeaExamOptionsDTO = baseMapper.queryTeaExamOptions(courseId, questionBankVO.getUserId());
        //无记录 未答题 给创建
        if (queryTeaExamOptionsDTO == null) {
            //开始答题
            answerStatus.setStatus(ItemStatus.NOT_START.getStatus());
            PostTeaExamExaminationPaper postTeaExamExaminationPaper = new PostTeaExamExaminationPaper();
            postTeaExamExaminationPaper.setFlag("1");
            postTeaExamExaminationPaper.setCourseId(courseId);
            postTeaExamExaminationPaper.setAnswerId(Integer.valueOf(CyUserUtil.getAuthenBusinessId()));
            postTeaExamExaminationPaper.setStartTime(new Date());
            postTeaExamExaminationPaper.setStatus(ItemStatus.LEARNING.getStatus());
            postTeaExamExaminationPaper.setRemarks(ItemStatus.NOT_START.getStatus());
            teaExamExaminationPaperRepository.insert(postTeaExamExaminationPaper);
            answerStatus.setBusinessId(postTeaExamExaminationPaper.getBusinessId());
            answerStatus.setLessonId(courseId);
            return answerStatus;
        }
        //完成答题
        if (queryTeaExamOptionsDTO.getStatus().equals(ItemStatus.FINISH.getStatus())) {
            PostTeaExamExaminationPaper postTeaExamExaminationPaper = new PostTeaExamExaminationPaper();
            postTeaExamExaminationPaper.setFlag("1");
            postTeaExamExaminationPaper.setCourseId(courseId);
            postTeaExamExaminationPaper.setAnswerId(Integer.valueOf(CyUserUtil.getAuthenBusinessId()));
            postTeaExamExaminationPaper.setStartTime(new Date());
            postTeaExamExaminationPaper.setStatus(ItemStatus.LEARNING.getStatus());
            postTeaExamExaminationPaper.setRemarks(ItemStatus.FINISH.getStatus());
            teaExamExaminationPaperRepository.insert(postTeaExamExaminationPaper);
            answerStatus.setBusinessId(postTeaExamExaminationPaper.getBusinessId());
            answerStatus.setLessonId(courseId);
            answerStatus.setStatus(ItemStatus.FINISH.getStatus());
        }
        // 第一次开始  1 0
        if (queryTeaExamOptionsDTO.getStatus().equals(ItemStatus.LEARNING.getStatus()) && queryTeaExamOptionsDTO.getRemarks().equals(ItemStatus.NOT_START.getStatus())) {
            answerStatus.setBusinessId(queryTeaExamOptionsDTO.getBusinessId());
            answerStatus.setLessonId(courseId);
            answerStatus.setStatus(ItemStatus.NOT_START.getStatus());
            return answerStatus;
        }
        // 继续答题
        if (queryTeaExamOptionsDTO.getStatus().equals(ItemStatus.LEARNING.getStatus()) && queryTeaExamOptionsDTO.getRemarks().equals(ItemStatus.LEARNING.getStatus())) {
            answerStatus.setBusinessId(queryTeaExamOptionsDTO.getBusinessId());
            answerStatus.setLessonId(courseId);
            answerStatus.setStatus(ItemStatus.LEARNING.getStatus());
            return answerStatus;
        }

        //考完后再次考试  1 2
        if (queryTeaExamOptionsDTO.getStatus().equals(ItemStatus.LEARNING.getStatus()) && queryTeaExamOptionsDTO.getRemarks().equals(ItemStatus.FINISH.getStatus())) {
            answerStatus.setBusinessId(queryTeaExamOptionsDTO.getBusinessId());
            answerStatus.setLessonId(courseId);
            answerStatus.setStatus(ItemStatus.FINISH.getStatus());
            return answerStatus;
        }
        return answerStatus;
    }

    @Override
    public Map<String, Object> findByLessonId(ExaminationPaperVO examPaperVO) {

        HashMap<String, Object> map = new HashMap<>();
        //根据答题记录查询用户答题状态
        int insert = 0;
        PostTeaExamExaminationPaper teaExamExaminationPaper = new PostTeaExamExaminationPaper();
        if (examPaperVO.getBusinessId() == null) {
            //创建答题记录
            teaExamExaminationPaper.setAnswerId(examPaperVO.getUserId());
            teaExamExaminationPaper.setStartTime(new Date());
            teaExamExaminationPaper.setCourseId(examPaperVO.getLessonId());
            teaExamExaminationPaper.setStatus(ItemStatus.LEARNING.getStatus());
            insert = teaExamExaminationPaperRepository.insert(teaExamExaminationPaper);
        } else {

            PostTeaExamExaminationPaper postTeaExamExaminationPaper =
                    teaExamExaminationPaperRepository.selectById(examPaperVO.getBusinessId());
            if (examPaperVO.getStatus().equals(ItemStatus.LEARNING.getStatus())) {
                if (postTeaExamExaminationPaper == null || postTeaExamExaminationPaper.getStatus().equals(ItemStatus.FINISH.getStatus())) {
                    teaExamExaminationPaper.setAnswerId(examPaperVO.getUserId());
                    teaExamExaminationPaper.setStartTime(new Date());
                    teaExamExaminationPaper.setCourseId(examPaperVO.getLessonId());
                    teaExamExaminationPaper.setStatus(ItemStatus.LEARNING.getStatus());
                    insert = teaExamExaminationPaperRepository.insert(teaExamExaminationPaper);
                } else {
                    teaExamExaminationPaper = postTeaExamExaminationPaper;
                }
            } else {
                teaExamExaminationPaper = postTeaExamExaminationPaper;
            }
        }
        if (teaExamExaminationPaper == null) {
            throw new CyServiceException(10001, "答题记录创建失败");
        }
        LambdaQueryWrapper<PostTeaExamQuestions> wrapper = new LambdaQueryWrapper<>();
        wrapper.eq(PostTeaExamQuestions::getCourseId, examPaperVO.getLessonId());
        wrapper.eq(PostTeaExamQuestions::getFlag, ItemStatus.LEARNING.getStatus());
        wrapper.orderByDesc(PostTeaExamQuestions::getWeight);
        List<PostTeaExamQuestions> teaExamQuestions = teaExamQuestionsRepository.selectList(wrapper);
        List<PostExamQuestionDto> examQuestionDtos = new ArrayList<>();
        if (!teaExamQuestions.isEmpty()) {
            PostTeaExamExaminationPaper finalTeaExamExaminationPaper = teaExamExaminationPaper;
            examQuestionDtos = teaExamQuestions.stream().map(obj -> {
                PostExamQuestionDto postExamQuestionDto = new PostExamQuestionDto();
                BeanUtils.copyProperties(obj, postExamQuestionDto);
                //查询用户答案
                if (finalTeaExamExaminationPaper.getStatus().equals(ItemStatus.LEARNING.getStatus())) {
                    //根据id查询用户的答案
                    PostTeaExamQuestionsExamination postTeaExamQuestionsExamination =
                            selectByQuestionsId(obj.getBusinessId(), finalTeaExamExaminationPaper.getBusinessId());
                    if (postTeaExamQuestionsExamination != null) {
                        postExamQuestionDto.setUanswer(postTeaExamQuestionsExamination.getAnswer());
                    }
                }
                //设置标准答案为空
                postExamQuestionDto.setRecordId(finalTeaExamExaminationPaper.getBusinessId());
                postExamQuestionDto.setAnswer(null);

                postExamQuestionDto.setOptionsList(queryTeaExamOptionss(obj));
                return postExamQuestionDto;
            }).collect(Collectors.toList());
        }
        //试题列表
        map.put("qsList", examQuestionDtos);
        //试卷总分
        map.put("totalScore", teaExamQuestions.stream().mapToInt(PostTeaExamQuestions::getMark).sum());
        //及格分
        map.put("priceScore", selectById(examPaperVO.getLessonId()).getPassingGrade());
        return map;
    }

    @Override
    public CyPersistModel answer(AnswerVO answerVO) {
        //修改为3

        PostTeaExamExaminationPaper postTeaExamExaminationPaper = new PostTeaExamExaminationPaper();
        postTeaExamExaminationPaper.setBusinessId(answerVO.getRecordId());
        postTeaExamExaminationPaper.setRemarks(ItemStatus.LEARNING.getStatus());
        teaExamExaminationPaperRepository.updateById(postTeaExamExaminationPaper);


        //根据题目id查询题目信息
        int insert = 0;
        PostTeaExamQuestions postTeaExamQuestions =
                teaExamQuestionsRepository.selectById(answerVO.getQuestionsId());
        //计算用户分数
        Integer answer = answer(postTeaExamQuestions, answerVO);
        PostTeaExamQuestionsExamination oldPostTeaExamQuestions = selectByQuestionsIdAndAnsw(answerVO);
        if (oldPostTeaExamQuestions != null) {
            oldPostTeaExamQuestions.setScore(answer);
            oldPostTeaExamQuestions.setAnswer(answerVO.getAnswer());
            insert = teaExamQuestionsExaminationRepository.updateById(oldPostTeaExamQuestions);
        } else {
            //根据条件查询题目是否存在
            PostTeaExamQuestionsExamination postTeaExamQuestionsExamination = new PostTeaExamQuestionsExamination();
            postTeaExamQuestionsExamination.setQuestionsId(answerVO.getQuestionsId());
            postTeaExamQuestionsExamination.setScore(answer);
            postTeaExamQuestionsExamination.setTeaPaperId(answerVO.getRecordId());
            postTeaExamQuestionsExamination.setAnswer(answerVO.getAnswer());
            postTeaExamQuestionsExamination.setFlag("1");
            insert = teaExamQuestionsExaminationRepository.insert(postTeaExamQuestionsExamination);
        }

        if (insert == 0) {
            throw new CyServiceException(10001, "答题记录创建失败");
        } else {
            return new CyPersistModel(insert);
        }
    }

    @Override
    public PostExamQuestionResultDto selectByQuestionsId(Integer questionsId) {
        PostExamQuestionResultDto postExamQuestionResultDto = new PostExamQuestionResultDto();
        PostTeaExamExaminationPaper postTeaExamExaminationPaper =
                teaExamExaminationPaperRepository.selectById(questionsId);
        if (postTeaExamExaminationPaper.getStatus().equals(ItemStatus.LEARNING.getStatus())) {
            postTeaExamExaminationPaper.setScore(sumAllQuestions(questionsId));
            postTeaExamExaminationPaper.setStatus(ItemStatus.FINISH.getStatus());
            postTeaExamExaminationPaper.setEndTime(new Date());
            int i = teaExamExaminationPaperRepository.updateById(postTeaExamExaminationPaper);
            if (i == 0) {
                throw new CyServiceException(10001, "答题记录更新失败");
            }
        }
        LambdaQueryWrapper<PostTeaExamQuestions> wrapper = new LambdaQueryWrapper<>();
        wrapper.eq(PostTeaExamQuestions::getCourseId, postTeaExamExaminationPaper.getCourseId());
        wrapper.eq(PostTeaExamQuestions::getFlag, ItemStatus.LEARNING.getStatus());
        wrapper.orderByDesc(PostTeaExamQuestions::getWeight);
        List<PostTeaExamQuestions> teaExamQuestions = teaExamQuestionsRepository.selectList(wrapper);
        List<PostExamQuestionDto> examQuestionDtos = new ArrayList<>();
        if (!teaExamQuestions.isEmpty()) {
            PostTeaExamExaminationPaper finalTeaExamExaminationPaper = postTeaExamExaminationPaper;
            examQuestionDtos = teaExamQuestions.stream().map(obj -> {
                PostExamQuestionDto postExamQuestionDto = new PostExamQuestionDto();
                BeanUtils.copyProperties(obj, postExamQuestionDto);
                if (obj.getQuestionType().equals(questionType)) {
                    postExamQuestionDto.setAnswer(Judgment.getCodeByName(obj.getAnswer()));
                }
                //查询用户答案
                if (finalTeaExamExaminationPaper.getStatus().equals(ItemStatus.FINISH.getStatus())) {
                    //根据id查询用户的答案
                    PostTeaExamQuestionsExamination postTeaExamQuestionsExamination =
                            selectByQuestionsId(obj.getBusinessId(), finalTeaExamExaminationPaper.getBusinessId());
                    if (postTeaExamQuestionsExamination != null) {
                        postExamQuestionDto.setUanswer(postTeaExamQuestionsExamination.getAnswer());
                        postExamQuestionDto.setGetScore(postTeaExamQuestionsExamination.getScore());
                        Integer score = postTeaExamQuestionsExamination.getScore();
                        postExamQuestionDto.setIsFalse(score == 0 ? "0" : "1");
                    }
                }
                postExamQuestionDto.setRecordId(finalTeaExamExaminationPaper.getBusinessId());

                postExamQuestionDto.setOptionsList(queryTeaExamOptionss(obj));
                return postExamQuestionDto;
            }).collect(Collectors.toList());
        }
        //试题列表
        postExamQuestionResultDto.setQsList(examQuestionDtos);
        postExamQuestionResultDto.setTotalScore(postTeaExamExaminationPaper.getScore());
        return postExamQuestionResultDto;
    }

    /**
     * 用户删除答题记录
     *
     * @param businessId
     * @return
     */
    @Override
    public CyPersistModel deleteLogical(Integer businessId) {
        int i = teaExamExaminationPaperRepository.deleteById(businessId);
        if (i == 0) {
            throw new CyServiceException(10001, "答题记录删除失败");
        } else {
            return new CyPersistModel(i);
        }
    }


    /**
     * 删除题目
     *
     * @param businessId
     * @return
     */
    @Override
    public CyPersistModel delete(Integer businessId) {

        if (teaExamQuestionsRepository.deleteById(businessId) > 0) {
            return new CyPersistModel(1);
        }

        throw new CyServiceException(10001, "修改失败");
    }

    /**
     * 导入数据
     *
     * @param file
     * @param courseId
     * @return
     */
    @Override
    public List<Integer> importDictData(MultipartFile file, String courseId) {
        List<ExcelPostTeaExamQuestionsVO> excelPostTeaExamQuestionsVOS =
                CyEpExcelUtil.importExcel(file, 1, 1, ExcelPostTeaExamQuestionsVO.class);
        if (excelPostTeaExamQuestionsVOS.isEmpty()) {
            throw new CyServiceException(10001, "导入数据为空");
        }
        List<Integer> list = new ArrayList<>();
        IntStream.range(0, excelPostTeaExamQuestionsVOS.size()).forEach(obj -> {
            /**
             * 如果 题目编号 题型 难度 题干 标准答案 都是空 认为是模板不对
             * **/
//            if (StringUtils.isEmpty(excelPostTeaExamQuestionsVOS.get(obj).getNumber()) && StringUtils.isEmpty(excelPostTeaExamQuestionsVOS.get(obj).getQuestionType()) && StringUtils.isEmpty(excelPostTeaExamQuestionsVOS.get(obj).getDifficulty()) && StringUtils.isEmpty(excelPostTeaExamQuestionsVOS.get(obj).getQuestionStem()) && StringUtils.isEmpty(excelPostTeaExamQuestionsVOS.get(obj).getAnswer()))
//                throw new CyServiceException(10001, "请上传正确的模板文件");
            PostExamQuestionDto postExamQuestionDto = new PostExamQuestionDto();
            postExamQuestionDto.setCourseId(courseId);
            ExcelPostTeaExamQuestionsVO excelPostTeaExamQuestionsVO = excelPostTeaExamQuestionsVOS.get(obj);
            Boolean notBlank = isNotBlank(excelPostTeaExamQuestionsVO);
            if (!notBlank) {
                list.add(obj + 1);
            } else {
                BeanUtils.copyProperties(excelPostTeaExamQuestionsVO, postExamQuestionDto);
                //判断题目类型
                if (excelPostTeaExamQuestionsVO.getQuestionType().equals(QuestionType.SINGLE_CHOICE.getName()) ||
                        excelPostTeaExamQuestionsVO.getQuestionType().equals(QuestionType.MULTIPLE_CHOICE.getName())) {
                    //判断导入的是否为abcd
                    if (StringUtils.isNotBlank(excelPostTeaExamQuestionsVO.getAnswer())) {
                        PostTeaExamOptions postTeaExamOptionsA = new PostTeaExamOptions();
                        PostTeaExamOptions postTeaExamOptionsB = new PostTeaExamOptions();
                        PostTeaExamOptions postTeaExamOptionsC = new PostTeaExamOptions();
                        PostTeaExamOptions postTeaExamOptionsD = new PostTeaExamOptions();
                        if (StringUtils.isNotBlank(excelPostTeaExamQuestionsVO.getOptionA())){
                            postTeaExamOptionsA.setType(OptionsEnum.A.getCode());
                            postTeaExamOptionsA.setDetails(excelPostTeaExamQuestionsVO.getOptionA());
                        }
                        if (StringUtils.isNotBlank(excelPostTeaExamQuestionsVO.getOptionB())){
                            postTeaExamOptionsB.setType(OptionsEnum.B.getCode());
                            postTeaExamOptionsB.setDetails(excelPostTeaExamQuestionsVO.getOptionB());
                        }
                        if (StringUtils.isNotBlank(excelPostTeaExamQuestionsVO.getOptionC())){
                            postTeaExamOptionsC.setType(OptionsEnum.C.getCode());
                            postTeaExamOptionsC.setDetails(excelPostTeaExamQuestionsVO.getOptionC());
                        }
                        if (StringUtils.isNotBlank(excelPostTeaExamQuestionsVO.getOptionD())){
                            postTeaExamOptionsD.setType(OptionsEnum.D.getCode());
                            postTeaExamOptionsD.setDetails(excelPostTeaExamQuestionsVO.getOptionD());
                        }
                        postExamQuestionDto.setOptionsList(Arrays.asList(postTeaExamOptionsA, postTeaExamOptionsB,
                                postTeaExamOptionsC, postTeaExamOptionsD));
                        postExamQuestionDto.setRemarks(excelPostTeaExamQuestionsVO.getRemark());
                    }


                }
                if (QuestionType.getCode(excelPostTeaExamQuestionsVO.getQuestionType()) == null) {
                    list.add(obj + 1);
                }
                if (DifficultyEnum.getCode(excelPostTeaExamQuestionsVO.getDifficulty()) == null) {
                    list.add(obj + 1);
                } else {
                    postExamQuestionDto.setQuestionType(QuestionType.getCode(excelPostTeaExamQuestionsVO.getQuestionType()));
                    postExamQuestionDto.setDifficulty(DifficultyEnum.getCode(excelPostTeaExamQuestionsVO.getDifficulty()));
                    postExamQuestionDto.setRemarks(excelPostTeaExamQuestionsVO.getRemark());
                    if (!addMerge(postExamQuestionDto)) {
                        list.add(obj + 1);
                    }
                }
            }
        });
        return list;
    }

    /**
     * 查询题库列表
     *
     * @param teaExamQuestions
     * @return
     */

    public List<PostTeaExamOptions> queryTeaExamOptionss(PostTeaExamQuestions teaExamQuestions) {
        LambdaQueryWrapper<PostTeaExamOptions> wrapper = new LambdaQueryWrapper<>();
        wrapper.eq(PostTeaExamOptions::getQuestionsId, teaExamQuestions.getBusinessId());
        wrapper.eq(PostTeaExamOptions::getFlag, ItemStatus.LEARNING.getStatus());
        wrapper.eq(PostTeaExamOptions::getDelFlag, ItemStatus.NOT_START.getStatus());
        wrapper.orderByAsc(PostTeaExamOptions::getBusinessId);
        return teaExamOptionsRepository.selectList(wrapper);
    }


    /**
     * 根据题目id和记录id 查询用户答题对象
     *
     * @param questionsId
     * @param teaPaperId
     * @return
     */

    public PostTeaExamQuestionsExamination selectByQuestionsId(Integer questionsId, Integer teaPaperId) {
        LambdaQueryWrapper<PostTeaExamQuestionsExamination> limitQueryWrapper = new LambdaQueryWrapper<>();
        limitQueryWrapper.eq(PostTeaExamQuestionsExamination::getQuestionsId, questionsId);
        limitQueryWrapper.eq(PostTeaExamQuestionsExamination::getTeaPaperId, teaPaperId);
        PostTeaExamQuestionsExamination postTeaExamQuestionsExamination =
                teaExamQuestionsExaminationRepository.selectOne(limitQueryWrapper);
        return postTeaExamQuestionsExamination;
    }

    /**
     * 获取试卷总分数
     *
     * @param teaPaperId
     * @return
     */
    public Integer sumAllQuestions(Integer teaPaperId) {
        LambdaQueryWrapper<PostTeaExamQuestionsExamination> limitQueryWrapper = new LambdaQueryWrapper<>();
        limitQueryWrapper.eq(PostTeaExamQuestionsExamination::getTeaPaperId, teaPaperId);
        List<PostTeaExamQuestionsExamination> postTeaExamQuestionsExaminations =
                teaExamQuestionsExaminationRepository.selectList(limitQueryWrapper);
        return postTeaExamQuestionsExaminations.stream().mapToInt(PostTeaExamQuestionsExamination::getScore).sum();
    }

    /**
     * 根据记录id 和题目id   查询用户是否答过题题目
     */
    public PostTeaExamQuestionsExamination selectByQuestionsIdAndAnsw(AnswerVO answer) {
        LambdaQueryWrapper<PostTeaExamQuestionsExamination> limitQueryWrapper = new LambdaQueryWrapper<>();
        limitQueryWrapper.eq(PostTeaExamQuestionsExamination::getQuestionsId, answer.getQuestionsId());
        limitQueryWrapper.eq(PostTeaExamQuestionsExamination::getTeaPaperId, answer.getRecordId());
        return teaExamQuestionsExaminationRepository.selectOne(limitQueryWrapper);
    }

    /**
     * 根据id 查询岗位题目
     */
    public PostBLesson selectById(String businessId) {
        return baseMapper.selectById(businessId);
    }


    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    public Boolean addMerge(PostExamQuestionDto examQuestionDto) {
        PostTeaExamQuestions teaExamQuestions = new PostTeaExamQuestions();
//        //增加操作
        BeanUtils.copyProperties(examQuestionDto, teaExamQuestions);

        if (teaExamQuestionsRepository.queryNumbeSomeCourse(teaExamQuestions) > 0) {
            //编号相同
            return false;
        }
//        if (teaExamQuestionsRepository.queryNumberSomeWeiht(teaExamQuestions) > 0) {
//            //权重相同
//            return false;
//        }
        // 判断examQuestionDto.getNumber()是否为数字
        if (examQuestionDto.getNumber() != null){
            try {
                // 尝试获取 number 属性并将其转换为整数
                int number = Integer.parseInt(examQuestionDto.getNumber());
            } catch (NumberFormatException e) {
                // 如果转换失败，说明 getNumber() 返回的不是一个有效的整数字符串
                return false;
            }
        }
        //判断题限制
        if (examQuestionDto.getQuestionType().equals(QuestionType.JUDGMENT.code)){
            if (!examQuestionDto.getAnswer().trim().equals("对") && !examQuestionDto.getAnswer().trim().equals("错")){
                return false;
            }
        }
        if (StringUtils.isNotEmpty(examQuestionDto.getRemarks())){
            if (examQuestionDto.getRemarks().length() > 255){
                //课题描述长度限制
                return false;
            }
        }
        if (examQuestionDto.getMark() > 9999) {
            //分数大小限制
            return false;
        }
        if (examQuestionDto.getAnswer().length() > 255){
            //答案长度限制
            return false;
        }
        if (examQuestionDto.getWeight() > 9999) {
            //权重大小限制
            return false;
        }
        if (examQuestionDto.getQuestionStem().length() > 255) {
            //题干长度过长
            return false;
        }
        if (examQuestionDto.getOptionsList() != null){
            if (StringUtils.isNotEmpty(examQuestionDto.getAnswer())){
                String[] parts = examQuestionDto.getAnswer().split("，");
                // 遍历分割后的每个部分
                for (String part : parts) {
                    char ch = part.trim().charAt(0);  // 去除前后空白并获取第一个字符
                    // 检查字符是否在 A, B, C, D 之中
                    if (ch != 'A' && ch != 'B' && ch != 'C' && ch != 'D') {
                        return false;  // 如果找到不符合条件的字符，则立即返回 false
                    }
                }
            }
            if (examQuestionDto.getOptionsList().get(0).getDetails().length() > 1000){
                //a选项输入的长度限制
                return false;
            }
            if (examQuestionDto.getOptionsList().get(1).getDetails().length() > 1000){
                //b选项输入的长度限制
                return false;
            }
            if (examQuestionDto.getOptionsList().get(2).getDetails().length() > 1000){
                //c选项输入的长度限制
                return false;
            }
            if (examQuestionDto.getOptionsList().get(3).getDetails().length() > 1000){
                //d选项输入的长度限制
                return false;
            }
        }
        teaExamQuestions.setCreateBy("1");
        teaExamQuestions.setFlag("1");
        teaExamQuestions.setRemarks(examQuestionDto.getRemarks());
        int line = teaExamQuestionsRepository.insert(teaExamQuestions);
        if (!CollectionUtil.isEmpty(examQuestionDto.getOptionsList())) {
            examQuestionDto.getOptionsList().stream().forEach(item -> {
                item.setQuestionsId(teaExamQuestions.getBusinessId());
                item.setFlag("1");
                teaExamOptionsRepository.insert(item);
            });
        }
        log.debug(CyUserUtil.getAuthenUsername() + "新增了ID为" +
                teaExamQuestions.getBusinessId() + "的试题表信息");
        if (line > 0) {
            return true;
        }
        return false;
    }


    /**
     * 判断导入的数据是否正确
     */
    public Boolean isNotBlank(ExcelPostTeaExamQuestionsVO excelPostTeaExamQuestionsVO) {
        if (StringUtils.isBlank(excelPostTeaExamQuestionsVO.getNumber()) ||
                StringUtils.isBlank(excelPostTeaExamQuestionsVO.getQuestionStem()) ||
                StringUtils.isBlank(excelPostTeaExamQuestionsVO.getQuestionType()) ||
                StringUtils.isBlank(excelPostTeaExamQuestionsVO.getDifficulty()) ||
                StringUtils.isBlank(excelPostTeaExamQuestionsVO.getAnswer())) {
            return false;
        }
        if (excelPostTeaExamQuestionsVO.getWeight() == null
                || excelPostTeaExamQuestionsVO.getMark() == null
        ) {
            return false;
        }
        // 判断题型
        QuestionType type = QuestionType.getCodeByName(excelPostTeaExamQuestionsVO.getQuestionType());
        if (type != null){
            switch (type) {
                case SINGLE_CHOICE:
                    if (StringUtils.isBlank(excelPostTeaExamQuestionsVO.getOptionA()) ||
                            StringUtils.isBlank(excelPostTeaExamQuestionsVO.getOptionB()) ||
                            StringUtils.isBlank(excelPostTeaExamQuestionsVO.getOptionC()) ||
                            StringUtils.isBlank(excelPostTeaExamQuestionsVO.getOptionD())) {
                        return false;
                    } else {
                        if (StringUtils.isBlank(excelPostTeaExamQuestionsVO.getOptionA()) ||
                                StringUtils.isBlank(excelPostTeaExamQuestionsVO.getOptionB()) ||
                                StringUtils.isBlank(excelPostTeaExamQuestionsVO.getOptionC()) ||
                                StringUtils.isBlank(excelPostTeaExamQuestionsVO.getOptionD())) {
                            return false;
                        }
                    }
                case MULTIPLE_CHOICE:
                    if (StringUtils.isBlank(excelPostTeaExamQuestionsVO.getOptionA()) ||
                            StringUtils.isBlank(excelPostTeaExamQuestionsVO.getOptionB()) ||
                            StringUtils.isBlank(excelPostTeaExamQuestionsVO.getOptionC()) ||
                            StringUtils.isBlank(excelPostTeaExamQuestionsVO.getOptionD())) {
                        return false;
                    }
                case JUDGMENT:
                    if (StringUtils.isBlank(excelPostTeaExamQuestionsVO.getAnswer())) {
                        return false;
                    }
                    break;
                default:
                    return false;

            }
        }else {
            return false;
        }
        return true;
    }

    /**
     * 用户判分
     */
    public Integer answer(PostTeaExamQuestions query, AnswerVO answerVO) {
        int score = 0;
        switch (QuestionType.getEnumByCode(query.getQuestionType())) {
            case SINGLE_CHOICE:
                if (query.getAnswer().equals(answerVO.getAnswer())) {
                    score = query.getMark();
                }
                break;
            case MULTIPLE_CHOICE:
                if (query.getAnswer().equals(answerVO.getAnswer())) {
                    score = query.getMark();
                }
                break;
            case JUDGMENT:
                if (Judgment.getNameByCode(answerVO.getAnswer()).equals(query.getAnswer())) {
                    score = query.getMark();
                }
                break;
            default:
                break;
        }
        return score;
    }

    /**
     * 判断一个字符串 里面是否 包含 A 或 B C D,
     */
    public Boolean isContain(String str) {
        String[] strArray = {"A", "B", "C", "D"};
        return Boolean.valueOf(Arrays.stream(strArray).anyMatch(str::contains));
    }


}
