package org.rcisoft.business.sysContest.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.business.sysContest.entity.CmsContest;
import org.rcisoft.business.sysContest.service.CmsContestService;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.exception.CyServiceException;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;


import java.util.List;

/**
* Created by cy on 2024年3月25日 下午7:45:56.
*/
@RestController
@RequestMapping("/cmscontest")
public class CmsContestController extends CyPaginationController<CmsContest> {


    @Autowired
    private CmsContestService cmsContestServiceImpl;

    @PreAuthorize("@cyPerm.hasPerm('cms:competition:increase')")
    @CyOpeLogAnno(title = "system-CmsContest管理-新增CmsContest", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="添加CmsContest", notes="添加CmsContest")
    @PostMapping(value = "/add")
    public CyResult add(@Valid CmsContest cmsContest, BindingResult bindingResult) {
        CyPersistModel data = cmsContestServiceImpl.persist(cmsContest);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        cmsContest);
    }
    @PreAuthorize("@cyPerm.hasPerm('cms:competition:removing')")
    @CyOpeLogAnno(title = "system-CmsContest管理-删除CmsContest", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="逻辑删除CmsContest", notes="逻辑删除CmsContest")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable Integer businessId,CmsContest cmsContest) {
        cmsContest.setBusinessId(businessId);
        CyPersistModel data = cmsContestServiceImpl.removeLogical(cmsContest);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:contest:delete')")
    @CyOpeLogAnno(title = "system-CmsContest管理-删除CmsContest", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="删除CmsContest", notes="删除CmsContest")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable Integer businessId,CmsContest cmsContest) {
        cmsContest.setBusinessId(businessId);
        CyPersistModel data = cmsContestServiceImpl.remove(cmsContest);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    @PreAuthorize("@cyPerm.hasPerm('cms:competition:modifications')")
    @CyOpeLogAnno(title = "system-CmsContest管理-修改CmsContest", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改CmsContest", notes="修改CmsContest")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable Integer businessId, @Valid CmsContest cmsContest, BindingResult bindingResult) {
        cmsContest.setBusinessId(businessId);
        CyPersistModel data = cmsContestServiceImpl.merge(cmsContest);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        cmsContest);
    }

    @PreAuthorize("@cyPerm.hasPerm('cms:competition:singleSearch')")
    @CyOpeLogAnno(title = "system-CmsContest管理-查询CmsContest", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单一CmsContest", notes="查询单一CmsContest")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable String businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        cmsContestServiceImpl.findById(businessId));
    }

//    @PreAuthorize("@cyPerm.hasPerm('cms:competition:search')")
    @CyOpeLogAnno(title = "system-CmsContest管理-查询CmsContest", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询CmsContest集合", notes="查询CmsContest集合")
    @GetMapping(value = "/queryCmsContests")
    public CyResult queryCmsContests(CmsContest cmsContest) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            cmsContestServiceImpl.findAll(cmsContest));
    }

    @PreAuthorize("@cyPerm.hasPerm('cms:competition:pageSearch')")
    @CyOpeLogAnno(title = "system-CmsContest管理-查询CmsContest", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="分页查询CmsContest集合", notes="分页查询CmsContest集合")
    @GetMapping(value = "/queryCmsContestByPagination")
    public CyGridModel listByPagination(CmsContest cmsContest) {
        cmsContestServiceImpl.findAllByPagination(getPaginationUtility(), cmsContest);
        return getGridModelResponse();
    }

    @PreAuthorize("@cyPerm.hasPerm('cms:competition:derive')")
    @CyOpeLogAnno(title = "system-CmsContest管理-查询CmsContest", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出CmsContest信息", notes = "导出CmsContest信息")
    @GetMapping(value = "/export")
    public void outCmsContest(HttpServletResponse response,CmsContest cmsContest,@PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="CmsContest信息.xls";break;
            case "1": excelName="CmsContest信息.xlsx";break;
            case "2": excelName="CmsContest信息.csv";break;
        }
        List<CmsContest> cmsContestList = cmsContestServiceImpl.export(cmsContest);
        CyEpExcelUtil.exportExcel(cmsContestList, "CmsContest信息", "CmsContest信息", CmsContest.class, excelName, response);
    }
}
