package org.rcisoft.business.sysContest.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.rcisoft.business.sysContest.dao.CmsContestRepository;
import org.rcisoft.business.sysContest.entity.CmsContest;
import org.rcisoft.business.sysContest.service.CmsContestService;
import org.rcisoft.common.component.Global;
import org.rcisoft.core.entity.CyFileEntity;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.aop.CyPageUtilAsp;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.core.service.CyBaseService;

import org.rcisoft.sys.ossInfo.dao.OssInfoMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.rcisoft.core.model.CyPageInfo;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import lombok.extern.slf4j.Slf4j;
import org.springframework.util.CollectionUtils;

/**
 * Created by cy on 2024年3月25日 下午7:45:56.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class CmsContestServiceImpl extends ServiceImpl<CmsContestRepository, CmsContest>  implements CmsContestService {

    @Autowired
    private Global global;
    @Autowired
    private OssInfoMapper ossInfoMapper;
    /**
    * 保存
    * @param cmsContest
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(CmsContest cmsContest){
        //增加操作
        int line = baseMapper.insert(cmsContest);
        log.debug(CyUserUtil.getAuthenUsername()+"新增了ID为"+
            cmsContest.getBusinessId()+"的信息");
        return new CyPersistModel(line);
    }

    /**
    * 删除
    * @param cmsContest
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(CmsContest cmsContest){
        int line = baseMapper.realDelete(cmsContest);
        log.debug(CyUserUtil.getAuthenUsername()+"删除了ID为"+
            cmsContest.getBusinessId()+"的信息");
        return new CyPersistModel(line);
    }

    /**
    * 逻辑删除
    * @param cmsContest
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(CmsContest cmsContest){
        cmsContest.setDeleted();
        int line = baseMapper.deleteById(cmsContest);
            log.debug(CyUserUtil.getAuthenUsername()+"逻辑删除了ID为"+
                cmsContest.getBusinessId()+"的信息");
            return new CyPersistModel(line);
    }

    /**
    * 修改
    * @param cmsContest
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(CmsContest cmsContest){
        cmsContest.setUpdateDate(new Date());
        cmsContest.setUpdateBy(CyUserUtil.getAuthenUsername());
        int line = baseMapper.updateCmsContestById(cmsContest);
        log.debug(CyUserUtil.getAuthenUsername()+"修改了ID为"+ cmsContest.getBusinessId()+"的信息");
        return new CyPersistModel(line);
    }

    /**
    * 根据id查询
    * @param id
    * @return
    */
    @Override
    public CmsContest findById(String id){
        CmsContest cmsContest = baseMapper.findCmsContestById(id);
        if (cmsContest.getUrl() != null){
            cmsContest.setUrl(global.getBase_Discovery()+cmsContest.getUrl());
        }
        return cmsContest;
    }

    /**
    * 分页查询
    * @param cmsContest
    * @return
    */
    @Override
    public IPage<CmsContest> findAllByPagination(CyPageInfo<CmsContest> paginationUtility,
        CmsContest cmsContest){
        IPage<CmsContest> result = baseMapper.queryCmsContestsPaged(paginationUtility, cmsContest);
        List<CmsContest> cmsContestList = result.getRecords();
        for (CmsContest cmsContest1 : cmsContestList) {
            if (cmsContest1.getUrl() != null){
                cmsContest1.setUrl(global.getBase_Discovery()+cmsContest1.getUrl());
            }
        }
        result.setRecords(cmsContestList);
        return   result;

    }

    /**
    * 查询list
    * @param cmsContest
    * @return
    */
    @Override
    public List<CmsContest> findAll(CmsContest cmsContest){
        List<CmsContest> cmsContests = baseMapper.queryCmsContests(cmsContest);
        if (!CollectionUtils.isEmpty(cmsContests)){
            for (CmsContest contest : cmsContests) {
                if (contest.getUrl() != null){
                    contest.setUrl(global.getBase_Discovery()+contest.getUrl());
                }
            }
        }
        return cmsContests;
    }

    /**
    * 导出
    * @return
    */
    @Override
    public List<CmsContest> export(CmsContest cmsContest) {
        List<CmsContest> cmsContestList = baseMapper.queryCmsContests(cmsContest);
        return cmsContestList;
    }

}
