package org.rcisoft.business.sysFeedBack.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.exception.CyServiceException;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;


import org.rcisoft.business.sysFeedBack.entity.CmsFeedback;
import org.rcisoft.business.sysFeedBack.service.CmsFeedbackService;

import java.util.List;

/**
* Created by cy on 2024年3月27日 下午1:53:08.
*/
@RestController
@RequestMapping("/cmsfeedback")
public class CmsFeedbackController extends CyPaginationController<CmsFeedback> {


    @Autowired
    private CmsFeedbackService cmsFeedbackServiceImpl;

    @PreAuthorize("@cyPerm.hasPerm('opm:cmsfeedback:add')")
    @CyOpeLogAnno(title = "system-意见反馈管理-新增意见反馈", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="添加意见反馈", notes="添加意见反馈")
    @PostMapping(value = "/add")
    public CyResult add(@Valid CmsFeedback cmsFeedback, BindingResult bindingResult) {
        CyPersistModel data = cmsFeedbackServiceImpl.persist(cmsFeedback);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        cmsFeedback);
    }
    @PreAuthorize("@cyPerm.hasPerm('opm:cmsfeedback:deleteLogical')")
    @CyOpeLogAnno(title = "system-意见反馈管理-删除意见反馈", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="逻辑删除意见反馈", notes="逻辑删除意见反馈")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable Integer businessId,CmsFeedback cmsFeedback) {
        cmsFeedback.setBusinessId(businessId);
        CyPersistModel data = cmsFeedbackServiceImpl.removeLogical(cmsFeedback);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:feedback:delete')")
    @CyOpeLogAnno(title = "system-意见反馈管理-删除意见反馈", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="删除意见反馈", notes="删除意见反馈")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable Integer businessId,CmsFeedback cmsFeedback) {
        cmsFeedback.setBusinessId(businessId);
        CyPersistModel data = cmsFeedbackServiceImpl.remove(cmsFeedback);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:cmsfeedback:update')")
    @CyOpeLogAnno(title = "system-意见反馈管理-修改意见反馈", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改意见反馈", notes="修改意见反馈")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable Integer businessId, @Valid CmsFeedback cmsFeedback, BindingResult bindingResult) {
        cmsFeedback.setBusinessId(businessId);
        CyPersistModel data = cmsFeedbackServiceImpl.merge(cmsFeedback);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        cmsFeedback);
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:cmsfeedback:detail')")
    @CyOpeLogAnno(title = "system-意见反馈管理-查询意见反馈", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单一意见反馈", notes="查询单一意见反馈")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable Integer businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        cmsFeedbackServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:feedback:list')")
    @CyOpeLogAnno(title = "system-意见反馈管理-查询意见反馈", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询意见反馈集合", notes="查询意见反馈集合")
    @GetMapping(value = "/queryCmsFeedbacks")
    public CyResult queryCmsFeedbacks(CmsFeedback cmsFeedback) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            cmsFeedbackServiceImpl.findAll(cmsFeedback));
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:cmsfeedback:queryCmsFeedbackByPagination')")
    @CyOpeLogAnno(title = "system-意见反馈管理-查询意见反馈", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="分页查询意见反馈集合", notes="分页查询意见反馈集合")
    @GetMapping(value = "/queryCmsFeedbackByPagination")
    public CyGridModel listByPagination(CmsFeedback cmsFeedback) {
        cmsFeedbackServiceImpl.findAllByPagination(getPaginationUtility(), cmsFeedback);
        return getGridModelResponse();
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:cmsfeedback:export')")
    @CyOpeLogAnno(title = "system-意见反馈管理-查询意见反馈", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出意见反馈信息", notes = "导出意见反馈信息")
    @GetMapping(value = "/export")
    public void outCmsFeedback(HttpServletResponse response,CmsFeedback cmsFeedback,@PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="意见反馈信息.xls";break;
            case "1": excelName="意见反馈信息.xlsx";break;
            case "2": excelName="意见反馈信息.csv";break;
        }
        List<CmsFeedback> cmsFeedbackList = cmsFeedbackServiceImpl.export(cmsFeedback);
        CyEpExcelUtil.exportExcel(cmsFeedbackList, "意见反馈信息", "意见反馈信息", CmsFeedback.class, excelName, response);
    }
    @PreAuthorize("@cyPerm.hasPerm('opm:cmsfeedback:queryFeedBackTypes')")
    @CyOpeLogAnno(title = "system-意见反馈管理-查询反馈类型", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询反馈类型集合", notes="查询反馈类型集合")
    @GetMapping(value = "/queryFeedBackTypes")
    public CyResult queryFeedBackTypes() {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                cmsFeedbackServiceImpl.findFeedBackType());
    }

}
