package org.rcisoft.business.sysFeedBack.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;

import org.apache.commons.lang3.StringUtils;
import org.rcisoft.business.sysFeedBack.dao.CmsFeedbackRepository;
import org.rcisoft.business.sysFeedBack.entity.CmsFeedback;
import org.rcisoft.business.sysFeedBack.entity.FeedBackType;
import org.rcisoft.business.sysFeedBack.service.CmsFeedbackService;
import org.rcisoft.common.component.Global;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.aop.CyPageUtilAsp;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.core.service.CyBaseService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.rcisoft.core.model.CyPageInfo;

import java.util.Date;
import java.util.List;
import lombok.extern.slf4j.Slf4j;

/**
 * Created by cy on 2024年3月27日 下午1:53:08.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class CmsFeedbackServiceImpl extends ServiceImpl<CmsFeedbackRepository, CmsFeedback>  implements CmsFeedbackService {

    @Autowired
    private Global global;

    /**
    * 保存 意见反馈
    * @param cmsFeedback
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(CmsFeedback cmsFeedback){
        //提交时间
        cmsFeedback.setSubmissionTime(new Date());
        //增加操作
        int line = baseMapper.insert(cmsFeedback);
        log.debug(CyUserUtil.getAuthenUsername()+"新增了ID为"+
            cmsFeedback.getBusinessId()+"的意见反馈信息");
        return new CyPersistModel(line);
    }

    /**
    * 删除 意见反馈
    * @param cmsFeedback
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(CmsFeedback cmsFeedback){
        int line = baseMapper.realDelete(cmsFeedback);
        log.debug(CyUserUtil.getAuthenUsername()+"删除了ID为"+
            cmsFeedback.getBusinessId()+"的意见反馈信息");
        return new CyPersistModel(line);
    }

    /**
    * 逻辑删除 意见反馈
    * @param cmsFeedback
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(CmsFeedback cmsFeedback){
        cmsFeedback.setDeleted();
        int line = baseMapper.deleteById(cmsFeedback);
            log.debug(CyUserUtil.getAuthenUsername()+"逻辑删除了ID为"+
                cmsFeedback.getBusinessId()+"的意见反馈信息");
            return new CyPersistModel(line);
    }

    /**
    * 修改 意见反馈
    * @param cmsFeedback
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(CmsFeedback cmsFeedback){
        int line = baseMapper.updateById(cmsFeedback);
        log.debug(CyUserUtil.getAuthenUsername()+"修改了ID为"+ cmsFeedback.getBusinessId()+"的意见反馈信息");
        return new CyPersistModel(line);
    }

    /**
    * 根据id查询 意见反馈
    * @param id
    * @return
    */
    @Override
    public CmsFeedback findById(Integer id){
        CmsFeedback cmsFeedback = baseMapper.queryById(id);
        if (StringUtils.isNotBlank(cmsFeedback.getAttachmentUrl())) {
            cmsFeedback.setAttachmentUrl(global.getBase_Discovery()+cmsFeedback.getAttachmentUrl());
        }
        return cmsFeedback;
    }

    /**
    * 分页查询 意见反馈
    * @param cmsFeedback
    * @return
    */
    @Override
    public IPage<CmsFeedback> findAllByPagination(CyPageInfo<CmsFeedback> paginationUtility,
        CmsFeedback cmsFeedback){
        return baseMapper.queryCmsFeedbacksPaged(paginationUtility,cmsFeedback);

    }

    /**
    * 查询list 意见反馈
    * @param cmsFeedback
    * @return
    */
    @Override
    public List<CmsFeedback> findAll(CmsFeedback cmsFeedback){
        return baseMapper.queryCmsFeedbacks(cmsFeedback);

    }

    /**
    * 导出意见反馈
    * @return
    */
    @Override
    public List<CmsFeedback> export(CmsFeedback cmsFeedback) {
        List<CmsFeedback> cmsFeedbackList = baseMapper.queryCmsFeedbacks(cmsFeedback);
        return cmsFeedbackList;
    }

    @Override
    public List<FeedBackType> findFeedBackType() {
        return baseMapper.queryFeedBackType();
    }

}
