package org.rcisoft.business.sysLecturer.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.business.sysLecturer.service.CmsLecturerService;
import org.rcisoft.business.sysuser.entity.SysUser;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.exception.CyServiceException;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import org.rcisoft.business.sysLecturer.entity.CmsLecturer;

import java.util.List;

/**
* Created by cy on 2024年3月28日 下午1:39:55.
*/
@RestController
@RequestMapping("/cmslecturer")
public class CmsLecturerController extends CyPaginationController<CmsLecturer> {


    @Autowired
    private CmsLecturerService cmsLecturerServiceImpl;

    @PreAuthorize("@cyPerm.hasPerm('opm:teacher:increase')")
    @CyOpeLogAnno(title = "system-讲师信息表管理-新增讲师信息表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="添加讲师信息表", notes="添加讲师信息表")
    @PostMapping(value = "/add")
    public CyResult add(@Valid CmsLecturer cmsLecturer, BindingResult bindingResult) {
        CyPersistModel data = cmsLecturerServiceImpl.persist(cmsLecturer);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        cmsLecturer);
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:teacher:removing')")
    @CyOpeLogAnno(title = "system-讲师信息表管理-删除讲师信息表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="逻辑删除讲师信息表", notes="逻辑删除讲师信息表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable Integer businessId,CmsLecturer cmsLecturer) {
        cmsLecturer.setBusinessId(businessId);
        CyPersistModel data = cmsLecturerServiceImpl.removeLogical(cmsLecturer);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }
//   // @PreAuthorize("@cyPerm.hasPerm('sys:lecturer:delete')")
    @CyOpeLogAnno(title = "system-讲师信息表管理-删除讲师信息表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="删除讲师信息表", notes="删除讲师信息表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable Integer businessId,CmsLecturer cmsLecturer) {
        cmsLecturer.setBusinessId(businessId);
        CyPersistModel data = cmsLecturerServiceImpl.remove(cmsLecturer);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:teacher:modifications')")
    @CyOpeLogAnno(title = "system-讲师信息表管理-修改讲师信息表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改讲师信息表", notes="修改讲师信息表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable Integer businessId, @Valid CmsLecturer cmsLecturer, BindingResult bindingResult) {
        cmsLecturer.setBusinessId(businessId);
        CyPersistModel data = cmsLecturerServiceImpl.merge(cmsLecturer);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        cmsLecturer);
    }

    @CyOpeLogAnno(title = "system-讲师信息表管理-通过用户修改讲师信息表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="通过用户修改讲师信息表", notes="通过用户修改讲师信息表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/updateLecturerByUser/{businessId:\\w+}")
    public CyResult updateLecturerByUser(@PathVariable Integer businessId) {
        CyPersistModel data = cmsLecturerServiceImpl.updateLecturerByUser(businessId);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                null);
    }

//    @PreAuthorize("@cyPerm.hasPerm('opm:teacher:singleSearch')")
    @CyOpeLogAnno(title = "system-讲师信息表管理-查询讲师信息表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单一讲师信息表", notes="查询单一讲师信息表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable Integer businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        cmsLecturerServiceImpl.findById(businessId));
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:teacher:search')")
    @CyOpeLogAnno(title = "system-讲师信息表管理-查询讲师信息表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询讲师信息表集合", notes="查询讲师信息表集合")
    @GetMapping(value = "/queryCmsLecturers")
    public CyResult queryCmsLecturers(CmsLecturer cmsLecturer) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            cmsLecturerServiceImpl.findAll(cmsLecturer));
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:teacher:pageSearch')")
    @CyOpeLogAnno(title = "system-讲师信息表管理-查询讲师信息表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="分页查询讲师信息表集合", notes="分页查询讲师信息表集合")
    @GetMapping(value = "/queryCmsLecturerByPagination")
    public CyGridModel listByPagination(CmsLecturer cmsLecturer) {
        cmsLecturerServiceImpl.findAllByPagination(getPaginationUtility(), cmsLecturer);
        return getGridModelResponse();
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:teacher:derive')")
    @CyOpeLogAnno(title = "system-讲师信息表管理-查询讲师信息表", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出讲师信息表信息", notes = "导出讲师信息表信息")
    @GetMapping(value = "/export")
    public void outCmsLecturer(HttpServletResponse response,CmsLecturer cmsLecturer,@PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="讲师信息表信息.xls";break;
            case "1": excelName="讲师信息表信息.xlsx";break;
            case "2": excelName="讲师信息表信息.csv";break;
        }
        List<CmsLecturer> cmsLecturerList = cmsLecturerServiceImpl.export(cmsLecturer);
        CyEpExcelUtil.exportExcel(cmsLecturerList, "讲师信息表信息", "讲师信息表信息", CmsLecturer.class, excelName, response);
    }
}
