package org.rcisoft.business.sysLecturer.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import io.swagger.models.auth.In;
import org.apache.commons.lang3.StringUtils;
import org.rcisoft.business.sysLecturer.dao.CmsLecturerRepository;
import org.rcisoft.business.sysLecturer.entity.CmsLecturer;
import org.rcisoft.business.sysLecturer.service.CmsLecturerService;
import org.rcisoft.business.sysuser.dao.PCSysUserRepository;
import org.rcisoft.business.sysuser.dto.PCUnitUserDTO;
import org.rcisoft.business.sysuser.entity.SysUser;
import org.rcisoft.common.component.Global;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.aop.CyPageUtilAsp;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.core.service.CyBaseService;

import org.rcisoft.sys.wbac.user.dao.SysUserPostRepository;
import org.rcisoft.sys.wbac.user.dao.SysUserRepository;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.rcisoft.core.model.CyPageInfo;

import java.util.List;

import lombok.extern.slf4j.Slf4j;

/**
 * Created by cy on 2024年3月28日 下午1:39:55.
 */
@Service
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class CmsLecturerServiceImpl extends ServiceImpl<CmsLecturerRepository, CmsLecturer> implements CmsLecturerService {

    @Autowired
    private Global global;

    @Autowired
    private PCSysUserRepository pcSysUserRepository;
    @Autowired
    private SysUserRepository sysUserRepository;
    /**
     * 保存 讲师信息表
     *
     * @param cmsLecturer
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(CmsLecturer cmsLecturer) {
        //如果头像为null 或为空
        if (cmsLecturer.getAvatarId() == null || cmsLecturer.getAvatarId() == 0) {
            //获取默认头像
            cmsLecturer.setAvatarId(Integer.valueOf(global.getDEFAULT_TEACHER_LOCATION()));
        }
        //增加操作
        int line = baseMapper.insert(cmsLecturer);
        log.debug(CyUserUtil.getAuthenUsername() + "新增了ID为" +
                cmsLecturer.getBusinessId() + "的讲师信息表信息");
        return new CyPersistModel(line);
    }

    /**
     * 删除 讲师信息表
     *
     * @param cmsLecturer
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(CmsLecturer cmsLecturer) {
        int line = baseMapper.realDelete(cmsLecturer);
        log.debug(CyUserUtil.getAuthenUsername() + "删除了ID为" +
                cmsLecturer.getBusinessId() + "的讲师信息表信息");
        return new CyPersistModel(line);
    }

    /**
     * 逻辑删除 讲师信息表
     *
     * @param cmsLecturer
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(CmsLecturer cmsLecturer) {
        cmsLecturer.setDeleted();
        int line = baseMapper.deleteById(cmsLecturer);
        log.debug(CyUserUtil.getAuthenUsername() + "逻辑删除了ID为" +
                cmsLecturer.getBusinessId() + "的讲师信息表信息");
        return new CyPersistModel(line);
    }

    /**
     * 修改 讲师信息表
     *
     * @param cmsLecturer
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(CmsLecturer cmsLecturer) {
        //根据userId去查这个人的信息 修改user表
        SysUser lecturer = pcSysUserRepository.selectOne(new QueryWrapper<SysUser>().eq("business_id", cmsLecturer.getUserId()));
        if (lecturer != null){
            lecturer.setName(cmsLecturer.getName());
            lecturer.setAvatar(cmsLecturer.getAvatar());
            lecturer.setFlag(cmsLecturer.getFlag());
            pcSysUserRepository.updateById(lecturer);
        }
        //修改讲师表
        int line = baseMapper.updateById(cmsLecturer);
        log.debug(CyUserUtil.getAuthenUsername() + "修改了ID为" + cmsLecturer.getBusinessId() + "的讲师信息表信息");
        return new CyPersistModel(line);
    }

    @Override
    public CyPersistModel updateLecturerByUser(Integer businessId) {
        QueryWrapper<CmsLecturer> qw = new QueryWrapper<>();
        qw.lambda().eq(CmsLecturer::getUserId, businessId);
        CmsLecturer cmsLecturer1 = baseMapper.selectOne(qw);
        if (cmsLecturer1 == null){
            return new CyPersistModel(1);
        }
        else{
            cmsLecturer1.setFlag("0");//停用
            int line = baseMapper.updateById(cmsLecturer1);
            return new CyPersistModel(line);
        }
    }

    /**
     * 根据id查询 讲师信息表
     *
     * @param id
     * @return
     */
    @Override
    public CmsLecturer findById(Integer id) {
        CmsLecturer cmsLecturer = baseMapper.queryById(id);
        if (cmsLecturer != null && cmsLecturer.getAvatarUrl() != null){
            cmsLecturer.setAvatarUrl(global.getBase_Discovery() + cmsLecturer.getAvatarUrl());
        }
        return cmsLecturer;
    }

    /**
     * 分页查询 讲师信息表
     *
     * @param cmsLecturer
     * @return
     */
    @Override
    public IPage<CmsLecturer> findAllByPagination(CyPageInfo<CmsLecturer> paginationUtility,
                                                  CmsLecturer cmsLecturer) {
        IPage<CmsLecturer> cmsLecturerIPage = baseMapper.queryCmsLecturersPaged(paginationUtility, cmsLecturer);
        List<CmsLecturer> records = cmsLecturerIPage.getRecords();
        for (CmsLecturer cmsLecturer1 : records) {
            if (cmsLecturer1.getAvatarUrl() != null) {
                cmsLecturer1.setAvatarUrl(global.getBase_Discovery() + cmsLecturer1.getAvatarUrl());
            }
        }
        cmsLecturerIPage.setRecords(records);
        return cmsLecturerIPage;

    }

    /**
     * 查询list 讲师信息表
     *
     * @param cmsLecturer
     * @return
     */
    @Override
    public List<CmsLecturer> findAll(CmsLecturer cmsLecturer) {
        return baseMapper.queryCmsLecturers(cmsLecturer);

    }

    /**
     * 导出讲师信息表
     *
     * @return
     */
    @Override
    public List<CmsLecturer> export(CmsLecturer cmsLecturer) {
        List<CmsLecturer> cmsLecturerList = baseMapper.queryCmsLecturers(cmsLecturer);
        return cmsLecturerList;
    }

}
