package org.rcisoft.business.syscontentnewsinformation.controller;


/*固定导入*/

import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.business.syscontentnewsinformation.entity.SysContentNewsInformation;
import org.rcisoft.business.syscontentnewsinformation.service.SysContentNewsInformationService;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.exception.CyServiceException;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;

import java.util.List;

/**
 * @author cy
 * @date 2024年3月25日 下午1:42:40
 */
@RestController
@RequestMapping("/syscontentnewsinformation")
public class SysContentNewsInformationController extends CyPaginationController<SysContentNewsInformation> {


    @Autowired
    private SysContentNewsInformationService sysContentNewsInformationServiceImpl;

    @PreAuthorize("@cyPerm.hasPerm('cms:newsmanagement:increase')")
    @CyOpeLogAnno(title = "system-新闻资讯管理-新增新闻资讯", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value = "添加新闻资讯", notes = "添加新闻资讯")
    @PostMapping(value = "/add")
    public CyResult add(@Valid SysContentNewsInformation sysContentNewsInformation, BindingResult bindingResult) {
        CyPersistModel data = sysContentNewsInformationServiceImpl.persist(sysContentNewsInformation);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysContentNewsInformation);
    }

    @PreAuthorize("@cyPerm.hasPerm('cms:newsmanagement:removing')")
    @CyOpeLogAnno(title = "system-新闻资讯管理-删除新闻资讯", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value = "删除新闻资讯", notes = "删除新闻资讯")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable Integer businessId, SysContentNewsInformation sysContentNewsInformation) {
        sysContentNewsInformation.setBusinessId(businessId);
        CyPersistModel data = sysContentNewsInformationServiceImpl.remove(sysContentNewsInformation);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }

    @PreAuthorize("@cyPerm.hasPerm('cms:newsmanagement:modifications')")
    @CyOpeLogAnno(title = "system-新闻资讯管理-修改新闻资讯", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value = "修改新闻资讯", notes = "修改新闻资讯")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PostMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable Integer businessId, @Valid SysContentNewsInformation sysContentNewsInformation, BindingResult bindingResult) {
        sysContentNewsInformation.setBusinessId(businessId);
        CyPersistModel data = sysContentNewsInformationServiceImpl.merge(sysContentNewsInformation);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysContentNewsInformation);
    }

//    @PreAuthorize("@cyPerm.hasPerm('cms:newsmanagement:singleSearch')")
    @CyOpeLogAnno(title = "system-新闻资讯管理-查询新闻资讯", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询单一新闻资讯", notes = "查询单一新闻资讯")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable Integer businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysContentNewsInformationServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:contentNewsInformation:list')")
    @CyOpeLogAnno(title = "system-新闻资讯管理-查询新闻资讯", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询新闻资讯集合", notes = "查询新闻资讯集合")

    @GetMapping(value = "/querySysContentNewsInformations")
    public CyResult querySysContentNewsInformations(SysContentNewsInformation sysContentNewsInformation) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysContentNewsInformationServiceImpl.findAll(sysContentNewsInformation));
    }

//    @PreAuthorize("@cyPerm.hasPerm('cms:newsmanagement:pageSearch')")
    @CyOpeLogAnno(title = "system-新闻资讯管理-查询新闻资讯", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "分页查询新闻资讯集合", notes = "分页查询新闻资讯集合")
    @GetMapping(value = "/querySysContentNewsInformationByPagination")
    public CyGridModel listByPagination(SysContentNewsInformation sysContentNewsInformation) {
        sysContentNewsInformationServiceImpl.findAllByPagination(getPaginationUtility(), sysContentNewsInformation);
        return getGridModelResponse();
    }

    //修改状态
    @PreAuthorize("@cyPerm.hasPerm('cms:newsmanagement:modificationsStatus')")
    @CyOpeLogAnno(title = "system-新闻资讯管理-修改新闻资讯状态", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value = "修改新闻资讯状态", notes = "修改新闻资讯状态")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @PostMapping("/updateStatus/{businessId:\\w+}")
    public CyResult updateStatus(SysContentNewsInformation sysContentNewsInformation) {
        CyPersistModel data = sysContentNewsInformationServiceImpl.updateStatus(sysContentNewsInformation);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysContentNewsInformation);
    }
    @PreAuthorize("@cyPerm.hasPerm('cms:newsmanagement:derive')")
    @CyOpeLogAnno(title = "system-新闻资讯管理-查询新闻资讯", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出新闻资讯信息", notes = "导出新闻资讯信息")
    @GetMapping(value = "/export")
    public void outSysContentNewsInformation(HttpServletResponse response, SysContentNewsInformation sysContentNewsInformation, @PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName = "";
        switch (excelId) {
            case "0":
                excelName = "新闻资讯信息.xls";
                break;
            case "1":
                excelName = "新闻资讯信息.xlsx";
                break;
            case "2":
                excelName = "新闻资讯信息.csv";
                break;
        }
        List<SysContentNewsInformation> sysContentNewsInformationList = sysContentNewsInformationServiceImpl.export(sysContentNewsInformation);
        CyEpExcelUtil.exportExcel(sysContentNewsInformationList, "新闻资讯信息", "新闻资讯信息", SysContentNewsInformation.class, excelName, response);
    }
}
