package org.rcisoft.business.syscontentnewsinformation.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.rcisoft.business.cmsproject.entity.CmsProject;
import org.rcisoft.business.syscontentnewsinformation.dao.SysContentNewsInformationRepository;
import org.rcisoft.business.syscontentnewsinformation.entity.SysContentNewsInformation;
import org.rcisoft.business.syscontentnewsinformation.service.SysContentNewsInformationService;
import org.rcisoft.common.component.Global;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.aop.CyPageUtilAsp;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.core.service.CyBaseService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.rcisoft.core.model.CyPageInfo;

import java.util.Date;
import java.util.List;

import lombok.extern.slf4j.Slf4j;

/**
 * @author cy
 * @date 2024年3月25日 下午1:42:40
 */
@Service
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class SysContentNewsInformationServiceImpl extends ServiceImpl<SysContentNewsInformationRepository, SysContentNewsInformation> implements SysContentNewsInformationService {

    @Autowired
    private Global global;


    /**
     * 保存 新闻资讯
     *
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(SysContentNewsInformation sysContentNewsInformation) {
        //增加操作
        sysContentNewsInformation.setDelFlag("0");
        //当图片字段没有时增加默认1
        if (ObjectUtil.isNull(sysContentNewsInformation.getPictureId())) {
            sysContentNewsInformation.setPictureId(global.getDEFAULT_NEWS_LOCATION());
        }
        SysContentNewsInformation check = baseMapper.checkWeight(sysContentNewsInformation.getWeight());
        if (ObjectUtil.isNotNull(check)) {
            throw new CyServiceException(500, "权重已存在");
        } else {
            int line = baseMapper.insert(sysContentNewsInformation);
            log.debug(CyUserUtil.getAuthenUsername() + "新增了ID为" +
                    sysContentNewsInformation.getBusinessId() + "的新闻资讯信息");
            return new CyPersistModel(line);
        }
    }

    /**
     * 删除 新闻资讯
     *
     * @param sysContentNewsInformation
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(SysContentNewsInformation sysContentNewsInformation) {
        int line = baseMapper.deleteSysContentNewsInformation(sysContentNewsInformation.getBusinessId());
        log.debug(CyUserUtil.getAuthenUsername() + "删除了ID为" +
                sysContentNewsInformation.getBusinessId() + "的新闻资讯信息");
        return new CyPersistModel(line);
    }

    /**
     * 修改 新闻资讯
     *
     * @param sysContentNewsInformation
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(SysContentNewsInformation sysContentNewsInformation) {
        //修改文本中的#image
        String details = sysContentNewsInformation.getDetails().replace("#image", "data:image");
        sysContentNewsInformation.setDetails(details);
        SysContentNewsInformation check = baseMapper.checkWeight(sysContentNewsInformation.getWeight());
        if (ObjectUtil.isNotNull(check) && !check.getBusinessId().equals(sysContentNewsInformation.getBusinessId())) {
            throw new CyServiceException(500, "权重已存在");
        } else {
            int line = baseMapper.updateById(sysContentNewsInformation);
            log.debug(CyUserUtil.getAuthenUsername() + "修改了ID为" + sysContentNewsInformation.getBusinessId() + "的新闻资讯信息");
            return new CyPersistModel(line);
        }
    }

    /**
     * 根据id查询 新闻资讯
     *
     * @param id
     * @return
     */
    @Override
    public SysContentNewsInformation findById(Integer id) {
        SysContentNewsInformation newsInformation = baseMapper.selectById(id);
        if (newsInformation.getPath() != null) {
            newsInformation.setPath(global.getBase_Discovery() + newsInformation.getPath());
        }
        return newsInformation;
    }

    /**
     * 分页查询 新闻资讯
     *
     * @param sysContentNewsInformation
     * @return
     */
    @Override
    public IPage<SysContentNewsInformation> findAllByPagination(CyPageInfo<SysContentNewsInformation> paginationUtility,
                                                                SysContentNewsInformation sysContentNewsInformation) {
        IPage<SysContentNewsInformation> sysContentNewsInformationIPage = baseMapper.querySysContentNewsInformationsPaged(paginationUtility, sysContentNewsInformation);
        List<SysContentNewsInformation> newsInformation = sysContentNewsInformationIPage.getRecords();
        for (SysContentNewsInformation news : newsInformation) {
            if (news.getPath() != null) {
                news.setPath(global.getBase_Discovery() + news.getPath());
            }
        }
        sysContentNewsInformationIPage.setRecords(newsInformation);
        return sysContentNewsInformationIPage;

    }

    /**
     * 查询list 新闻资讯
     *
     * @param sysContentNewsInformation
     * @return
     */
    @Override
    public List<SysContentNewsInformation> findAll(SysContentNewsInformation sysContentNewsInformation) {
        return baseMapper.querySysContentNewsInformations(sysContentNewsInformation);

    }

    /**
     * 导出新闻资讯
     *
     * @return
     */
    @Override
    public List<SysContentNewsInformation> export(SysContentNewsInformation sysContentNewsInformation) {
        List<SysContentNewsInformation> sysContentNewsInformationList = baseMapper.querySysContentNewsInformations(sysContentNewsInformation);
        return sysContentNewsInformationList;
    }

    @Override
    public CyPersistModel updateStatus(SysContentNewsInformation sysContentNewsInformation) {
        int line = baseMapper.updateStatus(sysContentNewsInformation);
        log.debug(CyUserUtil.getAuthenUsername() + "修改了ID为" + sysContentNewsInformation.getBusinessId() + "的新闻资讯信息状态");
        return new CyPersistModel(line);
    }

}
