package org.rcisoft.business.sysdictdata.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.exception.CyServiceException;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;


import org.rcisoft.business.sysdictdata.entity.SysDictData;
import org.rcisoft.business.sysdictdata.service.SysDictDataService;

import java.util.List;

/**
* Created by cy on 2024年3月30日 下午5:22:43.
*/
@RestController
@RequestMapping("/sysdictdata")
public class DictDataController extends CyPaginationController<SysDictData> {


    @Autowired
    private SysDictDataService sysDictDataServiceImpl;

    //@PreAuthorize("@cyPerm.hasPerm('sys:dictData:add')")
    @CyOpeLogAnno(title = "system-字典数据表管理-新增字典数据表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="添加字典数据表", notes="添加字典数据表")
    @PostMapping(value = "/add")
    public CyResult add(@Valid SysDictData sysDictData, BindingResult bindingResult) {
        CyPersistModel data = sysDictDataServiceImpl.persist(sysDictData);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        sysDictData);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:dictData:delete')")
    @CyOpeLogAnno(title = "system-字典数据表管理-删除字典数据表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="逻辑删除字典数据表", notes="逻辑删除字典数据表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable Integer businessId,SysDictData sysDictData) {
        sysDictData.setBusinessId(businessId);
        CyPersistModel data = sysDictDataServiceImpl.removeLogical(sysDictData);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:dictData:delete')")
    @CyOpeLogAnno(title = "system-字典数据表管理-删除字典数据表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="删除字典数据表", notes="删除字典数据表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable Integer businessId,SysDictData sysDictData) {
        sysDictData.setBusinessId(businessId);
        CyPersistModel data = sysDictDataServiceImpl.remove(sysDictData);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:dictData:update')")
    @CyOpeLogAnno(title = "system-字典数据表管理-修改字典数据表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改字典数据表", notes="修改字典数据表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable Integer businessId, @Valid SysDictData sysDictData, BindingResult bindingResult) {
        sysDictData.setBusinessId(businessId);
        CyPersistModel data = sysDictDataServiceImpl.merge(sysDictData);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        sysDictData);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:dictData:query')")
    @CyOpeLogAnno(title = "system-字典数据表管理-查询字典数据表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单一字典数据表", notes="查询单一字典数据表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable String businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        sysDictDataServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:dictData:list')")
    @CyOpeLogAnno(title = "system-字典数据表管理-查询字典数据表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询字典数据表集合", notes="查询字典数据表集合")
    @GetMapping(value = "/querySysDictDatas")
    public CyResult querySysDictDatas(SysDictData sysDictData) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            sysDictDataServiceImpl.findAll(sysDictData));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:dictData:list')")
    @CyOpeLogAnno(title = "system-字典数据表管理-查询字典数据表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="分页查询字典数据表集合", notes="分页查询字典数据表集合")
    @GetMapping(value = "/querySysDictDataByPagination")
    public CyGridModel listByPagination(SysDictData sysDictData) {
        sysDictDataServiceImpl.findAllByPagination(getPaginationUtility(), sysDictData);
        return getGridModelResponse();
    }

    @CyOpeLogAnno(title = "system-字典数据表管理-查询字典数据表", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出字典数据表信息", notes = "导出字典数据表信息")
    @GetMapping(value = "/export")
    public void outSysDictData(HttpServletResponse response,SysDictData sysDictData,@PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="字典数据表信息.xls";break;
            case "1": excelName="字典数据表信息.xlsx";break;
            case "2": excelName="字典数据表信息.csv";break;
        }
        List<SysDictData> sysDictDataList = sysDictDataServiceImpl.export(sysDictData);
        CyEpExcelUtil.exportExcel(sysDictDataList, "字典数据表信息", "字典数据表信息", SysDictData.class, excelName, response);
    }
}
