package org.rcisoft.business.sysdictdata.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.aop.CyPageUtilAsp;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.business.sysdictdata.dao.SysDictDataRepository;
import org.rcisoft.business.sysdictdata.entity.SysDictData;
import org.rcisoft.business.sysdictdata.service.SysDictDataService;
import org.rcisoft.core.service.CyBaseService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.rcisoft.core.model.CyPageInfo;

import java.util.List;
import lombok.extern.slf4j.Slf4j;

/**
 * Created by cy on 2024年3月30日 下午5:22:43.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class SysDictDataServiceImpl extends ServiceImpl<SysDictDataRepository,SysDictData>  implements SysDictDataService {


    /**
    * 保存 字典数据表
    * @param sysDictData
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(SysDictData sysDictData){
        //增加操作
        int line = baseMapper.insert(sysDictData);
        log.debug(CyUserUtil.getAuthenUsername()+"新增了ID为"+
            sysDictData.getBusinessId()+"的字典数据表信息");
        return new CyPersistModel(line);
    }

    /**
    * 删除 字典数据表
    * @param sysDictData
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(SysDictData sysDictData){
        int line = baseMapper.realDelete(sysDictData);
        log.debug(CyUserUtil.getAuthenUsername()+"删除了ID为"+
            sysDictData.getBusinessId()+"的字典数据表信息");
        return new CyPersistModel(line);
    }

    /**
    * 逻辑删除 字典数据表
    * @param sysDictData
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(SysDictData sysDictData){
        sysDictData.setDeleted();
        int line = baseMapper.deleteById(sysDictData);
            log.debug(CyUserUtil.getAuthenUsername()+"逻辑删除了ID为"+
                sysDictData.getBusinessId()+"的字典数据表信息");
            return new CyPersistModel(line);
    }

    /**
    * 修改 字典数据表
    * @param sysDictData
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(SysDictData sysDictData){
        int line = baseMapper.updateById(sysDictData);
        log.debug(CyUserUtil.getAuthenUsername()+"修改了ID为"+ sysDictData.getBusinessId()+"的字典数据表信息");
        return new CyPersistModel(line);
    }

    /**
    * 根据id查询 字典数据表
    * @param id
    * @return
    */
    @Override
    public SysDictData findById(String id){
        return baseMapper.selectById(id);
    }

    /**
    * 分页查询 字典数据表
    * @param sysDictData
    * @return
    */
    @Override
    public IPage<SysDictData> findAllByPagination(CyPageInfo<SysDictData> paginationUtility,
        SysDictData sysDictData){
        return baseMapper.querySysDictDatasPaged(paginationUtility,sysDictData);

    }

    /**
    * 查询list 字典数据表
    * @param sysDictData
    * @return
    */
    @Override
    public List<SysDictData> findAll(SysDictData sysDictData){
        return baseMapper.querySysDictDatas(sysDictData);

    }

    /**
    * 导出字典数据表
    * @return
    */
    @Override
    public List<SysDictData> export(SysDictData sysDictData) {
        List<SysDictData> sysDictDataList = baseMapper.querySysDictDatas(sysDictData);
        return sysDictDataList;
    }

}
