package org.rcisoft.business.sysunit.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.business.sysunit.entity.*;
import org.rcisoft.business.sysunit.service.UnitService;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.sys.rbac.user.entity.SysUserRbac;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.model.CyGridModel;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;




import java.util.List;

/**
* Created by cy on 2024年3月25日 下午7:38:48.
*/
@RestController
@RequestMapping("/sysunit")
public class SysUnitController extends CyPaginationController<SysUnit> {


    @Autowired
    private UnitService sysUnitServiceImpl;

    @PreAuthorize("@cyPerm.hasPerm('opm:unit:add')")
    @CyOpeLogAnno(title = "system-单位管理管理-新增单位管理", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="添加单位管理", notes="添加单位管理")
    @PostMapping(value = "/add")
    public CyResult add(@Valid SysUnit sysUnit, BindingResult bindingResult) {
        CyPersistModel data = sysUnitServiceImpl.persist(sysUnit);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        sysUnit);
    }
    @PreAuthorize("@cyPerm.hasPerm('opm:unit:delete')")
    @CyOpeLogAnno(title = "system-单位管理管理-删除单位管理", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="删除单位管理", notes="删除单位管理")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable Integer businessId,SysUnit sysUnit) {
        sysUnit.setBusinessId(businessId);
        CyPersistModel data = sysUnitServiceImpl.remove(sysUnit);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:unit:update')")
    @CyOpeLogAnno(title = "system-单位管理管理-修改单位管理", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改单位管理", notes="修改单位管理")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable Integer businessId, @Valid SysUnit sysUnit, BindingResult bindingResult) {
        sysUnit.setBusinessId(businessId);
        CyPersistModel data = sysUnitServiceImpl.merge(sysUnit);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        sysUnit);
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:unit:detail')")
    @CyOpeLogAnno(title = "system-单位管理管理-查询单位管理", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单一单位管理", notes="查询单一单位管理")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable String businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        sysUnitServiceImpl.findById(businessId));
    }





    @PreAuthorize("@cyPerm.hasPerm('opm:unit:querySysUnits')")
    @CyOpeLogAnno(title = "system-单位管理管理-查询单位管理", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单位管理集合", notes="查询单位管理集合")
    @GetMapping(value = "/querySysUnits")
    public CyResult querySysUnits(SysUnit sysUnit) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            sysUnitServiceImpl.findAll(sysUnit));
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:unit:querySysUnitByPagination')")
    @CyOpeLogAnno(title = "system-单位管理管理-查询单位管理", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="分页查询单位管理集合", notes="分页查询单位管理集合")
    @GetMapping(value = "/querySysUnitByPagination")
    public CyGridModel listByPagination(SysUnit sysUnit) {
        sysUnitServiceImpl.findAllByPagination(getPaginationUtility(), sysUnit);
        return getGridModelResponse();
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:unit:export')")
    @CyOpeLogAnno(title = "system-单位管理管理-查询单位管理", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出单位管理信息", notes = "导出单位管理信息")
    @GetMapping(value = "/export")
    public void outSysUnit(HttpServletResponse response,SysUnit sysUnit,@PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="单位管理信息.xls";break;
            case "1": excelName="单位管理信息.xlsx";break;
            case "2": excelName="单位管理信息.csv";break;
        }
        List<SysUnit> sysUnitList = sysUnitServiceImpl.export(sysUnit);
        CyEpExcelUtil.exportExcel(sysUnitList, "单位管理信息", "单位管理信息", SysUnit.class, excelName, response);
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:unit:queryAllUnitAdmins')")
    @CyOpeLogAnno(title = "system-单位管理管理-查询单位管理员", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询所有单位管理员集合", notes="查询所有单位管理员集合")
    @GetMapping(value = "/queryAllUnitAdmins")
    public CyResult queryAllUnitAdmins(String userId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUnitServiceImpl.listAllUnitAdmins(userId));
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:unit:querySysUsers')")
    @CyOpeLogAnno(title = "system-单位管理管理-查询单位管理", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单位管理集合", notes="查询单位管理集合")
    @GetMapping(value = "/querySysUsers")
    public CyResult querySysUsers(SysUserRbac sysUserRbac) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUnitServiceImpl.listAllUser(sysUserRbac));
    }

    /**
     * ip用户
     * 根据用户id查询单位信息
     */
    @PreAuthorize("@cyPerm.hasPerm('opm:unit:findByUserId')")
    @CyOpeLogAnno(title = "system-单位管理管理-查询单位管理", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="根据用户id查询单位信息", notes="根据用户id查询单位信息")
    @ApiImplicitParams({@ApiImplicitParam(name = "userId", value = "userId", required = true, dataType = "varchar")})
    @GetMapping("/findByUserId")
    public CyResult findByUserId() {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUnitServiceImpl.findByUserId());
    }


    @PreAuthorize("@cyPerm.hasPerm('opm:unit:getEnterprisesPeopleView')")
    @CyOpeLogAnno(title = "单位视图-查看企业数量/新增", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="单位视图-查看企业数量/新增", notes="单位视图-查看企业数量/新增")
    @GetMapping("/getEnterprisesView")
    public CyResult getEnterprisesView() {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            sysUnitServiceImpl.getEnterprisesView());
    }
    @PreAuthorize("@cyPerm.hasPerm('opm:unit:getCollegesPeopleView')")
    @CyOpeLogAnno(title = "单位视图-查看院校数量/新增", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="单位视图-查看院校数量/新增", notes="单位视图-查看院校数量/新增")
    @GetMapping("/getCollegesView")
    public CyResult getCollegesView() {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            sysUnitServiceImpl.getCollegesView());
    }


    @PreAuthorize("@cyPerm.hasPerm('opm:unit:getEnterprisesPeopleView')")
    @CyOpeLogAnno(title = "单位视图-企业用户数量/活跃", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="单位视图-企业用户数量/活跃", notes="单位视图-企业用户数量/活跃")
    @GetMapping("/getEnterprisesPeopleView")
    public CyResult getEnterprisesPeopleView() {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            sysUnitServiceImpl.getEnterprisesPeopleView());
    }


    @PreAuthorize("@cyPerm.hasPerm('opm:unit:getCollegesPeopleView')")
    @CyOpeLogAnno(title = "单位视图-院校用户数量/在校", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="单位视图-院校用户数量/在校", notes="单位视图-院校用户数量/在校")
    @GetMapping("/getCollegesPeopleView")
    public CyResult getCollegesPeopleView() {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            sysUnitServiceImpl.getCollegesPeopleView());
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:unit:getPayRank')")
    @CyOpeLogAnno(title = "单位视图-购买课程TOP", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="单位视图-购买课程TOP", notes="单位视图-购买课程TOP")
    @GetMapping("/getPayRank")
    public CyResult getPayRank() {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            sysUnitServiceImpl.getPayRank());
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:unit:getUnitView')")
    @CyOpeLogAnno(title = "单位视图-列表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="单位视图-列表", notes="单位视图-列表")
    @GetMapping("/getUnitView")
    public CyResult getUnitView() {
        CyPageInfo<UnitView> paginationUtility = new CyPageInfo<>();
        paginationUtility.setCurrent(getPaginationUtility().getCurrent());
        paginationUtility.setSize(getPaginationUtility().getSize());
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            sysUnitServiceImpl.getUnitView(paginationUtility));
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:unit:getStudentNumber')")
    @CyOpeLogAnno(title = "单位视图-列表-学员详细", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="单位视图-列表-学员详细", notes="单位视图-列表-学员详细")
    @GetMapping("/getStudentNumber")
    public CyResult getStudentNumber(SysUnit sysUnit) {
        CyPageInfo<StudentNumber> paginationUtility = new CyPageInfo<>();
        paginationUtility.setCurrent(getPaginationUtility().getCurrent());
        paginationUtility.setSize(getPaginationUtility().getSize());
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            sysUnitServiceImpl.getStudentNumber(paginationUtility,sysUnit));
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:unit:getPayed')")
    @CyOpeLogAnno(title = "单位视图-列表-付费课程详细", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="单位视图-列表-付费课程详细", notes="单位视图-列表-付费课程详细")
    @GetMapping("/getPayed")
    public CyResult getPayed(SysUnit sysUnit) {
        CyPageInfo<Payed> paginationUtility = new CyPageInfo<>();
        paginationUtility.setCurrent(getPaginationUtility().getCurrent());
        paginationUtility.setSize(getPaginationUtility().getSize());
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            sysUnitServiceImpl.getPayed(paginationUtility,sysUnit));
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:unit:getNoPayed')")
    @CyOpeLogAnno(title = "单位视图-列表-试用课程详细", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="单位视图-列表-试用课程详细", notes="单位视图-列表-试用课程详细")
    @GetMapping("/getNoPayed")
    public CyResult getNoPayed(SysUnit sysUnit) {
        CyPageInfo<Payed> paginationUtility = new CyPageInfo<>();
        paginationUtility.setCurrent(getPaginationUtility().getCurrent());
        paginationUtility.setSize(getPaginationUtility().getSize());
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            sysUnitServiceImpl.getNoPayed(paginationUtility,sysUnit));
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:unit:getExam')")

    @CyOpeLogAnno(title = "单位视图-列表-完成必修课详细", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="单位视图-列表-完成必修课详细", notes="单位视图-列表-完成必修课详细")
    @GetMapping("/getFinish")
    public CyResult getFinish(SysUnit unit) {
        CyPageInfo<Finish> paginationUtility = new CyPageInfo<>();
        paginationUtility.setCurrent(getPaginationUtility().getCurrent());
        paginationUtility.setSize(getPaginationUtility().getSize());
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            sysUnitServiceImpl.getFinish(paginationUtility,unit));
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:unit:getNotFinish')")
    @CyOpeLogAnno(title = "单位视图-列表-未完成必修课详细", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="单位视图-列表-未完成必修课详细", notes="单位视图-列表-未完成必修课详细")
    @GetMapping("/getNotFinish")
    public CyResult getNotFinish(SysUnit unit) {
        CyPageInfo<NotFinish> paginationUtility = new CyPageInfo<>();
        paginationUtility.setCurrent(getPaginationUtility().getCurrent());
        paginationUtility.setSize(getPaginationUtility().getSize());
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            sysUnitServiceImpl.getNotFinish(paginationUtility,unit));
    }


    /**
     * 查询企业信息
     * @return
     */
    @PreAuthorize("@cyPerm.hasPerm('opm:unit:findAllUnitInfo')")
    @CyOpeLogAnno(title = "单位视图-列表-查询企业信息", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="单位视图-列表-查询企业信息", notes="单位视图-列表-查询企业信息")
    @GetMapping("/findAllUnitInfo")
    public CyResult findAllUnitInfo(SysUnit unit) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUnitServiceImpl.findAllUnitInfo());
    }
    @PreAuthorize("@cyPerm.hasPerm('opm:unit:getExam')")
    @CyOpeLogAnno(title = "单位视图-列表-考核详细", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="单位视图-列表-考核详细", notes="单位视图-列表-考核详细")
    @GetMapping("/getExam")
    public CyResult getExam(SysUnit unit) {
        CyPageInfo<Exam> paginationUtility = new CyPageInfo<>();
        paginationUtility.setCurrent(getPaginationUtility().getCurrent());
        paginationUtility.setSize(getPaginationUtility().getSize());
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            sysUnitServiceImpl.getExam(paginationUtility,unit));
    }



}
