package org.rcisoft.business.sysunit.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.rcisoft.business.sysunit.dao.UnitRepository;
import org.rcisoft.business.sysunit.dto.UnitInfoDTO;
import org.rcisoft.business.sysunit.entity.*;
import org.rcisoft.business.sysunit.service.UnitService;
import org.rcisoft.business.sysunit.vo.*;
import org.rcisoft.business.sysuser.entity.SysUser;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.sys.rbac.user.entity.SysUserRbac;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import java.util.Collection;
import java.util.List;

/**
 * Created by cy on 2024年3月25日 下午7:38:48.
 */
@Service
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class UnitServiceImpl extends ServiceImpl<UnitRepository, SysUnit> implements UnitService {


    /**
     * 企业
     */
    private static String unitType = "0";
    private static String flag = "1";

    /**
     * 保存 单位管理
     *
     * @param sysUnit
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(SysUnit sysUnit) {
        //单位名称不能重复校验
        Integer count = baseMapper.selectCount(new LambdaQueryWrapper<SysUnit>()
                .eq(SysUnit::getUnitName, sysUnit.getUnitName())
                .eq(SysUnit::getUnitType, sysUnit.getUnitType())
                .eq(SysUnit::getDelFlag, 0));
        if (count > 0) {
            throw new CyServiceException(500, "单位名称已存在");
        }
        if ("0".equals(sysUnit.getLessonType())) {
            //技术端
            sysUnit.setLessonType("1");
            sysUnit.setLessonTypeSchool("0");
        } else if ("1".equals(sysUnit.getLessonType())) {
            //技能端
            sysUnit.setLessonType("0");
            sysUnit.setLessonTypeSchool("1");
        } else if ("2".equals(sysUnit.getLessonType())) {
            //技术端和技能端
            sysUnit.setLessonType("1");
            sysUnit.setLessonTypeSchool("1");
        }
        //增加操作
        int line = baseMapper.insert(sysUnit);
        //获取单位管理员账号信息
        Integer userId = sysUnit.getUserId();
        if (userId != null) {
            SysUserRbac sysUserRbac = baseMapper.queryUserByUserId(userId);
            //修改绑定单位
            sysUserRbac.setDeptId(sysUnit.getBusinessId());
            baseMapper.updateUserBind(sysUserRbac);
        }

        log.debug(CyUserUtil.getAuthenUsername() + "新增了ID为" +
                sysUnit.getBusinessId() + "的单位管理信息");
        return new CyPersistModel(line);
    }

    /**
     * 删除 单位管理
     *
     * @param sysUnit
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(SysUnit sysUnit) {
        sysUnit.setDeleted();
        int line = baseMapper.deleteById(sysUnit);
        log.debug(CyUserUtil.getAuthenUsername() + "删除了ID为" +
                sysUnit.getBusinessId() + "的单位管理信息");
        return new CyPersistModel(line);
    }

    /**
     * 修改 单位管理
     *
     * @param sysUnit
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(SysUnit sysUnit) {
        //单位名称不能重复校验
        Integer count = baseMapper.selectCount(new LambdaQueryWrapper<SysUnit>()
                .eq(SysUnit::getUnitName, sysUnit.getUnitName())
                .eq(SysUnit::getUnitType, sysUnit.getUnitType())
                .ne(SysUnit::getBusinessId, sysUnit.getBusinessId())
                .eq(SysUnit::getDelFlag, 0));
        if (count > 0) {
            throw new CyServiceException(500, "单位名称已存在");
        }
        if ("".equals(sysUnit.getLessonType())){
            //都没选
            sysUnit.setLessonType("");
            sysUnit.setLessonTypeSchool("");
        } else if ("0".equals(sysUnit.getLessonType())) {
            //技术端
            sysUnit.setLessonType("1");
            sysUnit.setLessonTypeSchool("0");
        } else if ("1".equals(sysUnit.getLessonType())) {
            //技能端
            sysUnit.setLessonType("0");
            sysUnit.setLessonTypeSchool("1");
        } else if ("2".equals(sysUnit.getLessonType())) {
            //技术端和技能端
            sysUnit.setLessonType("1");
            sysUnit.setLessonTypeSchool("1");
        }
        //修改单位表
        int line = baseMapper.updateUnitById(sysUnit);
        //获取单位管理员账号信息
        Integer userId = sysUnit.getUserId();
        if (userId != null) {
            //将sysUnit.getUserId()转为字符串
            String id1 = String.valueOf(sysUnit.getUserId());
            String id2 = sysUnit.getInitUserId();
            if (!id1.equals(id2)){
                //证明单位管理员发生了变化  修改旧的user
                if (StringUtils.isNotEmpty(id2)){
                    Integer oldUserId = Integer.parseInt(id2);
                    SysUserRbac oldUser = baseMapper.queryUserByUserId(oldUserId);
                    if (oldUser != null){
                        oldUser.setDeptId(null);
                        baseMapper.updateUserBind(oldUser);
                    }
                }
                //将新的user的单位id赋值
                Integer newUserId = Integer.parseInt(id1);
                SysUserRbac newUser = baseMapper.queryUserByUserId(newUserId);
                newUser.setDeptId(sysUnit.getBusinessId());
                baseMapper.updateUserBind(newUser);
            }
        }else {
            //现在的id为空 证明单位没有单位管理员了  需要修改老的单位管理员信息 字符串转int 将老的user的单位id变成null
            String id2 = sysUnit.getInitUserId();
            Integer oldUserId = Integer.parseInt(id2);
            SysUserRbac oldUser = baseMapper.queryUserByUserId(oldUserId);
            oldUser.setDeptId(null);
            baseMapper.updateUserBind(oldUser);
        }
        log.debug(CyUserUtil.getAuthenUsername() + "修改了ID为" + sysUnit.getBusinessId() + "的单位管理信息");
        return new CyPersistModel(line);
    }

    /**
     * 根据id查询 单位管理
     *
     * @param id
     * @return
     */
    @Override
    public SysUnit findById(String id) {
        return baseMapper.selectByIdU(id);
    }

    /**
     * 分页查询 单位管理
     *
     * @param sysUnit
     * @return
     */
    @Override
    public IPage<SysUnit> findAllByPagination(CyPageInfo<SysUnit> paginationUtility,
                                              SysUnit sysUnit) {
        if ("0".equals(sysUnit.getLessonType())) {
            //技术端
            sysUnit.setLessonType("1");
        } else if ("1".equals(sysUnit.getLessonType())) {
            //技能端
            sysUnit.setLessonType(null);
            sysUnit.setLessonTypeSchool("1");
        } else if ("2".equals(sysUnit.getLessonType())) {
            //技术端和技能端
            sysUnit.setLessonType("1");
            sysUnit.setLessonTypeSchool("1");
        }
        return baseMapper.querySysUnitsPaged(paginationUtility, sysUnit);

    }

    /**
     * 查询list 单位管理
     *
     * @param sysUnit
     * @return
     */
    @Override
    public List<SysUnit> findAll(SysUnit sysUnit) {
        return baseMapper.querySysUnits(sysUnit);

    }

    /**
     * 导出单位管理
     *
     * @return
     */
    @Override
    public List<SysUnit> export(SysUnit sysUnit) {
        List<SysUnit> sysUnitList = baseMapper.querySysUnits(sysUnit);
        return sysUnitList;
    }

    @Override
    public List<SysUserRbac> listAllUser(SysUserRbac sysUserRbac) {
        return baseMapper.listAllUser(sysUserRbac);
    }

    @Override
    public List<SysUserRbac> listAllUnitAdmins(String userId) {
        //所有的管理员账号信息
        List<SysUserRbac> sysUser = baseMapper.listAllUnitAdmins();
        //查询单位表里所有的userId
        SysUnit sysUnits = baseMapper.listAllUserId();
        String userIds = sysUnits.getUserIds();
        String[] split = userIds.split(",");
        // 使用 Iterator 来安全地移除元素
        sysUser.removeIf(sysUnit -> {
            for (String id : split) {
                if (sysUnit.getBusinessId().toString().equals(id) && !sysUnit.getBusinessId().toString().equals(userId)) {
                    return true; // 返回 true 表示要移除此元素
                }
            }
            return false; // 默认返回 false 表示不要移除此元素
        });

        return sysUser;
    }

    /**
     * 查询单位信息
     *
     * @return
     */
    @Override
    public SysUnit findByUserId() {
        String deptId = CyUserUtil.getAuthenDept();
        //根据deptId查询单位信息
        if (deptId != null) {
            return baseMapper.selectByDeptId(Integer.valueOf(deptId));
        }
        return null;
    }

    @Override
    public EnterprisesVO getEnterprisesView() {

        //创建返回对象
        EnterprisesVO res = new EnterprisesVO();

        //查询总数
        res.setNumber(baseMapper.getEnterprisesTotalNumber());

        //查询新增数量
        res.setAddNumber(baseMapper.getEnterprisesAddNumber());
        return res;
    }

    @Override
    public CollegesVO getCollegesView() {
        //创建返回对象
        CollegesVO res = new CollegesVO();

        //查询总数
        res.setNumber(baseMapper.getCollegesTotalNumber());

        //查询新增数量
        res.setAddNumber(baseMapper.getCollegesAddNumber());
        return res;
    }

    @Override
    public EnterprisesPeopleVO getEnterprisesPeopleView() {

        //创建返回对象
        EnterprisesPeopleVO res = new EnterprisesPeopleVO();

        //查询总人数
        res.setTotalNumber(baseMapper.getEnterprisesPeopleTotalNumber());

        //查询活跃人数
        res.setLiveNumber(baseMapper.getEnterprisesPeopleLiveNumber());

        return res;
    }

    @Override
    public CollegesPeopleVO getCollegesPeopleView() {
        //创建返回对象
        CollegesPeopleVO res = new CollegesPeopleVO();

        //查询总人数
        res.setTotalNumber(baseMapper.getCollegesPeopleTotalNumber());

        //查询在学人数
        res.setLearnNumber(baseMapper.getgetCollegesPeopleInSchoolNumber());

        return res;
    }

    @Override
    public List<PayRankVO> getPayRank() {

        //创建返回对象,查询数据
        List<PayRankVO> res = baseMapper.getPayRank();

        return res;
    }

    @Override
    public IPage<UnitView> getUnitView(CyPageInfo<UnitView> paginationUtility) {
        //查询记录
        return baseMapper.getUnitViewByPage(paginationUtility);

    }

    @Override
    public IPage<StudentNumber> getStudentNumber(CyPageInfo<StudentNumber> paginationUtility, SysUnit sysUnit) {
        //查询记录
        return baseMapper.getStudentNumberRecords(paginationUtility, sysUnit);
    }

    @Override
    public IPage<Payed> getPayed(CyPageInfo<Payed> paginationUtility, SysUnit unit) {
        //查询记录
        return baseMapper.getPayedRecords(paginationUtility, unit);
    }

    @Override
    public IPage<Payed> getNoPayed(CyPageInfo<Payed> paginationUtility, SysUnit unit) {
        return baseMapper.getNoPayedRecords(paginationUtility, unit);
    }

    @Override
    public IPage<Finish> getFinish(CyPageInfo<Finish> paginationUtility, SysUnit unit) {
        //查询记录
        return baseMapper.getFinishRecords(paginationUtility, unit);
    }

    @Override
    public IPage<NotFinish> getNotFinish(CyPageInfo<NotFinish> paginationUtility, SysUnit unit) {
        //查询记录
        return baseMapper.getNotFinishRecords(paginationUtility, unit);
    }

    @Override
    public IPage<Exam> getExam(CyPageInfo<Exam> paginationUtility, SysUnit unit) {
        //查询记录
        return baseMapper.getExamRecords(paginationUtility, unit);
    }

    /**
     * 查询企业集合
     *
     * @return
     */
    @Override
    public List<UnitInfoDTO> findAllUnitInfo() {
        LambdaQueryWrapper<SysUnit> wrapper = new LambdaQueryWrapper<>();
        wrapper.eq(SysUnit::getUnitType, unitType);
        wrapper.eq(SysUnit::getFlag, flag);
        Collection<SysUnit> sysUnits = baseMapper.selectList(wrapper);
        return sysUnits.stream().map(sysUnit1 -> {
            UnitInfoDTO unitInfoDTO = new UnitInfoDTO();
            unitInfoDTO.setBusinessId(sysUnit1.getBusinessId());
            unitInfoDTO.setUnitName(sysUnit1.getUnitName());
            return unitInfoDTO;
        }).toList();
    }

    @Override
    public List<Integer> SelectUserIdByEnterpriseId(Integer enterpriseId) {
        return baseMapper.SelectUserIdByEnterpriseId(enterpriseId);
    }


}
