package org.rcisoft.business.sysunitlesson.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.business.sysunitlesson.dto.OpeningCourseDto;
import org.rcisoft.business.sysunitlesson.entity.SysUnitLesson;
import org.rcisoft.business.sysunitlesson.service.SysUnitLessonService;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.model.CyGridModel;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;


import java.util.List;

/**
* Created by cy on 2024年3月26日 下午4:06:16.
*/
@RestController
@RequestMapping("/sysunitlesson")
public class SysUnitLessonController extends CyPaginationController<OpeningCourseDto> {


    @Autowired
    private SysUnitLessonService sysUnitLessonServiceImpl;

    //@PreAuthorize("@cyPerm.hasPerm('sys:unitLesson:add')")
    @CyOpeLogAnno(title = "system-课程和单位中间表管理-新增课程和单位中间表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="添加课程和单位中间表", notes="添加课程和单位中间表")
    @PostMapping(value = "/add")
    public CyResult add(@Valid SysUnitLesson sysUnitLesson, BindingResult bindingResult) {
        CyPersistModel data = sysUnitLessonServiceImpl.persist(sysUnitLesson);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        sysUnitLesson);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:unitLesson:delete')")
    @CyOpeLogAnno(title = "system-课程和单位中间表管理-删除课程和单位中间表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="删除课程和单位中间表", notes="删除课程和单位中间表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable Integer businessId,SysUnitLesson sysUnitLesson) {
        sysUnitLesson.setBusinessId(businessId);
        CyPersistModel data = sysUnitLessonServiceImpl.remove(sysUnitLesson);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:unitLesson:update')")
    @CyOpeLogAnno(title = "system-课程和单位中间表管理-修改课程和单位中间表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改课程和单位中间表", notes="修改课程和单位中间表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable Integer businessId, @Valid SysUnitLesson sysUnitLesson, BindingResult bindingResult) {
        sysUnitLesson.setBusinessId(businessId);
        CyPersistModel data = sysUnitLessonServiceImpl.merge(sysUnitLesson);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        sysUnitLesson);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:unitLesson:query')")
    @CyOpeLogAnno(title = "system-课程和单位中间表管理-查询课程和单位中间表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单一课程和单位中间表", notes="查询单一课程和单位中间表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable String businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        sysUnitLessonServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:unitLesson:list')")
    @CyOpeLogAnno(title = "system-课程和单位中间表管理-查询课程和单位中间表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询课程和单位中间表集合", notes="查询课程和单位中间表集合")
    @GetMapping(value = "/querySysUnitLessons")
    public CyResult querySysUnitLessons(SysUnitLesson sysUnitLesson) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            sysUnitLessonServiceImpl.findAll(sysUnitLesson));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:unitLesson:list')")
    @CyOpeLogAnno(title = "system-课程和单位中间表管理-查询课程和单位中间表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="分页查询课程和单位中间表集合", notes="分页查询课程和单位中间表集合")
    @GetMapping(value = "/querySysUnitLessonByPagination")
    public CyGridModel listByPagination(OpeningCourseDto openingCourseDto) {
        sysUnitLessonServiceImpl.findAllByPagination(getPaginationUtility(), openingCourseDto);
        return getGridModelResponse();
    }

    @CyOpeLogAnno(title = "system-课程和单位中间表管理-查询课程和单位中间表", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出课程和单位中间表信息", notes = "导出课程和单位中间表信息")
    @GetMapping(value = "/export")
    public void outSysUnitLesson(HttpServletResponse response,SysUnitLesson sysUnitLesson,@PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="课程和单位中间表信息.xls";break;
            case "1": excelName="课程和单位中间表信息.xlsx";break;
            case "2": excelName="课程和单位中间表信息.csv";break;
        }
        List<SysUnitLesson> sysUnitLessonList = sysUnitLessonServiceImpl.export(sysUnitLesson);
        CyEpExcelUtil.exportExcel(sysUnitLessonList, "课程和单位中间表信息", "课程和单位中间表信息", SysUnitLesson.class, excelName, response);
    }

    @CyOpeLogAnno(title = "运营管理-开课管理-根据单位id查询该单位下开的所有课程", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="根据单位id查询该单位下开的所有课程", notes="根据单位id查询该单位下开的所有课程")
    @GetMapping(value = "/queryOpenCourse")
    public CyResult queryOpenCourseByUnitId(SysUnitLesson sysUnitLesson) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUnitLessonServiceImpl.queryOpenCourseByUnitId(sysUnitLesson));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:unitLesson:query')")
    @CyOpeLogAnno(title = "运营管理-开课管理-校验该单位下是否开过这个课程", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="校验该单位下是否开过这个课程", notes="校验该单位下是否开过这个课程")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/validOpenCourse")
    public CyResult validOpenCourse(SysUnitLesson sysUnitLesson) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUnitLessonServiceImpl.validOpenCourse(sysUnitLesson));
    }

    @CyOpeLogAnno(title = "system-课程和单位中间表管理-批量新增课程和单位中间表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="批量添加课程和单位中间表", notes="批量添加课程和单位中间表")
    @PostMapping(value = "/batchAddUnitLesson")
    public CyResult batchAddUnitLesson(@RequestBody OpeningCourseDto openingCourseDto, BindingResult bindingResult) {
        CyPersistModel data = sysUnitLessonServiceImpl.batchAddUnitLesson(openingCourseDto);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                openingCourseDto);
    }
}
