package org.rcisoft.business.sysunitlesson.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.rcisoft.business.sysunitlesson.dao.SysUnitLessonRepository;
import org.rcisoft.business.sysunitlesson.dto.OpeningCourseDto;
import org.rcisoft.business.sysunitlesson.entity.SysUnitLesson;
import org.rcisoft.business.sysunitlesson.service.SysUnitLessonService;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyPersistModel;

import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.rcisoft.core.model.CyPageInfo;

import java.util.List;
import lombok.extern.slf4j.Slf4j;

/**
 * Created by cy on 2024年3月26日 下午4:06:16.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class SysUnitLessonServiceImpl extends ServiceImpl<SysUnitLessonRepository,SysUnitLesson> implements SysUnitLessonService {


    /**
    * 保存 课程和单位中间表
    * @param sysUnitLesson
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(SysUnitLesson sysUnitLesson){
        //增加操作
        int line = baseMapper.insert(sysUnitLesson);
        log.debug(CyUserUtil.getAuthenUsername()+"新增了ID为"+
            sysUnitLesson.getBusinessId()+"的课程和单位中间表信息");
        return new CyPersistModel(line);
    }

    /**
    * 删除 课程和单位中间表
    * @param sysUnitLesson
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(SysUnitLesson sysUnitLesson){
        int line = baseMapper.deleteUnitLesson(sysUnitLesson);
        return new CyPersistModel(line);
    }

    /**
    * 修改 课程和单位中间表
    * @param sysUnitLesson
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(SysUnitLesson sysUnitLesson){
        int line = baseMapper.updateUnitLesson(sysUnitLesson);
        log.debug(CyUserUtil.getAuthenUsername()+"修改了ID为"+ sysUnitLesson.getBusinessId()+"的课程和单位中间表信息");
        return new CyPersistModel(line);
    }

    /**
    * 根据id查询 课程和单位中间表
    * @param id
    * @return
    */
    @Override
    public SysUnitLesson findById(String id){
        return baseMapper.selectById(id);
    }

    /**
    * 分页查询 开课管理信息
    * @param openingCourseDto
    * @return
    */
    @Override
    public IPage<OpeningCourseDto> findAllByPagination(CyPageInfo<OpeningCourseDto> paginationUtility,
                                                       OpeningCourseDto openingCourseDto){
        return baseMapper.querySysUnitLessonsPaged(paginationUtility,openingCourseDto);

    }

    /**
    * 查询list 课程和单位中间表
    * @param sysUnitLesson
    * @return
    */
    @Override
    public List<SysUnitLesson> findAll(SysUnitLesson sysUnitLesson){
        return baseMapper.querySysUnitLessons(sysUnitLesson);

    }

    /**
    * 导出课程和单位中间表
    * @return
    */
    @Override
    public List<SysUnitLesson> export(SysUnitLesson sysUnitLesson) {
        List<SysUnitLesson> sysUnitLessonList = baseMapper.querySysUnitLessons(sysUnitLesson);
        return sysUnitLessonList;
    }

    @Override
    public List<OpeningCourseDto> queryOpenCourseByUnitId(SysUnitLesson sysUnitLesson) {
        return baseMapper.queryOpenCourseByUnitId(sysUnitLesson);
    }

    @Override
    public int validOpenCourse(SysUnitLesson sysUnitLesson) {
        if (baseMapper.validOpenCourse(sysUnitLesson) > 0) throw new CyServiceException(1001,"该单位已经开过这门课了");
        return 1;
    }

    @Override
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    public
    CyPersistModel batchAddUnitLesson(OpeningCourseDto openingCourseDto) {
        /**
         * 1.根据单位id删除该单位的所有开课信息
         * 2.批量添加该单位的开课信息
         * **/
        Integer unitId = openingCourseDto.getSettingList().get(0).getUnitId();
        baseMapper.deleteUnitLessonBYUnitId(unitId);
        saveBatch(openingCourseDto.getSettingList());
        return new CyPersistModel(1);
    }

}
