package org.rcisoft.business.sysuser.controller;


/*固定导入*/

import cn.afterturn.easypoi.excel.entity.ExportParams;
import cn.afterturn.easypoi.excel.entity.enmus.ExcelType;
import com.alipay.api.internal.util.file.IOUtils;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.ss.usermodel.WorkbookFactory;
import org.rcisoft.business.blesson.entity.StatisticsDetailVO;
import org.rcisoft.business.sysuser.dto.PCSysUserDTO;
import org.rcisoft.business.sysuser.dto.UserViewDetailsDTO;
import org.rcisoft.business.sysuser.entity.UserViewInfoPartA;
import org.rcisoft.business.sysuser.entity.excel.InitPasswordExcel;
import org.rcisoft.business.sysuser.service.PCSysUserService;
import org.rcisoft.business.sysuser.vo.UserInfoVO;
import org.rcisoft.common.component.Global;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.pc.pcrolelesson.dto.PcRoleUnitUser;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.model.CyGridModel;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;


import org.rcisoft.business.sysuser.entity.SysUser;
import org.springframework.web.multipart.MultipartFile;

import java.io.InputStream;
import java.io.OutputStream;
import java.net.URLEncoder;
import java.util.List;
import java.util.Map;

/**
 * Created by cy on 2024年4月8日 下午3:59:00.
 */
@RestController
@RequestMapping("/pc/sysuser")
public class PCSysUserController extends CyPaginationController<SysUser> {


    private static final String STUDENT_IMPORT_TEMPLATE_NAME = "learnerImportTemplate.xlsx";
    @Autowired
    private PCSysUserService sysUserServiceImpl;
    @Autowired
    private Global global;
    //@PreAuthorize("@cyPerm.hasPerm('sys:user:delete')")
    @CyOpeLogAnno(title = "system-用户表管理-删除用户表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value = "逻辑删除用户表", notes = "逻辑删除用户表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable int businessId, SysUser sysUser) {
        sysUser.setBusinessId(businessId);
        CyPersistModel data = sysUserServiceImpl.removeLogical(sysUser);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:user:delete')")
    @CyOpeLogAnno(title = "system-用户表管理-删除用户表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value = "删除用户表", notes = "删除用户表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable int businessId, SysUser sysUser) {
        sysUser.setBusinessId(businessId);
        CyPersistModel data = sysUserServiceImpl.remove(sysUser);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:user:update')")
    @CyOpeLogAnno(title = "system-用户表管理-修改用户表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value = "修改用户表", notes = "修改用户表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable int businessId, @RequestBody SysUser sysUser, BindingResult bindingResult) {
        sysUser.setBusinessId(businessId);
        CyPersistModel data = sysUserServiceImpl.merge(sysUser);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUser);
    }

    //
    @CyOpeLogAnno(title = "system-用户表管理-修改用户角色表表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value = "修改用户角色表", notes = "修改用户角色表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/updateRole/{businessId:\\w+}")
    public CyResult updateUserRole(@PathVariable int businessId, @RequestBody SysUser sysUser, BindingResult bindingResult) {
        sysUser.setBusinessId(businessId);
        CyPersistModel data = sysUserServiceImpl.updateRole(sysUser);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUser);
    }

    @CyOpeLogAnno(title = "system-用户表管理-修改用户小组表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value = "修改用户小组表", notes = "修改用户小组表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/updateGroup/{businessId:\\w+}")
    public CyResult updateUserGroup(@PathVariable int businessId, @RequestBody SysUser sysUser, BindingResult bindingResult) {
        sysUser.setBusinessId(businessId);
        CyPersistModel data = sysUserServiceImpl.updateGroup(sysUser);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUser);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:user:query')")
    @CyOpeLogAnno(title = "system-用户表管理-查询用户表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询单一用户表", notes = "查询单一用户表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable int businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUserServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:user:list')")
    @CyOpeLogAnno(title = "system-用户表管理-查询用户表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询用户表集合", notes = "查询用户表集合")
    @GetMapping(value = "/listAll")
    public CyResult listAll(SysUser sysUser) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUserServiceImpl.findAll(sysUser));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:user:list')")
    @CyOpeLogAnno(title = "system-用户表管理-查询用户表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "分页查询用户表集合", notes = "分页查询用户表集合")
    @GetMapping(value = "/list")
    public CyGridModel listByPagination(SysUser sysUser) {
        sysUserServiceImpl.findAllByPagination(getPaginationUtility(), sysUser);
        return getGridModelResponse();
    }

    //根据课程分页查询学员
    @CyOpeLogAnno(title = "system-用户表管理-查询用户表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "根据课程查询学员", notes = "根据课程查询学员")
    @GetMapping(value = "/queryUserByLesson")
    public CyGridModel queryUserByLessonByPagination(SysUser sysUser) {
        sysUserServiceImpl.queryUserByLessonByPagination(getPaginationUtility(), sysUser);
        return getGridModelResponse();
    }

    @CyOpeLogAnno(title = "system-用户表管理-查询用户表", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出用户表信息", notes = "导出用户表信息")
    @GetMapping(value = "/export")
    public void outSysUser(HttpServletResponse response, SysUser sysUser, @PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName = "";
        switch (excelId) {
            case "0":
                excelName = "用户表信息.xls";
                break;
            case "1":
                excelName = "用户表信息.xlsx";
                break;
            case "2":
                excelName = "用户表信息.csv";
                break;
        }
        List<SysUser> sysUserList = sysUserServiceImpl.export(sysUser);
        CyEpExcelUtil.exportExcel(sysUserList, "用户表信息", "用户表信息", SysUser.class, excelName, response);
    }


    //PC端登录信息
    //@PreAuthorize("@cyPerm.hasPerm('sys:user:add')")
    @CyOpeLogAnno(title = "system-用户表管理-新增用户表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value = "添加用户表", notes = "添加用户表")
    @PostMapping(value = "/add")
    public CyResult add(@RequestParam("sign") String sign) {
        final String token = sysUserServiceImpl.persist(sign);
        CyResult cyResult = CyResultGenUtil.genSuccessResult(token);
        return cyResult;
    }

    //管理端进行角色添加 个人用户添加讲师信息
    @CyOpeLogAnno(title = "system-用户表管理-新增讲师表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value = "通过用户添加到讲师表", notes = "通过用户添加到讲师表")
    @PostMapping(value = "/addLectureByUser")
    public CyResult addLectureByUser(SysUser sysUser) {
        sysUserServiceImpl.addLectureByUser(sysUser);
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                null);
    }


    //    查询单位管理员信息
    @ApiOperation(value = "查询单位管理员信息", notes = "查询单位管理员信息")
    @GetMapping(value = "/queryUnitAdmin")
    public CyResult queryUnitAdmin() {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUserServiceImpl.queryUnitAdmin());
    }


//    @PreAuthorize("@cyPerm.hasPerm('sys:user:resetPwd')")
    @CyOpeLogAnno(title = "system-用户管理-修改用户", businessType = CyLogTypeEnum.UPDATE)
    @ApiImplicitParams({@ApiImplicitParam(name = "phone", value = "phone", required = true, dataType = "varchar"),
            @ApiImplicitParam(name = "phoneCode", value = "phoneCode", required = true, dataType = "varchar")})
    @ApiOperation(value = "重置密码", notes = "重置密码")
    @PostMapping("/resetPassword")
    public CyResult resetPassword(@RequestParam String sign) {
        return CyResultGenUtil.builder(sysUserServiceImpl.resetPassword(sign),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                null);
    }

    /**
     * 获取手机验证码
     * obtainPhoneCode
     */
    @ApiOperation(value = "获取手机验证码", notes = "获取手机验证码")
    @ApiImplicitParams({@ApiImplicitParam(name = "phone", value = "phone", required = true, dataType = "varchar")})
    @PostMapping("/obtainPhoneCode")
    public CyResult obtainPhoneCode(@Valid PCSysUserDTO sysUser) {
        return CyResultGenUtil.builder(null,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUser);
    }

    /**
     * 校验验证码
     */
    @ApiOperation(value = "校验验证码", notes = "校验验证码")
    @ApiImplicitParams({@ApiImplicitParam(name = "phone", value = "phone", required = true, dataType = "varchar"),
            @ApiImplicitParam(name = "phoneCode", value = "phoneCode", required = true, dataType = "varchar")})
    @PostMapping("/checkPhoneCode")
    public CyResult checkPhoneCode(@RequestParam("sign") String sign) {
        return CyResultGenUtil.builder(sysUserServiceImpl.checkPhoneCode(sign),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                null);
    }

    /**
     * 手机号登录  第二步
     *
     * @return
     */
    @PostMapping("/phoneLogin")
    public Map<String, Object> phoneLogin(@Valid PCSysUserDTO sysUser) {
        return sysUserServiceImpl.phoneLogin(sysUser);
    }
    /**
     * 下载模版
     */
    @ApiOperation(value = "下载模版", notes = "下载模版")
    @GetMapping("/downloadTemplate")
    public void downloadTemplate(HttpServletResponse response) {
        OutputStream os = null;
        Workbook workbook = null;
        try {
            response.setCharacterEncoding("UTF-8");
            response.setHeader("content-Type", "application/vnd.ms-excel");
            response.setHeader("Content-Disposition", "attachment;filename=" + URLEncoder.encode("用户表信息模版.xlsx", "UTF-8"));
            ExportParams exportParams = new ExportParams("学员管理数据信息", "学员管理数据");
            exportParams.setType(ExcelType.XSSF);
            InputStream resourceAsStream = getClass().getClassLoader().getResourceAsStream(global.getEXCEL_TEMPLATE_LOCATION() + STUDENT_IMPORT_TEMPLATE_NAME);
            //workbook = ExcelExportUtil.exportExcel(exportParams,SysUser.class, new ArrayList<>());
//            String s = global.getEXCEL_TEMPLATE_LOCATION() + STUDENT_IMPORT_TEMPLATE_NAME;
            workbook = WorkbookFactory.create(resourceAsStream);
            os = response.getOutputStream();
            workbook.write(os);
        } catch (Exception e) {
            System.out.println("------------------------打印异常日志--------------------------------");
            System.out.println(e);
            throw new CyServiceException("下载模版失败");
        } finally {
            IOUtils.closeQuietly(workbook);
            IOUtils.closeQuietly(os);
        }
    }
    /**
     * 学员导入
     */
    @CyOpeLogAnno(
            title = "pc学员数据管理-导入学员数据",
            businessType = CyLogTypeEnum.IMPORT
    )
    @ApiOperation(
            value = "导入学员数据",
            notes = "导入学员数据"
    )
    @PostMapping("/import")
    public CyResult importData( MultipartFile file) {
        //校验文件是否为空
        if (file.isEmpty()) {
            return CyResultGenUtil.builder(new CyPersistModel(0), "导入失败，文件为空", "导入失败，文件为空", null);
        }
        //校验文件是否为excel
        String fileName = file.getOriginalFilename();
        if (fileName != null && !fileName.endsWith(".xls") && !fileName.endsWith(".xlsx")) {
            return CyResultGenUtil.builder(new CyPersistModel(0), "导入失败，文件格式不正确", "导入失败，文件格式不正确", null);
        }
        return CyResultGenUtil.builder(new CyPersistModel(1), "操作成功", "网络异常，请稍后重试", sysUserServiceImpl.importData(file));
    }


    /**
     * ip登录
     */
    @ApiOperation(value = "ip登录", notes = "ip登录")
    @PostMapping(value = "/ipLogin")
    public CyResult ipLogin(HttpServletRequest request) {
        final String token = sysUserServiceImpl.ipLogin(request);
        CyResult cyResult = CyResultGenUtil.genSuccessResult(token);
        return cyResult;
    }
    /**
     * 查询当前单位学习排名
     */
    @ApiOperation(value = "查询当前单位学习排名", notes = "查询当前单位学习排名")
    @GetMapping(value = "/queryUnitRank/{unit:\\w+}")
    public CyResult queryUnitRank(@PathVariable int unit) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUserServiceImpl.queryUnitRank(unit));
    }
    /**
     * 统计当前用户学习信息
     */
    @ApiOperation(value = "统计当前用户学习信息", notes = "统计当前用户学习信息")
    @GetMapping(value = "/queryUserStudyInfo")
    public CyResult queryUserStudyInfo() {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUserServiceImpl.queryUserStudyInfo());
    }

    /**
     * 个人资料
     * 查询用户信息
     */
    @ApiOperation(value = "查询用户信息", notes = "查询用户信息")
    @GetMapping(value = "/queryUserInfo/{businessId:\\d+}")
    public CyResult queryUserInfo(@PathVariable int businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUserServiceImpl.findByUserId(businessId));
    }

    /**
     * 单位用户已选学员
     */
    @ApiOperation(value = "单位用户已选学员查询", notes = "单位用户已选学员查询")
    @GetMapping(value = "/queryUnitUser")
    public CyResult queryUnitUser(PcRoleUnitUser dto) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUserServiceImpl.queryUnitUser(dto));
    }

    /**
     * 查询个人用户
     * @param sysUser
     * @return
     */
    @CyOpeLogAnno(title = "system-用户表管理-查询用户表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "分页查询用户表集合", notes = "分页查询用户表集合")
    @GetMapping(value = "/listByIdentity")
    public CyResult listByIdentity(SysUser sysUser) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUserServiceImpl.listByIdentity(getPaginationUtility(), sysUser));
    }

    @CyOpeLogAnno(title = "system-用户视图-查询用户视图数据", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "用户视图-查询用户视图数据", notes = "用户视图-查询用户视图数据")
    @GetMapping(value = "/getUserView")
    public CyResult getUserView(SysUser user) {
        CyPageInfo<UserViewInfoPartA> paginationUtility = new CyPageInfo<>();
        paginationUtility.setCurrent(getPaginationUtility().getCurrent());
        paginationUtility.setSize(getPaginationUtility().getSize());
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            sysUserServiceImpl.getUserView(paginationUtility,user));
    }

    @CyOpeLogAnno(title = "system-用户视图-分页查询计划课程总数", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "分页查询计划课程总数", notes = "分页查询计划课程总数")
    @GetMapping(value = "/getTotal")
    public CyResult getTotal(UserViewDetailsDTO userViewDetailsDTO) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            sysUserServiceImpl.getTotal(userViewDetailsDTO));
    }

    @CyOpeLogAnno(title = "system-用户视图-根据类型分页查询课程数", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "根据类型分页查询课程数", notes = "根据类型分页查询课程数")
    @GetMapping(value = "/getLearnType")
    public CyResult getLearnType(UserInfoVO vo) {
        CyPageInfo<StatisticsDetailVO> paginationUtility = new CyPageInfo<>();
        paginationUtility.setCurrent(getPaginationUtility().getCurrent());
        paginationUtility.setSize(getPaginationUtility().getSize());
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUserServiceImpl.getLearnType(paginationUtility, vo));
    }

    @CyOpeLogAnno(title = "system-用户视图-分页查询参与考核课程数", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "分页查询参与考核课程数", notes = "分页查询参与考核课程数")
    @GetMapping(value = "/getExamType")
    public CyResult getExamType(UserInfoVO vo) {
        CyPageInfo<StatisticsDetailVO> paginationUtility = new CyPageInfo<>();
        paginationUtility.setCurrent(getPaginationUtility().getCurrent());
        paginationUtility.setSize(getPaginationUtility().getSize());
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUserServiceImpl.getExamType(paginationUtility,vo));
    }
    //用户是否初次登陆
    @ApiOperation(value = "用户是否初次登陆", notes = "用户是否初次登陆")
    @GetMapping(value = "/isFirstLogin")
    public CyResult isFirstLogin() {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUserServiceImpl.isFirstLogin());
    }
    //用户修改密码后
    @ApiOperation(value = "用户修改密码后", notes = "用户修改密码后")
    @GetMapping(value = "/updatePassword")
    public CyResult updatePassword(Integer businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUserServiceImpl.updatePassword(businessId));
    }

    @CyOpeLogAnno(title = "system-用户表管理-查询用户表", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出用户表信息", notes = "导出用户表信息")
    @GetMapping(value = "/exportInitPassword")
    public void exportInitPassword(HttpServletResponse response, String deptId, @PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName = "";
        switch (excelId) {
            case "0":
                excelName = "用户表信息.xls";
                break;
            case "1":
                excelName = "用户表信息.xlsx";
                break;
            case "2":
                excelName = "用户表信息.csv";
                break;
        }
        List<InitPasswordExcel> sysUserList = sysUserServiceImpl.exportInitPassword(deptId);
        CyEpExcelUtil.exportExcel(sysUserList, "用户表信息", "用户表信息", InitPasswordExcel.class, excelName, response);
    }

}
