package org.rcisoft.business.sysuser.dao;

import org.rcisoft.business.blesson.entity.StatisticsDetailVO;
import org.rcisoft.business.sysuser.dto.*;
import org.rcisoft.business.sysuser.entity.*;
import org.rcisoft.business.sysuser.entity.excel.InitPasswordExcel;
import org.rcisoft.business.sysuser.entity.info.BaseUserInfoATemp;
import org.rcisoft.business.sysuser.entity.info.BaseUserInfoB;
import org.rcisoft.business.sysuser.entity.info.BaseUserInfoC;
import org.rcisoft.business.sysuser.entity.info.BaseUserInfoD;
import org.rcisoft.business.sysuser.vo.UserInfoVO;
import org.rcisoft.core.mapper.CyBaseMapper;
import org.rcisoft.core.model.CyPageInfo;
import org.apache.ibatis.annotations.Param;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.rcisoft.pc.pcgroupuser.entity.PcGroupUser;
import org.rcisoft.pc.pcrolelesson.dto.PcRoleUnitUser;
import org.rcisoft.pc.pcroleuser.entity.PcRoleUser;

import java.util.List;

/**
 * Created with cy on 2024年4月8日 下午3:59:00.
 */

public interface PCSysUserRepository extends CyBaseMapper<SysUser> {


    List<SysUser> querySysUsers(@Param("entity") SysUser sysUser);

    /**
     * 分页查询 sysUser
     */
    IPage<SysUser> querySysUsersPaged(CyPageInfo cyPageInfo, @Param("entity") SysUser sysUser);

    /**
     * 根据课程id分页查询用户
     */

    IPage<SysUser> queryUserByLesson(CyPageInfo cyPageInfo, @Param("entity") SysUser sysUser);

    /**
     * 查重用户
     *
     * @param userToAdd
     * @return
     */
    PCSysUserDTO checkAddRepeat(SysUser userToAdd);

    /**
     * 插入角色
     *
     * @param businessId
     * @param permission
     */
    void insertUserRole(@Param("userId") Integer businessId, @Param("roleId") String permission);

    /**
     * 根据电话查询用户
     *
     * @param phone
     * @return
     */
    List<SysUser> selectByPhone(String phone);

    /**
     * 根据电话号码查重
     *
     * @param phone
     * @return
     */
    List<SysUser> checkByPhone(String phone);

    //    批量删除角色用户中间表数据
    int deleteUserRole(List<PcRoleUser> pcRoleUserList);

    //批量删除小组用户中间表数据
    int deleteUserGroup(List<PcGroupUser> pcRoleUserList);

    //统计单位管理员信息
    PCUnitUserDTO queryUnitAdmin(Integer businessId);

    //统计单位管理员信息
    PCUnitUserDTO queryUnitCommonUser(Integer businessId);

    //统计单位学员信息
    int countUnitUser(@Param("userId") Integer userId);

    //登录名验重
    int weightName(String userName);

    //手机号验重
    int weightPhone(String phone);

    //查询当前单位学习排名
    List<PcSysUserCountDTO> queryUnitRank(String unit);

    //查询用户今日学习小节
    String queryTodayStudy(Integer userId);

    //查询用户累计学习小节
    String queryTotalStudy(Integer userId);

    /**
     * 检查 SysUserRbac 对象是否存在重复记录
     *
     * @param sysUser sysUser 对象
     * @return 如果存在重复记录，则返回对应的 SysUserRbacDTO 信息；否则返回 null。
     */
    SysUser checkInfoRepeat(@Param("entity") SysUser sysUser);

    /**
     * 个人资料查询用户信息
     *
     * @param businessId
     * @return
     */
    PCUnitUserDTO findByUserId(int businessId);

    /**
     * 角色已选用户
     *
     * @param dto
     * @return
     */
    List<PcRoleUnitUser> queryUnitUser(@Param("dto") PcRoleUnitUser dto);

    /**
     * 查询个人用户
     *
     * @param paginationUtility
     * @param sysUser
     * @return
     */
    IPage<SysUser> findListByIdentity(CyPageInfo<SysUser> paginationUtility, @Param("entity") SysUser sysUser);

    Integer getUserViewNumber(@Param("entity") UserViewInfoDTO userViewInfoDTO);

    IPage<UserViewInfoPartA> getUserViewInfoPartA(CyPageInfo<UserViewInfoPartA> paginationUtility, @Param("entity") SysUser user);

    List<UserViewInfoPartB> getUserViewInfoPartB(@Param("entity") List<UserViewInfoPartA> partA);

    List<UserViewInfoPartC> getUserViewInfoPartC(@Param("entity") List<UserViewInfoPartA> partA);

    List<UserViewInfoPartD> getUserViewInfoPartD(@Param("entity") List<UserViewInfoPartA> partA);

    List<UserViewInfoPartE> getUserViewInfoPartE(@Param("entity") List<UserViewInfoPartA> partA);

    List<BaseUserInfoATemp> getInformation(@Param("entity") UserViewDetailsDTO userViewDetailsDTO, @Param("offset") Integer offset);

    List<BaseUserInfoATemp> getStatus(@Param("entity") List<BaseUserInfoATemp> temp, @Param("buId") Integer businessId);

    Integer getTotalsRecordsInformation(@Param("entity") UserViewDetailsDTO userViewDetailsDTO);

    Integer getTotalsLearningInformation(@Param("entity") UserViewDetailsDTO userViewDetailsDTO);

    Integer getTotalsStartInformation(@Param("entity") UserViewDetailsDTO userViewDetailsDTO);

    Integer getTotalsExamedNumber(@Param("entity") UserViewDetailsDTO userViewDetailsDTO);

    List<BaseUserInfoB> getExamedInformation(@Param("entity") UserViewDetailsDTO userViewDetailsDTO, @Param("offset") Integer offset);

    Integer getTotalsNotExamedNumber(@Param("entity") UserViewDetailsDTO userViewDetailsDTO);

    List<BaseUserInfoC> getNotExamedInformation(@Param("entity") UserViewDetailsDTO userViewDetailsDTO, @Param("offset") Integer offset);

    Integer getTotalsFinishInformation(@Param("entity") UserViewDetailsDTO userViewDetailsDTO);

    List<BaseUserInfoD> getFinishInformation(@Param("entity") UserViewDetailsDTO userViewDetailsDTO, @Param("offset") Integer offset);

    List<Persent> getPersent(@Param("entity") List<BaseUserInfoATemp> temp, @Param("buId") Integer businessId);


    //sql逻辑，首先通过userid查出当前管理员下的学员数量以及单位id，在通过单位id查询出在字典中关联的单位名称，并计算当前的最大允许学员数量
    Integer countUserDeptId(@Param("integer") Integer integer);


    Integer countUserDefault(String authenBusinessId);

    IPage<StatisticsDetailVO> getUserLearning(CyPageInfo<StatisticsDetailVO> paginationUtility, @Param("entity") SysUser user);

    IPage<StatisticsDetailVO> getLearnType(CyPageInfo<StatisticsDetailVO> paginationUtility, @Param("entity") UserInfoVO vo);

    IPage<StatisticsDetailVO> getExamType(CyPageInfo<StatisticsDetailVO> paginationUtility, @Param("entity") UserInfoVO vo);

    void isFirstLogin(String authenBusinessId);

    List<InitPasswordExcel> exportInitPassword(@Param("authenDept") String authenDept);

    void updatePassword(@Param("businessId") String businessId);
}

