package org.rcisoft.business.sysuser.dto;


import cn.afterturn.easypoi.excel.annotation.Excel;
import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import com.google.common.collect.Lists;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import org.rcisoft.business.sysuser.enums.IdentityStaCons;
import org.rcisoft.core.constant.CyDelStaCons;
import org.rcisoft.core.constant.CySysCons;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.format.annotation.DateTimeFormat;

import java.util.Date;
import java.util.List;

@Data
@ConditionalOnProperty(prefix = "cy.model", name = "permission", havingValue = CySysCons.WORK_BASE)
public class PCSysUserDTO {

    /**
     * @desc 主键
     * @column business_id
     * @default
     */
    @ApiModelProperty(name = "businessId", value = "主键", required = true, dataType = "varchar")
    private String businessId;

    /**
     * @desc 登录名
     * @column username
     * @default
     */
    @ApiModelProperty(name = "username", value = "登录名", required = true, dataType = "varchar")
    private String username;

    /**
     * @desc 密码
     * @column password
     * @default
     */
    @ApiModelProperty(name = "password", value = "密码", required = true, dataType = "varchar")
    private String password;

    /**
     * @desc 昵称
     * @column nick_name
     * @default
     */
    @ApiModelProperty(name = "nickName", value = "昵称", required = true, dataType = "varchar")
    private String nickName;

    /**
     * @desc 用户类型
     * @column user_type
     * @default
     */
    @ApiModelProperty(name = "userType", value = "用户类型", required = true, dataType = "varchar")
    private String userType;

    /**
     * @desc 姓名
     * @column name
     * @default
     */
    @ApiModelProperty(name = "name", value = "姓名", required = true, dataType = "varchar")
    private String name;

    /**
     * @desc 邮箱
     * @column email
     * @default
     */
    @ApiModelProperty(name = "email", value = "邮箱", required = true, dataType = "varchar")
    private String email;

    /**
     * @desc 手机号
     * @column phone
     * @default
     */
    @ApiModelProperty(name = "phone", value = "手机号", required = true, dataType = "varchar")
    private String phone;

    /**
     * 手机验证码
     */
    private  String phoneCode;

    /**
     * @desc 性别（0：男，1：女）
     * @column sex
     * @default 0
     */
    @ApiModelProperty(name = "sex", value = "性别（0：男，1：女）", required = true, dataType = "varchar")
    private String sex;

    /**
     * @desc 身份证号
     * @column id_number
     * @default
     */
    @ApiModelProperty(name = "idNumber", value = "身份证号", required = true, dataType = "varchar")
    private String idNumber;

    /**
     * @desc 最后登录IP
     * @column login_ip
     * @default
     */
    @ApiModelProperty(name = "loginIp", value = "最后登录IP", required = true, dataType = "varchar")
    private String loginIp;

    /**
     * @desc 身份（1管理员;2单位用户;3个人用户）
     * @column identity
     * @default
     */
    @Excel(name = "身份（1管理员;2单位用户;3个人用户）", orderNum = "13", width = 20)
    private String identity;

    /**
     * @desc 最后登录时间
     * @column login_date
     * @default
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @ApiModelProperty(name = "loginDate", value = "最后登录时间", required = true, dataType = "date")
    private Date loginDate;

    @ApiModelProperty(name = "delFlag", value = "删除标记（0：正常；1：删除；2：审核）", required = true, dataType = "varchar")
    protected String delFlag;

    @TableField(value = "FLAG", fill = FieldFill.INSERT)
    protected String flag; // 启用标记（0：停用；1：启用）

    @TableField(value = "CREATE_DATE", fill = FieldFill.INSERT)
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    protected Date createDate;// 创建日期

    /**
     * 开始时间
     */
    @TableField(exist = false)
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    private Date beginTime;

    /**
     * 结束时间
     */
    @TableField(exist = false)
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    private Date endTime;


    @TableField(exist = false)
    private List<String> childrenList = Lists.newArrayList(); // 所在部门的子节点

    @TableField(exist = false)
    private String deptId; // 部门Id

    /**
     * 设置非删除
     */
    public void setDeleted() {
        this.setDelFlag(CyDelStaCons.NORMAL.getStatus());
    }

    /**
     * 设置身份
     */
    public void setIdentity() {
        this.setIdentity(IdentityStaCons.INDIVIDUAL.getStatus());}

}
