package org.rcisoft.business.sysuser.entity;

import cn.afterturn.easypoi.excel.annotation.Excel;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.google.common.collect.Lists;
import lombok.Data;
import org.rcisoft.core.entity.CyIdIncreEntity;
import org.rcisoft.sys.wbac.menu.entity.SysMenu;
import org.springframework.format.annotation.DateTimeFormat;
import org.springframework.security.core.authority.SimpleGrantedAuthority;

import java.math.BigInteger;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * Created with cy on 2024年4月8日 下午3:59:00.
 */
@Data
@TableName("sys_user")
public class SysUser extends CyIdIncreEntity<SysUser> {


    /**
     * @desc 登录名
     * @column username
     * @default
     */
    @Excel(name = "登录名", orderNum = "0", width = 20)
    private String username;

    /**
     * @desc 用户昵称
     * @column nick_name
     * @default
     */
//     @Excel(name = "用户昵称", orderNum = "1", width = 20)
    private String nickName;

    /**
     * @desc 用户类型（0系统用户 1普通用户）
     * @column user_type
     * @default
     */
//     @Excel(name = "用户类型（0系统用户 1普通用户）", orderNum = "2", width = 20)
    private String userType;

    /**
     * @desc 用户姓名
     * @column name
     * @default
     */
    @Excel(name = "姓名\n(必填)", orderNum = "1", width = 30, height = 40)
    private String name;

    /**
     * @desc 用户邮箱
     * @column email
     * @default
     */
//     @Excel(name = "用户邮箱", orderNum = "4", width = 20)
    private String email;

    /**
     * @desc 手机号码
     * @column phone
     * @default
     */
    @Excel(name = "手机号码", orderNum = "3", width = 20)
    private String phone;

    // 手机验证码
    @TableField(exist = false)
    private String smsCode;

    /**
     * @desc 用户性别（0男 1女 2未知）
     * @column sex
     * @default
     */
    @Excel(name = "用户性别", orderNum = "2", width = 20)
    private String sex;

    /**
     * @desc 密码
     * @column password
     * @default
     */
//     @Excel(name = "密码", orderNum = "7", width = 20)
    private String password;

    /**
     * @desc 身份证号
     * @column id_number
     * @default
     */
//     @Excel(name = "身份证号", orderNum = "8", width = 20)
    private String idNumber;

    /**
     * @desc 头像地址
     * @column avatar
     * @default
     */
//     @Excel(name = "头像地址", orderNum = "9", width = 20)
    private String avatar;

    /**
     * @desc 最后登录ip
     * @column login_ip
     * @default
     */
//     @Excel(name = "最后登录ip", orderNum = "10", width = 20)
    private String loginIp;

    /**
     * @desc 最后登录时间
     * @column login_date
     * @default
     */
    @JsonFormat(
            pattern = "yyyy-MM-dd"
    )
//     @Excel(name = "最后登录时间", orderNum = "11", width = 20, format = "yyyy-MM-dd")
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    private Date loginDate;

    /**
     * @desc 所属部门id
     * @column dept_id
     * @default
     */
//     @Excel(name = "所属部门id", orderNum = "12", width = 20)
    private BigInteger deptId;


    /**
     * @desc 身份（1管理员;2单位用户;3个人用户）
     * @column identity
     * @default
     */
//     @Excel(name = "身份（1管理员;2单位用户;3个人用户）", orderNum = "13", width = 20)
    private String identity;

    /**
     * @desc 微信id
     * @column wx_openid
     * @default
     */
//     @Excel(name = "微信id", orderNum = "14", width = 20)
    private String wxOpenid;

    /**
     * @desc wx地址
     * @column wx_address
     * @default
     */
//     @Excel(name = "wx地址", orderNum = "15", width = 20)
    private String wxAddress;

    /**
     * @desc wx头像
     * @column wx_head
     * @default
     */
//     @Excel(name = "wx头像", orderNum = "16", width = 20)
    private String wxHead;

    /**
     * @desc wx性别
     * @column wx_sex
     * @default
     */
//     @Excel(name = "wx性别", orderNum = "17", width = 20)
    private String wxSex;

    /**
     * @desc wx昵称
     * @column wx_nick_name
     * @default
     */
//     @Excel(name = "wx昵称", orderNum = "18", width = 20)
    private String wxNickName;

    /**
     * @desc 地址
     * @column address
     * @default
     */
//     @Excel(name = "地址", orderNum = "19", width = 20)
    private String address;

    /**
     * 开始时间
     */
    @JsonIgnore
    @TableField(exist = false)
    private String beginTime;

    /**
     * 结束时间
     */
    @JsonIgnore
    @TableField(exist = false)
    private String endTime;

    /**
     * 手机验证码
     */
    private transient String phoneCode;

    //用户新增后是否修改过密码 1 修改了 0 没修改
    private String updatePassword;

    //初始密码
    private String initPassword;


    @TableField(exist = false)
    private List<Integer> postId = new ArrayList<Integer>(); // 拥有角色列表

    @TableField(exist = false)
    private List<SysMenu> menuList = Lists.newArrayList(); // 拥有权限列表

    @TableField(exist = false)

    private String postName; // 岗位名称

    @TableField(exist = false)
    private String avatarUrl;

    // 查询关键字 手机号或用户名
    @TableField(exist = false)
    private String searchKey;
    //职位
    @Excel(name = "职业/专业", orderNum = "4", width = 20)
    private String position;
    //角色名list
    @TableField(exist = false)
    @Excel(name = "角色", orderNum = "5", width = 20)
    private String roleNames;
    //角色idlist
    @TableField(exist = false)
    private String roleIds;
    //小组名list
    @TableField(exist = false)
    @Excel(name = "小组", orderNum = "6", width = 20)
    private String groupNames;
    @Excel(name = "状态（启用/禁用）", orderNum = "7", width = 20)
    private String flag;
    //小组id
    @TableField(exist = false)
    private String groupId;
    //小组idlist
    @TableField(exist = false)
    private String groupIds;
    @TableField(exist = false)
    //角色idlist
    private List<Integer> roleIdsList;
    //小组idlist
    @TableField(exist = false)
    private List<Integer> groupIdsList;
    //课程id
    @TableField(exist = false)
    private String lessonId;

    //用户注册时区分 1个人 2讲师
    @TableField(exist = false)
    private String typeOfRegistration;

    //头衔
    @TableField(exist = false)
    private String title;
    //简介
    @TableField(exist = false)
    private String details;


    /**
     * 权限列表
     *
     * @return
     */
    @JsonIgnore
    public List<SimpleGrantedAuthority> getSimpleAuthorities() {
        List<SimpleGrantedAuthority> authorities = new ArrayList<SimpleGrantedAuthority>();
        SimpleGrantedAuthority auth = null;
        //有没有管理员
        if (this.businessId - 1 == 0) {
            authorities.add(new SimpleGrantedAuthority("*:*:*"));
        } else {
            for (SysMenu sysMenu : menuList) {
                auth = new SimpleGrantedAuthority(sysMenu.getPerms());
                authorities.add(auth);
            }
        }
        return authorities;
    }

}

