package org.rcisoft.business.sysuser.service;

import com.baomidou.mybatisplus.core.metadata.IPage;
import org.rcisoft.business.blesson.entity.StatisticsDetailVO;
import org.rcisoft.business.sysuser.dto.*;
import org.rcisoft.business.sysuser.entity.SysUser;
import org.rcisoft.business.sysuser.entity.UserViewInfoPartA;
import org.rcisoft.business.sysuser.entity.excel.InitPasswordExcel;
import org.rcisoft.business.sysuser.vo.UserInfoAllVO;
import org.rcisoft.business.sysuser.vo.UserInfoVO;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.pc.pcrolelesson.dto.PcRoleUnitUser;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import java.util.List;
import java.util.Map;

/**
 * Created by cy on 2024年4月8日 下午3:59:00.
 */
public interface PCSysUserService {

    /**
    * 保存 用户表
    * @param sign
    * @return
    */
    String persist(String sign);

    /**
    * 删除 用户表
    * @param sysUser
    * @return
    */
    CyPersistModel remove(SysUser sysUser);

    /**
    * 逻辑删除 用户表
    * @param sysUser
    * @return
    */
    CyPersistModel removeLogical(SysUser sysUser);

    /**
    * 修改 用户表
    * @param sysUser
    * @return
    */
    CyPersistModel merge(SysUser sysUser);
    /**
     * 修改 用户角色中间表
     * @param sysUser
     * @return
     */
    CyPersistModel updateRole(SysUser sysUser);
    /**
     * 修改 用户小组中间表
     * @param sysUser
     * @return
     */
    CyPersistModel updateGroup(SysUser sysUser);

    /**
    * 根据id查询 用户表
    * @param id
    * @return
    */
    SysUser findById(int id);

    /**
     * 查询单位管理员信息
     * @return
     */
   PCUnitUserDTO queryUnitAdmin();
    /**
    * 分页查询 用户表
    * @param sysUser
    * @return
    */
    IPage<SysUser> findAllByPagination(CyPageInfo<SysUser> paginationUtility,
              SysUser sysUser);

    /**
     * 根据课程id分页查询用户
     *
     */

    IPage<SysUser> queryUserByLessonByPagination(CyPageInfo<SysUser> paginationUtility,
              SysUser sysUser);
    /**
    * 查询list 用户表
    * @param sysUser
    * @return
    */
    List<SysUser> findAll(SysUser sysUser);


    /**
    * 导出用户表
    * @return
    */
    List<SysUser> export(SysUser sysUser);

    /**
     * 重置密码
     * @param sign
     * @return
     */
    CyPersistModel resetPassword(String sign);

    /**
     * 校验验证码
     * @param sign
     * @return
     */
    CyPersistModel checkPhoneCode(String sign);

    /**
     * 手机登录
     * @param sysUser
     * @return
     */
    Map<String, Object> phoneLogin(PCSysUserDTO sysUser);
    /**
     * 导入学员数据
     */
    String importData(MultipartFile file);

    /**
     * ip登录
     * @return
     */
    String ipLogin(HttpServletRequest request);
    /**
     *  查询当前单位学习排名
     */
    List<PcSysUserCountDTO> queryUnitRank(int unit);

    /**
     *  查询当前单位学员学习信息
     */
    PcUserInfoDTO queryUserStudyInfo();

    /**
     * 个人资料
     * @param businessId
     * @return
     */
    PCUnitUserDTO findByUserId(int businessId);

    /**
     * 单位用户已选学员查询
     * @return
     */
    List<PcRoleUnitUser> queryUnitUser(PcRoleUnitUser dto);

    /**
     * 查询个人用户
     *
     * @param paginationUtility
     * @param sysUser
     * @return
     */
    IPage<SysUser> listByIdentity(CyPageInfo<SysUser> paginationUtility, SysUser sysUser);



    IPage<UserViewInfoPartA> getUserView(CyPageInfo<UserViewInfoPartA> paginationUtility,SysUser user);

    UserInfoAllVO getTotal(UserViewDetailsDTO userViewDetailsDTO);
//
//    IPage<StatisticsDetailVO> getLearning(CyPageInfo<StatisticsDetailVO> paginationUtility,SysUser user);
//
//    UserInfoVO getFinish(UserViewDetailsDTO userViewDetailsDTO);
//
//    UserInfoVO getNotStart(UserViewDetailsDTO userViewDetailsDTO);
//
//    UserInfoVO getExamedNumber(UserViewDetailsDTO userViewDetailsDTO);
//
//    UserInfoVO getNotExamedNumber(UserViewDetailsDTO userViewDetailsDTO);

    /**
     * 根据类型分页查询 用户视图详情
     * @param paginationUtility
     * @param user
     * @return
     */
    IPage<StatisticsDetailVO> getLearnType(CyPageInfo<StatisticsDetailVO> paginationUtility, UserInfoVO user);

    IPage<StatisticsDetailVO> getExamType(CyPageInfo<StatisticsDetailVO> paginationUtility, UserInfoVO vo);

    Boolean isFirstLogin();

    List<InitPasswordExcel> exportInitPassword(String deptId);

    Boolean updatePassword(Integer businessId);

    CyPersistModel addLectureByUser(SysUser sysUser);
}
