package org.rcisoft.business.sysuser.service.impl;

import cn.hutool.core.util.ObjectUtil;
import cn.hutool.json.JSONUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.rcisoft.business.blesson.entity.BLesson;
import org.rcisoft.business.blesson.entity.StatisticsDetailVO;
import org.rcisoft.business.blesson.service.BLessonService;
import org.rcisoft.business.blesson.service.impl.BLessonServiceImpl;
import org.rcisoft.business.sysLecturer.dao.CmsLecturerRepository;
import org.rcisoft.business.sysLecturer.entity.CmsLecturer;
import org.rcisoft.business.sysunit.dao.UnitRepository;
import org.rcisoft.business.sysunit.entity.SysUnit;
import org.rcisoft.business.sysuser.dao.PCSysUserRepository;
import org.rcisoft.business.sysuser.dto.*;
import org.rcisoft.business.sysuser.entity.SysUser;
import org.rcisoft.business.sysuser.entity.UserViewInfoPartA;
import org.rcisoft.business.sysuser.entity.excel.InitPasswordExcel;
import org.rcisoft.business.sysuser.enums.IdentityStaCons;
import org.rcisoft.business.sysuser.enums.LeaningTypeEnum;
import org.rcisoft.business.sysuser.enums.PCUserInfoExceptionEnums;
import org.rcisoft.business.sysuser.service.PCSysUserService;
import org.rcisoft.business.sysuser.vo.UserInfoAllVO;
import org.rcisoft.business.sysuser.vo.UserInfoVO;
import org.rcisoft.common.component.CyGlobal;
import org.rcisoft.core.component.CyInitComp;
import org.rcisoft.core.component.CySmsComp;
import org.rcisoft.core.constant.CyDelStaCons;
import org.rcisoft.core.constant.CyFlagStaCons;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.jwt.model.CyJwtUser;
import org.rcisoft.core.jwt.util.CyJwtUtil;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.result.enums.CyResSysExcEnum;
import org.rcisoft.core.service.CyAuthService;
import org.rcisoft.core.service.CyRedisService;
import org.rcisoft.core.threadpool.CyAsyncFactory;
import org.rcisoft.core.threadpool.CyAsyncManager;
import org.rcisoft.core.util.*;
import org.rcisoft.pc.pcgroup.entity.PcGroup;
import org.rcisoft.pc.pcgroup.service.PcGroupService;
import org.rcisoft.pc.pcgroupuser.entity.PcGroupUser;
import org.rcisoft.pc.pcgroupuser.service.PcGroupUserService;
import org.rcisoft.pc.pcrole.entity.PcRole;
import org.rcisoft.pc.pcrole.service.PcRoleService;
import org.rcisoft.pc.pcrolelesson.dto.PcRoleUnitUser;
import org.rcisoft.pc.pcroleuser.entity.PcRoleUser;
import org.rcisoft.pc.pcroleuser.service.PcRoleUserService;
import org.rcisoft.sys.constant.CyUserCons;
import org.rcisoft.sys.log.entity.SysLoginInfo;
import org.rcisoft.sys.rbac.user.entity.SysUserRbac;
import org.rcisoft.sys.rbac.user.enums.UserInfoExceptionEnums;
import org.rcisoft.sys.wbac.menu.dao.SysMenuRepository;
import org.rcisoft.sys.wbac.menu.dto.SysMenuDTO;
import org.rcisoft.sys.wbac.menu.entity.SysMenu;
import org.rcisoft.sys.wbac.user.dao.SysUserRepository;
import org.rcisoft.tencent.cons.CyWxMiniCons;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.security.authentication.AuthenticationManager;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.security.crypto.password.PasswordEncoder;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import java.math.BigInteger;
import java.util.*;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.stream.Collectors;

/**
 * Created by cy on 2024年4月8日 下午3:59:00.
 */
@Service
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class PCSysUserServiceImpl extends ServiceImpl<PCSysUserRepository, SysUser> implements PCSysUserService {

    /**
     * @desc 用户登录token
     * @sample login:user:token:{userName}
     */
    static final String LOGIN_USER_TOKEN = "LOGIN_USER_TOKEN:";
    @Autowired(required = false)
    CyRedisService cyRedisService;
    @Autowired
    private PCSysUserRepository pcSysUserRepository;
    /**
     * 调用rabc 用户方法
     */
    @Autowired
    private SysUserRepository sysUserRepository;
    @Autowired
    private SysMenuRepository sysMenuRepository;
    @Autowired
    private PasswordEncoder passwordEncoder;
    @Autowired
    private PcRoleUserService roleUserService;
    @Autowired
    private PcGroupUserService groupUserService;
    @Autowired
    private CyInitComp cyInitComp;
    @Autowired
    private CyAuthService authenticationServiceImpl;
    @Autowired
    private PcRoleService PcRoleService;
    @Autowired
    private PcGroupService groupService;
    @Autowired
    private AuthenticationManager authenticationManager;
    @Autowired
    private BLessonServiceImpl bLessonService;
    @Autowired
    private UnitRepository unitRepository;
    @Autowired
    private BLessonService bLessonServiceImpl;

    @Autowired
    private PcGroupService pcGroupService;
    @Autowired
    private CmsLecturerRepository cmsLecturerRepository;

    @Value("${cy.model.login.log:}")
    private Boolean loginLog;
    //    @Value("${cy.init.unit:}")
//    private List<String> initUnit;
    @Value("${cy.init.password:}")
    private String initPassword;
    @Autowired(required = false)
    private CySmsComp cySmsComp;
    @Autowired
    private CyGlobal cyGlobal;

    /**
     * 删除 用户表
     *
     * @param sysUser
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(SysUser sysUser) {
        int line = baseMapper.realDelete(sysUser);
        log.debug(CyUserUtil.getAuthenUsername() + "删除了ID为" +
                sysUser.getBusinessId() + "的用户表信息");
        return new CyPersistModel(line);
    }

    /**
     * 逻辑删除 用户表
     *
     * @param sysUser
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(SysUser sysUser) {
        sysUser.setDeleted();
        int line = baseMapper.deleteById(sysUser);
        log.debug(CyUserUtil.getAuthenUsername() + "逻辑删除了ID为" +
                sysUser.getBusinessId() + "的用户表信息");
        return new CyPersistModel(line);
    }

    /**
     * 修改 用户表
     *
     * @param sysUser
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(SysUser sysUser) {
        //数据校验是否重复
        if (sysUser.getBusinessId() == null) {
            throw new CyServiceException(PCUserInfoExceptionEnums.USERNAME_NOT_EXISTS);
        }
        //如果sysUser中的username为空的话 则为修改用户状态请求 不进行验重
        if (StringUtils.isNotEmpty(sysUser.getUsername())) {
            SysUser findUser = baseMapper.checkInfoRepeat(sysUser);
            if (findUser != null) {
                if (StringUtils.isNotEmpty(findUser.getUsername())) {
                    throw new CyServiceException(UserInfoExceptionEnums.USERNAME_EXISTS);
                }
                //手机号无法修改注掉
//                if (StringUtils.isNotEmpty(findUser.getPhone())) {
//                    throw new CyServiceException(UserInfoExceptionEnums.PHONE_EXISTS);
//                }
            }
        }
        // 根据id查询原来的值
        SysUser oldUser = baseMapper.selectById(sysUser.getBusinessId());
        sysUser.setUsername(oldUser.getUsername());
        int line = baseMapper.updateById(sysUser);
        //如果有title 和 简介 就修改讲师表
        CmsLecturer cmsLecturer = cmsLecturerRepository.selectByUserId(sysUser.getBusinessId());
        if (cmsLecturer != null && sysUser.getTitle() != null || sysUser.getDetails() != null) {
            cmsLecturer.setTitle(sysUser.getTitle());
            cmsLecturer.setDetails(sysUser.getDetails());
            cmsLecturer.setName(sysUser.getName());
            cmsLecturerRepository.updateById(cmsLecturer);
        }

        return new CyPersistModel(line);
    }

    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT, rollbackFor = Exception.class)
    @Override
    public CyPersistModel updateRole(SysUser sysUser) {
        //根据用户id全查用户角色关联表
        PcRoleUser pcRoleUser = new PcRoleUser();
        pcRoleUser.setUserId(sysUser.getBusinessId());
        List<PcRoleUser> pcRoleUserList = roleUserService.findAll(pcRoleUser);
        if (pcRoleUserList != null && !pcRoleUserList.isEmpty()) {
            //删除用户角色关联表
            baseMapper.deleteUserRole(pcRoleUserList);
        }
        if (sysUser.getRoleIdsList() == null || sysUser.getRoleIdsList().isEmpty()) {

        } else {
            //在中间表中添加数据
            List<Integer> roleIdList = sysUser.getRoleIdsList();
            if (roleIdList != null && !roleIdList.isEmpty()) {
                for (Integer roleId : roleIdList) {
                    PcRoleUser pcRoleUser1 = new PcRoleUser();
                    pcRoleUser1.setUserId(sysUser.getBusinessId());
                    pcRoleUser1.setPcRoleId(roleId);
                    roleUserService.persist(pcRoleUser1);
                }
            }

        }
//        int line = baseMapper.updateById(sysUser);
        log.debug(CyUserUtil.getAuthenUsername() + "修改了ID为" + sysUser.getBusinessId() + "的用户表信息");
        return new CyPersistModel(1);
    }

    @Override
    public CyPersistModel updateGroup(SysUser sysUser) {
        PcGroupUser pcGroupUser = new PcGroupUser();
        pcGroupUser.setUserId(sysUser.getBusinessId());
        List<PcGroupUser> pcGroupUserList = groupUserService.findAll(pcGroupUser);
        if (pcGroupUserList != null && !pcGroupUserList.isEmpty()) {
            //删除用户小组关联表
            baseMapper.deleteUserGroup(pcGroupUserList);
        }
        if (sysUser.getGroupIdsList() == null || sysUser.getGroupIdsList().isEmpty()) {
            //如果为空的话则不用添加
        } else {
            List<Integer> groupIdList = sysUser.getGroupIdsList();
            if (groupIdList != null && !groupIdList.isEmpty()) {
                for (Integer groupId : groupIdList) {
                    PcGroupUser pcGroupUser1 = new PcGroupUser();
                    pcGroupUser1.setUserId(sysUser.getBusinessId());
                    pcGroupUser1.setGroupId(groupId);
                    //导入默认没有组长
                    pcGroupUser1.setType(0);
                    groupUserService.persist(pcGroupUser1);
                }
            }
        }
        //在中间表中添加数据

        log.debug(CyUserUtil.getAuthenUsername() + "修改了ID为" + sysUser.getBusinessId() + "的用户表信息");
        return new CyPersistModel(1);

    }

    /**
     * 根据id查询 用户表
     *
     * @param id
     * @return
     */
    @Override
    public SysUser findById(int id) {
        return baseMapper.selectById(id);
    }

    @Override
    public PCUnitUserDTO queryUnitAdmin() {
//      //获取登录人id
        Integer currentUserId = Integer.valueOf(CyUserUtil.getAuthenBusinessId());
        SysUnit sysUnit = new SysUnit();
        List<SysUnit> sysUnits = unitRepository.querySysUnits(sysUnit);
        List<Integer> userIds = sysUnits.stream().map(SysUnit::getUserId).collect(Collectors.toList());
        PCUnitUserDTO pcUnitUserDTO = new PCUnitUserDTO();
        if (userIds.contains(currentUserId)) {
            //证明是单位管理员
            pcUnitUserDTO = baseMapper.queryUnitAdmin(currentUserId);
            Integer studentCount = baseMapper.countUnitUser(currentUserId);
            pcUnitUserDTO.setStudentCount(String.valueOf(studentCount));
        } else {
            //普通单位学员
            PcGroup pcGroup = new PcGroup();
            pcUnitUserDTO = baseMapper.queryUnitAdmin(currentUserId);
            List<PcGroup> pcGroups = pcGroupService.listAllLinkGroup(pcGroup);
            //设置小组数量
            int groupNum = pcGroups.size();
            pcUnitUserDTO.setGroupCount(String.valueOf(groupNum));
            //设置学员数量
            int count = 0;
            for (PcGroup group : pcGroups) {
                if (group.getGroupIds() != null){
                    String groupIds = group.getGroupIds();
                    String[] split = groupIds.split(",");
                    int length = split.length;
                    count = count + length;
                }
            }
            pcUnitUserDTO.setStudentCount(String.valueOf(count));
        }
        CyPageInfo<BLesson> paginationUtility = new CyPageInfo<>();
        BLesson bLesson = new BLesson();
        String dept = CyUserUtil.getAuthenDept();
        IPage<BLesson> bLessonIPage = new Page<>();
        if (!dept.equals("null")){
            bLesson.setUnitId(Integer.valueOf(CyUserUtil.getAuthenDept()));
            bLessonIPage = bLessonServiceImpl.queryPcBLessonsByPagination(paginationUtility, bLesson);
            long total = bLessonIPage.getTotal();
            pcUnitUserDTO.setLessonCount(String.valueOf(total));
        }
        return pcUnitUserDTO;
    }

    /**
     * 分页查询 用户表
     *
     * @param sysUser
     * @return
     */
    @Override
    public IPage<SysUser> findAllByPagination(CyPageInfo<SysUser> paginationUtility,
                                              SysUser sysUser) {
//        sysUser.setDeptId(BigInteger.valueOf(Long.parseLong(CyUserUtil.getAuthenDept())));
        String authenBusinessId = CyUserUtil.getAuthenBusinessId();
        SysUser user = baseMapper.selectById(authenBusinessId);
        sysUser.setDeptId(user.getDeptId());
        IPage<SysUser> sysUserIPage = baseMapper.querySysUsersPaged(paginationUtility, sysUser);
        //循环
        sysUserIPage.getRecords().forEach(sysUser1 -> {
            if (StringUtils.isNotEmpty(sysUser1.getInitPassword()) && !"2".equals(sysUser1.getUpdatePassword())) {
                try {
                    RC4Util rc4Util = new RC4Util();
                    sysUser1.setInitPassword(rc4Util.decryptFromHex(sysUser1.getInitPassword(), null));
                } catch (Exception e) {
                    sysUser1.setInitPassword("前往管理端重置密码");
                }
            }
        });
        return sysUserIPage;

    }

    /**
     * 根据课程id分页查询用户
     */
    @Override
    public IPage<SysUser> queryUserByLessonByPagination(CyPageInfo<SysUser> paginationUtility, SysUser sysUser) {
        sysUser.setDeptId(BigInteger.valueOf(Long.parseLong(CyUserUtil.getAuthenDept())));
        return baseMapper.queryUserByLesson(paginationUtility, sysUser);
    }

    /**
     * 查询list 用户表
     *
     * @param sysUser
     * @return
     */
    @Override
    public List<SysUser> findAll(SysUser sysUser) {
//        sysUser.setDeptId(BigInteger.valueOf(Long.parseLong(CyUserUtil.getAuthenDept())));
        String userId = CyUserUtil.getAuthenBusinessId();
        SysUser user = pcSysUserRepository.selectById(userId);
        sysUser.setDeptId(user.getDeptId());
        List<SysUser> sysUsers = baseMapper.querySysUsers(sysUser);
        //查询当前用户id
        String authenUsername = CyUserUtil.getAuthenUsername();
        //剔除当前用户id的数据
        if (CollectionUtils.isNotEmpty(sysUsers)) {
            sysUsers.removeIf(sysUser1 -> sysUser1.getUsername().equals(authenUsername));
        }
        return sysUsers;
    }

    /**
     * 导出用户表
     *
     * @return
     */
    @Override
    public List<SysUser> export(SysUser sysUser) {
        List<SysUser> sysUserList = baseMapper.querySysUsers(sysUser);
        return sysUserList;
    }

    //pc端

    /**
     * 保存 用户表
     *
     * @param sign
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public String persist(String sign) {
        // 1.解密
        SysUser userToAdd = null;
        String phone, sms = null;
        try {
            String userJson = CyRSAUtil.decryptByPrivateKey(null, sign);
            userToAdd = JSONUtil.toBean(userJson, SysUser.class);
            phone = userToAdd.getPhone();
            sms = userToAdd.getSmsCode();
            //信息为空
            if (StringUtils.isAnyEmpty(phone) || StringUtils.isAnyEmpty(sms))
                throw new CyServiceException(CyResSysExcEnum.PARAMETER_ERROR);
        } catch (Exception e) {
            throw new CyServiceException(CyResSysExcEnum.PARAMETER_ERROR);
        }
        // 3.校验短信验证码是否正确
        cySmsComp.checkVerification(phone, sms);
        //查重
        PCSysUserDTO sysUserRbacDTO = baseMapper.checkAddRepeat(userToAdd);
        if (null != sysUserRbacDTO) {
            if (StringUtils.isNotEmpty(sysUserRbacDTO.getUsername())) {
                throw new CyServiceException(UserInfoExceptionEnums.USERNAME_EXISTS);
            }
            if (StringUtils.isNotEmpty(sysUserRbacDTO.getPhone())) {
                throw new CyServiceException(UserInfoExceptionEnums.PHONE_EXISTS);
            }
        }
        //增加操作
        userToAdd.setFlag(CyFlagStaCons.NORMAL.getStatus());
        userToAdd.setDelFlag(CyDelStaCons.NORMAL.getStatus());
        userToAdd.setUserType(CyUserCons.USER_TYPE_COMMON);
        String password = userToAdd.getPassword();
        userToAdd.setPassword(passwordEncoder.encode(userToAdd.getPassword()));
        //配置身份
        userToAdd.setIdentity(IdentityStaCons.INDIVIDUAL.getStatus());
        //插入人
        baseMapper.insert(userToAdd);
        //角色有变 1为个人 2为讲师
        //当注册用户为讲师
        if ("2".equals(userToAdd.getTypeOfRegistration())) {
            baseMapper.insertUserRole(userToAdd.getBusinessId(), cyInitComp.getPermission()[4]);
            //创建讲师
            CmsLecturer cmsLecturer = new CmsLecturer();
            //备注 -》用户id
            cmsLecturer.setUserId(userToAdd.getBusinessId());
            //头像 默认头像
            cmsLecturer.setAvatarId(2);
            //姓名
            cmsLecturer.setName(userToAdd.getName());
            //flag
            cmsLecturer.setFlag(CyFlagStaCons.NORMAL.getStatus());
            cmsLecturerRepository.insert(cmsLecturer);
        } else {
            baseMapper.insertUserRole(userToAdd.getBusinessId(), cyInitComp.getPermission()[0]);
        }
        HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes()).getRequest();
        String token = persistLogin(userToAdd, request, password);
        // 注册成功调用登录接口，返回token
        return token;
    }

    /**
     * 注册后直接登录  发布时间
     *
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    public String persistLogin(SysUser userToAdd, HttpServletRequest request, String password) {
        //1. 获取ip
        String ip = CyAddressUtils.IpUtils.getIpAddr(request);
        if (StringUtils.isBlank(ip)) {
            throw new CyServiceException(PCUserInfoExceptionEnums.USERNAME_NOT_EXISTS);
        }
        // 1.创建虚拟用户
        String username = userToAdd.getUsername();
        // 3. 登录
        Authentication authentication = null;
        SysLoginInfo sysLoginInfo = new SysLoginInfo();
        sysLoginInfo.setIpaddr(ip);
        //登录名
        sysLoginInfo.setUsername(username);
        sysLoginInfo.setLoginTime(new Date());
        //创建虚拟用户
        SysUserRbac sysUser = new SysUserRbac();
        sysUser.setBusinessId(userToAdd.getBusinessId());
        sysUser.setLoginIp(ip);
        sysUser.setIdentity("3");
        sysUser.setUsername(username);
        sysUser.setPassword(password);
        if (loginLog) {
            //登录成功sysLoginInfo
            sysLoginInfo.setSuccess();
            CyAsyncManager.me().execute(CyAsyncFactory.recordLoad(sysLoginInfo));
        }
        boolean notLocked = true;
        CyJwtUser jwtUser = CyJwtUtil.createRbacJwtUser(sysUser, notLocked);
        // 4. 生成token
        final String token = CyJwtUtil.generateToken(jwtUser);
        SecurityContextHolder.getContext().setAuthentication(authentication);
        return token;
    }

    /**
     * 重置密码
     *
     * @param sign
     * @return
     */
    @Override
    public CyPersistModel resetPassword(String sign) {
        PCSysUserDTO sysUser = null;
        String phone = null;
        try {
            String userJson = CyRSAUtil.decryptByPrivateKey(null, sign);
            sysUser = JSONUtil.toBean(userJson, PCSysUserDTO.class);
            phone = sysUser.getPhone();
            //信息为空
            if (StringUtils.isAnyEmpty(phone))
                throw new CyServiceException(CyResSysExcEnum.PARAMETER_ERROR);
        } catch (Exception e) {
            throw new CyServiceException(CyResSysExcEnum.PARAMETER_ERROR);
        }

        //根据手机号查询用户
        QueryWrapper<SysUser> qw = new QueryWrapper<>();
        qw.eq("phone", sysUser.getPhone());
        SysUser sysUser1 = baseMapper.selectOne(qw);
        if (null == sysUser1) {
            throw new CyServiceException(PCUserInfoExceptionEnums.PHONE_NOT_EXISTS);
        }
        //验证码验证正确
        int line = sysUserRepository.changePassword(String.valueOf(sysUser1.getBusinessId()), passwordEncoder.encode(sysUser.getPassword()));
        log.info(CyUserUtil.getAuthenUsername() + "为" +
                sysUser.getBusinessId() + "重置了密码");
        return new CyPersistModel(line);
    }

    /**
     * 校验手机验证码
     *
     * @param sign
     * @return
     */
    @Override
    public CyPersistModel checkPhoneCode(String sign) {
        // 1.解密
        PCSysUserDTO sysUser = null;
        String phone, sms = null;
        try {
            String userJson = CyRSAUtil.decryptByPrivateKey(null, sign);
            sysUser = JSONUtil.toBean(userJson, PCSysUserDTO.class);
            phone = sysUser.getPhone();
            sms = sysUser.getPhoneCode();
            //信息为空
            if (StringUtils.isAnyEmpty(phone) || StringUtils.isAnyEmpty(sms))
                throw new CyServiceException(CyResSysExcEnum.PARAMETER_ERROR);
        } catch (Exception e) {
            throw new CyServiceException(CyResSysExcEnum.PARAMETER_ERROR);
        }
        // 2.校验短信验证码是否正确
        cySmsComp.checkVerification(phone, sms);
        return new CyPersistModel(1);
    }

    /**
     * ip登录  发布时间
     *
     * @return
     */
    @Override
    public String ipLogin(HttpServletRequest request) {
        //1. 获取ip登录
        String ip = CyAddressUtils.IpUtils.getIpAddr(request);
        if (StringUtils.isBlank(ip)) {
            throw new CyServiceException(PCUserInfoExceptionEnums.USERNAME_NOT_EXISTS);
        }
        // 1.创建虚拟用户
        String username = ip;
        String password = ip;
        // 3. 登录
        Authentication authentication = null;
        SysLoginInfo sysLoginInfo = new SysLoginInfo();
        sysLoginInfo.setIpaddr(ip);
        //登录名
        sysLoginInfo.setUsername(username);
        sysLoginInfo.setLoginTime(new Date());
        //创建虚拟用户
        SysUserRbac sysUser = new SysUserRbac();
        try {
            //查询当前ip地址属于那个单位数据
            List<SysUnit> list = unitRepository.selectByIp(ip);
            if (CollectionUtils.isNotEmpty(list)) {
                //获取单位id
                Integer businessId = list.get(0).getBusinessId();
                sysUser.setDeptId(businessId);
                sysUser.setLoginIp(ip);
                sysUser.setIdentity("4");
                sysUser.setUsername(username);
                sysUser.setPassword(password);
            } else {
                throw new CyServiceException(PCUserInfoExceptionEnums.USER_NOT_LOGINPERMISSIOR.getCode(),
                        PCUserInfoExceptionEnums.USER_NOT_LOGINPERMISSIOR.getMessage());
            }
        } catch (Exception e) {
            if (loginLog) {
                //登录失败的日志
                sysLoginInfo.setMsg(StringUtils.substring(e.getMessage(), 0, 2000));
                sysLoginInfo.setFail();
                CyAsyncManager.me().execute(CyAsyncFactory.recordLoad(sysLoginInfo));
            }
            throw e;
        }
        if (loginLog) {
            //登录成功sysLoginInfo
            sysLoginInfo.setSuccess();
            CyAsyncManager.me().execute(CyAsyncFactory.recordLoad(sysLoginInfo));
        }
        boolean notLocked = true;
        CyJwtUser jwtUser = CyJwtUtil.createRbacJwtUser(sysUser, notLocked);
        // 4. 生成token
        final String token = CyJwtUtil.generateToken(jwtUser);
        SecurityContextHolder.getContext().setAuthentication(authentication);

        // 5. token存储redis
        cyRedisService.set(LOGIN_USER_TOKEN + ip + username, token, Long.parseLong(cyGlobal.getLOGIN_TTL()));
        return token;
    }

    @Override
    public List<PcSysUserCountDTO> queryUnitRank(int unit) {
        return baseMapper.queryUnitRank(String.valueOf(unit));
    }

    @Override
    public PcUserInfoDTO queryUserStudyInfo() {
        PcUserInfoDTO PcUserInfoDTO = new PcUserInfoDTO();
        //统计今日学习小结
        String todayStudy = baseMapper.queryTodayStudy(Integer.valueOf(CyUserUtil.getAuthenBusinessId()));
        if (StringUtils.isEmpty(todayStudy)) {
            todayStudy = "0";
        }
        PcUserInfoDTO.setTodayStudy(Integer.valueOf(todayStudy));
        //统计累计学习小结
        String totalStudy = baseMapper.queryTotalStudy(Integer.valueOf(CyUserUtil.getAuthenBusinessId()));
        if (StringUtils.isEmpty(totalStudy)) {
            totalStudy = "0";
        }
        PcUserInfoDTO.setTotalStudy(Integer.valueOf(totalStudy));
        List<BLesson> allBLessons = bLessonServiceImpl.getAllBLessonByUserId(CyUserUtil.getAuthenBusinessId());
        // 必修未完成数量
        AtomicInteger obligatoryIncompleteCount = new AtomicInteger();
        // 必修已完成数量
        AtomicInteger obligatoryCompleteCount = new AtomicInteger();
        allBLessons.forEach(bLesson -> {
            String isCompleteLearned = bLesson.getIsCompleteLearned();
            if ("0".equals(isCompleteLearned)) {
                obligatoryIncompleteCount.incrementAndGet();
            } else if ("1".equals(isCompleteLearned)) {
                obligatoryCompleteCount.incrementAndGet();
            }

        });
        PcUserInfoDTO.setStudying(obligatoryIncompleteCount.get());
        PcUserInfoDTO.setStudyFinish(obligatoryCompleteCount.get());

        return PcUserInfoDTO;
    }

    /**
     * 个人资料查询用户信息
     *
     * @param businessId
     * @return
     */
    @Override
    public PCUnitUserDTO findByUserId(int businessId) {
        PCUnitUserDTO byUserId = baseMapper.findByUserId(businessId);
        //查询出当前用户的讲师信息
        CmsLecturer cmsLecturer = cmsLecturerRepository.selectByUserId(businessId);
        if (cmsLecturer != null) {
            byUserId.setTitle(cmsLecturer.getTitle());
            byUserId.setDetails(cmsLecturer.getDetails());
        }
        return byUserId;
    }

    /**
     * 单位用户已选学员查询
     *
     * @return
     */
    @Override
    public List<PcRoleUnitUser> queryUnitUser(PcRoleUnitUser dto) {
        List<PcRoleUnitUser> list = baseMapper.queryUnitUser(dto);
        return list;
    }

    /**
     * 查询个人用户
     *
     * @param paginationUtility
     * @param sysUser
     * @return
     */
    @Override
    public IPage<SysUser> listByIdentity(CyPageInfo<SysUser> paginationUtility, SysUser sysUser) {
        IPage<SysUser> listByIdentity = baseMapper.findListByIdentity(paginationUtility, sysUser);
        return listByIdentity;
    }


    /**
     * 手机账号登录
     *
     * @param sysUser
     * @return
     */
    @Override
    public Map<String, Object> phoneLogin(PCSysUserDTO sysUser) {
        //TODO:验证手机验证码
        String phone = sysUser.getPhone();
        List<SysUser> sysUsers = pcSysUserRepository.selectByPhone(phone);
        //2.1 手机号已存在
        if (CollectionUtils.isNotEmpty(sysUsers))
            return this.phoneLogin(sysUsers.get(0), phone);
        //2.2 手机号不存在,客户第一次登录
        return this.phoneLogin(null, phone);
    }

    /**
     * 导入学员
     *
     * @param file
     * @return
     */
    @Override
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT, rollbackFor = Exception.class)
    public String importData(MultipartFile file) {
        List<PCUserImportDTO> pcUserImportDTOS = CyEpExcelUtil.importExcel(file, 1, 1, PCUserImportDTO.class);
        //导入是否为空
        if (CollectionUtils.isEmpty(pcUserImportDTOS)) {
            throw new CyServiceException("导入数据为空");
        }


        //正确的条数
        int successNum = 0;
        //错误的条数
        int errorNum = 0;
        //看一下当前的用户组下能放多少个
        //获得用户信息
        String authenBusinessId = CyUserUtil.getAuthenBusinessId();
        //查询能够导入学员的数量
        Integer studentNum = pcSysUserRepository.countUserDeptId(Integer.valueOf(authenBusinessId));
        if (studentNum == null) {
            //默认导入学员数量sql
            studentNum = pcSysUserRepository.countUserDefault(authenBusinessId);
        }
        if (studentNum <= 0) {
            throw new CyServiceException("当前单位的学员已经到达上限");
        }
//        //导入进数据查看 是否有重复
//        //按照姓名分组
//        Map<String, List<PCUserImportDTO>> collect = pcUserImportDTOS.stream().collect(Collectors.groupingBy(PCUserImportDTO::getName));
//        //按照手机号分组
//        Map<String, List<PCUserImportDTO>> phoneCollect = pcUserImportDTOS.stream().collect(Collectors.groupingBy(PCUserImportDTO::getPhone));
//        //按照登录名分组
//        Map<String, List<PCUserImportDTO>> usernameCollect = pcUserImportDTOS.stream().collect(Collectors.groupingBy(PCUserImportDTO::getUsername));
//

        StringBuilder errorMessage = new StringBuilder();
        //记录导入失败条数
        //登录名
        List<String> duplicateLogins = new ArrayList<>();
        //手机号
        List<String> mobilePhoneNumbersAreDuplicated = new ArrayList<>();
        //性别
        List<String> sexIsIncorrect = new ArrayList<>();
        //状态
        List<String> statusIsIncorrect = new ArrayList<>();
        //姓名
        List<String> nameIsIncorrect = new ArrayList<>();
        //角色名称
        List<String> roleNameIncorrect = new ArrayList<>();
        //小组名称
        List<String> groupNameIncorrect = new ArrayList<>();
        //职位
        List<String> positionIncorrect = new ArrayList<>();
        if (CollectionUtils.isNotEmpty(pcUserImportDTOS)) {


            for (int i = 0; i < pcUserImportDTOS.size(); i++) {
                if (pcUserImportDTOS.get(i).getUsername() != null) {
                    PCUserImportDTO pcUserImportDTO = pcUserImportDTOS.get(i);
                    SysUser sysUser = new SysUser();
                    BeanUtils.copyProperties(pcUserImportDTO, sysUser);
                    //查重
                    //校验必填项
                    //校验登录名
                    if (StringUtils.isEmpty(pcUserImportDTO.getUsername()) || pcUserImportDTO.getUsername().length() > 25) {
                        errorNum += 1;
                        duplicateLogins.add(String.valueOf(i + 1));
//                        errorMessage.append("第").append(i + 1).append("条登录名重复数据导入失败").append("\n");
                        continue;
                    }
                    //姓名长度
                    if (StringUtils.isEmpty(pcUserImportDTO.getName()) || pcUserImportDTO.getName().length() > 20) {
                        errorNum += 1;
                        nameIsIncorrect.add(String.valueOf(i + 1));
//                        errorMessage.append("第").append(i + 1).append("条姓名错误数据导入失败").append("\n");
                        continue;
                    }
                    //职位长度
                    if (StringUtils.isEmpty(pcUserImportDTO.getPosition()) || pcUserImportDTO.getPosition().length() > 100) {
                        errorNum += 1;
                        positionIncorrect.add(String.valueOf(i + 1));
//                        errorMessage.append("第").append(i + 1).append("条姓名错误数据导入失败").append("\n");
                        continue;
                    }
                    //角色名称长度
                    if (StringUtils.isNotEmpty(pcUserImportDTO.getRoleNames()) && pcUserImportDTO.getRoleNames().length() > 100) {
                        errorNum += 1;
                        roleNameIncorrect.add(String.valueOf(i + 1));
//                        errorMessage.append("第").append(i + 1).append("条姓名错误数据导入失败").append("\n");
                        continue;
                    }
                    //小组名称长度
                    if (StringUtils.isNotEmpty(pcUserImportDTO.getGroupNames()) && pcUserImportDTO.getGroupNames().length() > 20) {
                        errorNum += 1;
                        groupNameIncorrect.add(String.valueOf(i + 1));
//                        errorMessage.append("第").append(i + 1).append("条姓名错误数据导入失败").append("\n");
                        continue;
                    }
                    //校验手机号
                    if (StringUtils.isEmpty(pcUserImportDTO.getPhone()) || pcUserImportDTO.getPhone().length() != 11) {
                        errorNum += 1;
                        mobilePhoneNumbersAreDuplicated.add(String.valueOf(i + 1));
//                        errorMessage.append("第").append(i + 1).append("条手机号重复或错误数据导入失败").append("\n");
                        continue;
                    }
                    //校验性别不为空并且为男或女
                    if (StringUtils.isEmpty(pcUserImportDTO.getSex()) || (!"男".equals(pcUserImportDTO.getSex()) && !"女".equals(pcUserImportDTO.getSex()))) {
                        errorNum += 1;
                        sexIsIncorrect.add(String.valueOf(i + 1));
//                        errorMessage.append("第").append(i + 1).append("条性别错误数据导入失败").append("\n");
                        continue;
                    }
//                //校验角色不为空
//                if (StringUtils.isEmpty(pcUserImportDTO.getRoleNames())) {
//                    errorNum += 1;
//                    errorMessage.append("第").append(i + 1).append("条数据导入失败").append("\n");
//                    continue;
//                }
//                //校验小组不为空
//                if (StringUtils.isEmpty(pcUserImportDTO.getGroupNames())) {
//                    errorNum += 1;
//                    errorMessage.append("第").append(i + 1).append("条数据导入失败").append("\n");
//                    continue;
//                }
                    //校验状态不为空 并且为启用或禁用
                    if (StringUtils.isEmpty(pcUserImportDTO.getFlag()) || (!"启用".equals(pcUserImportDTO.getFlag()) && !"停用".equals(pcUserImportDTO.getFlag()))) {
                        errorNum += 1;
                        statusIsIncorrect.add(String.valueOf(i + 1));
//                        errorMessage.append("第").append(i + 1).append("条状态错误数据导入失败").append("\n");
                        continue;
                    }
                    //登录名验重
//                Integer count = baseMapper.weightName(pcUserImportDTO.getUsername());
                    if (baseMapper.weightName(pcUserImportDTO.getUsername()) > 0) {
                        errorNum += 1;
                        duplicateLogins.add(String.valueOf(i + 1));
//                        errorMessage.append("第").append(i + 1).append("条登录名重复数据导入失败").append("\n");
                        continue;
                    }
                    sysUser.setNickName(pcUserImportDTO.getName());
                    //生成 大小写字母+数字+特殊符号的8位随机数
                    String password = RandomPasswordGenerator.generatePassword();
                    RC4Util rc4Util = new RC4Util();
                    //16进制加密
                    sysUser.setInitPassword(rc4Util.encryptToHex(password, null));
                    sysUser.setUpdatePassword("0");
                    sysUser.setPassword(passwordEncoder.encode(password));
                    String id = CyUserUtil.getAuthenBusinessId();
                    SysUser user = pcSysUserRepository.selectById(id);
                    if (user.getDeptId() != null){
                        sysUser.setDeptId(user.getDeptId());
                    }
                    sysUser.setIdentity(Arrays.toString(cyInitComp.getUnit()));
                    if ("男".equals(pcUserImportDTO.getSex())) {
                        sysUser.setSex("0");
                    } else {
                        sysUser.setSex("1");
                    }
                    if ("启用".equals(pcUserImportDTO.getFlag())) {
                        sysUser.setFlag("1");
                    } else {
                        sysUser.setFlag("0");
                    }
                    sysUser.setCreateDate(new Date());
                    sysUser.setUpdateDate(new Date());
                    sysUser.setNotDeleted();
                    sysUser.setIdentity(IdentityStaCons.UNIT_USER.getStatus());
                    pcSysUserRepository.insert(sysUser);
                    successNum += 1;
                    //插入后台角色
                    this.baseMapper.insertUserRole(sysUser.getBusinessId(), cyInitComp.getPermission()[3]);
                    //查询该单位所有角色
                    PcRole pcRole = new PcRole();
                    //查询所有的角色
                    List<PcRole> pcRoles = PcRoleService.findAll(pcRole);
                    List<Integer> roleIds = new ArrayList<>();
                    //判断是否有角色
                    if (sysUser.getRoleNames() != null && !sysUser.getRoleNames().isEmpty()) {
                        if (!(pcRoles == null || pcRoles.isEmpty())) {
                            //根据角色名判断是否有对应角色
                            String[] userRoleNames = sysUser.getRoleNames().split(",");
                            for (String userRoleName : userRoleNames) {
                                for (PcRole role : pcRoles) {
                                    String[] roleNames = role.getName().split(",");
                                    for (String roleName : roleNames) {
                                        if (roleName.trim().equals(userRoleName.trim())) {
                                            roleIds.add(role.getBusinessId());
                                            break; // 如果找到对应角色名，跳出内层循环
                                        }
                                    }
                                }
                            }
                            if (!roleIds.isEmpty()) {
                                sysUser.setRoleIdsList(roleIds);
                                //调用修改角色方法
                                this.updateRole(sysUser);
                            }
                        }
                    }
                    //查询该单位所有小组
                    PcGroup pcGroup = new PcGroup();
                    //查询所有的小组
                    List<PcGroup> pcGroups = groupService.findAll(pcGroup);
                    List<Integer> groupIds = new ArrayList<>();
                    //判断是否有小组
                    if (sysUser.getGroupNames() != null && !sysUser.getGroupNames().isEmpty()) {
                        if (!(pcGroups == null || pcGroups.isEmpty())) {
                            //根据小组名判断是否有对应小组
                            String[] userGroupNames = sysUser.getGroupNames().split(",");
                            for (String userGroupName : userGroupNames) {
                                for (PcGroup group : pcGroups) {
                                    String[] groupNames = group.getName().split(",");
                                    for (String groupName : groupNames) {
                                        if (groupName.trim().equals(userGroupName.trim())) {
                                            groupIds.add(group.getBusinessId());
                                            break; // 如果找到对应小组名，跳出内层循环
                                        }
                                    }
                                }
                            }
                            if (!groupIds.isEmpty()) {
                                sysUser.setGroupIdsList(groupIds);
                                //调用修改小组方法
                                this.updateGroup(sysUser);
                            }
                        }
                    }
                }
            }

            if (successNum > 0) {
                //list判断将登录名重复的拼接成stirng.stream流
                //登录名
                if (duplicateLogins.size() > 0) {
                    errorMessage = errorMessage.append(new StringBuilder("第【" + String.join(",", duplicateLogins) + "】条登录名数据有问题"));
                }
                //手机号
                if (mobilePhoneNumbersAreDuplicated.size() > 0) {
                    errorMessage = errorMessage.append(new StringBuilder("第【" + String.join(",", mobilePhoneNumbersAreDuplicated) + "】条手机号重复或错误"));
                }
                //性别
                if (sexIsIncorrect.size() > 0) {
                    errorMessage = errorMessage.append(new StringBuilder("第【" + String.join(",", sexIsIncorrect) + "】条性别数据有问题"));
                }
                //状态
                if (statusIsIncorrect.size() > 0) {
                    errorMessage = errorMessage.append(new StringBuilder("第【" + String.join(",", statusIsIncorrect) + "】条状态数据有问题"));
                }
                //姓名
                if (nameIsIncorrect.size() > 0) {
                    errorMessage = errorMessage.append(new StringBuilder("第【" + String.join(",", nameIsIncorrect) + "】条姓名数据有问题"));
                }
                //角色名称
                if (roleNameIncorrect.size() > 0) {
                    errorMessage = errorMessage.append(new StringBuilder("第【" + String.join(",", roleNameIncorrect) + "】条角色名称数据有问题"));
                }
                //小组名称
                if (groupNameIncorrect.size() > 0) {
                    errorMessage = errorMessage.append(new StringBuilder("第【" + String.join(",", groupNameIncorrect) + "】条小组名称数据有问题"));
                }
                //职位过长
                if (positionIncorrect.size() > 0) {
                    errorMessage = errorMessage.append(new StringBuilder("第【" + String.join(",", positionIncorrect) + "】条职位数据有问题"));
                }

                return successNum + "条数据导入成功，" + errorMessage;
            } else {
                //list判断将登录名重复的拼接成stirng.stream流
                //登录名
                if (duplicateLogins.size() > 0) {
                    errorMessage = errorMessage.append(new StringBuilder("第【" + String.join(",", duplicateLogins) + "】条登录名数据有问题"));
                }
                //手机号
                if (mobilePhoneNumbersAreDuplicated.size() > 0) {
                    errorMessage = errorMessage.append(new StringBuilder("第【" + String.join(",", mobilePhoneNumbersAreDuplicated) + "】条手机号重复或错误"));
                }
                //性别
                if (sexIsIncorrect.size() > 0) {
                    errorMessage = errorMessage.append(new StringBuilder("第【" + String.join(",", sexIsIncorrect) + "】条性别数据有问题"));
                }
                //状态
                if (statusIsIncorrect.size() > 0) {
                    errorMessage = errorMessage.append(new StringBuilder("第【" + String.join(",", statusIsIncorrect) + "】条状态数据有问题"));
                }
                //姓名
                if (nameIsIncorrect.size() > 0) {
                    errorMessage = errorMessage.append(new StringBuilder("第【" + String.join(",", nameIsIncorrect) + "】条姓名数据有问题"));
                }
                //角色名称
                if (roleNameIncorrect.size() > 0) {
                    errorMessage = errorMessage.append(new StringBuilder("第【" + String.join(",", roleNameIncorrect) + "】条角色名称数据有问题"));
                }
                //小组名称
                if (groupNameIncorrect.size() > 0) {
                    errorMessage = errorMessage.append(new StringBuilder("第【" + String.join(",", groupNameIncorrect) + "】条小组名称数据有问题"));
                }
                //职位过长
                if (positionIncorrect.size() > 0) {
                    errorMessage = errorMessage.append(new StringBuilder("第【" + String.join(",", positionIncorrect) + "】条职位数据有问题"));
                }
                throw new CyServiceException("导入失败：" + errorMessage);
            }
        } else {
            throw new CyServiceException(UserInfoExceptionEnums.EXCEL_NULL);
        }

    }

    /**
     * 手机登录
     *
     * @return
     */
    private Map<String, Object> phoneLogin(SysUser sysUser, String phone) {
        HashMap<String, Object> resultMap = new HashMap<>();
        //2.1.1 第一次登录
        if (null == sysUser) {
            //不存在 创建账号登录
            sysUser = new SysUser();
            sysUser.setPhone(phone);
            sysUser.setCreateDate(new Date());
            sysUser.setUpdateDate(new Date());
            sysUser.setNotDeleted();
            sysUser.setIdentity(IdentityStaCons.INDIVIDUAL.getStatus());
            sysUser.setStart();
            pcSysUserRepository.insert(sysUser);
        }
        //存在用户
        /*根据用户名查询用户权限*/
        SysMenuDTO sysMenu = new SysMenuDTO();
        sysMenu.setUsername(sysUser.getUsername());
        List<SysMenu> menus = sysMenuRepository.queryIdByUsername(sysMenu);
        if (org.apache.commons.collections4.CollectionUtils.isEmpty(menus))
            menus = Collections.emptyList();
        sysUser.setMenuList(menus);
        boolean notLocked = true;
        SysUserRbac sysUserRbac = new SysUserRbac();
        if (ObjectUtil.isNotEmpty(sysUser)) {
            BeanUtils.copyProperties(sysUser, sysUserRbac);
        }
        CyJwtUser userDetails = CyJwtUtil.createRbacJwtUser(sysUserRbac, notLocked);
        //创建token
        resultMap.put(CyWxMiniCons.TOKEN, CyJwtUtil.generateToken(userDetails));
        sysUser.setPassword(null);
        resultMap.put(CyWxMiniCons.DATA, sysUser);
        return resultMap;
    }

    @Override
    public IPage<UserViewInfoPartA> getUserView(CyPageInfo<UserViewInfoPartA> paginationUtility, SysUser user) {

        //查询人员列表
        IPage<UserViewInfoPartA> page = baseMapper.getUserViewInfoPartA(paginationUtility, user);

        List<UserViewInfoPartA> partA = page.getRecords();

//        List<StatisticsDetailVO> statisticsDetailVOList = new ArrayList<>();

//        PcBLessonQuery queryDetail = new PcBLessonQuery();

//        CyPageInfo<StatisticsDetailVO> pagin = new CyPageInfo<>();
        // 获取当前分页中的组员id
        String userIds = partA.stream()
                .map(UserViewInfoPartA::getBusinessId)
                .map(String::valueOf)
                .distinct()
                .collect(Collectors.joining(","));
//        queryDetail.setUserId(userIds);
        List<StatisticsDetailVO> statisticsDetailVOList = bLessonService.getBaseMapper().pagingStudentStatisticsDetailAll(userIds);
        // 将全部统计详情数据按照 userId 分组
        Map<String, List<StatisticsDetailVO>> statisticsDetailVoMap = statisticsDetailVOList.stream()
                .collect(Collectors.groupingBy(StatisticsDetailVO::getUserId));
        if (!partA.isEmpty()) {
            for (UserViewInfoPartA myGroupStatisticsVO : partA) {
                if (statisticsDetailVoMap.containsKey(myGroupStatisticsVO.getBusinessId().toString())) {
                    // 如果存在该用户的统计详情数据
                    List<StatisticsDetailVO> statisticsDetailList = statisticsDetailVoMap.get(myGroupStatisticsVO.getBusinessId().toString());
                    // 根据学习状态进行分组
                    Map<String, Long> learningStateCounts = statisticsDetailList.stream()
                            .collect(Collectors.groupingBy(
                                    StatisticsDetailVO::getLearningState,
                                    Collectors.counting()
                            ));
                    // 根据考核状态进行分组
                    Map<String, Long> isCompleteExamCounts = statisticsDetailList.stream()
                            .collect(Collectors.groupingBy(
                                    detail -> String.valueOf(detail.getIsCompleteExam()),
                                    Collectors.counting()
                            ));
                    //根据课程是否考核分组
                    Map<String, Long> isAppraisal = statisticsDetailList.stream()
                            .collect(Collectors.groupingBy(
                                    StatisticsDetailVO::getIsAppraisal,
                                    Collectors.counting()
                            ));
                    // 累计完成课时数
                    myGroupStatisticsVO.setLessonHour(statisticsDetailList.stream()
                            .mapToInt(StatisticsDetailVO::getLearnCourseNum)
                            .sum());
                    // 计划课程总数
                    myGroupStatisticsVO.setTotal(String.valueOf(statisticsDetailList.size()));
                    // 学习中课程数
                    myGroupStatisticsVO.setLearning(String.valueOf(learningStateCounts.getOrDefault("学习中", 0L)));
                    // 已完成课程数
                    myGroupStatisticsVO.setFinish(String.valueOf(learningStateCounts.getOrDefault("已完成", 0L)));
                    // 未开始课程数
                    myGroupStatisticsVO.setNotStart(String.valueOf(learningStateCounts.getOrDefault("未开始", 0L)));
                    // 参与考核课程数
                    myGroupStatisticsVO.setExamedNumber(String.valueOf(isCompleteExamCounts.getOrDefault("1", 0L)));
                    // 未考核课程数
                    myGroupStatisticsVO.setNotExamedNumber(String.valueOf(isAppraisal.getOrDefault("0", 0L) - isCompleteExamCounts.getOrDefault("1", 0L)));
                } else {
                    // 如果不存在该用户的统计详情数据 全部赋 0
                    // 累计完成课时数
                    myGroupStatisticsVO.setLessonHour(0);
                    // 计划课程总数
                    myGroupStatisticsVO.setTotal("0");
                    // 学习中课程数
                    myGroupStatisticsVO.setLearning("0");
                    // 已完成课程数
                    myGroupStatisticsVO.setFinish("0");
                    // 未开始课程数
                    myGroupStatisticsVO.setNotStart("0");
                    // 参与考核课程数
                    myGroupStatisticsVO.setExamedNumber("0");
                    // 未考核课程数
                    myGroupStatisticsVO.setNotExamedNumber("0");
                }
            }
        }
        //返回
        return page;
    }


    @Override
    public UserInfoAllVO getTotal(UserViewDetailsDTO userViewDetailsDTO) {
        CyPageInfo paginationUtility = new CyPageInfo<>();
        paginationUtility.setCurrent(userViewDetailsDTO.getPage());
        paginationUtility.setSize(userViewDetailsDTO.getRows());
        //健壮性判断
        if (userViewDetailsDTO.getPage() == null) {
            userViewDetailsDTO.setPage(1);
        }
        if (userViewDetailsDTO.getRows() == null) {
            userViewDetailsDTO.setRows(10);
        }

        IPage<BLesson> allBLessonByUserIdNew = bLessonService.getBaseMapper()
                .getAllBLessonByUserIdNew(paginationUtility, userViewDetailsDTO.getBusinessId().toString());
        //创建返回类型
        UserInfoAllVO res = new UserInfoAllVO();

        Integer totals = baseMapper.getTotalsRecordsInformation(userViewDetailsDTO);
        res.setRecords(allBLessonByUserIdNew.getRecords());
        res.setTotal((int) allBLessonByUserIdNew.getTotal());

        return res;
    }

    /**
     * 根据学习状态查询数据
     *
     * @param paginationUtility
     * @param vo
     * @return
     */
    @Override
    public IPage<StatisticsDetailVO> getLearnType(CyPageInfo<StatisticsDetailVO> paginationUtility, UserInfoVO vo) {
        //数据预处理
        if (LeaningTypeEnum.COMPLETED.getCode().equals(vo.getType())) {
            vo.setType(LeaningTypeEnum.COMPLETED.getMessage());
        } else if (LeaningTypeEnum.inLearning.getCode().equals(vo.getType())) {
            vo.setType(LeaningTypeEnum.inLearning.getMessage());
        } else if (LeaningTypeEnum.notStarted.getCode().equals(vo.getType())) {
            vo.setType(LeaningTypeEnum.notStarted.getMessage());
        }
        return baseMapper.getLearnType(paginationUtility, vo);
    }

    /**
     * 根据考试类型查询数据
     *
     * @param paginationUtility
     * @param vo
     * @return
     */
    @Override
    public IPage<StatisticsDetailVO> getExamType(CyPageInfo<StatisticsDetailVO> paginationUtility, UserInfoVO vo) {
        return baseMapper.getExamType(paginationUtility, vo);
    }

    @Override
    public Boolean isFirstLogin() {
        String authenBusinessId = CyUserUtil.getAuthenBusinessId();
        PCUnitUserDTO byUserId = pcSysUserRepository.findByUserId(Integer.parseInt(authenBusinessId));
        if (StringUtils.isEmpty(byUserId.getUpdatePassword()) || "2".equals(byUserId.getUpdatePassword()) || "1".equals(byUserId.getUpdatePassword())) {
            return false;
        } else {
            //修改用户状tai
            pcSysUserRepository.isFirstLogin(authenBusinessId);
            return true;
        }
    }

    @Override
    public List<InitPasswordExcel> exportInitPassword(String deptId) {
        //根据dept查询未登陆过的
        List<InitPasswordExcel> sysUsers = baseMapper.exportInitPassword(deptId);
        //解密
        for (InitPasswordExcel user : sysUsers) {
            try {
                RC4Util rc4Util = new RC4Util();
                user.setInitPassword(rc4Util.decryptFromHex(user.getInitPassword(), null));
            } catch (Exception e) {
                user.setInitPassword("请联系管理员重置密码");
            }
        }
        return sysUsers;
    }

    @Override
    public Boolean updatePassword(Integer businessId) {
        //修改用户状tai
        pcSysUserRepository.updatePassword(String.valueOf(businessId));
        return true;
    }


    /**
     * 查询list 用户表
     *
     * @param sysUser
     * @return
     */
    public List<SysUser> getAllByUnitId(SysUser sysUser) {
        List<SysUser> sysUsers = baseMapper.querySysUsers(sysUser);
        //根据unitid查询单位管理员的登录名
        BigInteger deptId = sysUser.getDeptId();
        int deptIdInt = deptId.intValue();
        SysUser user = unitRepository.selectByUnitId(deptIdInt);
        //剔除当前用户id的数据
        if (CollectionUtils.isNotEmpty(sysUsers)) {
            sysUsers.removeIf(sysUser1 -> sysUser1.getUsername().equals(user.getUsername()));
        }
        return sysUsers;
    }

    @Override
    public CyPersistModel addLectureByUser(SysUser sysUser) {
        //判断该讲师是否存在
        QueryWrapper<CmsLecturer> qw = new QueryWrapper<>();
        qw.lambda().eq(CmsLecturer::getUserId,sysUser.getBusinessId());
        CmsLecturer cmsLecturer1 = cmsLecturerRepository.selectOne(qw);
        if (cmsLecturer1 != null){
            cmsLecturer1.setFlag("1");
            cmsLecturerRepository.updateById(cmsLecturer1);
            return new CyPersistModel(1);
        }
        else{
            //创建讲师
            CmsLecturer cmsLecturer = new CmsLecturer();
            //备注 -》用户id
            cmsLecturer.setUserId(sysUser.getBusinessId());
            //头像 默认头像
            cmsLecturer.setAvatarId(2);
            //姓名
            cmsLecturer.setName(sysUser.getName());
            //flag
            cmsLecturer.setFlag(CyFlagStaCons.NORMAL.getStatus());
            cmsLecturerRepository.insert(cmsLecturer);
        }
        return new CyPersistModel(1);
    }
}
