package org.rcisoft.business.teaexamexaminationpaper.service.impl;

import cn.hutool.core.collection.CollectionUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.rcisoft.business.teaexamexaminationpaper.dao.TeaExamExaminationPaperRepository;
import org.rcisoft.business.teaexamexaminationpaper.dto.ResultDto;
import org.rcisoft.business.teaexamexaminationpaper.entity.TeaExamExamination;
import org.rcisoft.business.teaexamexaminationpaper.entity.TeaExamExaminationDTO;
import org.rcisoft.business.teaexamexaminationpaper.entity.TeaExamExaminationPaper;
import org.rcisoft.business.teaexamexaminationpaper.service.TeaExamExaminationPaperService;
import org.rcisoft.business.teaexamquestions.dto.ExamQuestionDto;
import org.rcisoft.business.teaexamquestions.enums.QuestionTypeEnum;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyUserUtil;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;

/**
 * @author cy
 * @date 2024年3月28日 下午1:38:34
 */
@Service
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class TeaExamExaminationPaperServiceImpl extends ServiceImpl<TeaExamExaminationPaperRepository, TeaExamExaminationPaper> implements TeaExamExaminationPaperService {


    /**
     * 保存 试卷表
     *
     * @param teaExamExaminationPaper
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(TeaExamExaminationPaper teaExamExaminationPaper) {
        //增加操作
        int line = baseMapper.insert(teaExamExaminationPaper);
        log.debug(CyUserUtil.getAuthenUsername() + "新增了ID为" +
                teaExamExaminationPaper.getBusinessId() + "的试卷表信息");
        return new CyPersistModel(line);
    }

    /**
     * 删除 试卷表
     *
     * @param teaExamExaminationPaper
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(TeaExamExaminationPaper teaExamExaminationPaper) {
        int line = baseMapper.realDelete(teaExamExaminationPaper);
        log.debug(CyUserUtil.getAuthenUsername() + "删除了ID为" +
                teaExamExaminationPaper.getBusinessId() + "的试卷表信息");
        return new CyPersistModel(line);
    }

    /**
     * 逻辑删除 试卷表
     *
     * @param teaExamExaminationPaper
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(TeaExamExaminationPaper teaExamExaminationPaper) {
        teaExamExaminationPaper.setDeleted();
        int line = baseMapper.deleteById(teaExamExaminationPaper);
        log.debug(CyUserUtil.getAuthenUsername() + "逻辑删除了ID为" +
                teaExamExaminationPaper.getBusinessId() + "的试卷表信息");
        return new CyPersistModel(line);
    }

    /**
     * 修改 试卷表
     *
     * @param teaExamExaminationPaper
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(TeaExamExaminationPaper teaExamExaminationPaper) {
        int line = baseMapper.updateById(teaExamExaminationPaper);
        log.debug(CyUserUtil.getAuthenUsername() + "修改了ID为" + teaExamExaminationPaper.getBusinessId() + "的试卷表信息");
        return new CyPersistModel(line);
    }

    /**
     * 根据id查询 试卷表
     *
     * @param id
     * @return
     */
    @Override
    public TeaExamExaminationPaper findById(Integer id) {
        return baseMapper.selectById(id);
    }

    /**
     * 根据id查询 试卷表
     *
     * @param businessId
     * @return
     */
    @Override
    public List<TeaExamExaminationDTO> selectById(Integer businessId) {
        return baseMapper.queryById(businessId);
    }


    /**
     * 分页查询 试卷表
     *
     * @param teaExamExaminationPaper
     * @return
     */
    @Override
    public IPage<TeaExamExaminationPaper> findAllByPagination(CyPageInfo<TeaExamExaminationPaper> paginationUtility,
                                                              TeaExamExaminationPaper teaExamExaminationPaper) {
        return baseMapper.queryTeaExamExaminationPapersPaged(paginationUtility, teaExamExaminationPaper);

    }

    /**
     * 查询list 试卷表
     *
     * @param teaExamExaminationPaper
     * @return
     */
    @Override
    public List<TeaExamExaminationPaper> findAll(TeaExamExaminationPaper teaExamExaminationPaper) {
        return baseMapper.queryTeaExamExaminationPapers(teaExamExaminationPaper);

    }

    /**
     * 导出试卷表
     *
     * @return
     */
    @Override
    public List<TeaExamExaminationPaper> export(TeaExamExaminationPaper teaExamExaminationPaper) {
        List<TeaExamExaminationPaper> teaExamExaminationPaperList = baseMapper.queryTeaExamExaminationPapers(teaExamExaminationPaper);
        return teaExamExaminationPaperList;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public boolean markPapers(TeaExamExamination teaExamExamination) {
        //增加操作
        int updateCount = baseMapper.updateBatch(teaExamExamination.getTeaExamExaminationDTOList());
        TeaExamExaminationPaper teaExamExaminationPaper = new TeaExamExaminationPaper();
        teaExamExaminationPaper.setBusinessId(teaExamExamination.getBusinessId());
        teaExamExaminationPaper.setScore(teaExamExamination.getCountScore());
        baseMapper.updateFlag(teaExamExaminationPaper);
        return updateCount > 0;
    }

    /**
     * 查询用户考核结果
     *
     * @param lessonId
     * @return
     */
    @Override
    public Map<String, Object> queryUserExamResult(String lessonId) {
        Map<String, Object> map = new HashMap<>();
        //用户id
        String authenBusinessId = CyUserUtil.getAuthenBusinessId();
        if (StringUtils.isNotBlank(lessonId) && StringUtils.isNotBlank(authenBusinessId)) {
            Integer userId = Integer.valueOf(authenBusinessId);
            //查询用户考核结果 总分
            //TODO:selectone 测试修改
            QueryWrapper<TeaExamExaminationPaper> paperQueryWrapper = new QueryWrapper<>();
            paperQueryWrapper.eq("answer_id", userId)
                    .eq("course_id", lessonId);
            //TeaExamExaminationPaper paper = baseMapper.selectOne(paperQueryWrapper);
            List<TeaExamExaminationPaper> teaExamExaminationPapers = baseMapper.selectList(paperQueryWrapper);
            TeaExamExaminationPaper paper = teaExamExaminationPapers.get(teaExamExaminationPapers.size() - 1);
            map.put("totalScore", paper.getScore());
            //根据试卷id查询题目信息
//            List<ExamQuestionDto> list = baseMapper.queryUserExamResultById(paper.getBusinessId());
            //根据用户和课程查出答题信息
            List<ExamQuestionDto> list = baseMapper.queryUserExamResult(paper);
            //重新进行试卷以及题目的
            list.forEach(item -> {
                //非空判断
                if (item.getAnswer() != null && item.getUanswer() != null) {
                    //单选
                    if (1 == item.getQuestionType()) {
                        if (item.getUanswer().equals(item.getAnswer())) {
                            item.setIsFalse("1");
                        } else {
                            item.setIsFalse("0");

                        }
                    }
                    //多选
                    if (2 == item.getQuestionType()) {
                        //切割
                        String[] uanswer = item.getUanswer().split(",");
                        String[] answer = item.getAnswer().split(",");
                        if (uanswer.length == answer.length) {
                            if (new HashSet<>(Arrays.asList(answer)).equals(new HashSet<>(Arrays.asList(uanswer)))) {
                                item.setIsFalse("1");
                            } else {
                                item.setIsFalse("0");
                            }
                        }
                    }
                    //判断
                    if (3 == item.getQuestionType()) {
                        if ("1".equals(item.getUanswer()) && "对".equals(item.getAnswer())) {
                            item.setIsFalse("1");
                        } else if ("0".equals(item.getUanswer()) && "错".equals(item.getAnswer())) {
                            item.setIsFalse("1");
                        } else {
                            item.setIsFalse("0");
                        }
                    }

                }
            });


            HashMap<Integer, List<ExamQuestionDto>> typeMap = new HashMap<>();
            list.forEach(item -> {
                if (typeMap.containsKey(item.getQuestionType())) {
                    typeMap.get(item.getQuestionType()).add(item);
                } else {
                    List<ExamQuestionDto> questionDtoList = new ArrayList<>();
                    questionDtoList.add(item);
                    typeMap.put(item.getQuestionType(), questionDtoList);
                }
            });
            //客观题总分
            Integer objectiveScore = 0;
            List<ResultDto> objectiveResultDtos = new ArrayList<>();
            //单选
            if (typeMap.containsKey(QuestionTypeEnum.SINGLE_SELECT.getCode())) {
                ResultDto resultDto = new
                        ResultDto(QuestionTypeEnum.SINGLE_SELECT.getCode(), 0, 0, null, 0, 0);
                resultDto.setType(QuestionTypeEnum.SINGLE_SELECT.getCode());
                //对的分数,错的分数
                Integer correctScore = 0;
                Integer wrongScore = 0;
                for (ExamQuestionDto dto : typeMap.get(QuestionTypeEnum.SINGLE_SELECT.getCode())) {
                    if ("1".equals(dto.getIsFalse())) {
                        resultDto.setCorrect(resultDto.getCorrect() + 1);
                        correctScore += dto.getMark();
                    } else {
                        resultDto.setWrong(resultDto.getWrong() + 1);
                        wrongScore += dto.getMark();
                    }
                }
                resultDto.setScore(correctScore + "/" + (correctScore + wrongScore));
                objectiveScore += correctScore;
                objectiveResultDtos.add(resultDto);
            }

            //多选
            if (typeMap.containsKey(QuestionTypeEnum.MULTIPLE_SELECT.getCode())) {
                ResultDto resultDto = new
                        ResultDto(QuestionTypeEnum.MULTIPLE_SELECT.getCode(), 0, 0, null, 0, 0);
                resultDto.setType(QuestionTypeEnum.MULTIPLE_SELECT.getCode());
                //对的分数,错的分数
                Integer correctScore = 0;
                Integer wrongScore = 0;
                for (ExamQuestionDto dto : typeMap.get(QuestionTypeEnum.MULTIPLE_SELECT.getCode())) {
                    if ("1".equals(dto.getIsFalse())) {
                        resultDto.setCorrect(resultDto.getCorrect() + 1);
                        correctScore += dto.getMark();
                    } else {
                        resultDto.setWrong(resultDto.getWrong() + 1);
                        wrongScore += dto.getMark();
                    }
                }
                resultDto.setScore(correctScore + "/" + (correctScore + wrongScore));
                objectiveScore += correctScore;
                objectiveResultDtos.add(resultDto);
            }
            //判断
            if (typeMap.containsKey(QuestionTypeEnum.JUDGE.getCode())) {
                ResultDto resultDto = new
                        ResultDto(QuestionTypeEnum.JUDGE.getCode(), 0, 0, null, 0, 0);
                resultDto.setType(QuestionTypeEnum.JUDGE.getCode());
                //对的分数,错的分数
                Integer correctScore = 0;
                Integer wrongScore = 0;
                for (ExamQuestionDto dto : typeMap.get(QuestionTypeEnum.JUDGE.getCode())) {
                    if ("1".equals(dto.getIsFalse())) {
                        resultDto.setCorrect(resultDto.getCorrect() + 1);
                        correctScore += dto.getMark();
                    } else {
                        resultDto.setWrong(resultDto.getWrong() + 1);
                        wrongScore += dto.getMark();
                    }
                }
                resultDto.setScore(correctScore + "/" + (correctScore + wrongScore));
                objectiveScore += correctScore;
                objectiveResultDtos.add(resultDto);
            }
            //客观题总分
            map.put("objectiveScore", objectiveScore);
            map.put("objectiveList", objectiveResultDtos);
            //简答题总分
            Integer questionScore = 0;
            ArrayList<ResultDto> questionResultDtos = new ArrayList<>();
            //简答
            if (typeMap.containsKey(QuestionTypeEnum.TEXT.getCode())) {
                //简答题为空不需要判题流程 总分自动提供
                for (int i = 0; i < typeMap.get(QuestionTypeEnum.TEXT.getCode()).size(); i++) {
                    ResultDto resultDto = new ResultDto();
                    resultDto.setType(QuestionTypeEnum.TEXT.getCode());
                    //题号
                    resultDto.setNumber(i + 1);
                    //得分 判断当前是否有得分
                    if (typeMap.get(QuestionTypeEnum.TEXT.getCode()).get(i).getGetScore() != null) {
                        resultDto.setScore(String.valueOf(typeMap.get(QuestionTypeEnum.TEXT.getCode()).get(i).getGetScore()));
                        questionScore += typeMap.get(QuestionTypeEnum.TEXT.getCode()).get(i).getGetScore();
                    } else {
                        map.putIfAbsent("totalScore", null);
                    }
                    //小题总分
                    resultDto.setSubtitleTotalScore(typeMap.get(QuestionTypeEnum.TEXT.getCode()).get(i).getMark());
                    questionResultDtos.add(resultDto);
                }
            } else {
                map.putIfAbsent("totalScore", objectiveScore);
            }
            //判断非空
            if (map.get("totalScore") != null) {
                map.put("totalScore", objectiveScore + questionScore);
            }
            map.put("questionScore", questionScore);
            map.put("questionList", questionResultDtos);
        }
        return map;
    }

}
