package org.rcisoft.business.teaexamoptions.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.business.teaexamoptions.entity.TeaExamOptions;
import org.rcisoft.business.teaexamoptions.service.TeaExamOptionsService;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.exception.CyServiceException;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;

import java.util.List;

/**
* Created by cy on 2024年3月29日 上午9:33:36.
*/
@RestController
@RequestMapping("/teaexamoptions")
public class TeaExamOptionsController extends CyPaginationController<TeaExamOptions> {


    @Autowired
    private TeaExamOptionsService teaExamOptionsServiceImpl;

    //@PreAuthorize("@cyPerm.hasPerm('sys:examOptions:add')")
    @CyOpeLogAnno(title = "system-选项表管理-新增选项表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="添加选项表", notes="添加选项表")
    @PostMapping(value = "/add")
    public CyResult add(@Valid TeaExamOptions teaExamOptions, BindingResult bindingResult) {
        CyPersistModel data = teaExamOptionsServiceImpl.persist(teaExamOptions);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        teaExamOptions);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:examOptions:delete')")
    @CyOpeLogAnno(title = "system-选项表管理-删除选项表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="逻辑删除选项表", notes="逻辑删除选项表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable Integer businessId,TeaExamOptions teaExamOptions) {
        teaExamOptions.setBusinessId(businessId);
        CyPersistModel data = teaExamOptionsServiceImpl.removeLogical(teaExamOptions);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:examOptions:delete')")
    @CyOpeLogAnno(title = "system-选项表管理-删除选项表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="删除选项表", notes="删除选项表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable Integer businessId,TeaExamOptions teaExamOptions) {
        teaExamOptions.setBusinessId(businessId);
        CyPersistModel data = teaExamOptionsServiceImpl.remove(teaExamOptions);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:examOptions:update')")
    @CyOpeLogAnno(title = "system-选项表管理-修改选项表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改选项表", notes="修改选项表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable Integer businessId, @Valid TeaExamOptions teaExamOptions, BindingResult bindingResult) {
        teaExamOptions.setBusinessId(businessId);
        CyPersistModel data = teaExamOptionsServiceImpl.merge(teaExamOptions);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        teaExamOptions);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:examOptions:query')")
    @CyOpeLogAnno(title = "system-选项表管理-查询选项表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单一选项表", notes="查询单一选项表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable Integer businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        teaExamOptionsServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:examOptions:list')")
    @CyOpeLogAnno(title = "system-选项表管理-查询选项表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询选项表集合", notes="查询选项表集合")
    @GetMapping(value = "/queryTeaExamOptionss")
    public CyResult queryTeaExamOptionss(TeaExamOptions teaExamOptions) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            teaExamOptionsServiceImpl.findAll(teaExamOptions));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:examOptions:list')")
    @CyOpeLogAnno(title = "system-选项表管理-查询选项表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="分页查询选项表集合", notes="分页查询选项表集合")
    @GetMapping(value = "/queryTeaExamOptionsByPagination")
    public CyGridModel listByPagination(TeaExamOptions teaExamOptions) {
        teaExamOptionsServiceImpl.findAllByPagination(getPaginationUtility(), teaExamOptions);
        return getGridModelResponse();
    }

    @CyOpeLogAnno(title = "system-选项表管理-查询选项表", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出选项表信息", notes = "导出选项表信息")
    @GetMapping(value = "/export")
    public void outTeaExamOptions(HttpServletResponse response,TeaExamOptions teaExamOptions,@PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="选项表信息.xls";break;
            case "1": excelName="选项表信息.xlsx";break;
            case "2": excelName="选项表信息.csv";break;
        }
        List<TeaExamOptions> teaExamOptionsList = teaExamOptionsServiceImpl.export(teaExamOptions);
        CyEpExcelUtil.exportExcel(teaExamOptionsList, "选项表信息", "选项表信息", TeaExamOptions.class, excelName, response);
    }
}
