package org.rcisoft.business.teaexamoptions.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.rcisoft.business.teaexamoptions.dao.TeaExamOptionsRepository;
import org.rcisoft.business.teaexamoptions.entity.TeaExamOptions;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.aop.CyPageUtilAsp;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.business.teaexamoptions.service.TeaExamOptionsService;
import org.rcisoft.core.service.CyBaseService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.rcisoft.core.model.CyPageInfo;

import java.util.List;
import lombok.extern.slf4j.Slf4j;

/**
 * Created by cy on 2024年3月29日 上午9:33:36.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class TeaExamOptionsServiceImpl extends ServiceImpl<TeaExamOptionsRepository, TeaExamOptions>  implements TeaExamOptionsService {


    /**
    * 保存 选项表
    * @param teaExamOptions
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(TeaExamOptions teaExamOptions){
        //增加操作
        int line = baseMapper.insert(teaExamOptions);
        log.debug(CyUserUtil.getAuthenUsername()+"新增了ID为"+
            teaExamOptions.getBusinessId()+"的选项表信息");
        return new CyPersistModel(line);
    }

    /**
    * 删除 选项表
    * @param teaExamOptions
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(TeaExamOptions teaExamOptions){
        int line = baseMapper.realDelete(teaExamOptions);
        log.debug(CyUserUtil.getAuthenUsername()+"删除了ID为"+
            teaExamOptions.getBusinessId()+"的选项表信息");
        return new CyPersistModel(line);
    }

    /**
    * 逻辑删除 选项表
    * @param teaExamOptions
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(TeaExamOptions teaExamOptions){
        teaExamOptions.setDeleted();
        int line = baseMapper.deleteById(teaExamOptions);
            log.debug(CyUserUtil.getAuthenUsername()+"逻辑删除了ID为"+
                teaExamOptions.getBusinessId()+"的选项表信息");
            return new CyPersistModel(line);
    }

    /**
    * 修改 选项表
    * @param teaExamOptions
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(TeaExamOptions teaExamOptions){
        int line = baseMapper.updateById(teaExamOptions);
        log.debug(CyUserUtil.getAuthenUsername()+"修改了ID为"+ teaExamOptions.getBusinessId()+"的选项表信息");
        return new CyPersistModel(line);
    }

    /**
    * 根据id查询 选项表
    * @param id
    * @return
    */
    @Override
    public TeaExamOptions findById(Integer id){
        return baseMapper.selectById(id);
    }

    /**
    * 分页查询 选项表
    * @param teaExamOptions
    * @return
    */
    @Override
    public IPage<TeaExamOptions> findAllByPagination(CyPageInfo<TeaExamOptions> paginationUtility,
        TeaExamOptions teaExamOptions){
        return baseMapper.queryTeaExamOptionssPaged(paginationUtility,teaExamOptions);

    }

    /**
    * 查询list 选项表
    * @param teaExamOptions
    * @return
    */
    @Override
    public List<TeaExamOptions> findAll(TeaExamOptions teaExamOptions){
        return baseMapper.queryTeaExamOptionss(teaExamOptions);

    }

    /**
    * 导出选项表
    * @return
    */
    @Override
    public List<TeaExamOptions> export(TeaExamOptions teaExamOptions) {
        List<TeaExamOptions> teaExamOptionsList = baseMapper.queryTeaExamOptionss(teaExamOptions);
        return teaExamOptionsList;
    }

}
