package org.rcisoft.business.teaexamquestions.controller;


/*固定导入*/

import cn.afterturn.easypoi.excel.ExcelExportUtil;
import cn.afterturn.easypoi.excel.entity.ExportParams;
import cn.afterturn.easypoi.excel.entity.enmus.ExcelType;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;

import org.rcisoft.business.teaexamquestions.dto.ExamQuestionDto;

import org.rcisoft.business.teaexamquestions.dto.ExportExamQuestionDto;
import org.rcisoft.business.teaexamquestions.entity.TeaExamQuestions;
import org.rcisoft.business.teaexamquestions.service.TeaExamQuestionsService;

import org.rcisoft.core.anno.CyEncryptSm4Anno;
import org.rcisoft.core.anno.CyOpeLogAnno;

import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.core.util.ExcelUtil;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;

import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.exception.CyServiceException;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;


import java.io.IOException;
import java.io.OutputStream;
import java.net.URLEncoder;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * Created by cy on 2024年3月28日 下午1:38:34.
 */
@RestController
@RequestMapping("/teaexamquestions")
public class TeaExamQuestionsController extends CyPaginationController<TeaExamQuestions> {
    private static final Logger log = LoggerFactory.getLogger(CyEpExcelUtil.class);

    @Autowired
    private TeaExamQuestionsService teaExamQuestionsServiceImpl;

    //@PreAuthorize("@cyPerm.hasPerm('sys:examQuestions:add')")


    @CyOpeLogAnno(title = "system-试题表管理-新增试题表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value = "添加试题表", notes = "添加试题表")
    @PostMapping(value = "/add")
    public CyResult add(@Valid @RequestBody ExamQuestionDto examQuestionDto, BindingResult bindingResult) {
        CyPersistModel data = teaExamQuestionsServiceImpl.persist(examQuestionDto);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                examQuestionDto);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:examQuestions:update')")
    @CyOpeLogAnno(title = "system-试题表管理-修改试题表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value = "修改试题表", notes = "修改试题表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update")
    public CyResult update(@Valid @RequestBody ExamQuestionDto examQuestionDto, BindingResult bindingResult) {
        CyPersistModel data = teaExamQuestionsServiceImpl.merge(examQuestionDto);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                examQuestionDto);
    }

    @CyOpeLogAnno(title = "system-试题表管理-修改试题状态", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value = "修改试题状态", notes = "修改试题状态")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/updateStatus")
    public CyResult updateStatus(@Valid TeaExamQuestions teaExamQuestions, BindingResult bindingResult) {
        CyPersistModel data = teaExamQuestionsServiceImpl.changeStatus(teaExamQuestions);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                teaExamQuestions);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:examQuestions:delete')")
    @CyOpeLogAnno(title = "system-试题表管理-删除试题表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value = "逻辑删除试题表", notes = "逻辑删除试题表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable Integer businessId, TeaExamQuestions teaExamQuestions) {
        teaExamQuestions.setBusinessId(businessId);
        CyPersistModel data = teaExamQuestionsServiceImpl.removeLogical(teaExamQuestions);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:examQuestions:delete')")
    @CyOpeLogAnno(title = "system-试题表管理-删除试题表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value = "删除试题表", notes = "删除试题表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable Integer businessId, TeaExamQuestions teaExamQuestions) {
        teaExamQuestions.setBusinessId(businessId);
        CyPersistModel data = teaExamQuestionsServiceImpl.remove(teaExamQuestions);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }


    //@PreAuthorize("@cyPerm.hasPerm('sys:examQuestions:query')")
    @CyOpeLogAnno(title = "system-试题表管理-查询试题表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询单一试题表", notes = "查询单一试题表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable String businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                teaExamQuestionsServiceImpl.queryAllExamQuestionDto(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:examQuestions:list')")
    @CyOpeLogAnno(title = "system-试题表管理-查询试题表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询试题表集合", notes = "查询试题表集合")
    @GetMapping(value = "/queryTeaExamQuestionss")
    public CyResult queryTeaExamQuestionss(TeaExamQuestions teaExamQuestions) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                teaExamQuestionsServiceImpl.findAll(teaExamQuestions));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:examQuestions:list')")
    @CyOpeLogAnno(title = "system-试题表管理-查询试题表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "分页查询试题表集合", notes = "分页查询试题表集合")
    @GetMapping(value = "/queryTeaExamQuestionsByPagination")
    public CyGridModel listByPagination(TeaExamQuestions teaExamQuestions) {
        teaExamQuestionsServiceImpl.findAllByPagination(getPaginationUtility(), teaExamQuestions);
        return getGridModelResponse();
    }

    @CyOpeLogAnno(title = "system-试题表管理-查询试题表", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出试题表信息", notes = "导出试题表信息")
    @GetMapping(value = "/export")
    public void outTeaExamQuestions(HttpServletResponse response, TeaExamQuestions teaExamQuestions, @PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName = "";
        switch (excelId) {
            case "0":
                excelName = "试题表信息.xls";
                break;
            case "1":
                excelName = "试题表信息.xlsx";
                break;
            case "2":
                excelName = "试题表信息.csv";
                break;
        }
        List<TeaExamQuestions> teaExamQuestionsList = teaExamQuestionsServiceImpl.export(teaExamQuestions);
        CyEpExcelUtil.exportExcel(teaExamQuestionsList, "试题表信息", "试题表信息", TeaExamQuestions.class, excelName, response);
    }


    @CyOpeLogAnno(
            title = "system-试题管理-导出试题数据空模板",
            businessType = CyLogTypeEnum.EXPORT
    )
    @ApiOperation(
            value = "导出试题数据空模板",
            notes = "导出试题数据空模板"
    )
    @GetMapping({"/importTemplate"})
    @CyEncryptSm4Anno
    public void importTemplate(HttpServletResponse response) {
        OutputStream outputStream = null;
        Workbook workbook = null;
        try {
            response.setCharacterEncoding("UTF-8");
            response.setHeader("content-Type", "application/vnd.ms-excel");
            response.setHeader("Content-Disposition", "attachment;filename=" + URLEncoder.encode("试题数据信息.xlsx", "UTF-8"));
            ExportParams exportParams = new ExportParams("试题数据信息", "试题数据");
            exportParams.setType(ExcelType.XSSF);
            List<ExportExamQuestionDto> exportList = new ArrayList();
            workbook = ExcelExportUtil.exportExcel(exportParams, ExportExamQuestionDto.class, exportList);
            Sheet sheet = workbook.getSheetAt(0);
            // 获取 题型 下拉数据
            String[] typeStars = new String[]{"单选题", "多选题", "判断题", "简答题"};
            // 获取 题目难度难度 下拉数据
            String[] difficultyStars = new String[]{"简单", "一般", "困难"};

            // 题型名称列 第二列
            ExcelUtil.XSSFSetDropDownAndHidden(typeStars, workbook, sheet, 2, 10000, 1, 1);
            // 题目难度难度名称列 第三列
            ExcelUtil.XSSFSetDropDownAndHidden(difficultyStars, workbook, sheet, 2, 10000, 2, 2);

            outputStream = response.getOutputStream();
            workbook.write(outputStream);
        } catch (IOException var12) {
            throw new CyServiceException(var12.getMessage());
        } finally {
            try {
                if (outputStream != null) {
                    outputStream.close();
                }
            } catch (IOException var11) {
                log.info("context:" + var11);
            }
        }
    }

    @CyOpeLogAnno(
            title = "system-单位开课数据管理-导入单位开课数据",
            businessType = CyLogTypeEnum.IMPORT
    )
    @ApiOperation(
            value = "导入单位开课数据",
            notes = "导入单位开课数据"
    )
    @PostMapping({"/importDictData"})
    @CyEncryptSm4Anno
    public CyResult importDictData(MultipartFile file, String courseId) {
        return CyResultGenUtil.builder(new CyPersistModel(1), "操作成功", "网络异常，请稍后重试", this.teaExamQuestionsServiceImpl.importExcel(file, courseId));
    }

    //pc

    /**
     * 根据课程id查询试题
     */
    @CyOpeLogAnno(title = "system-试题表管理-查询试题表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "根据课程id查询试题", notes = "根据课程id查询试题")
    @ApiImplicitParams({@ApiImplicitParam(name = "lessonId", value = "lessonId", required = true, dataType = "varchar")})
    @GetMapping("/findByLessonId")
    public CyResult findByLessonId(String lessonId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                teaExamQuestionsServiceImpl.findByLessonId(lessonId));
    }


    /**
     * 保存用户试卷填写答案
     */
    @CyOpeLogAnno(title = "system-试卷表管理-保存试卷表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value = "保存用户试卷填写答案", notes = "保存用户试卷填写答案")
    @PostMapping(value = "/save")
    public CyResult save(String param) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                teaExamQuestionsServiceImpl.save(param));
    }

    /**
     * 根据课程id和用户id查询试题
     */
    @CyOpeLogAnno(title = "system-试题表管理-查询试题表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "根据课程id和用户id查询试题", notes = "根据课程id和用户id查询试题")
    @ApiImplicitParams({@ApiImplicitParam(name = "lessonId", value = "lessonId", required = true, dataType = "varchar"),
            @ApiImplicitParam(name = "userId", value = "userId", required = true, dataType = "varchar")})
    @GetMapping("/findByLessonIdAndUserId")
    public CyResult findByLessonIdAndUserId(@RequestParam("lessonId") String lessonId, @RequestParam("userId") Integer userId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                teaExamQuestionsServiceImpl.findByLessonIdAndUserId(lessonId, userId));
    }

}
