package org.rcisoft.business.teaexamquestions.service.impl;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.rcisoft.business.blesson.entity.BLesson;
import org.rcisoft.business.blesson.service.BLessonService;
import org.rcisoft.business.pcfeedexamflag.entity.PcFeedExamFlag;
import org.rcisoft.business.pcfeedexamflag.service.PcFeedExamFlagService;
import org.rcisoft.business.sysdictdata.entity.SysDictData;
import org.rcisoft.business.sysunit.entity.SysUnit;
import org.rcisoft.business.teaexamexaminationpaper.dao.TeaExamExaminationPaperRepository;
import org.rcisoft.business.teaexamexaminationpaper.entity.TeaExamExaminationPaper;
import org.rcisoft.business.teaexamexaminationpaper.service.TeaExamExaminationPaperService;
import org.rcisoft.business.teaexamoptions.dao.TeaExamOptionsRepository;
import org.rcisoft.business.teaexamoptions.entity.TeaExamOptions;
import org.rcisoft.business.teaexamquestions.dao.TeaExamQuestionsRepository;
import org.rcisoft.business.teaexamquestions.dto.ExamQuestionDto;
import org.rcisoft.business.teaexamquestions.dto.ExportExamQuestionDto;
import org.rcisoft.business.teaexamquestions.entity.TeaExamQuestions;
import org.rcisoft.business.teaexamquestions.service.TeaExamQuestionsService;
import org.rcisoft.business.teaexamquestionsexamination.dao.TeaExamQuestionsExaminationRepository;
import org.rcisoft.business.teaexamquestionsexamination.entity.TeaExamQuestionsExamination;

import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.sys.rbac.user.enums.UserInfoExceptionEnums;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;

import java.util.*;
import java.util.stream.Collectors;

/**
 * @author cy
 * @date 2024年3月28日 下午1:38:34
 */
@Service
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class TeaExamQuestionsServiceImpl extends ServiceImpl<TeaExamQuestionsRepository, TeaExamQuestions> implements TeaExamQuestionsService {

    @Autowired
    private TeaExamOptionsRepository teaExamOptionsRepository;

    @Autowired
    private TeaExamExaminationPaperRepository teaExamExaminationPaperRepository;

    @Autowired
    private TeaExamQuestionsExaminationRepository teaExamQuestionsExaminationRepository;

    @Autowired
    private TeaExamExaminationPaperService teaExamExaminationPaperServiceImpl;
    @Autowired
    private PcFeedExamFlagService pcFeedExamFlagService;

    @Autowired
    private BLessonService bLessonService;
    /**
     * 保存 试题表
     *
     * @param examQuestionDto
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(ExamQuestionDto examQuestionDto) {
        TeaExamQuestions teaExamQuestions = new TeaExamQuestions();
//        //增加操作
        BeanUtils.copyProperties(examQuestionDto, teaExamQuestions);

        if (baseMapper.queryNumbeSomeCourse(teaExamQuestions) > 0)
            throw new CyServiceException(1001, "同一课程下,该题目编号已存在");
        if (baseMapper.queryNumberSomeWeiht(teaExamQuestions) > 0)
            throw new CyServiceException(1001, "同一课程下,该权重已存在");
        teaExamQuestions.setCreateBy("1");
        int line = baseMapper.insert(teaExamQuestions);
        if (CollectionUtils.isNotEmpty(examQuestionDto.getOptionsList())) {
            examQuestionDto.getOptionsList().stream().forEach(item -> {
                item.setQuestionsId(teaExamQuestions.getBusinessId());
                item.setFlag("1");
                teaExamOptionsRepository.insert(item);
            });
        }
        log.debug(CyUserUtil.getAuthenUsername() + "新增了ID为" +
                teaExamQuestions.getBusinessId() + "的试题表信息");
        return new CyPersistModel(line);
    }


    /**
     * 查询 试提信息
     *
     * @param id
     * @return ExamQuestionDto
     */
    @Override
    public ExamQuestionDto queryAllExamQuestionDto(String id) {
        /**
         * 1.根据id查询试信息
         * 2.将其克隆到questionDto
         * 3.根据试题id查询对应的选项信息
         * **/
        TeaExamQuestions teaExamQuestions = baseMapper.selectById(id);
        ExamQuestionDto questionDto = new ExamQuestionDto();
        BeanUtils.copyProperties(teaExamQuestions, questionDto);
        log.info("试提主表信息: {}", questionDto);
        List<TeaExamOptions> teaExamOptions = teaExamOptionsRepository.queryTeaExamOptionById(Integer.valueOf(id));
        questionDto.setOptionsList(teaExamOptions);
        return questionDto;
    }

    /**
     * 修改 试题表
     *
     * @param examQuestionDto
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(ExamQuestionDto examQuestionDto) {
        /**
         * 1.修改试题信息
         * 2.根据试题id修改与本试题有关的所有选项
         * **/
        TeaExamQuestions teaExamQuestions = new TeaExamQuestions();
        BeanUtils.copyProperties(examQuestionDto, teaExamQuestions);
        if (baseMapper.queryNumbeSomeCourse(teaExamQuestions) > 0)
            throw new CyServiceException(1001, "同一课程下,该题目编号已存在");
        if (baseMapper.queryNumberSomeWeiht(teaExamQuestions) > 0)
            throw new CyServiceException(1001, "同一课程下,该权重已存在");
        int line = baseMapper.updateById(teaExamQuestions);
        teaExamOptionsRepository.deleteByQuestionsId(examQuestionDto.getBusinessId());
        if (!examQuestionDto.getOptionsList().isEmpty()) {
            examQuestionDto.getOptionsList().stream().forEach(item -> {
                item.setQuestionsId(examQuestionDto.getBusinessId());
                item.setFlag("1");
                teaExamOptionsRepository.insert(item);
            });
        }
        log.debug(CyUserUtil.getAuthenUsername() + "修改了ID为" + teaExamQuestions.getBusinessId() + "的试题表信息");
        return new CyPersistModel(line);
    }

    @Override
    public CyPersistModel changeStatus(TeaExamQuestions teaExamQuestions) {
        int line = baseMapper.updateById(teaExamQuestions);
        log.debug(CyUserUtil.getAuthenUsername() + "修改了ID为" + teaExamQuestions.getBusinessId() + "的试题表信息");
        return new CyPersistModel(line);
    }

    /**
     * 删除 试题表
     *
     * @param teaExamQuestions
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(TeaExamQuestions teaExamQuestions) {
        int line = baseMapper.realDelete(teaExamQuestions);

        log.debug(CyUserUtil.getAuthenUsername() + "删除了ID为" +
                teaExamQuestions.getBusinessId() + "的试题表信息");
        return new CyPersistModel(line);
    }

    /**
     * 逻辑删除 试题表
     *
     * @param teaExamQuestions
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(TeaExamQuestions teaExamQuestions) {
        /**
         * 1.对选项进行批量逻辑删除
         * 2.删除试题选项
         * **/
        teaExamOptionsRepository.deleteByQuestionsId(teaExamQuestions.getBusinessId());
        teaExamQuestions.setDeleted();
        int line = baseMapper.deleteById(teaExamQuestions);
        log.debug(CyUserUtil.getAuthenUsername() + "逻辑删除了ID为" +
                teaExamQuestions.getBusinessId() + "的试题表信息");
        return new CyPersistModel(line);
    }


    /**
     * 根据id查询 试题表
     *
     * @param id
     * @return
     */
    @Override
    public TeaExamQuestions findById(String id) {

        return baseMapper.selectById(id);
    }

    /**
     * 分页查询 试题表
     *
     * @param teaExamQuestions
     * @return
     */
    @Override
    public IPage<TeaExamQuestions> findAllByPagination(CyPageInfo<TeaExamQuestions> paginationUtility,
                                                       TeaExamQuestions teaExamQuestions) {
        return baseMapper.queryTeaExamQuestionssPaged(paginationUtility, teaExamQuestions);

    }

    /**
     * 查询list 试题表
     *
     * @param teaExamQuestions
     * @return
     */
    @Override
    public List<TeaExamQuestions> findAll(TeaExamQuestions teaExamQuestions) {
        return baseMapper.queryTeaExamQuestionss(teaExamQuestions);

    }

    /**
     * 导出试题表
     *
     * @return
     */
    @Override
    public List<TeaExamQuestions> export(TeaExamQuestions teaExamQuestions) {
        List<TeaExamQuestions> teaExamQuestionsList = baseMapper.queryTeaExamQuestionss(teaExamQuestions);
        return teaExamQuestionsList;
    }

    @Transactional(
            readOnly = true,
            propagation = Propagation.NOT_SUPPORTED
    )
    @Override
    public String importExcel(MultipartFile file, String courseId) {
        List<ExportExamQuestionDto> examDTOList = CyEpExcelUtil.importExcel(file, 1, 1, ExportExamQuestionDto.class);
        if (examDTOList.size() > 0) {
            // 获取全部考试课题信息
            CyPageInfo<TeaExamQuestions> pagination = new CyPageInfo<>();
            pagination.setCurrent(1);
            pagination.setSize(-1);
            TeaExamQuestions queryTeaExamQuestions = new TeaExamQuestions();
            List<TeaExamQuestions> allTeaExamQuestionsList = this.findAllByPagination(pagination, queryTeaExamQuestions).getRecords();
            Set<String> examCourseSet = allTeaExamQuestionsList.stream()
                    .map(course -> course.getNumber() + "_" + course.getCourseId())
                    .collect(Collectors.toCollection(HashSet::new));

            // 待保存的数据
            List<ExamQuestionDto> savedList = new ArrayList<>();
            // 带保存的唯一key
            Set<String> savedSet = new HashSet<>();
            // 反转列表使只保留最下面的一条重复数据
            Collections.reverse(examDTOList);
            for (ExportExamQuestionDto importDTO : examDTOList) {
                ExamQuestionDto examQuestions = new ExamQuestionDto();
                List<TeaExamOptions> optionsList = new ArrayList<>();
                // 反解出类型id
                if (StringUtils.isNotBlank(importDTO.getQuestionType())) {
                    switch (importDTO.getQuestionType()) {
                        case "单选题" -> examQuestions.setQuestionType(1);
                        case "多选题" -> examQuestions.setQuestionType(2);
                        case "判断题" -> examQuestions.setQuestionType(3);
                        case "简答题" -> examQuestions.setQuestionType(4);
                    }

                }
                // 反解出难度id
                if (StringUtils.isNotBlank(importDTO.getDifficulty())) {
                    switch (importDTO.getDifficulty()) {
                        case "简单" -> examQuestions.setDifficulty(1);
                        case "一般" -> examQuestions.setDifficulty(2);
                        case "困难" -> examQuestions.setDifficulty(3);

                    }
                }
                // 编号
                examQuestions.setNumber(importDTO.getNumber());
                //题干
                examQuestions.setQuestionStem(importDTO.getQuestionStem());
                //标准答案 单选只能是ABCD 的其中一种 多选 答案只能在ABCD中
                if (StringUtils.isNotBlank(importDTO.getAnswer())) {
                    if (examQuestions.getQuestionType() == 1) {
                        if (importDTO.getAnswer().length() != 1) {
                            continue;
                        }
                        if (!importDTO.getAnswer().equalsIgnoreCase("A") &&
                                !importDTO.getAnswer().equalsIgnoreCase("B") &&
                                !importDTO.getAnswer().equalsIgnoreCase("C") &&
                                !importDTO.getAnswer().equalsIgnoreCase("D")) {
                            continue;
                        }
                    }
                    if (examQuestions.getQuestionType() == 2) {
                        //切割答案循环 判断
                        String[] answerArray = importDTO.getAnswer().split(",");
                        //长度不能大于4
                        if (answerArray.length > 4) {
                            continue;
                        }
                        //控制器 默认为false不能
                        Boolean isTrue = false;
                        for (String answer : answerArray) {
                            if (!answer.equalsIgnoreCase("A") &&
                                    !answer.equalsIgnoreCase("B") &&
                                    !answer.equalsIgnoreCase("C") &&
                                    !answer.equalsIgnoreCase("D")) {
                                isTrue = true;
                            }
                        }
                        if (isTrue) {
                            continue;
                        }

                    }
                    if (examQuestions.getQuestionType() == 3) {
                        if (!importDTO.getAnswer().equalsIgnoreCase("对") &&
                                !importDTO.getAnswer().equalsIgnoreCase("错")) {
                            continue;
                        }
                    }
                    examQuestions.setAnswer(importDTO.getAnswer());
                }


                //课程id
                examQuestions.setCourseId(courseId);
                //分数
                examQuestions.setMark(importDTO.getMark());
                //权重
                examQuestions.setWeight(Integer.valueOf(importDTO.getNumber()));
                // 课题描述
                examQuestions.setRemarks(importDTO.getRemark());

                //选项A
                if (StringUtils.isNotBlank(importDTO.getOptionA())) {

                    TeaExamOptions examOptions = new TeaExamOptions();
                    //设置试题id
//                    examOptions.setQuestionsId();
                    //选项类型
                    examOptions.setType("A");

                    //选项描述
                    examOptions.setDetails(importDTO.getOptionA());
                    examOptions.setDelFlag("0");
                    examOptions.setFlag("1");

                    //将选项加入集合
                    optionsList.add(examOptions);
                    examQuestions.setOptionsList(optionsList);
                }
                //选项B
                if (StringUtils.isNotBlank(importDTO.getOptionB())) {
                    TeaExamOptions examOptions = new TeaExamOptions();
                    //设置试题id
//                    examOptions.setQuestionsId();
                    //选项类型
                    examOptions.setType("B");
                    //选项描述
                    examOptions.setDetails(importDTO.getOptionB());
                    examOptions.setDelFlag("0");
                    examOptions.setFlag("1");
                    optionsList.add(examOptions);
                    examQuestions.setOptionsList(optionsList);
                }
                //选项C
                if (StringUtils.isNotBlank(importDTO.getOptionC())) {
                    TeaExamOptions examOptions = new TeaExamOptions();
                    //设置试题id
//                    examOptions.setQuestionsId();
                    //选项类型
                    examOptions.setType("C");
                    //选项描述
                    examOptions.setDetails(importDTO.getOptionC());
                    examOptions.setDelFlag("0");
                    examOptions.setFlag("1");
                    optionsList.add(examOptions);
                    examQuestions.setOptionsList(optionsList);
                }

                //选项D
                if (StringUtils.isNotBlank(importDTO.getOptionD())) {
                    TeaExamOptions examOptions = new TeaExamOptions();
                    //设置试题id
//                    examOptions.setQuestionsId();
                    //选项类型
                    examOptions.setType("D");
                    //选项描述
                    examOptions.setDetails(importDTO.getOptionD());
                    examOptions.setDelFlag("0");
                    examOptions.setFlag("1");
                    optionsList.add(examOptions);
                    examQuestions.setOptionsList(optionsList);
                }

                examQuestions.setDelFlag("0");
                examQuestions.setFlag("1");
                if (StringUtils.isNotBlank(examQuestions.getNumber()) && StringUtils.isNotBlank(courseId)) {
                    String key = examQuestions.getNumber() + "_" + examQuestions.getCourseId();
                    if (!savedSet.contains(key) && !examCourseSet.contains(key)) {
                        savedList.add(examQuestions);
                        savedSet.add(key);
                    }
                }
            }

            //让examDTOList通过题目编号和题型进行排序
            savedList.sort(Comparator.comparing(TeaExamQuestions::getNumber)
                    .thenComparing(TeaExamQuestions::getQuestionType));
//            //排序完将权重赋予
//            for (int i = 0; i < savedList.size(); i++) {
//                savedList.get(i).setWeight(i + 1);
//            }


            if (savedList.size() > 0) {
                TeaExamQuestions delTeaExamQuestions = new TeaExamQuestions();
                Set<String> stringSet = savedList.stream()
                        .map(examQuestions -> examQuestions.getNumber() + "_" + courseId)
                        .collect(Collectors.toCollection(HashSet::new));
                for (String str : stringSet) {
                    String[] strings = str.split("_");
                    delTeaExamQuestions.setNumber(strings[0]);
                    delTeaExamQuestions.setCourseId(strings[1]);
                    List<TeaExamQuestions> delTeaExamQuestionsList = baseMapper.queryTeaExamQuestionss(delTeaExamQuestions);
                    // 批量删除
                    if (!delTeaExamQuestionsList.isEmpty()) {
                        baseMapper.deleteBatch(delTeaExamQuestionsList);
                    }
                }
//                saveBatch(savedList);
                for (ExamQuestionDto examQuestionDto : savedList) {
                    persist(examQuestionDto);
                }
            }
            //判断是否相等
            if (examDTOList.size() != savedList.size()) {
                //去重
                examDTOList.removeAll(savedList);
                String errorMsg = "";
                for (ExportExamQuestionDto examQuestionDto : examDTOList) {
                    errorMsg += examQuestionDto.getNumber() + "、";
                }
                return savedList.size() + "条数据导入成功；" + errorMsg + "数据导入失败。";
            }


            return savedList.size() + "条数据导入成功；" + (examDTOList.size() - savedList.size()) + "条数据导入失败。";
        } else {
            throw new CyServiceException(UserInfoExceptionEnums.EXCEL_NULL);
        }
    }

    /**
     * 根据课程id查询试题
     *
     * @param lessonId
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public Map<String, Object> findByLessonId(String lessonId) {
        HashMap<String, Object> map = new HashMap<>();
        //根据课程id查询所有试题信息
        QueryWrapper<TeaExamQuestions> qw = new QueryWrapper<>();
        qw.eq("course_id", lessonId)
                .eq("del_flag", 0)
                .eq("flag", 1)
                .orderByAsc("question_type")
                .orderByAsc("weight");

        List<TeaExamQuestions> teaExamQuestions = baseMapper.selectList(qw);
        List<ExamQuestionDto> examQuestionDtos = new ArrayList<>();
        if (!teaExamQuestions.isEmpty()) {
            for (TeaExamQuestions teaExamQuestion : teaExamQuestions) {
                ExamQuestionDto examQuestionDto = new ExamQuestionDto();
                BeanUtils.copyProperties(teaExamQuestion, examQuestionDto);
                //设置标准答案为空
                examQuestionDto.setAnswer(teaExamQuestion.getAnswer());
                examQuestionDto.setAnswerNew(teaExamQuestion.getAnswer());
                examQuestionDtos.add(examQuestionDto);
                //根据试题id查询选项
                examQuestionDto.setOptionsList(
                        teaExamOptionsRepository.queryTeaExamOptionssById(teaExamQuestion.getBusinessId()));
            }
        }
        BLesson bLesson = new BLesson();
        bLesson.setBusinessId(lessonId);
        BLesson bLesson1 = bLessonService.selectOne(bLesson);
        map.put("lessonName", bLesson1.getLessonName());
        //试题列表
        map.put("qsList", examQuestionDtos);
        //试卷总分
        map.put("totalScore", teaExamQuestions.stream().mapToInt(TeaExamQuestions::getMark).sum());
        return map;
    }

    /**
     * 保存用户试卷填写答案
     *
     * @param paramString
     * @return
     */
    @Override
    public Map<String, Object> save(String paramString) {
        //将数据转换为List
        List<ExamQuestionDto> param = JSON.parseArray(paramString, ExamQuestionDto.class);
        //获取当前用户的id
        String authenBusinessId = CyUserUtil.getAuthenBusinessId();
        //添加试卷表
        if (!CollectionUtils.isEmpty(param)) {
            TeaExamExaminationPaper paper = new TeaExamExaminationPaper();
            paper.setAnswerId(Integer.valueOf(authenBusinessId));
            paper.setFillingTime(new Date());
            paper.setFlag("1");
            int score = 0;
            //当循环中出现有简答题的题目时将 是否自动判卷
            for (ExamQuestionDto examQuestionDto : param) {
                if (4 == examQuestionDto.getQuestionType()) {
                    paper.setFlag("0");
                }
                if (null != examQuestionDto.getAnswerNew() && null != examQuestionDto.getUanswer()) {
                    //选择
                    if (1 == examQuestionDto.getQuestionType()) {
                        if (examQuestionDto.getAnswerNew().equals(examQuestionDto.getUanswer())) {
                            score += examQuestionDto.getMark();
                        }
                    }
                    //多选
                    if (2 == examQuestionDto.getQuestionType()) {
                        String[] uanswers = examQuestionDto.getUanswer().split(",");
                        String[] answers = examQuestionDto.getAnswerNew().split(",");
                        if (uanswers.length == answers.length) {
                            if (new HashSet<>(Arrays.asList(answers)).equals(new HashSet<>(Arrays.asList(uanswers)))) {
                                score += examQuestionDto.getMark();
                            }
                        }
                    }

                    //判断
                    if (3 == examQuestionDto.getQuestionType()) {
                        //判断  1是对 0是否
                        if ("1".equals(examQuestionDto.getUanswer()) && "对".equals(examQuestionDto.getAnswerNew())) {
                            score += examQuestionDto.getMark();
                        }
                        if ("0".equals(examQuestionDto.getUanswer()) && "错".equals(examQuestionDto.getAnswerNew())) {
                            score += examQuestionDto.getMark();
                        }
                    }


                }
            }
            if ("1".equals(paper.getFlag())) {
                paper.setScore(score);
            }
            paper.setCourseId(param.get(0).getCourseId());
            //判断当前试卷是否存在
            QueryWrapper<TeaExamExaminationPaper> paperQueryWrapper = new QueryWrapper<>();
            paperQueryWrapper.eq("course_id", param.get(0).getCourseId())
                    .eq("answer_id", Integer.valueOf(authenBusinessId))
                    .eq("del_flag", 0);
//            //修改考卷已经完成
            pcFeedExamFlagService.examCompleted(paper);
            //判断是否提交过试卷
            if (teaExamExaminationPaperRepository.selectCount(paperQueryWrapper) > 0) {
                //抛出异常
                throw new CyServiceException("当前试卷已存在，请勿重复提交");
            }
            if (teaExamExaminationPaperRepository.insert(paper) > 0) {
                //查询当前试卷id
                //TODO:测试之后可以查询唯一一条数据
                //paper = teaExamExaminationPaperRepository.selectOne(paperQueryWrapper);
                List<TeaExamExaminationPaper> teaExamExaminationPapers = teaExamExaminationPaperRepository.selectList(paperQueryWrapper);
                paper = teaExamExaminationPapers.get(teaExamExaminationPapers.size() - 1);
                //添加试卷选项表
                for (ExamQuestionDto questionDto : param) {
                    TeaExamQuestionsExamination examination = new TeaExamQuestionsExamination();
                    //试题id
                    examination.setQuestionsId(questionDto.getBusinessId());
                    examination.setAnswer(questionDto.getUanswer());
                    //判断他的答案是否正确
                    if (questionDto.getAnswerNew() != null) {
                        //单选
                        if (1 == questionDto.getQuestionType()) {
                            if (questionDto.getAnswerNew().equals(questionDto.getUanswer())) {
                                examination.setScore(questionDto.getMark());
                            } else {
                                examination.setScore(0);
                            }
                        }
                        //多选
                        if (2 == questionDto.getQuestionType()) {
                            //切割
                            String[] uanswer = questionDto.getUanswer().split(",");
                            String[] answer = questionDto.getAnswerNew().split(",");
                            if (uanswer.length == answer.length) {
                                if (new HashSet<>(Arrays.asList(answer)).equals(new HashSet<>(Arrays.asList(uanswer)))) {
                                    examination.setScore(questionDto.getMark());
                                } else {
                                    examination.setScore(0);
                                }
                            }
                        }
                        //判断
                        if (3 == questionDto.getQuestionType()) {
                            if ("1".equals(questionDto.getUanswer()) && "对".equals(questionDto.getAnswerNew())) {
                                examination.setScore(questionDto.getMark());
                            } else if ("0".equals(questionDto.getUanswer()) && "错".equals(questionDto.getAnswerNew())) {
                                examination.setScore(questionDto.getMark());
                            } else {
                                examination.setScore(0);
                            }
                        }
                    }
                    //设置试卷id
                    examination.setExaminationId(paper.getBusinessId());
                    examination.setFlag("1");
                    teaExamQuestionsExaminationRepository.insert(examination);
                }
                return teaExamExaminationPaperServiceImpl.queryUserExamResult(param.get(0).getCourseId());
            }
        }
        return null;
    }

    /**
     * @param lessonId
     * @param userId
     * @return
     */
    @Override
    public List<ExamQuestionDto> findByLessonIdAndUserId(String lessonId, Integer userId) {
        List<ExamQuestionDto> examQuestionDtos = new ArrayList<>();
        //查询试卷表中的数据
        QueryWrapper<TeaExamExaminationPaper> paperQw = new QueryWrapper<>();
        paperQw.eq("course_id", lessonId)
                .eq("answer_id", userId)
                .eq("del_flag", 0);
        //TODO:测试修改
        //TeaExamExaminationPaper paper = teaExamExaminationPaperRepository.selectOne(paperQw);
        List<TeaExamExaminationPaper> teaExamExaminationPapers = teaExamExaminationPaperRepository.selectList(paperQw);
        TeaExamExaminationPaper paper = teaExamExaminationPapers.get(teaExamExaminationPapers.size() - 1);
        //查询试卷选项表中试题 根据试题id查询试题
        if (paper != null) {
            QueryWrapper<TeaExamQuestionsExamination> examinationQw = new QueryWrapper<>();
            examinationQw.eq("examination_id", paper.getBusinessId())
                    .eq("del_flag", 0)
                    .eq("flag", 1);
            //根据试题id查询选项
            List<TeaExamQuestionsExamination> examinations = teaExamQuestionsExaminationRepository.selectList(examinationQw);
            if (!CollectionUtils.isEmpty(examinations)) {
                //试题id
                List<Integer> list = examinations.stream().map(TeaExamQuestionsExamination::getQuestionsId).distinct().toList();
                //根据试题id查询试题信息  包含已经删除
                List<TeaExamQuestions> teaExamQuestions = baseMapper.selectByIds(list);
                HashMap<Integer, TeaExamQuestions> questionsMap = new HashMap<>();
                teaExamQuestions.forEach(
                        teaExamQuestion -> {
                            questionsMap.put(teaExamQuestion.getBusinessId(), teaExamQuestion);
                        }
                );

                //选项
                List<TeaExamOptions> teaExamOptions = teaExamOptionsRepository.selectByQuestionIds(list);
                HashMap<Integer, List<TeaExamOptions>> optionsMap = new HashMap<>();
                teaExamOptions.forEach(teaExamOption -> {
                    if (!optionsMap.containsKey(teaExamOption.getQuestionsId())) {
                        ArrayList<TeaExamOptions> options = new ArrayList<>();
                        options.add(teaExamOption);
                        optionsMap.put(teaExamOption.getQuestionsId(), options);
                    } else {
                        List<TeaExamOptions> teaExamOptions1 = optionsMap.get(teaExamOption.getQuestionsId());
                        teaExamOptions1.add(teaExamOption);
                        optionsMap.put(teaExamOption.getQuestionsId(), teaExamOptions1);
                    }
                });
                //封装数据
                for (TeaExamQuestionsExamination examination : examinations) {
                    TeaExamQuestions examQuestions = questionsMap.get(examination.getQuestionsId());
                    if (questionsMap.containsKey(examination.getQuestionsId())) {
                        ExamQuestionDto examQuestionDto = new ExamQuestionDto();
                        BeanUtils.copyProperties(examQuestions, examQuestionDto);
                        //设置用户选择的答案
                        examQuestionDto.setUanswer(examination.getAnswer());
                        //用户得分
                        examQuestionDto.setGetScore(examination.getScore());
                        //通过得分情况来确定正确与否
                        if (examQuestionDto.getGetScore() != null) {
                            if (0 == examQuestionDto.getGetScore()) {
                                examQuestionDto.setIsFalse("0");
                            } else {
                                examQuestionDto.setIsFalse("1");
                            }
                        }


//                        //是否正确
//                        if ("1".equals(examQuestionDto.getIsFalse())) {
//                            if (examQuestionDto.getGetScore() == null) {
//                                examQuestionDto.setGetScore(examQuestionDto.getMark());
//                            } else {
//                                examQuestionDto.setGetScore(examination.getScore());
//                            }
//                        }
                        //配置选项
                        if (optionsMap.containsKey(examination.getQuestionsId())) {
                            examQuestionDto.setOptionsList(optionsMap.get(examination.getQuestionsId()));
                        }
                        examQuestionDtos.add(examQuestionDto);
                    }
                }
            }
        }
        return examQuestionDtos;
    }


}
