package org.rcisoft.business.teaexamquestionsexamination.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.exception.CyServiceException;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;


import org.rcisoft.business.teaexamquestionsexamination.entity.TeaExamQuestionsExamination;
import org.rcisoft.business.teaexamquestionsexamination.service.TeaExamQuestionsExaminationService;

import java.util.List;

/**
* Created by cy on 2024年4月18日 下午2:07:57.
*/
@RestController
@RequestMapping("examination")
public class TeaExamQuestionsExaminationController extends CyPaginationController<TeaExamQuestionsExamination> {


    @Autowired
    private TeaExamQuestionsExaminationService teaExamQuestionsExaminationServiceImpl;

    //@PreAuthorize("@cyPerm.hasPerm('sys:examQuestionsExamination:add')")
    @CyOpeLogAnno(title = "system-试题试卷关联表管理-新增试题试卷关联表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="添加试题试卷关联表", notes="添加试题试卷关联表")
    @PostMapping(value = "/add")
    public CyResult add(@Valid TeaExamQuestionsExamination teaExamQuestionsExamination, BindingResult bindingResult) {
        CyPersistModel data = teaExamQuestionsExaminationServiceImpl.persist(teaExamQuestionsExamination);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        teaExamQuestionsExamination);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:examQuestionsExamination:delete')")
    @CyOpeLogAnno(title = "system-试题试卷关联表管理-删除试题试卷关联表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="逻辑删除试题试卷关联表", notes="逻辑删除试题试卷关联表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable int businessId,TeaExamQuestionsExamination teaExamQuestionsExamination) {
        teaExamQuestionsExamination.setBusinessId(businessId);
        CyPersistModel data = teaExamQuestionsExaminationServiceImpl.removeLogical(teaExamQuestionsExamination);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:examQuestionsExamination:delete')")
    @CyOpeLogAnno(title = "system-试题试卷关联表管理-删除试题试卷关联表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="删除试题试卷关联表", notes="删除试题试卷关联表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable int businessId,TeaExamQuestionsExamination teaExamQuestionsExamination) {
        teaExamQuestionsExamination.setBusinessId(businessId);
        CyPersistModel data = teaExamQuestionsExaminationServiceImpl.remove(teaExamQuestionsExamination);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:examQuestionsExamination:update')")
    @CyOpeLogAnno(title = "system-试题试卷关联表管理-修改试题试卷关联表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改试题试卷关联表", notes="修改试题试卷关联表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable int businessId, @Valid TeaExamQuestionsExamination teaExamQuestionsExamination, BindingResult bindingResult) {
        teaExamQuestionsExamination.setBusinessId(businessId);
        CyPersistModel data = teaExamQuestionsExaminationServiceImpl.merge(teaExamQuestionsExamination);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        teaExamQuestionsExamination);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:examQuestionsExamination:query')")
    @CyOpeLogAnno(title = "system-试题试卷关联表管理-查询试题试卷关联表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单一试题试卷关联表", notes="查询单一试题试卷关联表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable int businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        teaExamQuestionsExaminationServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:examQuestionsExamination:list')")
    @CyOpeLogAnno(title = "system-试题试卷关联表管理-查询试题试卷关联表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询试题试卷关联表集合", notes="查询试题试卷关联表集合")
    @GetMapping(value = "/listAll")
    public CyResult listAll(TeaExamQuestionsExamination teaExamQuestionsExamination) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            teaExamQuestionsExaminationServiceImpl.findAll(teaExamQuestionsExamination));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:examQuestionsExamination:list')")
    @CyOpeLogAnno(title = "system-试题试卷关联表管理-查询试题试卷关联表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="分页查询试题试卷关联表集合", notes="分页查询试题试卷关联表集合")
    @GetMapping(value = "/list")
    public CyGridModel listByPagination(TeaExamQuestionsExamination teaExamQuestionsExamination) {
        teaExamQuestionsExaminationServiceImpl.findAllByPagination(getPaginationUtility(), teaExamQuestionsExamination);
        return getGridModelResponse();
    }

    @CyOpeLogAnno(title = "system-试题试卷关联表管理-查询试题试卷关联表", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出试题试卷关联表信息", notes = "导出试题试卷关联表信息")
    @GetMapping(value = "/export")
    public void outTeaExamQuestionsExamination(HttpServletResponse response,TeaExamQuestionsExamination teaExamQuestionsExamination,@PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="试题试卷关联表信息.xls";break;
            case "1": excelName="试题试卷关联表信息.xlsx";break;
            case "2": excelName="试题试卷关联表信息.csv";break;
        }
        List<TeaExamQuestionsExamination> teaExamQuestionsExaminationList = teaExamQuestionsExaminationServiceImpl.export(teaExamQuestionsExamination);
        CyEpExcelUtil.exportExcel(teaExamQuestionsExaminationList, "试题试卷关联表信息", "试题试卷关联表信息", TeaExamQuestionsExamination.class, excelName, response);
    }
}
