package org.rcisoft.business.teaexamquestionsexamination.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.aop.CyPageUtilAsp;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.business.teaexamquestionsexamination.dao.TeaExamQuestionsExaminationRepository;
import org.rcisoft.business.teaexamquestionsexamination.entity.TeaExamQuestionsExamination;
import org.rcisoft.business.teaexamquestionsexamination.service.TeaExamQuestionsExaminationService;
import org.rcisoft.core.service.CyBaseService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.rcisoft.core.model.CyPageInfo;

import java.util.List;
import lombok.extern.slf4j.Slf4j;

/**
 * Created by cy on 2024年4月18日 下午2:07:57.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class TeaExamQuestionsExaminationServiceImpl extends ServiceImpl<TeaExamQuestionsExaminationRepository,TeaExamQuestionsExamination>  implements TeaExamQuestionsExaminationService {


    /**
    * 保存 试题试卷关联表
    * @param teaExamQuestionsExamination
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(TeaExamQuestionsExamination teaExamQuestionsExamination){
        //增加操作
        int line = baseMapper.insert(teaExamQuestionsExamination);
        log.debug(CyUserUtil.getAuthenUsername()+"新增了ID为"+
            teaExamQuestionsExamination.getBusinessId()+"的试题试卷关联表信息");
        return new CyPersistModel(line);
    }

    /**
    * 删除 试题试卷关联表
    * @param teaExamQuestionsExamination
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(TeaExamQuestionsExamination teaExamQuestionsExamination){
        int line = baseMapper.realDelete(teaExamQuestionsExamination);
        log.debug(CyUserUtil.getAuthenUsername()+"删除了ID为"+
            teaExamQuestionsExamination.getBusinessId()+"的试题试卷关联表信息");
        return new CyPersistModel(line);
    }

    /**
    * 逻辑删除 试题试卷关联表
    * @param teaExamQuestionsExamination
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(TeaExamQuestionsExamination teaExamQuestionsExamination){
        teaExamQuestionsExamination.setDeleted();
        int line = baseMapper.deleteById(teaExamQuestionsExamination);
            log.debug(CyUserUtil.getAuthenUsername()+"逻辑删除了ID为"+
                teaExamQuestionsExamination.getBusinessId()+"的试题试卷关联表信息");
            return new CyPersistModel(line);
    }

    /**
    * 修改 试题试卷关联表
    * @param teaExamQuestionsExamination
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(TeaExamQuestionsExamination teaExamQuestionsExamination){
        int line = baseMapper.updateById(teaExamQuestionsExamination);
        log.debug(CyUserUtil.getAuthenUsername()+"修改了ID为"+ teaExamQuestionsExamination.getBusinessId()+"的试题试卷关联表信息");
        return new CyPersistModel(line);
    }

    /**
    * 根据id查询 试题试卷关联表
    * @param id
    * @return
    */
    @Override
    public TeaExamQuestionsExamination findById(int id){
        return baseMapper.selectById(id);
    }

    /**
    * 分页查询 试题试卷关联表
    * @param teaExamQuestionsExamination
    * @return
    */
    @Override
    public IPage<TeaExamQuestionsExamination> findAllByPagination(CyPageInfo<TeaExamQuestionsExamination> paginationUtility,
        TeaExamQuestionsExamination teaExamQuestionsExamination){
        return baseMapper.queryTeaExamQuestionsExaminationsPaged(paginationUtility,teaExamQuestionsExamination);

    }

    /**
    * 查询list 试题试卷关联表
    * @param teaExamQuestionsExamination
    * @return
    */
    @Override
    public List<TeaExamQuestionsExamination> findAll(TeaExamQuestionsExamination teaExamQuestionsExamination){
        return baseMapper.queryTeaExamQuestionsExaminations(teaExamQuestionsExamination);

    }

    /**
    * 导出试题试卷关联表
    * @return
    */
    @Override
    public List<TeaExamQuestionsExamination> export(TeaExamQuestionsExamination teaExamQuestionsExamination) {
        List<TeaExamQuestionsExamination> teaExamQuestionsExaminationList = baseMapper.queryTeaExamQuestionsExaminations(teaExamQuestionsExamination);
        return teaExamQuestionsExaminationList;
    }

}
