package org.rcisoft.business.tealessonandapplication.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.exception.CyServiceException;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;


import org.rcisoft.business.tealessonandapplication.entity.TeaLessonAndApplication;
import org.rcisoft.business.tealessonandapplication.service.TeaLessonAndApplicationService;

import java.util.List;

/**
* Created by cy on 2024年4月3日 上午10:08:10.
*/
@RestController
@RequestMapping("/tealessonandapplication")
public class TeaLessonAndApplicationController extends CyPaginationController<TeaLessonAndApplication> {


    @Autowired
    private TeaLessonAndApplicationService teaLessonAndApplicationServiceImpl;

    //@PreAuthorize("@cyPerm.hasPerm('sys:lessonAndApplication:add')")
    @CyOpeLogAnno(title = "system-课程和申请的中间表管理-新增课程和申请的中间表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="添加课程和申请的中间表", notes="添加课程和申请的中间表")
    @PostMapping(value = "/add")
    public CyResult add(@Valid TeaLessonAndApplication teaLessonAndApplication, BindingResult bindingResult) {
        CyPersistModel data = teaLessonAndApplicationServiceImpl.persist(teaLessonAndApplication);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        teaLessonAndApplication);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:lessonAndApplication:delete')")
    @CyOpeLogAnno(title = "system-课程和申请的中间表管理-删除课程和申请的中间表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="删除课程和申请的中间表", notes="删除课程和申请的中间表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable int businessId,TeaLessonAndApplication teaLessonAndApplication) {
        teaLessonAndApplication.setBusinessId(businessId);
        CyPersistModel data = teaLessonAndApplicationServiceImpl.remove(teaLessonAndApplication);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:lessonAndApplication:update')")
    @CyOpeLogAnno(title = "system-课程和申请的中间表管理-修改课程和申请的中间表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改课程和申请的中间表", notes="修改课程和申请的中间表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable int businessId, @Valid TeaLessonAndApplication teaLessonAndApplication, BindingResult bindingResult) {
        teaLessonAndApplication.setBusinessId(businessId);
        CyPersistModel data = teaLessonAndApplicationServiceImpl.merge(teaLessonAndApplication);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        teaLessonAndApplication);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:lessonAndApplication:query')")
    @CyOpeLogAnno(title = "system-课程和申请的中间表管理-查询课程和申请的中间表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单一课程和申请的中间表", notes="查询单一课程和申请的中间表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable int businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        teaLessonAndApplicationServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:lessonAndApplication:list')")
    @CyOpeLogAnno(title = "system-课程和申请的中间表管理-查询课程和申请的中间表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询课程和申请的中间表集合", notes="查询课程和申请的中间表集合")
    @GetMapping(value = "/listAll")
    public CyResult listAll(TeaLessonAndApplication teaLessonAndApplication) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            teaLessonAndApplicationServiceImpl.findAll(teaLessonAndApplication));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:lessonAndApplication:list')")
    @CyOpeLogAnno(title = "system-课程和申请的中间表管理-查询课程和申请的中间表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="分页查询课程和申请的中间表集合", notes="分页查询课程和申请的中间表集合")
    @GetMapping(value = "/list")
    public CyGridModel listByPagination(TeaLessonAndApplication teaLessonAndApplication) {
        teaLessonAndApplicationServiceImpl.findAllByPagination(getPaginationUtility(), teaLessonAndApplication);
        return getGridModelResponse();
    }

    @CyOpeLogAnno(title = "system-课程和申请的中间表管理-查询课程和申请的中间表", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出课程和申请的中间表信息", notes = "导出课程和申请的中间表信息")
    @GetMapping(value = "/export")
    public void outTeaLessonAndApplication(HttpServletResponse response,TeaLessonAndApplication teaLessonAndApplication,@PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="课程和申请的中间表信息.xls";break;
            case "1": excelName="课程和申请的中间表信息.xlsx";break;
            case "2": excelName="课程和申请的中间表信息.csv";break;
        }
        List<TeaLessonAndApplication> teaLessonAndApplicationList = teaLessonAndApplicationServiceImpl.export(teaLessonAndApplication);
        CyEpExcelUtil.exportExcel(teaLessonAndApplicationList, "课程和申请的中间表信息", "课程和申请的中间表信息", TeaLessonAndApplication.class, excelName, response);
    }
}
