package org.rcisoft.business.tealessonandapplication.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.aop.CyPageUtilAsp;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.business.tealessonandapplication.dao.TeaLessonAndApplicationRepository;
import org.rcisoft.business.tealessonandapplication.entity.TeaLessonAndApplication;
import org.rcisoft.business.tealessonandapplication.service.TeaLessonAndApplicationService;
import org.rcisoft.core.service.CyBaseService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.rcisoft.core.model.CyPageInfo;

import java.util.List;
import lombok.extern.slf4j.Slf4j;

/**
 * Created by cy on 2024年4月3日 上午10:08:10.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class TeaLessonAndApplicationServiceImpl extends ServiceImpl<TeaLessonAndApplicationRepository,TeaLessonAndApplication>  implements TeaLessonAndApplicationService {


    /**
    * 保存 课程和申请的中间表
    * @param teaLessonAndApplication
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(TeaLessonAndApplication teaLessonAndApplication){
        //增加操作
        int line = baseMapper.insert(teaLessonAndApplication);
        log.debug(CyUserUtil.getAuthenUsername()+"新增了ID为"+
            teaLessonAndApplication.getBusinessId()+"的课程和申请的中间表信息");
        return new CyPersistModel(line);
    }

    /**
    * 删除 课程和申请的中间表
    * @param teaLessonAndApplication
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(TeaLessonAndApplication teaLessonAndApplication){
        int line = baseMapper.realDelete(teaLessonAndApplication);
        log.debug(CyUserUtil.getAuthenUsername()+"删除了ID为"+
            teaLessonAndApplication.getBusinessId()+"的课程和申请的中间表信息");
        return new CyPersistModel(line);
    }

    /**
    * 修改 课程和申请的中间表
    * @param teaLessonAndApplication
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(TeaLessonAndApplication teaLessonAndApplication){
        int line = baseMapper.updateById(teaLessonAndApplication);
        log.debug(CyUserUtil.getAuthenUsername()+"修改了ID为"+ teaLessonAndApplication.getBusinessId()+"的课程和申请的中间表信息");
        return new CyPersistModel(line);
    }

    /**
    * 根据id查询 课程和申请的中间表
    * @param id
    * @return
    */
    @Override
    public TeaLessonAndApplication findById(int id){
        return baseMapper.selectById(id);
    }

    /**
    * 分页查询 课程和申请的中间表
    * @param teaLessonAndApplication
    * @return
    */
    @Override
    public IPage<TeaLessonAndApplication> findAllByPagination(CyPageInfo<TeaLessonAndApplication> paginationUtility,
        TeaLessonAndApplication teaLessonAndApplication){
        return baseMapper.queryTeaLessonAndApplicationsPaged(paginationUtility,teaLessonAndApplication);

    }

    /**
    * 查询list 课程和申请的中间表
    * @param teaLessonAndApplication
    * @return
    */
    @Override
    public List<TeaLessonAndApplication> findAll(TeaLessonAndApplication teaLessonAndApplication){
        return baseMapper.queryTeaLessonAndApplications(teaLessonAndApplication);

    }

    /**
    * 导出课程和申请的中间表
    * @return
    */
    @Override
    public List<TeaLessonAndApplication> export(TeaLessonAndApplication teaLessonAndApplication) {
        List<TeaLessonAndApplication> teaLessonAndApplicationList = baseMapper.queryTeaLessonAndApplications(teaLessonAndApplication);
        return teaLessonAndApplicationList;
    }

}
