package org.rcisoft.business.teaoperate.controller;

import io.swagger.annotations.ApiOperation;
import org.rcisoft.business.sysuser.entity.SysUser;
import org.rcisoft.business.teaoperate.dto.TeaOperateRedisResultDto;
import org.rcisoft.business.teaoperate.service.TeaOperateService;
import org.rcisoft.business.teatrialcourse.entity.TeaTrialCourse;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * @Author: gy
 * @Date: 2024/5/30 10:40
 * @Description:
 */
@RestController
@RequestMapping("/teaOperate")
public class TeaOperateController {

    @Autowired
    private TeaOperateService teaOperateService;

    /**
     * 根据类型所有对应的key的列表
     * **/
    @CyOpeLogAnno(title = "system-运营管理-根据类型所有对应的key的列表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "根据类型所有对应的key的列表", notes = "根据类型所有对应的key的列表")
    @GetMapping(value = "/acquireKey")
    public CyResult listByPagination(@RequestParam("type") String type) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                teaOperateService.acquireKey(type));
    }

    /**
     * 根据key值删除对应redis
     * **/
    @CyOpeLogAnno(title = "system-运营管理-根据key值删除对应redis", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value = "根据key值删除对应redis", notes = "根据key值删除对应redis")
    @DeleteMapping(value = "/clearRedisByKey")
    public CyResult clearRedisByKey(TeaOperateRedisResultDto teaOperateRedisResultDto) {
        CyPersistModel data = teaOperateService.clearRedisByKey(teaOperateRedisResultDto);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                null);
    }


    /**
     * 查询用户list集合
     * **/
    @CyOpeLogAnno(title = "system-运营管理-查询用户list集合", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询用户list集合", notes = "查询用户list集合")
    @GetMapping(value = "/queryListUserInfoByUnameOrPhone")
    public CyResult queryListUserInfoByUnameOrPhone(SysUser sysUser) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                teaOperateService.queryListUserInfoByUnameOrPhone(sysUser));
    }

}
