package org.rcisoft.business.teaoperate.enums;

import org.rcisoft.core.enums.CyCaptchaEnum;
import org.rcisoft.core.service.impl.CyAuthServiceImpl;
import org.rcisoft.openapi.api.redisconfig.RedisKeyDisposition;

/**
 * 运营管理类型
 * **/
public enum TeaOperateTypeEnum {

    // 用户密码每分钟允许错误次数
    UNAME_MiN("1", CyAuthServiceImpl.UNAME_MIN_KEY),

    // 用户密码每天允许错误次数的key值前缀
    UNAME_DAY("2",CyAuthServiceImpl.UNAME_DAY_KEY),

    // 短信验证码每分钟允许错误次数的key值前缀
    PHONE_MIN("3",CyAuthServiceImpl.PHONE_MIN_KEY),

    // 短信验证码每天允许错误次数的key值前缀
    PHONE_DAY("4",CyAuthServiceImpl.PHONE_MIN_KEY),

    // 同一个ip 每分钟允许失败的次数
    IP_MIN("5",CyAuthServiceImpl.IP_MIN_KEY),

    // 同一个ip 每天允许失败的次数
    IP_DAY("6",CyAuthServiceImpl.IP_DAY_KEY),

    //  用户密码登录锁定
    LOGIN_USER_PWD("7","login:user_pwd:lock:"),

    // 短信验证码登录锁定
    LOGIN_PHONE("8","login:phone:lock:"),

    // 登录锁定
    LOGIN_IP("9","login:ip:lock:"),

    //服务器
    //Ip访问不合法 分钟    固定60秒
    OPEN_API_IP_ILLEGALLY_MIN("10", RedisKeyDisposition.OPEN_API_IP_ILLEGALLY_MIN.getKey()),
    //Ip访问不合法 天     当天23.59.59
    OPEN_API_IP_ILLEGALLY_DAY("11",RedisKeyDisposition.OPEN_API_IP_ILLEGALLY_DAY.getKey()),
    //Ip访问频繁 分钟
    OPEN_API_IP_ACCESS_NUM_MIN("12",RedisKeyDisposition.OPEN_API_IP_ACCESS_NUM_MIN.getKey()),
    //Ip访问频繁 天
    OPEN_API_IP_ACCESS_NUM_DAY("13",RedisKeyDisposition.OPEN_API_IP_ACCESS_NUM_DAY.getKey()),

    //客户端
    //Ip访问不合法 分钟    固定60秒
    OPEN_API_IP_ILLEGALLY_LOGIN_MIN("14", RedisKeyDisposition.OPEN_API_IP_ILLEGALLY_LOGIN_MIN.getKey()),
    //Ip访问不合法 天     当天23.59.59
    OPEN_API_IP_ILLEGALLY_LOGIN_DAY("15",RedisKeyDisposition.OPEN_API_IP_ILLEGALLY_LOGIN_DAY.getKey()),
    //Ip访问频繁 分钟
    OPEN_API_IP_ACCESS_NUM_LOGIN_MIN("16",RedisKeyDisposition.OPEN_API_IP_ACCESS_NUM_LOGIN_MIN.getKey()),
    //Ip访问频繁 天
    OPEN_API_IP_ACCESS_NUM_LOGIN_DAY("17",RedisKeyDisposition.OPEN_API_IP_ACCESS_NUM_LOGIN_DAY.getKey())
    ;























    private String label;
    private String value;

    TeaOperateTypeEnum(String label,String value) {
        this.label = label;
        this.value = value;
    }

    /**
     * 通过key查找value
     * @param type
     * @return
     */
    public static TeaOperateTypeEnum getEnum(String type) {
        for (TeaOperateTypeEnum testEnum : TeaOperateTypeEnum.values()) {
            if (testEnum.label.equals(type)) {
                return testEnum;
            }
        }
        return TeaOperateTypeEnum.UNAME_MiN;
    }

    public String getLabel() {
        return label;
    }

    public void setLabel(String label) {
        this.label = label;
    }

    public String getValue() {
        return value;
    }

    public void setValue(String value) {
        this.value = value;
    }
}
