package org.rcisoft.business.teaoperate.service.impl;

import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections4.SetUtils;
import org.apache.commons.lang3.StringUtils;
import org.rcisoft.business.sysuser.dao.PCSysUserRepository;
import org.rcisoft.business.sysuser.entity.SysUser;
import org.rcisoft.business.teaoperate.dto.TeaOperateRedisResultDto;
import org.rcisoft.business.teaoperate.enums.TeaOperateExcEnum;
import org.rcisoft.business.teaoperate.enums.TeaOperateTypeEnum;
import org.rcisoft.business.teaoperate.service.TeaOperateService;
import org.rcisoft.core.component.CyInitComp;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.service.CyRedisService;
import org.rcisoft.core.util.CyUserUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.Set;

/**
 * @Author: gy
 * @Date: 2024/5/30 10:24
 * @Description:
 */
@Service
@Slf4j
public class TeaOperateServiceImpl implements TeaOperateService {

    @Autowired
    private RedisTemplate<String, Object> redisTemplate;

    @Autowired(required = false)
    private CyRedisService cyRedisServiceImpl;

    @Autowired
    private CyInitComp cyInitComp;

    @Autowired
    private PCSysUserRepository pcSysUserRepository;

    /**
     * 根据类型所有对应的key的列表 单价点击率 Click through rate 来源
     * **/
    @Override
    public List<TeaOperateRedisResultDto> acquireKey(String type) {
       /* 1.判断用户的权限是不是超级管理员,如果不是抛出异常没有权限*/
        if (StringUtils.isNotBlank(CyUserUtil.getAuthenRoleIds()) && (!CyUserUtil.getAuthenRoleIds().contains(cyInitComp.admin[0])))
            throw new CyServiceException(TeaOperateExcEnum.No_PERMISSION.getCode(),TeaOperateExcEnum.No_PERMISSION.getMessage());
        List<TeaOperateRedisResultDto> list = new ArrayList<>();
        // 2.根据前端的类型获取前缀
        TeaOperateTypeEnum dataTeaOperateTypeEnum = TeaOperateTypeEnum.getEnum(type);
        // 3.根据前缀获取redis所有对应key
        Set<String> listKey = this.getListKey(dataTeaOperateTypeEnum.getValue());
        // 4.如果listKey等于null后为空，返回空集合
        if (listKey == null || listKey.isEmpty())
            return list;
        for (String key : listKey) {
           /* 5.如果不为空 遍历该集合 创建TeaOperateRedisResultDto对象 key对redis的key值
            value值为redis中对应的value值 将其加入list集合中*/
            if (cyRedisServiceImpl.hasKey(key)) {
                TeaOperateRedisResultDto teaOperateRedisResultDto = TeaOperateRedisResultDto.builder()
                        .key(key)
                        .value(String.valueOf(cyRedisServiceImpl.get(key)))
                        .build();
                list.add(teaOperateRedisResultDto);
            }
        }
        return list;
    }

    @Override
    public CyPersistModel clearRedisByKey(TeaOperateRedisResultDto teaOperateRedisResultDto) {
        /* 1.判断用户的权限是不是超级管理员,如果不是抛出异常没有权限*/
        if (StringUtils.isNotBlank(CyUserUtil.getAuthenRoleIds()) && (!CyUserUtil.getAuthenRoleIds().contains(cyInitComp.admin[0])))
            throw new CyServiceException(TeaOperateExcEnum.No_PERMISSION.getCode(),TeaOperateExcEnum.No_PERMISSION.getMessage());
        /*2.判断redis中是否存在key,存在则删除*/
        if (cyRedisServiceImpl.hasKey(teaOperateRedisResultDto.getKey()))
            cyRedisServiceImpl.del(teaOperateRedisResultDto.getKey());
        return new CyPersistModel(1);
    }

    @Override
    public List<SysUser> queryListUserInfoByUnameOrPhone(SysUser sysUser) {


        return pcSysUserRepository.querySysUsers(sysUser);

    }


    // 根据前缀获取redis中的key值

    /**
     * 根据前缀获取所有的key
     * 例如：pro_*
     */
    public Set<String> getListKey(String prefix) {
        Set<String> keys = null;
        keys = redisTemplate.keys(prefix.concat("*"));
        return keys;
    }
}
