package org.rcisoft.business.teatrialcourse.controller;


/*固定导入*/

import cn.afterturn.easypoi.excel.ExcelExportUtil;
import cn.afterturn.easypoi.excel.entity.ExportParams;
import cn.afterturn.easypoi.excel.entity.enmus.ExcelType;
import com.baomidou.mybatisplus.core.metadata.IPage;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

import java.io.IOException;
import java.io.OutputStream;
import java.net.URLEncoder;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;

import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.rcisoft.business.blesson.entity.BLesson;
import org.rcisoft.business.blesson.service.impl.BLessonServiceImpl;
import org.rcisoft.business.sysdictdata.entity.SysDictData;
import org.rcisoft.business.sysdictdata.service.impl.SysDictDataServiceImpl;
import org.rcisoft.business.sysunit.entity.SysUnit;
import org.rcisoft.business.sysunit.service.impl.UnitServiceImpl;
import org.rcisoft.business.teatrialcourse.dto.ExportTrialCourseDTO;
import org.rcisoft.business.teatrialcourse.dto.TrialCourseQueryDto;
import org.rcisoft.business.teatrialcourse.entity.TeaTrialCourse;
import org.rcisoft.business.teatrialcourse.entity.TeaTrialCourseDTO;
import org.rcisoft.business.teatrialcourse.service.TeaTrialCourseService;
import org.rcisoft.core.anno.CyEncryptSm4Anno;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.util.ExcelUtil;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

/**
 * Created by cy on 2024年4月1日 下午2:35:26.
 */
@RestController
@RequestMapping("/teatrialcourse")
public class TeaTrialCourseController extends CyPaginationController<TeaTrialCourse> {

    private static final Logger log = LoggerFactory.getLogger(CyEpExcelUtil.class);

    @Autowired
    private TeaTrialCourseService teaTrialCourseServiceImpl;

    @Autowired
    private UnitServiceImpl unitService;

    @Autowired
    private BLessonServiceImpl bLessonService;

    @Autowired
    private SysDictDataServiceImpl sysDictDataService;

    //@PreAuthorize("@cyPerm.hasPerm('sys:trialCourse:add')")
    @PreAuthorize("@cyPerm.hasPerm('opm:teatrialcourse:add')")
    @CyOpeLogAnno(title = "system-试用开课管理-新增试用开课", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value = "添加试用开课", notes = "添加试用开课")
    @PostMapping(value = "/add")
    public CyResult add(@Valid TeaTrialCourse teaTrialCourse, BindingResult bindingResult) {
        Date endTrialTime = teaTrialCourse.getEndTrialTime();
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(endTrialTime);
        // 增加 23 小时
        calendar.add(Calendar.HOUR_OF_DAY, 23);
        // 增加 59 分钟
        calendar.add(Calendar.MINUTE, 59);
        // 增加 59 秒
        calendar.add(Calendar.SECOND, 59);
        // 获取增加后的日期对象
        endTrialTime = calendar.getTime();
        teaTrialCourse.setEndTrialTime(endTrialTime);
        CyPersistModel data = teaTrialCourseServiceImpl.persist(teaTrialCourse);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                teaTrialCourse);
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:teatrialcourse:deleteLogical')")
    @CyOpeLogAnno(title = "system-试用开课管理-删除试用开课", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value = "逻辑删除试用开课", notes = "逻辑删除试用开课")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable Integer businessId, TeaTrialCourse teaTrialCourse) {
        teaTrialCourse.setBusinessId(businessId);
        CyPersistModel data = teaTrialCourseServiceImpl.removeLogical(teaTrialCourse);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:trialCourse:delete')")

    @CyOpeLogAnno(title = "system-试用开课管理-删除试用开课", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value = "删除试用开课", notes = "删除试用开课")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable Integer businessId, TeaTrialCourse teaTrialCourse) {
        teaTrialCourse.setBusinessId(businessId);
        CyPersistModel data = teaTrialCourseServiceImpl.remove(teaTrialCourse);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:trialCourse:update')")
    @PreAuthorize("@cyPerm.hasPerm('opm:teatrialcourse:update')")
    @CyOpeLogAnno(title = "system-试用开课管理-修改试用开课", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value = "修改试用开课", notes = "修改试用开课")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable Integer businessId, @Valid TeaTrialCourse teaTrialCourse, BindingResult bindingResult) {
        //修改endtreialTime 的时间为 23.59.59
        Date endTrialTime = teaTrialCourse.getEndTrialTime();
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(endTrialTime);
        // 增加 23 小时
        calendar.add(Calendar.HOUR_OF_DAY, 23);
        // 增加 59 分钟
        calendar.add(Calendar.MINUTE, 59);
        // 增加 59 秒
        calendar.add(Calendar.SECOND, 59);
        // 获取增加后的日期对象
        endTrialTime = calendar.getTime();
        teaTrialCourse.setEndTrialTime(endTrialTime);

        teaTrialCourse.setBusinessId(businessId);
        CyPersistModel data = teaTrialCourseServiceImpl.merge(teaTrialCourse);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                teaTrialCourse);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:trialCourse:query')")
    @PreAuthorize("@cyPerm.hasPerm('opm:teatrialcourse:detail')")
    @CyOpeLogAnno(title = "system-试用开课管理-查询试用开课", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询单一试用开课", notes = "查询单一试用开课")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable Integer businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                teaTrialCourseServiceImpl.findById(businessId));
    }

    //PC端查询开课课程
    //@PreAuthorize("@cyPerm.hasPerm('sys:trialCourse:list')")
    @PreAuthorize("@cyPerm.hasPerm('opm:teatrialcourse:queryTeaTrialCourses')")
    @CyOpeLogAnno(title = "system-试用开课管理-查询试用开课", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询试用开课集合", notes = "查询试用开课集合")
    @GetMapping(value = "/queryTeaTrialCourses")
    public CyResult queryTeaTrialCourses(TeaTrialCourse teaTrialCourse) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                teaTrialCourseServiceImpl.findAll(teaTrialCourse));
    }

    // 管理端查询开课课程
    //@PreAuthorize("@cyPerm.hasPerm('sys:trialCourse:list')")
    @PreAuthorize("@cyPerm.hasPerm('opm:teatrialcourse:queryTeaTrialCourses')")
    @CyOpeLogAnno(title = "system-试用开课管理-查询试用开课", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "分页查询试用开课集合", notes = "分页查询试用开课集合")
    @GetMapping(value = "/queryTeaTrialCourseByPagination")
    public CyGridModel listByPagination(TeaTrialCourse teaTrialCourse) {
        teaTrialCourseServiceImpl.findAllByPagination(getPaginationUtility(), teaTrialCourse);
        return getGridModelResponse();
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:teatrialcourse:export')")
    @CyOpeLogAnno(title = "system-试用开课管理-查询试用开课", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出试用开课信息", notes = "导出试用开课信息")
    @GetMapping(value = "/export")
    public void outTeaTrialCourse(HttpServletResponse response, TeaTrialCourse teaTrialCourse, @PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName = "";
        switch (excelId) {
            case "0":
                excelName = "试用开课信息.xls";
                break;
            case "1":
                excelName = "试用开课信息.xlsx";
                break;
            case "2":
                excelName = "试用开课信息.csv";
                break;
        }
        List<TeaTrialCourse> teaTrialCourseList = teaTrialCourseServiceImpl.export(teaTrialCourse);
        CyEpExcelUtil.exportExcel(teaTrialCourseList, "试用开课信息", "试用开课信息", TeaTrialCourse.class, excelName, response);
    }

    //批量新增
    @PreAuthorize("@cyPerm.hasPerm('opm:teatrialcourse:batchAdd')")
    @CyOpeLogAnno(title = "system-开课管理-新增开课", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value = "批量新增试用开课", notes = "批量新增开课")
    @PostMapping(value = "/batchAdd")
    public CyResult batchAdd(@RequestBody TeaTrialCourseDTO teaTrialCourseDTO, BindingResult bindingResult) {
        CyPersistModel data = teaTrialCourseServiceImpl.batchAdd(teaTrialCourseDTO);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                teaTrialCourseDTO);
    }


    @PreAuthorize("@cyPerm.hasPerm('opm:teatrialcourse:importTemplate')")
    @CyOpeLogAnno(
            title = "system-单位开课数据管理-导出单位开课数据空模板",
            businessType = CyLogTypeEnum.EXPORT
    )
    @ApiOperation(
            value = "导出单位开课数据空模板",
            notes = "导出单位开课数据空模板"
    )
    @GetMapping({"/importTemplate"})
    @CyEncryptSm4Anno
    public void importTemplate(HttpServletResponse response) {
        OutputStream outputStream = null;
        Workbook workbook = null;
        try {
            response.setCharacterEncoding("UTF-8");
            response.setHeader("content-Type", "application/vnd.ms-excel");
            response.setHeader("Content-Disposition", "attachment;filename=" + URLEncoder.encode("单位开课数据信息.xlsx", "UTF-8"));
            ExportParams exportParams = new ExportParams("单位开课数据信息", "单位开课数据");
            exportParams.setType(ExcelType.XSSF);
            List<ExportTrialCourseDTO> exportList = new ArrayList();
            workbook = ExcelExportUtil.exportExcel(exportParams, ExportTrialCourseDTO.class, exportList);
            Sheet sheet = workbook.getSheetAt(0);
            // 获取 单位名称 下拉数据
            SysUnit queryUnit = new SysUnit();
            queryUnit.setDelFlag("0");
            queryUnit.setFlag("1");
            List<SysUnit> sysUnitList = unitService.findAll(queryUnit);
            String[] unitNameStrs = sysUnitList.stream()
                    .map(SysUnit::getUnitName)
                    .toArray(String[]::new);
            // 获取 课程名称 下拉数据
            CyPageInfo<BLesson> paginationUtility = new CyPageInfo<>();
            paginationUtility.setCurrent(1);
            paginationUtility.setSize(-1);
            BLesson queryBLesson = new BLesson();
            queryBLesson.setDelFlag("0");
            queryBLesson.setFlag("1");
            List<BLesson> bLessonList = bLessonService.queryBLessonsByPagination(paginationUtility, queryBLesson, getToken()).getRecords();
            String[] lessonNameStrs = bLessonList.stream()
                    .map(BLesson::getLessonName)
                    .toArray(String[]::new);
            SysDictData querySysDictData = new SysDictData();
            querySysDictData.setDelFlag("0");
            querySysDictData.setFlag("1");
            // 获取 开课类型 下拉选项
            String[] applicantTypeList = new String[]{"试用", "付费"};
            // 获取 岗位分类 数据字典
            querySysDictData.setDictType("job_classify");
            List<SysDictData> jobClassificationList = sysDictDataService.findAll(querySysDictData);
            String[] jobClassificationStrs = jobClassificationList.stream()
                    .map(SysDictData::getDictLabel)
                    .toArray(String[]::new);
            // 获取 技术分类 数据字典
            querySysDictData.setDictType("tec_classify");
            List<SysDictData> technicalClassificationList = sysDictDataService.findAll(querySysDictData);
            String[] technicalClassificationStrs = technicalClassificationList.stream()
                    .map(SysDictData::getDictLabel)
                    .toArray(String[]::new);
            // 单位名称列 第一列
            ExcelUtil.XSSFSetDropDownAndHidden(unitNameStrs, workbook, sheet, 2, 10000, 0, 0);
            // 课程名称列 第二列
            ExcelUtil.XSSFSetDropDownAndHidden(lessonNameStrs, workbook, sheet, 2, 10000, 1, 1);
            // 开课类型列 第五列
            ExcelUtil.XSSFSetDropDownAndHidden(applicantTypeList, workbook, sheet, 2, 10000, 4, 4);
            // 岗位分类列 第六列
            ExcelUtil.XSSFSetDropDownAndHidden(jobClassificationStrs, workbook, sheet, 2, 10000, 5, 5);
            // 技术分类列 第七列
            ExcelUtil.XSSFSetDropDownAndHidden(technicalClassificationStrs, workbook, sheet, 2, 10000, 6, 6);
            outputStream = response.getOutputStream();
            workbook.write(outputStream);
        } catch (IOException var12) {
            throw new CyServiceException(var12.getMessage());
        } finally {
            try {
                if (outputStream != null) {
                    outputStream.close();
                }
            } catch (IOException var11) {
                log.info("context:" + var11);
            }
        }
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:teatrialcourse:importDictData')")
    @CyOpeLogAnno(
            title = "system-单位开课数据管理-导入单位开课数据",
            businessType = CyLogTypeEnum.IMPORT
    )
    @ApiOperation(
            value = "导入单位开课数据",
            notes = "导入单位开课数据"
    )
    @PostMapping({"/importDictData"})
    @CyEncryptSm4Anno
    public CyResult importDictData(MultipartFile file) {
        return CyResultGenUtil.builder(new CyPersistModel(1), "操作成功", "网络异常，请稍后重试", this.teaTrialCourseServiceImpl.importExcel(file));
    }

    @PreAuthorize("@cyPerm.hasPerm('opm:teatrialcourse:queryNoSchoolBegins')")
    @CyOpeLogAnno(title = "system-试用开课管理-查询申请人未开过的课程", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询申请人未开过的课程", notes = "查询申请人未开过的课程")
    @GetMapping(value = "/queryNoSchoolBegins")
    public IPage<BLesson> queryNoSchoolBegins(TrialCourseQueryDto teaTrialCourse) {
        return teaTrialCourseServiceImpl.queryNoSchoolBegins(getPaginationUtility(), teaTrialCourse);
    }

    /**
     * 试用课程到期数据查询
     */
    @CyOpeLogAnno(title = "system-定时任务-试用课程到期数据查询", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "定时任务-试用课程到期数据查询", notes = "定时任务-试用课程到期数据查询")
    @Scheduled(cron = "0 0 0 * * ?")
    public void expireTrialCourse() {
        teaTrialCourseServiceImpl.expireTrialCourse();
    }
}
