package org.rcisoft.business.teatrialcourse.dao;

import com.baomidou.mybatisplus.core.metadata.IPage;
import org.apache.ibatis.annotations.Param;
import org.rcisoft.business.blesson.entity.BLesson;
import org.rcisoft.business.teatrialcourse.dto.TrialCourseDto;
import org.rcisoft.business.teatrialcourse.dto.TrialCourseQueryDto;
import org.rcisoft.business.teatrialcourse.entity.TeaTrialCourse;
import org.rcisoft.core.mapper.CyBaseMapper;
import org.rcisoft.core.model.CyPageInfo;

import java.util.List;

/**
 * Created with cy on 2024年4月1日 下午2:35:26.
 */

public interface TeaTrialCourseRepository extends CyBaseMapper<TeaTrialCourse> {


    List<TeaTrialCourse> queryTeaTrialCourses(@Param("entity") TeaTrialCourse teaTrialCourse);

    /**
     * 分页查询 teaTrialCourse
     */
    IPage<TeaTrialCourse> queryTeaTrialCoursesPaged(CyPageInfo cyPageInfo, @Param("entity") TeaTrialCourse teaTrialCourse);

    //批量删除
    int deleteBatch(List<TeaTrialCourse> teaTrialCourseList);

    /**
     * 查询当前用户拥有的课程
     *
     * @param businessId
     * @return
     */
    List<TeaTrialCourse> selectListByUserId(Integer businessId);

    /**
     * 查询当前用户可以看的课程信息
     *
     * @param userId
     * @param lessonId
     * @return
     */
    List<TrialCourseDto> selectByUserIdAndLessonId(@Param("userId") Integer userId, @Param("lessonId") String lessonId);

    /**
     * 查询单位用户可以看的课程信息
     *
     * @param businessId
     * @param lessonId
     * @return
     */
    List<TrialCourseDto> selectByUNITUserIdAndLessonId(@Param("userId") Integer businessId, @Param("lessonId") String lessonId);

    /**
     * 查询当前用户是否为单位管理员
     *
     * @param businessId
     * @param lessonId
     * @return
     */
    List<TrialCourseDto> findByAdmin(@Param("userId") Integer businessId, @Param("lessonId") String lessonId);

    /**
     * 查询该申请人已经开过的课程ID
     *
     * @param teaTrialCourse
     * @return
     */
    List<String> queryNoSchoolBegins(@Param("entity") TrialCourseQueryDto teaTrialCourse);

    IPage<BLesson> queryAll(CyPageInfo<TeaTrialCourse> paginationUtility, @Param("entity") TrialCourseQueryDto teaTrialCourse, @Param("idList") List<String> teaTrialCourseList);

    /**
     * ip 用户查询单位课程信息
     *
     * @param deptId
     * @param lessonId
     * @return
     */
    List<TrialCourseDto> selectByIpUser(@Param("deptId") String deptId, @Param("lessonId") String lessonId);

    /**
     * 查询用户已经过期的课程
     *
     * @return
     */
    List<TeaTrialCourse> queryExpireTrialCourse();

    Integer getLessonCount(@Param("authenBusinessId") String authenBusinessId);
}

