package org.rcisoft.business.teatrialcourse.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.rcisoft.business.blesson.entity.BLesson;
import org.rcisoft.business.blesson.service.impl.BLessonServiceImpl;
import org.rcisoft.business.pcmanage.entity.PcManage;
import org.rcisoft.business.pcmanage.enums.PCManageTypeEnums;
import org.rcisoft.business.pcmanage.service.impl.PcManageServiceImpl;
import org.rcisoft.business.sysdictdata.entity.SysDictData;
import org.rcisoft.business.sysdictdata.service.impl.SysDictDataServiceImpl;
import org.rcisoft.business.sysunit.entity.SysUnit;
import org.rcisoft.business.sysunit.service.impl.UnitServiceImpl;
import org.rcisoft.business.sysuser.dao.PCSysUserRepository;
import org.rcisoft.business.sysuser.entity.SysUser;
import org.rcisoft.business.sysuser.service.impl.PCSysUserServiceImpl;
import org.rcisoft.business.teatrialcourse.dao.TeaTrialCourseRepository;
import org.rcisoft.business.teatrialcourse.dto.ExportTrialCourseDTO;
import org.rcisoft.business.teatrialcourse.dto.TrialCourseQueryDto;
import org.rcisoft.business.teatrialcourse.entity.TeaTrialCourse;
import org.rcisoft.business.teatrialcourse.entity.TeaTrialCourseDTO;
import org.rcisoft.business.teatrialcourse.service.TeaTrialCourseService;
import org.rcisoft.core.component.CyInitComp;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.pc.pcrole.entity.PcRole;
import org.rcisoft.pc.pcrole.service.impl.PcRoleServiceImpl;
import org.rcisoft.pc.pcrolelesson.dao.PcRoleLessonRepository;
import org.rcisoft.pc.pcrolelesson.entity.PcRoleLesson;
import org.rcisoft.pc.pcrolelesson.service.PcRoleLessonService;
import org.rcisoft.pc.pcrolelesson.service.impl.PcRoleLessonServiceImpl;
import org.rcisoft.pc.pcroleuser.entity.PcRoleUser;
import org.rcisoft.pc.pcroleuser.service.impl.PcRoleUserServiceImpl;
import org.rcisoft.sys.rbac.user.enums.UserInfoExceptionEnums;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;

import java.math.BigInteger;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;

/**
 * Created by cy on 2024年4月1日 下午2:35:26.
 */
@Service
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class TeaTrialCourseServiceImpl extends ServiceImpl<TeaTrialCourseRepository, TeaTrialCourse> implements TeaTrialCourseService {

    @Autowired
    private CyInitComp cyInitComp;

    @Autowired
    private UnitServiceImpl unitService;

    @Autowired
    private BLessonServiceImpl bLessonService;

    @Autowired
    private SysDictDataServiceImpl sysDictDataService;

    @Autowired
    private PcManageServiceImpl pcManageService;

    @Autowired
    private PcRoleServiceImpl pcRoleService;

    @Autowired
    private PCSysUserServiceImpl pcSysUserService;

    @Autowired
    private PcRoleUserServiceImpl pcRoleUserService;

    @Autowired
    private PcRoleLessonService pcRoleLessonService;

    @Autowired
    private PcRoleLessonRepository pcRoleLessonRepository;

    @Autowired
    private PCSysUserRepository pcSysUserRepository;

    @Autowired
    private TeaTrialCourseService teaTrialCourseService;
//    @Autowired
//    private TeaTrialCourseRepository teaTrialCourseRepository;


    /**
     * 保存 试用开课
     *
     * @param teaTrialCourse
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(TeaTrialCourse teaTrialCourse) {
        //增加操作
        int line = baseMapper.insert(teaTrialCourse);
        log.debug(CyUserUtil.getAuthenUsername() + "新增了ID为" +
                teaTrialCourse.getBusinessId() + "的试用开课信息");
        return new CyPersistModel(line);
    }

    /**
     * 删除 试用开课
     *
     * @param teaTrialCourse
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(TeaTrialCourse teaTrialCourse) {
        int line = baseMapper.realDelete(teaTrialCourse);
        log.debug(CyUserUtil.getAuthenUsername() + "删除了ID为" +
                teaTrialCourse.getBusinessId() + "的试用开课信息");
        return new CyPersistModel(line);
    }

    /**
     * 逻辑删除 试用开课
     *
     * @param teaTrialCourse
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(TeaTrialCourse teaTrialCourse) {

        //删除角色下的该课程信息
        TeaTrialCourse trialCourse = baseMapper.selectById(teaTrialCourse);
        PcRoleLesson pcRoleLesson = new PcRoleLesson();
        pcRoleLesson.setLessonId(trialCourse.getLessonId());
        List<PcRoleLesson> all = pcRoleLessonService.findAll(pcRoleLesson);
        for (PcRoleLesson roleLesson : all) {
            roleLesson.setDeleted();
            int line1 = pcRoleLessonRepository.deleteById(roleLesson);
        }

        //删除开课信息
        teaTrialCourse.setDeleted();
        int line = baseMapper.deleteById(teaTrialCourse);
        //根据business_id查询单位名字  根据单位名字查询单位id
        log.debug(CyUserUtil.getAuthenUsername() + "逻辑删除了ID为" +
                teaTrialCourse.getBusinessId() + "的试用开课信息");
        return new CyPersistModel(line);
    }

    /**
     * 修改 试用开课
     *
     * @param teaTrialCourse
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(TeaTrialCourse teaTrialCourse) {
        Integer isPay = teaTrialCourse.getIsPay();//付费 试用
        Date endTrialTime = teaTrialCourse.getEndTrialTime();//修改后的结束日期
        //查询课程id
        TeaTrialCourse course = teaTrialCourseService.findById(teaTrialCourse.getBusinessId());
        //查询角色下的这门课程信息
        QueryWrapper<PcRoleLesson> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(PcRoleLesson::getLessonId, course.getLessonId());
        List<PcRoleLesson> pcRoleLessons = pcRoleLessonRepository.selectList(queryWrapper);
        for (PcRoleLesson pcRoleLesson : pcRoleLessons) {
            //角色下的课程
            //获取课程的startTime
            if (pcRoleLesson.getStartTime() == null){
                pcRoleLesson.setStartTime(new Date());
            }
            Date startTime = pcRoleLesson.getStartTime();
            if (isPay.equals(1)) {
                //付费课程  startTime+1年 和传过来的endTrialTime比较
                Date beginTrialTime = new Date();
                Calendar calendar1 = Calendar.getInstance();
                calendar1.setTime(startTime);
                calendar1.add(calendar1.YEAR, 1);//开始时间+1年
                //取calendar.getTime()和calendar1.getTime()的最小值
                long time = endTrialTime.getTime();//结束时间
                long time1 = calendar1.getTime().getTime();//开始时间+1年
                if (time < time1){
                    //结束时间小  结束时间取结束时间
                    // 获取增加后的日期对象
                    Date date = new Date(time);
                    pcRoleLesson.setStartTime(new Date());
                    pcRoleLesson.setEndTime(date);
                }else {
                    //开始时间+1年 小   结束时间取开始时间+1年
                    Date date1 = new Date(time1);
                    pcRoleLesson.setStartTime(new Date());
                    pcRoleLesson.setEndTime(date1);
                }
            }else{
                //试用课程
                Date beginTrialTime = new Date();
                Calendar calendar2 = Calendar.getInstance();
                calendar2.setTime(startTime);
                //免费 试用课程增加两周
                calendar2.add(Calendar.WEEK_OF_YEAR,2);
                //取calendar.getTime()和calendar1.getTime()的最小值
                long time = endTrialTime.getTime();//结束时间
                long time1 = calendar2.getTime().getTime();//开始时间+两周
                if (time < time1){
                    //结束时间小  结束时间取结束时间
                    // 获取增加后的日期对象
                    Date date = new Date(time);
                    pcRoleLesson.setStartTime(new Date());
                    pcRoleLesson.setEndTime(date);
                }else {
                    //开始时间+1年 小   结束时间取开始时间+1年
                    Date date1 = new Date(time1);
                    pcRoleLesson.setStartTime(new Date());
                    pcRoleLesson.setEndTime(date1);
                }
            }

            int line = pcRoleLessonRepository.updateById(pcRoleLesson);
        }


        int line = baseMapper.updateById(teaTrialCourse);
        log.debug(CyUserUtil.getAuthenUsername() + "修改了ID为" + teaTrialCourse.getBusinessId() + "的试用开课信息");
        return new CyPersistModel(line);
    }

    /**
     * 根据id查询 试用开课
     *
     * @param id
     * @return
     */
    @Override
    public TeaTrialCourse findById(Integer id) {
        return baseMapper.selectById(id);
    }

    /**
     * 分页查询 试用开课
     *
     * @param teaTrialCourse
     * @return
     */
    @Override
    public IPage<TeaTrialCourse> findAllByPagination(CyPageInfo<TeaTrialCourse> paginationUtility,
                                                     TeaTrialCourse teaTrialCourse) {
        return baseMapper.queryTeaTrialCoursesPaged(paginationUtility, teaTrialCourse);

    }

    /**
     * 查询list 试用开课
     *
     * @param teaTrialCourse
     * @return
     */
    @Override
    public List<TeaTrialCourse> findAll(TeaTrialCourse teaTrialCourse) {
//        teaTrialCourse.setApplicantUnit(Integer.valueOf(CyUserUtil.getAuthenDept()));
        String userId = CyUserUtil.getAuthenBusinessId();
        SysUser user = pcSysUserRepository.selectById(userId);
        List<TeaTrialCourse> list = new ArrayList<>();
        if (user.getDeptId() != null){
            int intVal = user.getDeptId().intValueExact();
            teaTrialCourse.setApplicantUnit(intVal);
            list = baseMapper.queryTeaTrialCourses(teaTrialCourse);
        }else {
            list = null;
        }
        return list;

    }

    /**
     * 导出试用开课
     *
     * @return
     */
    @Override
    public List<TeaTrialCourse> export(TeaTrialCourse teaTrialCourse) {
        List<TeaTrialCourse> teaTrialCourseList = baseMapper.queryTeaTrialCourses(teaTrialCourse);
        return teaTrialCourseList;
    }

    /**
     * 批量添加
     *
     * @param teaTrialCourseDTO
     * @return
     */
    @Override
    public CyPersistModel batchAdd(TeaTrialCourseDTO teaTrialCourseDTO) {
        //将所有课程结束日期设置为23.00.00
        teaTrialCourseDTO.getSettingList().forEach(teaTrialCourse -> {
            //将结束时间设置为 年月日 时分秒后 时分秒为 23.59.59
            Date endTrialTime = teaTrialCourse.getEndTrialTime();
            Calendar calendar = Calendar.getInstance();
            calendar.setTime(endTrialTime);
            // 增加 23 小时
            calendar.add(Calendar.HOUR_OF_DAY, 23);
            // 增加 59 分钟
            calendar.add(Calendar.MINUTE, 59);
            // 增加 59 秒
            calendar.add(Calendar.SECOND, 59);
            // 获取增加后的日期对象
            endTrialTime = calendar.getTime();
            teaTrialCourse.setEndTrialTime(endTrialTime);
        });
        if (!teaTrialCourseDTO.getSettingList().isEmpty()) {
            //获取teaTrialCourseDTO.getSettingList()中的课程ID
            List<String> businessIdList = teaTrialCourseDTO.getSettingList().stream().map(TeaTrialCourse::getLessonId).distinct().toList();
            List<TeaTrialCourse> teaTrialCourses = baseMapper.selectList(
                    new LambdaQueryWrapper<TeaTrialCourse>()
                            .eq(TeaTrialCourse::getDelFlag, "0")
                            .eq(TeaTrialCourse::getApplicantType,
                                    teaTrialCourseDTO.getApplicantType())
                            .eq(teaTrialCourseDTO.getApplicant() != null,
                                    TeaTrialCourse::getApplicant, teaTrialCourseDTO.getApplicant())
                            .eq(teaTrialCourseDTO.getApplicantUnit() != null,
                                    TeaTrialCourse::getApplicantUnit,
                                    teaTrialCourseDTO.getApplicantUnit())
                            .in(TeaTrialCourse::getLessonId, businessIdList)
            );
            if (!teaTrialCourses.isEmpty()) {
                //获取teaTrialCourses中的课程名称并且拼接成字符串
                String lessonName = teaTrialCourses.stream().map(TeaTrialCourse::getLessonName).collect(Collectors.joining(","));
                throw new CyServiceException(202, "课程:" + lessonName + "已经申请过，请重新选择");
            }
        }
        TeaTrialCourse teaTrialCourse = new TeaTrialCourse();
        if (StringUtils.isNotBlank(String.valueOf(teaTrialCourseDTO.getApplicantUnit()))) {
            teaTrialCourse.setApplicantUnit(teaTrialCourseDTO.getApplicantUnit());
        }
        if (StringUtils.isNotBlank(String.valueOf(teaTrialCourseDTO.getApplicant()))) {
            teaTrialCourse.setApplicant(teaTrialCourseDTO.getApplicant());
        }
        teaTrialCourse.setApplicantType(teaTrialCourseDTO.getApplicantType());
        List<TeaTrialCourse> teaTrialCourse1 = baseMapper.queryTeaTrialCourses(teaTrialCourse);
        List<TeaTrialCourse> teaTrialCourse2 = teaTrialCourseDTO.getSettingList();
        teaTrialCourse2 = teaTrialCourse2.stream()
                .filter(item2 -> teaTrialCourse1.stream().noneMatch(item1 -> item1.equals(item2))).toList();
//        //批量删除
//        if (!teaTrialCourse1.isEmpty()) {
//            baseMapper.deleteBatch(teaTrialCourse1);
//        }
        //添加用户提示消息
        if (CollectionUtils.isNotEmpty(teaTrialCourse2)) {
            pcManageService.persist(teaTrialCourse2, PCManageTypeEnums.TRIAL_TIPS.getCode());
        }

        //批量添加课程
        saveBatch(teaTrialCourse2);


//        if (teaTrialCourseDTO.getApplicantUnit() != null && teaTrialCourseDTO.getApplicantUnit() != 0){
//            //添加课程的时候  每一门课自动新增一个角色，并且该角色下需要有该单位下的所有的学员
//            //给当前角色添加新增的课程
//            List<Map<String, String>> lessonList = new ArrayList<>();
//
//            //给当前单位添加一个角色
//            PcRole pcRole = new PcRole();
//            pcRole.setUnit(teaTrialCourseDTO.getApplicantUnit());
//            SimpleDateFormat sdf = new SimpleDateFormat("yyyy:MM:dd HH:mm");
//            String formattedDate = sdf.format(new Date());
//            pcRole.setName(formattedDate);
//            //将课的信息放入pcrole的lessonList集合中  进行添加
//            for (TeaTrialCourse trialCourse1 : teaTrialCourse2) {
//                HashMap<String, String> map = new HashMap<>();
//                //查询课程的名称 还有讲师名称
//                TeaTrialCourse trialCourse = new TeaTrialCourse();
//                trialCourse.setApplicantUnit(teaTrialCourseDTO.getApplicantUnit());
//                trialCourse.setApplicantType(2);
//                trialCourse.setLessonId(trialCourse1.getLessonId());
//                List<TeaTrialCourse> course = baseMapper.queryTeaTrialCourses(trialCourse);//根据课程id查询
//                TeaTrialCourse courses = course.get(0);
//                map.put(courses.getLessonId(),courses.getLessonName()+"("+courses.getLecturer()+")");
//                lessonList.add(map);
//            }
//
//            pcRole.setLessonList(lessonList);
//            pcRole.setUnit(teaTrialCourseDTO.getApplicantUnit());
//            Integer isPay = teaTrialCourseDTO.getSettingList().get(0).getIsPay();
//            pcRoleService.addRoleWithCourse(pcRole, teaTrialCourseDTO.getApplicantUnit(),isPay);
//
//            //查询该单位下的所有学员
//            SysUser user = new SysUser();
//            user.setDeptId(BigInteger.valueOf(teaTrialCourseDTO.getApplicantUnit()));
//            List<SysUser> all = pcSysUserService.getAllByUnitId(user);
//            List<Integer> userIds = all.stream().map(SysUser::getBusinessId).collect(Collectors.toList());
//            //将list强制转化成string并以逗号分隔
//            String userIdsString ="["+ StringUtils.join(userIds, ",")+"]";
//            PcRoleUser pcRoleUser = new PcRoleUser();
//            pcRoleUser.setUserIds(userIdsString);
//            pcRoleUser.setPcRoleId(pcRole.getBusinessId());
//            pcRoleUserService.addRoleUser(pcRoleUser);
//        }

        return new CyPersistModel(1);
    }

    @Transactional(
            readOnly = true,
            propagation = Propagation.NOT_SUPPORTED
    )
    public String importExcel(MultipartFile file) {
        List<ExportTrialCourseDTO> trialCourseDTOList = CyEpExcelUtil.importExcel(file, 1, 1, ExportTrialCourseDTO.class);
        if (trialCourseDTOList.size() > 0) {
            // 获取全部开课信息
            CyPageInfo<TeaTrialCourse> pagination = new CyPageInfo<>();
            pagination.setCurrent(1);
            pagination.setSize(-1);
            TeaTrialCourse queryTeaTrialCourse = new TeaTrialCourse();
            List<TeaTrialCourse> allTeaTrialCourseList = this.findAllByPagination(pagination, queryTeaTrialCourse).getRecords();
            Set<String> teaTrialCourseSet = allTeaTrialCourseList.stream()
                    .map(course -> course.getApplicantUnit() + "_" + course.getLessonId())
                    .collect(Collectors.toCollection(HashSet::new));
            // 获取全部单位数据
            SysUnit queryUnit = new SysUnit();
            queryUnit.setDelFlag("0");
            queryUnit.setFlag("1");
            List<SysUnit> sysUnitList = unitService.findAll(queryUnit);
            // 以 单位名称 为key 构建map
            Map<String, List<SysUnit>> sysUnitMap = sysUnitList.stream()
                    .collect(Collectors.groupingBy(SysUnit::getUnitName));
            // 获取全部课程数据
            CyPageInfo<BLesson> paginationUtility = new CyPageInfo<>();
            paginationUtility.setCurrent(1);
            paginationUtility.setSize(-1);
            BLesson queryBLesson = new BLesson();
            queryBLesson.setDelFlag("0");
            queryBLesson.setFlag("1");
            List<BLesson> bLessonList = bLessonService.queryBLessonsByPagination(paginationUtility, queryBLesson, null).getRecords();
            Map<String, List<BLesson>> bLessonMap = bLessonList.stream()
                    .collect(Collectors.groupingBy(BLesson::getLessonName));
            SysDictData querySysDictData = new SysDictData();
            querySysDictData.setDelFlag("0");
            querySysDictData.setFlag("1");
            // 获取岗位分类数据字典
            querySysDictData.setDictType("job_classify");
            List<SysDictData> jobClassificationList = sysDictDataService.findAll(querySysDictData);
            Map<String, List<SysDictData>> jobClassificationMap = jobClassificationList.stream()
                    .collect(Collectors.groupingBy(SysDictData::getDictLabel));
            // 获取技术分类数据字典
            querySysDictData.setDictType("tec_classify");
            List<SysDictData> technicalClassificationList = sysDictDataService.findAll(querySysDictData);
            Map<String, List<SysDictData>> technicalClassificationMap = technicalClassificationList.stream()
                    .collect(Collectors.groupingBy(SysDictData::getDictLabel));
            // 待保存的数据
            List<TeaTrialCourse> savedList = new ArrayList<>();
            // 带保存的唯一key
            Set<String> savedSet = new HashSet<>();
            // 反转列表使只保留最下面的一条重复数据
            Collections.reverse(trialCourseDTOList);
            for (ExportTrialCourseDTO importDTO : trialCourseDTOList) {
                TeaTrialCourse teaTrialCourse = new TeaTrialCourse();
                // 反解出单位id
                if (StringUtils.isNotBlank(importDTO.getApplicantUnitName()) && sysUnitMap.containsKey(importDTO.getApplicantUnitName())) {
                    teaTrialCourse.setApplicantUnit(sysUnitMap.get(importDTO.getApplicantUnitName()).get(0).getBusinessId());
                }
                // 反解出课程id
                if (StringUtils.isNotBlank(importDTO.getLessonName()) && bLessonMap.containsKey(importDTO.getLessonName())) {
                    teaTrialCourse.setLessonId(bLessonMap.get(importDTO.getLessonName()).get(0).getBusinessId());
                }
                // 开课类型
                if (StringUtils.isNotBlank(importDTO.getApplicantType())) {
                    teaTrialCourse.setIsPay(importDTO.getApplicantType().equals("试用") ? 0 : 1);
                }
                // 反解出岗位分类
                if (StringUtils.isNotBlank(importDTO.getJobClassification()) && jobClassificationMap.containsKey(importDTO.getJobClassification())) {
                    teaTrialCourse.setJobClassification(jobClassificationMap.get(importDTO.getJobClassification()).get(0).getDictValue());
                }
                // 反解出技术分类
                if (StringUtils.isNotBlank(importDTO.getTechnicalClassification()) && technicalClassificationMap.containsKey(importDTO.getTechnicalClassification())) {
                    teaTrialCourse.setTechnicalClassification(technicalClassificationMap.get(importDTO.getTechnicalClassification()).get(0).getDictValue());
                }
                // 开始时间
                teaTrialCourse.setBeginTrialTime(importDTO.getBeginTrialTime());
                // 结束时间
                teaTrialCourse.setEndTrialTime(importDTO.getEndTrialTime());
                // 备注
                teaTrialCourse.setRemarks(importDTO.getRemarks());
                teaTrialCourse.setApplicantType(2);
                teaTrialCourse.setDelFlag("0");
                teaTrialCourse.setFlag("0");
                if (StringUtils.isNotBlank(teaTrialCourse.getApplicantUnit().toString()) && StringUtils.isNotBlank(teaTrialCourse.getLessonId())) {
                    String key = teaTrialCourse.getApplicantUnit() + "_" + teaTrialCourse.getLessonId();
                    if (!savedSet.contains(key) && !teaTrialCourseSet.contains(key)) {
                        savedList.add(teaTrialCourse);
                        savedSet.add(key);
                    }
                }
            }
            if (savedList.size() > 0) {
                TeaTrialCourse delTeaTrialCourse = new TeaTrialCourse();
                Set<String> stringSet = savedList.stream()
                        .map(teaTrialCourse -> teaTrialCourse.getApplicantUnit() + "_" + teaTrialCourse.getApplicantType())
                        .collect(Collectors.toCollection(HashSet::new));
                for (String str : stringSet) {
                    String[] strings = str.split("_");
                    delTeaTrialCourse.setApplicantUnit(Integer.valueOf(strings[0]));
                    delTeaTrialCourse.setApplicantType(Integer.valueOf(strings[1]));
                    List<TeaTrialCourse> delTeaTrialCourseList = baseMapper.queryTeaTrialCourses(delTeaTrialCourse);
                    // 批量删除
                    if (!delTeaTrialCourseList.isEmpty()) {
                        baseMapper.deleteBatch(delTeaTrialCourseList);
                    }
                }
                saveBatch(savedList);
            }
            return savedList.size() + "条数据导入成功；" + (trialCourseDTOList.size() - savedList.size()) + "条数据导入失败。";
        } else {
            throw new CyServiceException(UserInfoExceptionEnums.EXCEL_NULL);
        }
    }

    @Override
    public IPage<BLesson> queryNoSchoolBegins(CyPageInfo<TeaTrialCourse> paginationUtility,
                                              TrialCourseQueryDto teaTrialCourse) {
        // 根据申请人ID查询已经开过的课程ID
        List<String> teaTrialCourseList = baseMapper.queryNoSchoolBegins(teaTrialCourse);
        // 查询该申请人未开过的所有课程

        // 0企业 1院校
//        if ("0".equals(teaTrialCourse.getLessonType())) {
//            teaTrialCourse.setLessonType("1");
//        } else if ("1".equals(teaTrialCourse.getLessonType())) {
//            teaTrialCourse.setLessonType("");
//            teaTrialCourse.setLessonTypeSchool("1");
//        }
        if ("0".equals(teaTrialCourse.getLessonType())) {
            teaTrialCourse.setLessonType("1");
        } else if ("1".equals(teaTrialCourse.getLessonType())) {
            teaTrialCourse.setLessonType(null);
            teaTrialCourse.setLessonTypeSchool("1");
        } else if ("2".equals(teaTrialCourse.getLessonType())) {
            teaTrialCourse.setLessonType("1");
            teaTrialCourse.setLessonTypeSchool("1");
        }
        return baseMapper.queryAll(paginationUtility, teaTrialCourse, teaTrialCourseList);
    }

    /**
     * 试用课程到期数据查询
     */
    @Override
    public void expireTrialCourse() {
        // 查询试用课程以及剩余天数
        List<TeaTrialCourse> teaTrialCourseList = baseMapper.queryExpireTrialCourse();
        if (CollectionUtils.isNotEmpty(teaTrialCourseList)) {
            pcManageService.persist(teaTrialCourseList, PCManageTypeEnums.EXPIRATION_REMINDER.getCode());
        }
    }
}

