package org.rcisoft.core.util;

import org.rcisoft.core.model.CyCommonPageGridModel;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.model.CyPageInfo;

import javax.servlet.http.HttpServletRequest;

/**
 * 分页工具类
 */
public class PageUtil {

    private PageUtil() {
    }

    /**
     * 获取分页信息
     *
     * @param request 请求
     * @return 分页信息
     */
    public static <T> CyPageInfo<T> getPageInfo(HttpServletRequest request) {
        CyPageInfo<T> paginationUtility = (CyPageInfo<T>) request.getAttribute("pagination");
        if (paginationUtility == null) {
            throw new NullPointerException("未传递分页参数（page&rows），却在方法中使用paginationUtility对象。");
        } else {
            return paginationUtility;
        }
    }

    /**
     * 获取分页后的结果
     *
     * @param pageInfo 分页信息
     * @return 分页后的结果
     */
    public static CyGridModel getGridModelResponse(CyPageInfo<?> pageInfo) {
        return null != pageInfo ? pageInfo.getGridModel() : new CyCommonPageGridModel();
    }
}
