package org.rcisoft.core.util;
import cn.hutool.crypto.symmetric.RC4;
import org.apache.commons.lang3.StringUtils;

import java.util.Arrays;

import java.util.Base64;

public class RC4Util {
    private static final String KEY = "Rf439VnSQh5uPggcm0ZkLf3XXuo21ziUVNbQkIWvDPWnLKVFWo8VOuyAeIBHwpXdAp28hov0wVwgC2aPQl9mpFQHdtOm6Re2qYWdhkuf6xYQT6IH1bZLr4FX75nvGeRR";
    private int[] S = new int[256];
    private int[] T = new int[256];

    public static void example(String[] args) {
        RC4Util rc4 = new RC4Util();
        String plaintext = "Thisismessage";
        //16进制数据的RC4加解密
        String ciphertext_hex = rc4.encryptToHex(plaintext, KEY);
        System.out.println("16进制数据的RC4加密:" + ciphertext_hex);

        //16进制数据的RC4解密
        String decrypted_text_hex = rc4.decryptFromHex(ciphertext_hex, KEY);
        System.out.println("16进制数据的RC4解密:" + decrypted_text_hex);

        //base64数据的RC4加密
        String ciphertext_base64 = rc4.encryptToBase64(plaintext, KEY);
        System.out.println("base64数据的RC4加密:" + ciphertext_base64);

        //base64数据的RC4解密
        String decrypted_text_base64 = rc4.decryptFromBase64(ciphertext_base64, KEY);
        System.out.println("base64数据的RC4解密:" + decrypted_text_base64);
    }

    private void ksa(byte[] key) {
        for (int i = 0; i < 256; i++) {
            S[i] = i;
            T[i] = key[i % key.length];
        }

        int j = 0;
        for (int i = 0; i < 256; i++) {
            j = (j + S[i] + T[i]) % 256;
            swap(i, j);
        }
    }

    private void swap(int i, int j) {
        int temp = S[i];
        S[i] = S[j];
        S[j] = temp;
    }

    public byte[] encrypt(byte[] plaintext, byte[] key) {
        ksa(key);
        int i = 0, j = 0;
        byte[] ciphertext = new byte[plaintext.length];

        for (int k = 0; k < plaintext.length; k++) {
            i = (i + 1) % 256;
            j = (j + S[i]) % 256;
            swap(i, j);
            int t = (S[i] + S[j]) % 256;
            ciphertext[k] = (byte) (plaintext[k] ^ S[t]);
        }

        return ciphertext;
    }

    public byte[] decrypt(byte[] ciphertext, byte[] key) {
        return encrypt(ciphertext, key);
    }

    public String encryptToBase64(String plaintext, String key) {
        if (StringUtils.isEmpty(key)){
            key = KEY;
        }
        byte[] bytes = encrypt(plaintext.getBytes(), key.getBytes());
        return Base64.getEncoder().encodeToString(bytes);
    }

    public String decryptFromBase64(String ciphertext, String key) {
        if (StringUtils.isEmpty(key)){
            key = KEY;
        }
        byte[] bytes = Base64.getDecoder().decode(ciphertext);
        byte[] decrypted = decrypt(bytes, key.getBytes());
        return new String(decrypted);
    }

    public  String encryptToHex(String plaintext, String key) {
        if (StringUtils.isEmpty(key)){
            key = KEY;
        }
        byte[] bytes = encrypt(plaintext.getBytes(), key.getBytes());
        StringBuilder sb = new StringBuilder();

        for (byte b : bytes) {
            sb.append(String.format("%02x", b));
        }

        return sb.toString();
    }

    public String decryptFromHex(String ciphertext, String key) {
        if (StringUtils.isEmpty(key)){
            key = KEY;
        }
        byte[] bytes = new byte[ciphertext.length() / 2];

        for (int i = 0; i < ciphertext.length(); i += 2) {
            bytes[i / 2] = (byte) Integer.parseInt(ciphertext.substring(i, i + 2), 16);
        }

        byte[] decrypted = decrypt(bytes, key.getBytes());
        return new String(decrypted);
    }
}
