package org.rcisoft.core.util;

import java.security.SecureRandom;
import java.util.Random;

public class RandomPasswordGenerator {

    private static final String upperCaseLetters = "ABCDEFGHIJKLMNOPQRSTUVWXYZ";
    private static final String lowerCaseLetters = "abcdefghijklmnopqrstuvwxyz";
    private static final String numbers = "0123456789";
    private static final String specialCharacters = "!@#$%^&*_=+-/.?<>)";

    private static final String allCharacters = upperCaseLetters + lowerCaseLetters + numbers + specialCharacters;

    private static SecureRandom random = new SecureRandom();

    // 生成8位包含大小写字母、数字和特殊符号的随机密码
    public static String generatePassword() {
        StringBuilder password = new StringBuilder();

        // 至少包含一个大写字母
        password.append(upperCaseLetters.charAt(random.nextInt(upperCaseLetters.length())));
        // 至少包含一个小写字母
        password.append(lowerCaseLetters.charAt(random.nextInt(lowerCaseLetters.length())));
        // 至少包含一个数字
        password.append(numbers.charAt(random.nextInt(numbers.length())));
        // 至少包含一个特殊符号
        password.append(specialCharacters.charAt(random.nextInt(specialCharacters.length())));

        // 剩余字符随机生成
        for (int i = 4; i < 8; i++) {
            password.append(allCharacters.charAt(random.nextInt(allCharacters.length())));
        }

        // 将密码字符串打乱顺序，增加密码强度
        String shuffledPassword = shuffleString(password.toString());

        return shuffledPassword;
    }

    // 打乱字符串顺序
    private static String shuffleString(String input) {
        char[] characters = input.toCharArray();
        for (int i = 0; i < characters.length; i++) {
            int randomIndex = random.nextInt(characters.length);
            char temp = characters[i];
            characters[i] = characters[randomIndex];
            characters[randomIndex] = temp;
        }
        return new String(characters);
    }
}
