package org.rcisoft.openapi.api.log;

import org.rcisoft.core.component.CySpringBeanComp;
import org.rcisoft.core.threadpool.CyAsyncManager;
import org.rcisoft.core.util.CyThreadUtil;

import java.util.TimerTask;
import java.util.concurrent.ScheduledExecutorService;
import java.util.concurrent.TimeUnit;

public class OpenApiAsyncManager {
    private static OpenApiAsyncManager me = new OpenApiAsyncManager();
    /**
     * 操作延迟10毫秒
     */
    private final int OPERATE_DELAY_TIME = 10;
    /**
     * 异步操作任务调度线程池
     */
    private ScheduledExecutorService executor = CySpringBeanComp.getBean("scheduledExecutorService");

    /**
     * 单例模式
     */
    private OpenApiAsyncManager() {
    }

    public static OpenApiAsyncManager me() {
        return me;
    }

    /**
     * 执行任务
     *
     * @param task 任务
     */
    public void execute(TimerTask task) {
        executor.schedule(task, OPERATE_DELAY_TIME, TimeUnit.MILLISECONDS);
    }

    /**
     * 停止任务线程池
     */
    public void shutdown() {
        CyThreadUtil.shutdownAndAwaitTermination(executor);
    }
}
