package org.rcisoft.openapi.api.redisconfig;

import lombok.extern.slf4j.Slf4j;
import org.rcisoft.openapi.api.util.TimeUtil;
import org.rcisoft.core.service.CyRedisService;
import org.rcisoft.core.util.CyAddressUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import javax.servlet.http.HttpServletRequest;

/**
 * @author Liushuaiyang
 */
@Component
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class RedisSetKeyValue {

    @Autowired(required = false)
    CyRedisService cyRedisService;

    /**
     *  访问不合法
     * */
    public void accessIsNotLegal(HttpServletRequest request){
        //ip
        String ip = CyAddressUtils.IpUtils.getIpAddr(request);
        //访问不合法 先查询 查出来加1 塞回 没有 创建
        if (cyRedisService.hasKey(RedisKeyDisposition.OPEN_API_IP_ILLEGALLY_MIN.getKey()+ip)) {
            cyRedisService.incr(RedisKeyDisposition.OPEN_API_IP_ILLEGALLY_MIN.getKey()+ip, Long.valueOf(1));
        }else {
            cyRedisService.set(RedisKeyDisposition.OPEN_API_IP_ILLEGALLY_MIN.getKey()+ip,1, Long.valueOf(60));
        }
        if (cyRedisService.hasKey(RedisKeyDisposition.OPEN_API_IP_ILLEGALLY_DAY.getKey()+ip)) {
            cyRedisService.incr(RedisKeyDisposition.OPEN_API_IP_ILLEGALLY_DAY.getKey()+ip, Long.valueOf(1));
        }else {
            //当天时间到当天时间的23.59.59
            cyRedisService.set(RedisKeyDisposition.OPEN_API_IP_ILLEGALLY_DAY.getKey() + ip, 1, TimeUtil.getSecondsToTomorrow());
        }
    }
    /**
     * login访问不合法
     * */
    public void loginAccessIsNotLegal(HttpServletRequest request){
        //ip
        String ip = CyAddressUtils.IpUtils.getIpAddr(request);
        //访问不合法 先查询 查出来加1 塞回 没有 创建
        if (cyRedisService.hasKey(RedisKeyDisposition.OPEN_API_IP_ILLEGALLY_LOGIN_MIN.getKey()+ip)) {
            cyRedisService.incr(RedisKeyDisposition.OPEN_API_IP_ILLEGALLY_LOGIN_MIN.getKey()+ip, Long.valueOf(1));
        }else {
            cyRedisService.set(RedisKeyDisposition.OPEN_API_IP_ILLEGALLY_LOGIN_MIN.getKey()+ip,1, Long.valueOf(60));
        }
        if (cyRedisService.hasKey(RedisKeyDisposition.OPEN_API_IP_ILLEGALLY_LOGIN_DAY.getKey()+ip)) {
            cyRedisService.incr(RedisKeyDisposition.OPEN_API_IP_ILLEGALLY_LOGIN_DAY.getKey()+ip, Long.valueOf(1));
        }else {
            //当天时间到当天时间的23.59.59
            cyRedisService.set(RedisKeyDisposition.OPEN_API_IP_ILLEGALLY_LOGIN_DAY.getKey() + ip, 1, TimeUtil.getSecondsToTomorrow());
        }
    }
    /**
     * 访问频繁
     * */
    public void accessIsFrequently(HttpServletRequest request) {
        //ip
        String ip = CyAddressUtils.IpUtils.getIpAddr(request);
        //记录ip访问次数
        if (cyRedisService.hasKey(RedisKeyDisposition.OPEN_API_IP_ACCESS_NUM_MIN.getKey() + ip)) {
            cyRedisService.incr(RedisKeyDisposition.OPEN_API_IP_ACCESS_NUM_MIN.getKey() + ip, Long.valueOf(1));
        } else {
            cyRedisService.set(RedisKeyDisposition.OPEN_API_IP_ACCESS_NUM_MIN.getKey() + ip, 1, Long.valueOf(60));
        }
        if (cyRedisService.hasKey(RedisKeyDisposition.OPEN_API_IP_ACCESS_NUM_DAY.getKey() + ip)) {
            cyRedisService.incr(RedisKeyDisposition.OPEN_API_IP_ACCESS_NUM_DAY.getKey() + ip, Long.valueOf(1));
        } else {
            cyRedisService.set(RedisKeyDisposition.OPEN_API_IP_ACCESS_NUM_DAY.getKey() + ip, 1, TimeUtil.getSecondsToTomorrow());
        }
    }
    /**
     * login访问频繁
     * */
    public void loginAccessIsFrequently(HttpServletRequest request) {
        //ip
        String ip = CyAddressUtils.IpUtils.getIpAddr(request);
        //记录ip访问次数
        if (cyRedisService.hasKey(RedisKeyDisposition.OPEN_API_IP_ACCESS_NUM_LOGIN_MIN.getKey() + ip)) {
            cyRedisService.incr(RedisKeyDisposition.OPEN_API_IP_ACCESS_NUM_LOGIN_MIN.getKey() + ip, Long.valueOf(1));
        } else {
            cyRedisService.set(RedisKeyDisposition.OPEN_API_IP_ACCESS_NUM_LOGIN_MIN.getKey() + ip, 1, Long.valueOf(60));
        }
        if (cyRedisService.hasKey(RedisKeyDisposition.OPEN_API_IP_ACCESS_NUM_LOGIN_DAY.getKey() + ip)) {
            cyRedisService.incr(RedisKeyDisposition.OPEN_API_IP_ACCESS_NUM_LOGIN_DAY.getKey() + ip, Long.valueOf(1));
        } else {
            cyRedisService.set(RedisKeyDisposition.OPEN_API_IP_ACCESS_NUM_LOGIN_DAY.getKey() + ip, 1, TimeUtil.getSecondsToTomorrow());
        }
    }








}
