package org.rcisoft.openapi.api.service.impl;


import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.rcisoft.common.component.CyGlobal;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.jwt.model.CyJwtUser;
import org.rcisoft.core.jwt.util.CyJwtUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.service.CyRedisService;
import org.rcisoft.core.service.impl.CyAuthServiceImpl;
import org.rcisoft.core.util.CyAddressUtils;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.openapi.api.accesscontrol.AccessControl;
import org.rcisoft.openapi.api.component.OpenApiGlobal;
import org.rcisoft.openapi.api.cons.OpenApiCons;
import org.rcisoft.openapi.api.redisconfig.RedisKeyDisposition;
import org.rcisoft.openapi.api.redisconfig.RedisSetKeyValue;
import org.rcisoft.openapi.api.service.OpenApiService;
import org.rcisoft.openapi.api.util.AESUtils;
import org.rcisoft.openapi.api.util.EncryptionDecrypt;
import org.rcisoft.openapi.iaminstitution.entity.IamInstitution;
import org.rcisoft.sys.rbac.user.dao.SysUserRbacRepository;
import org.rcisoft.sys.rbac.user.entity.SysUserRbac;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.HashMap;
import java.util.List;
import java.util.UUID;

import static org.rcisoft.openapi.api.redisconfig.RedisKeyDisposition.OPEN_API_IP_GEI_TOKEN;

@Service
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class OpenApiServiceImpl implements OpenApiService {

    @Autowired
    RedisSetKeyValue redisSetKeyValue;
    @Autowired(required = false)
    CyRedisService cyRedisService;
    @Autowired
    OpenApiGlobal openApiGlobal;
    @Autowired
    EncryptionDecrypt encryptionDecrypt;
    @Autowired
    SysUserRbacRepository sysUserRbacRepository;
    @Autowired
    CyAuthServiceImpl cyAuthServiceImpl;
    @Autowired
    private AccessControl accessControl;
    @Autowired
    private CyGlobal cyGlobal;

    @Override
    public CyResult getToken(HttpServletRequest request, HttpServletResponse response, String sign) {
        //全局拦截
        accessControl.ipGlobalInterceptor(request, response);
        //Ip密钥查询
        IamInstitution iamInstitution = accessControl.ipSecretInterceptor(request, response);
        //解密处理
        if (StringUtils.isNotEmpty(sign)) {
            //进行解密
            HashMap<String, String> parameters = encryptionDecrypt.decrypt(request, iamInstitution.getApiSecretKey(), sign);
            //通过固定key 取出 参数
            String accessKey = parameters.get("accessKey");
            String secretKey = parameters.get("secretKey");
            //secretKey 解密
            try {
                iamInstitution.setSecretKey(AESUtils.decryptCBC(iamInstitution.getSecretKey(), null));
            } catch (Exception e) {
                redisSetKeyValue.accessIsNotLegal(request);
                throw new CyServiceException(OpenApiCons.DATA_DECRYPTION_FAILED_OR_COMPARISON_FAILED);
            }


            if (StringUtils.isNotEmpty(accessKey) &&
                    StringUtils.isNotEmpty(secretKey) &&
                    accessKey.equals(iamInstitution.getAccessKey()) &&
                    secretKey.equals(iamInstitution.getSecretKey())) {
                //uuid生成 ip token  存储
                String token = UUID.randomUUID().toString().replace("-", "");
                cyRedisService.set(OPEN_API_IP_GEI_TOKEN.getKey() + CyAddressUtils.IpUtils.getIpAddr(request), token, openApiGlobal.getGetTokenTTL());
                return CyResultGenUtil.builder(new CyPersistModel(1),
                        CyMessCons.MESSAGE_ALERT_SUCCESS,
                        CyMessCons.MESSAGE_ALERT_ERROR,
                        token);
            } else {
                redisSetKeyValue.accessIsNotLegal(request);
                throw new CyServiceException(OpenApiCons.DATA_DECRYPTION_FAILED_OR_COMPARISON_FAILED);
            }
        } else {
            redisSetKeyValue.accessIsNotLegal(request);
            throw new CyServiceException(OpenApiCons.DATA_DECRYPTION_FAILED_OR_COMPARISON_FAILED);
        }
    }


    @Override
    public CyResult getUcode(HttpServletRequest request, HttpServletResponse response, String sign) {
        //全局拦截
        accessControl.ipGlobalInterceptor(request, response);
        //token验证
        accessControl.tokenInterceptor(request, response);
        //Ip密钥查询
        IamInstitution iamInstitution = accessControl.ipSecretInterceptor(request, response);
        log.error("iamInstitution:{}",iamInstitution);
        //解密处理
        if (StringUtils.isNotEmpty(sign)) {
            //进行解密
            HashMap<String, String> parameters = encryptionDecrypt.decrypt(request, iamInstitution.getApiSecretKey(), sign);
            //通过固定key 取出 参数
            String username = parameters.get("username");
            String phone = parameters.get("phone");
            log.info("parameters:{}",parameters);
            log.info("username:{}",username);
            log.info("phone:{}",phone);
            if (StringUtils.isNotEmpty(username) && StringUtils.isNotEmpty(phone)) {
                //通过用户名 手机号查询 当前用户
                List<SysUserRbac> sysUserRbacsUsername = sysUserRbacRepository.queryUserByUserName(username);
                log.info("sysUserRbacsUsername:{}",sysUserRbacsUsername);
                //通过用户名查询到当前用户
                //控制器
                Boolean isSysUserRbac = false;
                SysUserRbac sysUserRbac = null;
                if (!sysUserRbacsUsername.isEmpty()) {
                    sysUserRbac = sysUserRbacsUsername.get(0);
                    isSysUserRbac = true;
                }
                if (!isSysUserRbac) {
                    //通过手机号来找到这个用户
                    List<SysUserRbac> sysUserRbacsPhone = sysUserRbacRepository.queryUserByPhone(phone);
                    if (!sysUserRbacsPhone.isEmpty()) {
                        sysUserRbac = sysUserRbacsPhone.get(0);
                        isSysUserRbac = true;
                    }
                }
                if (isSysUserRbac) {
                    if (iamInstitution.getUnitId() == null || sysUserRbac.getDeptId() == null || iamInstitution.getUnitId() != sysUserRbac.getDeptId())
                        isSysUserRbac = false;
                    log.info("iamInstitution.getUnitId():",iamInstitution.getUnitId());
                    log.info("sysUserRbac.getDeptId()",sysUserRbac.getDeptId());
                    log.info("isSysUserRbac:{}",isSysUserRbac);
                }
                if (isSysUserRbac) {
                    boolean notLocked = true;
                    CyJwtUser jwtUser = CyJwtUtil.createRbacJwtUser(sysUserRbac, notLocked);
                    final String token = CyJwtUtil.generateToken(jwtUser);
                    //随机uuid
                    String ucode = UUID.randomUUID().toString().replace("-", "");
                    //redis存储       一个是 token 一个是 登录用户
                    cyRedisService.set(RedisKeyDisposition.OPEN_API_UCODE.getKey() + ucode, token, openApiGlobal.getUcodeTTL());
                    cyRedisService.set(RedisKeyDisposition.OPEN_API_UCODE_USER.getKey() + ucode, sysUserRbac.getUsername(), openApiGlobal.getUcodeTTL());
                    cyRedisService.hset(RedisKeyDisposition.OPEN_API_UCODE_BIND.getKey() + ucode, "theNameOfTheOrganization", iamInstitution.getOrganizationalStructure(), openApiGlobal.getUcodeTTL());
                    cyRedisService.hset(RedisKeyDisposition.OPEN_API_UCODE_BIND.getKey() + ucode, "organizationCode", iamInstitution.getInstitutionCode(), openApiGlobal.getUcodeTTL());
                    return CyResultGenUtil.builder(new CyPersistModel(1),
                            CyMessCons.MESSAGE_ALERT_SUCCESS,
                            CyMessCons.MESSAGE_ALERT_ERROR,
                            ucode);
                } else {
                    throw new CyServiceException(OpenApiCons.USER_NOT_EXIST);
                }
            } else {
                redisSetKeyValue.accessIsNotLegal(request);
                throw new CyServiceException(OpenApiCons.DATA_DECRYPTION_FAILED_OR_COMPARISON_FAILED);
            }
        } else {
            redisSetKeyValue.accessIsNotLegal(request);
            throw new CyServiceException(OpenApiCons.IP_LOCKED_OR_NOT_MATCH);
        }
    }

    @Override
    public CyResult login(HttpServletRequest request, HttpServletResponse response, String uc) {
        //全局拦截
        accessControl.ipGlobalLoginInterceptor(request, response);
        //参数校验
        if (StringUtils.isNotEmpty(uc)) {
            try {
                String token = cyRedisService.get(RedisKeyDisposition.OPEN_API_UCODE.getKey() + uc).toString();
                String username = cyRedisService.get(RedisKeyDisposition.OPEN_API_UCODE_USER.getKey() + uc).toString();
                if (StringUtils.isNotEmpty(token)) {
                    cyRedisService.del(RedisKeyDisposition.OPEN_API_UCODE.getKey() + uc);
                    cyRedisService.del(RedisKeyDisposition.OPEN_API_UCODE_USER.getKey() + uc);
                    //向redis中写入正常登录token
                    cyRedisService.set(RedisKeyDisposition.LOGIN_USER_TOKEN.getKey() + CyAddressUtils.IpUtils.getIpAddr(request) + username, token, Long.valueOf(cyGlobal.getLOGIN_TTL()));
                    return CyResultGenUtil.builder(new CyPersistModel(1),
                            CyMessCons.MESSAGE_ALERT_SUCCESS,
                            CyMessCons.MESSAGE_ALERT_ERROR,
                            token);
                } else {
                    throw new CyServiceException(OpenApiCons.TOKEN_INVALID_OR_ERROR);
                }
            } catch (Exception e) {
                redisSetKeyValue.loginAccessIsNotLegal(request);
                throw new CyServiceException(OpenApiCons.DATA_DECRYPTION_FAILED_OR_COMPARISON_FAILED);
            }
        } else {
            redisSetKeyValue.loginAccessIsNotLegal(request);
            throw new CyServiceException(OpenApiCons.DATA_DECRYPTION_FAILED_OR_COMPARISON_FAILED);
        }
    }
}
