package org.rcisoft.openapi.iaminstitution.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.core.util.CyRSAUtil;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.model.CyGridModel;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;


import org.rcisoft.openapi.iaminstitution.entity.IamInstitution;
import org.rcisoft.openapi.iaminstitution.service.IamInstitutionService;

import java.util.List;

/**
* Created by cy on 2024年7月19日 下午1:57:38.
*/
@RestController
@RequestMapping("/iaminstitution")
public class IamInstitutionController extends CyPaginationController<IamInstitution> {


    @Autowired
    private IamInstitutionService iamInstitutionServiceImpl;

    //@PreAuthorize("@cyPerm.hasPerm('sys:institution:add')")
    @CyOpeLogAnno(title = "system-open机构表管理-新增open机构表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="添加open机构表", notes="添加open机构表")
    @PostMapping(value = "/add")
    public CyResult add(@Valid IamInstitution iamInstitution, BindingResult bindingResult) {
        CyPersistModel data = iamInstitutionServiceImpl.persist(iamInstitution);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        iamInstitution);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:institution:delete')")
    @CyOpeLogAnno(title = "system-open机构表管理-删除open机构表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="逻辑删除open机构表", notes="逻辑删除open机构表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable int businessId,IamInstitution iamInstitution) {
        iamInstitution.setBusinessId(businessId);
        CyPersistModel data = iamInstitutionServiceImpl.removeLogical(iamInstitution);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:institution:delete')")
    @CyOpeLogAnno(title = "system-open机构表管理-删除open机构表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="删除open机构表", notes="删除open机构表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable int businessId,IamInstitution iamInstitution) {
        iamInstitution.setBusinessId(businessId);
        CyPersistModel data = iamInstitutionServiceImpl.remove(iamInstitution);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:institution:update')")
    @CyOpeLogAnno(title = "system-open机构表管理-修改open机构表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改open机构表", notes="修改open机构表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable int businessId, @Valid IamInstitution iamInstitution, BindingResult bindingResult) {
        iamInstitution.setBusinessId(businessId);
        CyPersistModel data = iamInstitutionServiceImpl.merge(iamInstitution);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        iamInstitution);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:institution:query')")
    @CyOpeLogAnno(title = "system-open机构表管理-查询open机构表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单一open机构表", notes="查询单一open机构表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable int businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        iamInstitutionServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:institution:list')")
    @CyOpeLogAnno(title = "system-open机构表管理-查询open机构表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询open机构表集合", notes="查询open机构表集合")
    @GetMapping(value = "/listAll")
    public CyResult listAll(IamInstitution iamInstitution) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            iamInstitutionServiceImpl.findAll(iamInstitution));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:institution:list')")
    @CyOpeLogAnno(title = "system-open机构表管理-查询open机构表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="分页查询open机构表集合", notes="分页查询open机构表集合")
    @GetMapping(value = "/list")
    public CyGridModel listByPagination(IamInstitution iamInstitution) {
        iamInstitutionServiceImpl.findAllByPagination(getPaginationUtility(), iamInstitution);
        return getGridModelResponse();
    }

    @CyOpeLogAnno(title = "system-open机构表管理-查询open机构表", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出open机构表信息", notes = "导出open机构表信息")
    @GetMapping(value = "/export")
    public void outIamInstitution(HttpServletResponse response,IamInstitution iamInstitution,@PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="open机构表信息.xls";break;
            case "1": excelName="open机构表信息.xlsx";break;
            case "2": excelName="open机构表信息.csv";break;
        }
        List<IamInstitution> iamInstitutionList = iamInstitutionServiceImpl.export(iamInstitution);
        CyEpExcelUtil.exportExcel(iamInstitutionList, "open机构表信息", "open机构表信息", IamInstitution.class, excelName, response);
    }
    /**
     * 解密
     * */
    @GetMapping("/decrypt")
    public CyResult decrypt(@PathVariable String secretKey ) throws Exception {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
                CyRSAUtil.decryptByPrivateKey(null, secretKey)
        );

    }
}
