package org.rcisoft.openapi.iaminstitution.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.openapi.api.log.ApiLogAnno;
import org.rcisoft.openapi.iaminstitution.dao.IamInstitutionRepository;
import org.rcisoft.openapi.iaminstitution.entity.IamInstitution;
import org.rcisoft.openapi.iaminstitution.service.IamInstitutionService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.rcisoft.core.model.CyPageInfo;

import java.util.List;
import lombok.extern.slf4j.Slf4j;

/**
 * Created by cy on 2024年7月19日 下午1:57:38.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class IamInstitutionServiceImpl extends ServiceImpl<IamInstitutionRepository,IamInstitution>  implements IamInstitutionService {

    @Autowired
    private IamInstitutionRepository iamInstitutionRepository;

    /**
    * 保存 open机构表
    * @param iamInstitution
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(IamInstitution iamInstitution){
        //增加操作
        int line = baseMapper.insert(iamInstitution);
        log.debug(CyUserUtil.getAuthenUsername()+"新增了ID为"+
            iamInstitution.getBusinessId()+"的open机构表信息");
        return new CyPersistModel(line);
    }

    /**
    * 删除 open机构表
    * @param iamInstitution
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(IamInstitution iamInstitution){
        int line = baseMapper.realDelete(iamInstitution);
        log.debug(CyUserUtil.getAuthenUsername()+"删除了ID为"+
            iamInstitution.getBusinessId()+"的open机构表信息");
        return new CyPersistModel(line);
    }

    /**
    * 逻辑删除 open机构表
    * @param iamInstitution
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(IamInstitution iamInstitution){
        iamInstitution.setDeleted();
        int line = baseMapper.deleteById(iamInstitution);
            log.debug(CyUserUtil.getAuthenUsername()+"逻辑删除了ID为"+
                iamInstitution.getBusinessId()+"的open机构表信息");
            return new CyPersistModel(line);
    }

    /**
    * 修改 open机构表
    * @param iamInstitution
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(IamInstitution iamInstitution){
        int line = baseMapper.updateById(iamInstitution);
        log.debug(CyUserUtil.getAuthenUsername()+"修改了ID为"+ iamInstitution.getBusinessId()+"的open机构表信息");
        return new CyPersistModel(line);
    }

    /**
    * 根据id查询 open机构表
    * @param id
    * @return
    */
    @Override
    public IamInstitution findById(int id){
        return baseMapper.selectById(id);
    }

    /**
    * 分页查询 open机构表
    * @param iamInstitution
    * @return
    */
    @Override
    public IPage<IamInstitution> findAllByPagination(CyPageInfo<IamInstitution> paginationUtility,
        IamInstitution iamInstitution){
        return baseMapper.queryIamInstitutionsPaged(paginationUtility,iamInstitution);

    }

    /**
    * 查询list open机构表
    * @param iamInstitution
    * @return
    */
    @Override
    public List<IamInstitution> findAll(IamInstitution iamInstitution){
        return baseMapper.queryIamInstitutions(iamInstitution);

    }

    /**
    * 导出open机构表
    * @return
    */
    @Override
    public List<IamInstitution> export(IamInstitution iamInstitution) {
        List<IamInstitution> iamInstitutionList = baseMapper.queryIamInstitutions(iamInstitution);
        return iamInstitutionList;
    }

    @Override
    public IamInstitution findByIp(String ip) {
        return iamInstitutionRepository.findByIp(ip);
    }

}
