package org.rcisoft.openapi.openapilog.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.model.CyGridModel;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;


import org.rcisoft.openapi.openapilog.entity.OpenApiLog;
import org.rcisoft.openapi.openapilog.service.OpenApiLogService;

import java.util.List;

/**
* Created by cy on 2024年7月19日 下午1:57:38.
*/
@RestController
@RequestMapping("/openapilog")
public class OpenApiLogController extends CyPaginationController<OpenApiLog> {


    @Autowired
    private OpenApiLogService openApiLogServiceImpl;

    //@PreAuthorize("@cyPerm.hasPerm('sys:nApiLog:add')")
    @CyOpeLogAnno(title = "system-开放api操作日志管理-新增开放api操作日志", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="添加开放api操作日志", notes="添加开放api操作日志")
    @PostMapping(value = "/add")
    public CyResult add(@Valid OpenApiLog openApiLog, BindingResult bindingResult) {
        CyPersistModel data = openApiLogServiceImpl.persist(openApiLog);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        openApiLog);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:nApiLog:delete')")
    @CyOpeLogAnno(title = "system-开放api操作日志管理-删除开放api操作日志", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="逻辑删除开放api操作日志", notes="逻辑删除开放api操作日志")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable int businessId,OpenApiLog openApiLog) {
        openApiLog.setBusinessId(businessId);
        CyPersistModel data = openApiLogServiceImpl.removeLogical(openApiLog);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:nApiLog:delete')")
    @CyOpeLogAnno(title = "system-开放api操作日志管理-删除开放api操作日志", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="删除开放api操作日志", notes="删除开放api操作日志")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable int businessId,OpenApiLog openApiLog) {
        openApiLog.setBusinessId(businessId);
        CyPersistModel data = openApiLogServiceImpl.remove(openApiLog);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:nApiLog:update')")
    @CyOpeLogAnno(title = "system-开放api操作日志管理-修改开放api操作日志", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改开放api操作日志", notes="修改开放api操作日志")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable int businessId, @Valid OpenApiLog openApiLog, BindingResult bindingResult) {
        openApiLog.setBusinessId(businessId);
        CyPersistModel data = openApiLogServiceImpl.merge(openApiLog);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        openApiLog);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:nApiLog:query')")
    @CyOpeLogAnno(title = "system-开放api操作日志管理-查询开放api操作日志", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单一开放api操作日志", notes="查询单一开放api操作日志")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable int businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        openApiLogServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:nApiLog:list')")
    @CyOpeLogAnno(title = "system-开放api操作日志管理-查询开放api操作日志", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询开放api操作日志集合", notes="查询开放api操作日志集合")
    @GetMapping(value = "/listAll")
    public CyResult listAll(OpenApiLog openApiLog) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            openApiLogServiceImpl.findAll(openApiLog));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:nApiLog:list')")
    @CyOpeLogAnno(title = "system-开放api操作日志管理-查询开放api操作日志", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="分页查询开放api操作日志集合", notes="分页查询开放api操作日志集合")
    @GetMapping(value = "/list")
    public CyGridModel listByPagination(OpenApiLog openApiLog) {
        openApiLogServiceImpl.findAllByPagination(getPaginationUtility(), openApiLog);
        return getGridModelResponse();
    }

    @CyOpeLogAnno(title = "system-开放api操作日志管理-查询开放api操作日志", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出开放api操作日志信息", notes = "导出开放api操作日志信息")
    @GetMapping(value = "/export")
    public void outOpenApiLog(HttpServletResponse response,OpenApiLog openApiLog,@PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="开放api操作日志信息.xls";break;
            case "1": excelName="开放api操作日志信息.xlsx";break;
            case "2": excelName="开放api操作日志信息.csv";break;
        }
        List<OpenApiLog> openApiLogList = openApiLogServiceImpl.export(openApiLog);
        CyEpExcelUtil.exportExcel(openApiLogList, "开放api操作日志信息", "开放api操作日志信息", OpenApiLog.class, excelName, response);
    }
}
