package org.rcisoft.openapi.openapilog.service.impl;

import cn.hutool.json.JSONUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.google.gson.JsonArray;
import com.google.gson.JsonObject;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.ArrayUtils;
import org.apache.commons.lang3.StringUtils;
import org.aspectj.lang.JoinPoint;
import org.aspectj.lang.reflect.MethodSignature;
import org.rcisoft.core.component.CyCxtTreadComp;
import org.rcisoft.core.component.CySpringBeanComp;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.log.impl.CyOpeLogStandaloneSvcImpl;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.service.CyRedisService;
import org.rcisoft.core.util.CyAddressUtils;
import org.rcisoft.core.util.CyServletUtil;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.openapi.api.log.ApiLogAnno;
import org.rcisoft.openapi.api.log.OpenApiAsyncFactory;
import org.rcisoft.openapi.api.log.OpenApiAsyncManager;
import org.rcisoft.openapi.api.redisconfig.RedisKeyDisposition;
import org.rcisoft.openapi.iaminstitution.entity.IamInstitution;
import org.rcisoft.openapi.iaminstitution.service.impl.IamInstitutionServiceImpl;
import org.rcisoft.openapi.openapilog.dao.OpenApiLogRepository;
import org.rcisoft.openapi.openapilog.entity.OpenApiLog;
import org.rcisoft.openapi.openapilog.service.OpenApiLogService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * Created by cy on 2024年7月19日 下午1:57:38.
 */
@Service
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class OpenApiLogServiceImpl extends ServiceImpl<OpenApiLogRepository, OpenApiLog> implements OpenApiLogService {
    /**
     * prefix 前缀
     */
    public static final String OPELOG_VAR_PREFIX = "cy_log_";
    /**
     * 取消日志
     */
    public static final String OPELOG_CANCEL_LOG = "cy_log_cancel";
    @Autowired(required = false)
    CyRedisService cyRedisService;
    @Value("${cy.systemName}")
    private String systemValue;
    @Value("${cy.model.opeLogDb.ignorePackage:}")
    private String[] ignorePackage;

    /**
     * 保存 开放api操作日志
     *
     * @param openApiLog
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(OpenApiLog openApiLog) {
        //增加操作
        int line = baseMapper.insert(openApiLog);
        log.debug(CyUserUtil.getAuthenUsername() + "新增了ID为" +
                openApiLog.getBusinessId() + "的开放api操作日志信息");
        return new CyPersistModel(line);
    }

    /**
     * 删除 开放api操作日志
     *
     * @param openApiLog
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(OpenApiLog openApiLog) {
        int line = baseMapper.realDelete(openApiLog);
        log.debug(CyUserUtil.getAuthenUsername() + "删除了ID为" +
                openApiLog.getBusinessId() + "的开放api操作日志信息");
        return new CyPersistModel(line);
    }

    /**
     * 逻辑删除 开放api操作日志
     *
     * @param openApiLog
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(OpenApiLog openApiLog) {
        openApiLog.setDeleted();
        int line = baseMapper.deleteById(openApiLog);
        log.debug(CyUserUtil.getAuthenUsername() + "逻辑删除了ID为" +
                openApiLog.getBusinessId() + "的开放api操作日志信息");
        return new CyPersistModel(line);
    }

    /**
     * 修改 开放api操作日志
     *
     * @param openApiLog
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(OpenApiLog openApiLog) {
        int line = baseMapper.updateById(openApiLog);
        log.debug(CyUserUtil.getAuthenUsername() + "修改了ID为" + openApiLog.getBusinessId() + "的开放api操作日志信息");
        return new CyPersistModel(line);
    }

    /**
     * 根据id查询 开放api操作日志
     *
     * @param id
     * @return
     */
    @Override
    public OpenApiLog findById(int id) {
        return baseMapper.selectById(id);
    }

    /**
     * 分页查询 开放api操作日志
     *
     * @param openApiLog
     * @return
     */
    @Override
    public IPage<OpenApiLog> findAllByPagination(CyPageInfo<OpenApiLog> paginationUtility,
                                                 OpenApiLog openApiLog) {
        return baseMapper.queryOpenApiLogsPaged(paginationUtility, openApiLog);

    }

    /**
     * 查询list 开放api操作日志
     *
     * @param openApiLog
     * @return
     */
    @Override
    public List<OpenApiLog> findAll(OpenApiLog openApiLog) {
        return baseMapper.queryOpenApiLogs(openApiLog);

    }

    /**
     * 导出开放api操作日志
     *
     * @return
     */
    @Override
    public List<OpenApiLog> export(OpenApiLog openApiLog) {
        List<OpenApiLog> openApiLogList = baseMapper.queryOpenApiLogs(openApiLog);
        return openApiLogList;
    }

    @Override
    public void keepALog(ApiLogAnno controllerLog, JoinPoint joinPoint, Exception e, Object jsonResult) {
        // 请求的地址
        String ip = CyAddressUtils.IpUtils.getIpAddr(CyServletUtil.getRequest());
        // 设置方法名称
        String className = joinPoint.getTarget().getClass().getName();
        /**
         * @date 2021-05-07 增加配置项   忽略系统日志 org.rcisoft.sys
         */
        boolean ignoreFlag = false;
        if (StringUtils.isNotEmpty(className) && ArrayUtils.isNotEmpty(ignorePackage)) {
            for (String ignore : ignorePackage) {
                if (className.contains(ignore)) {
                    ignoreFlag = true;
                    break;
                }
            }
        }
        // 忽略日志
        if (ignoreFlag && e == null)
            return;

        /**
         * @date 2021-05-15 增加配置，取消日志
         */
        Object cancel = CyCxtTreadComp.get(OPELOG_CANCEL_LOG);
        if (cancel != null && e == null) {
            CyCxtTreadComp.remove(OPELOG_CANCEL_LOG);
            return;
        }

        String methodName = joinPoint.getSignature().getName();


        if (e != null) {
            // *========异常日志=========*//
            OpenApiLog openApiLog = new OpenApiLog();
            openApiLog.setFlag(String.valueOf(1));
            openApiLog.setIp(ip);
            // 返回参数
            openApiLog.setMethod(className + "." + methodName + "()");
            // 设置请求方式
            openApiLog.setRequest(CyServletUtil.getRequest().getMethod());
            //错误消息
            openApiLog.setErrorMessage(StringUtils.substring(e.getMessage(), 0, 2000));
//            openApiLog.setRequestData(CyServletUtil.getRequest().getRequestURI());
            openApiLog.setRemarks(CyServletUtil.getRequest().getRequestURI());
            // 处理设置注解上的参数
            try {
                getControllerMethodDescription(joinPoint, controllerLog, openApiLog);
            } catch (Exception e1) {
                log.error("异常信息:{}", e1.getMessage());
            }
            CyServiceException cyServiceException = (CyServiceException) e;
            JsonObject jsonObject = new JsonObject();
            jsonObject.addProperty("code", cyServiceException.getCode());
            jsonObject.addProperty("data", (String) cyServiceException.getData());
            jsonObject.addProperty("message", cyServiceException.getMessage());


            if (openApiLog.getTitle().contains("查询") || controllerLog.businessType().ordinal() == 10)
                openApiLog.setResponseData("");
            else
                openApiLog.setResponseData(jsonObject.toString());
            IamInstitution byIp = CySpringBeanComp.getBean(IamInstitutionServiceImpl.class).findByIp(ip);
            if (byIp != null) {
                openApiLog.setOrganizationalStructure(byIp.getOrganizationalStructure());
                openApiLog.setInstitutionCode(byIp.getInstitutionCode());
            }


            // 操作时间
            openApiLog.setRequestTime(new Date());
            // 保存数据库
            OpenApiAsyncManager.me().execute(OpenApiAsyncFactory.recordOper(openApiLog));
        } else {
            // *========操作日志=========*//
            OpenApiLog openApiLog = new OpenApiLog();
            openApiLog.setFlag(String.valueOf(1));
            openApiLog.setIp(ip);
            openApiLog.setMethod(className + "." + methodName + "()");
            // 设置请求方式
            openApiLog.setRequest(CyServletUtil.getRequest().getMethod());
            openApiLog.setRemarks(CyServletUtil.getRequest().getRequestURI());
            // 处理设置注解上的参数
            try {
                getControllerMethodDescription(joinPoint, controllerLog, openApiLog);
            } catch (Exception e1) {
                log.error("异常信息:{}", e1.getMessage() + e1.getClass().toString());
            }
            // 返回参数
            if (openApiLog.getTitle().contains("查询") || controllerLog.businessType().ordinal() == 10)
                openApiLog.setResponseData("");
            else
                openApiLog.setResponseData(JSONUtil.toJsonStr(jsonResult));
            // 操作时间
            openApiLog.setRequestTime(new Date());
            IamInstitution byIp = CySpringBeanComp.getBean(IamInstitutionServiceImpl.class).findByIp(ip);
            if (byIp != null) {
                openApiLog.setOrganizationalStructure(byIp.getOrganizationalStructure());
                openApiLog.setInstitutionCode(byIp.getInstitutionCode());
            }
            //将requestData 转化成map并提判断uc是否存在
            Map<String, Object> requestDataMap = JSONUtil.toBean(openApiLog.getRequestData(), Map.class);
            String uc = (String) requestDataMap.get("uc");
            if (StringUtils.isNotEmpty(uc)) {
                if (cyRedisService.hasKey(RedisKeyDisposition.OPEN_API_UCODE_BIND.getKey() + uc)) {
                    openApiLog.setOrganizationalStructure((String) cyRedisService.hget(RedisKeyDisposition.OPEN_API_UCODE_BIND.getKey() + uc, "theNameOfTheOrganization"));
                    openApiLog.setInstitutionCode((String) cyRedisService.hget(RedisKeyDisposition.OPEN_API_UCODE_BIND.getKey() + uc, "organizationCode"));
                    //删除key
                    cyRedisService.del(RedisKeyDisposition.OPEN_API_UCODE_BIND.getKey() + uc);
                }
            }
            //保存数据库
            OpenApiAsyncManager.me().execute(OpenApiAsyncFactory.recordOper(openApiLog));
        }
    }

    /**
     * 获取注解中对方法的描述信息 用于Controller层注解
     *
     * @param log       日志
     * @param logEntity 操作日志
     * @throws Exception
     */
    public void getControllerMethodDescription(JoinPoint joinPoint, ApiLogAnno log, OpenApiLog logEntity) throws Exception {
        // 设置action动作
        logEntity.setBusinessType(String.valueOf(log.businessType().ordinal()));
        String title = log.title().replace("system", systemValue);
        // 参数
        Map<String, Object> param = CyCxtTreadComp.threadLocal.get();
        if (null != param)
            for (Map.Entry entry : param.entrySet()) {
                /**
                 * 批量替换 日志 title
                 */
                if (null != entry.getKey() &&
                        entry.getKey().toString().startsWith(CyOpeLogStandaloneSvcImpl.OPELOG_VAR_PREFIX))
                    title = title.replace(entry.getKey().toString(),
                            (null == entry.getValue() ? null : entry.getValue().toString()));
            }
        // 设置标题
        logEntity.setTitle(title);
        // 设置操作人类别
//        logEntity.setOperatorType(log.operatorType().ordinal());
        // 是否需要保存request，参数和值
        if (log.isSaveRequestData()) {
            // 获取参数的信息，传入到数据库中。
            String requestValue = getRequestValue(joinPoint).replaceAll("\\s", "");
            requestValue = requestValue.replaceAll(";", "");
            //get请求 将 string 转化为 json map
            if (logEntity.getRequest().equals("GET")) {
                // 切割字符串
                String[] pairs = requestValue.split("&");

                // 创建一个 JsonArray 对象
                JsonArray jsonArray = new JsonArray();

                // 遍历每个键值对，构建 JsonObject 并添加到 JsonArray
                for (String pair : pairs) {
                    String[] parts = pair.split(":");
                    if (parts.length == 2) {
                        JsonObject jsonObject = new JsonObject();
                        jsonObject.addProperty(parts[0], parts[1]);
                        jsonArray.add(jsonObject);
                    }
                }

                // 使用 Gson 转换为 JSON 字符串 去=去掉【】
                String jsonString = jsonArray.toString();

                // 去除最外层的 [ 和 ]
                requestValue = jsonString.substring(1, jsonString.length() - 1);
            }

            logEntity.setRequestData(requestValue);
        }
    }

    /**
     * 获取请求的参数，放到log中
     *
     * @throws Exception 异常
     */
    private String getRequestValue(JoinPoint joinPoint) throws Exception {
        /*String requestMethod = operLog.getRequestMethod();
        if (HttpMethod.PUT.name().equals(requestMethod) || HttpMethod.POST.name().equals(requestMethod))
        {
            String params = argsArrayToString(joinPoint.getArgs());
            operLog.setOperParam(StringUtils.substring(params, 0, 2000));
        }
        else
        {
            Map<?, ?> paramsMap = (Map<?, ?>) CyServletUtils.getRequest().getAttribute(HandlerMapping.URI_TEMPLATE_VARIABLES_ATTRIBUTE);
            operLog.setOperParam(StringUtils.substring(paramsMap.toString(), 0, 2000));
        }*/
        String[] argNames = ((MethodSignature) joinPoint.getSignature()).getParameterNames(); // 参数名
        String params = argsArrayToString(joinPoint.getArgs(), argNames);
        return StringUtils.substring(params, 0, 2000);
    }


    /**
     * 参数拼装
     */
    private String argsArrayToString(Object[] paramsArray, String[] argNames) {
        String params = "";
        if (paramsArray != null && paramsArray.length > 0) {
            for (int i = 0; i < paramsArray.length; i++) {
                if (!isFilterObject(paramsArray[i])) {
                    //对象类型，
                    Object jsonObj = null;
                    try {
                        jsonObj = JSONUtil.toJsonPrettyStr(paramsArray[i]);
                    } catch (Exception e) {
                        //json 解析异常
                        jsonObj = argNames[i] + " : " + paramsArray[i];
                    }
                    params += jsonObj.toString() + "  ;  ";
                }
            }
        }
        return params.trim();
    }


    /**
     * 判断是否需要过滤的对象。
     *
     * @param o 对象信息。
     * @return 如果是需要过滤的对象，则返回true；否则返回false。
     */
    public boolean isFilterObject(final Object o) {
        return o instanceof MultipartFile || o instanceof HttpServletRequest || o instanceof HttpServletResponse;
    }
}
