package org.rcisoft.pc.pcgroup.controller;


/*固定导入*/

import com.baomidou.mybatisplus.core.metadata.IPage;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.lang3.StringUtils;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.pc.pcgroup.dto.BLessonDTO;
import org.rcisoft.pc.pcgroup.dto.BLessonPersonDTO;
import org.rcisoft.pc.pcgroup.dto.GroupCourseDTO;
import org.rcisoft.pc.pcgroup.dto.GroupPersonDTO;
import org.rcisoft.pc.pcgroup.dto.GroupRecordDTO;
import org.rcisoft.pc.pcgroup.dto.GroupUserDTO;
import org.rcisoft.pc.pcgroup.dto.PcGroupCourseDTO;
import org.rcisoft.pc.pcgroup.dto.PcGroupDTO;
import org.rcisoft.pc.pcgroup.entity.PcGroup;
import org.rcisoft.pc.pcgroup.service.PcGroupService;
import org.rcisoft.result.ResultServiceEnums;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

/**
 * Created by cy on 2024年4月10日 下午4:20:18.
 */
@RestController
@RequestMapping("/pcgroup")
public class PcGroupController extends CyPaginationController<PcGroup> {


    @Autowired
    private PcGroupService pcGroupServiceImpl;

    //@PreAuthorize("@cyPerm.hasPerm('sys:roup:add')")
    @CyOpeLogAnno(title = "system-小组表管理-新增小组表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value = "添加小组表", notes = "添加小组表")
    @PostMapping(value = "/add")
    public CyResult add(@RequestBody PcGroup pcGroup, BindingResult bindingResult) {
        CyPersistModel data = pcGroupServiceImpl.persist(pcGroup);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                pcGroup);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:roup:delete')")
    @CyOpeLogAnno(title = "system-小组表管理-删除小组表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value = "逻辑删除小组表", notes = "逻辑删除小组表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable int businessId, PcGroup pcGroup) {
        pcGroup.setBusinessId(businessId);
        CyPersistModel data = pcGroupServiceImpl.removeLogical(pcGroup);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:roup:delete')")
    @CyOpeLogAnno(title = "system-小组表管理-删除小组表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value = "删除小组表", notes = "删除小组表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable int businessId, PcGroup pcGroup) {
        pcGroup.setBusinessId(businessId);
        CyPersistModel data = pcGroupServiceImpl.remove(pcGroup);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:roup:update')")
    @CyOpeLogAnno(title = "system-小组表管理-修改小组表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value = "修改小组表", notes = "修改小组表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable int businessId, @RequestBody PcGroup pcGroup, BindingResult bindingResult) {
        pcGroup.setBusinessId(businessId);

        //先设置组长在看组员情况
        CyPersistModel data = pcGroupServiceImpl.merge(pcGroup);

        //除了现在设置的组长之外查询出当前组中所有组员有谁在当组长
        pcGroupServiceImpl.identityOfTheTeamLeader(pcGroup);

        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                pcGroup);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:roup:query')")
    @CyOpeLogAnno(title = "system-小组表管理-查询小组表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询单一小组表", notes = "查询单一小组表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable int businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                pcGroupServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:roup:list')")
    @CyOpeLogAnno(title = "system-小组表管理-查询小组表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询小组表集合", notes = "查询小组表集合")
    @GetMapping(value = "/listAll")
    public CyResult listAll(PcGroup pcGroup) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                pcGroupServiceImpl.findAll(pcGroup));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:roup:list')")
    @CyOpeLogAnno(title = "system-小组表管理-查询小组表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "分页查询小组表集合", notes = "分页查询小组表集合")
    @GetMapping(value = "/list")
    public CyGridModel listByPagination(PcGroup pcGroup) {
        pcGroupServiceImpl.findAllByPagination(getPaginationUtility(), pcGroup);
        return getGridModelResponse();
    }

    @CyOpeLogAnno(title = "system-小组表管理-查询小组表", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出小组表信息", notes = "导出小组表信息")
    @GetMapping(value = "/export")
    public void outPcGroup(HttpServletResponse response, PcGroup pcGroup, @PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName = "";
        switch (excelId) {
            case "0":
                excelName = "小组表信息.xls";
                break;
            case "1":
                excelName = "小组表信息.xlsx";
                break;
            case "2":
                excelName = "小组表信息.csv";
                break;
        }
        List<PcGroup> pcGroupList = pcGroupServiceImpl.export(pcGroup);
        CyEpExcelUtil.exportExcel(pcGroupList, "小组表信息", "小组表信息", PcGroup.class, excelName, response);
    }

    @CyOpeLogAnno(title = "system-小组表管理-查询小组表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询当前登录用户全部关联小组信息", notes = "查询当前登录用户全部关联小组信息")
    @GetMapping(value = "/listAllLinkGroup")
    public CyResult listAllLinkGroup(PcGroup pcGroup) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                pcGroupServiceImpl.listAllLinkGroup(pcGroup));
    }

    @CyOpeLogAnno(title = "system-数据统计-小组页面", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询数据统计小组分页查询", notes = "查询数据统计小组分页查询")
    @GetMapping(value = "/groupListAll")
    public IPage<PcGroupDTO> groupListAll(PcGroupDTO pcGroup) {
        return pcGroupServiceImpl.groupListAll(getPaginationUtility(), pcGroup);
    }

    @CyOpeLogAnno(title = "system-数据统计-小组页面", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询数据统计小组组内人数详情", notes = "查询数据统计小组组内人数详情")
    @GetMapping(value = "/groupDetailsAll")
    public IPage<GroupPersonDTO> groupDetailsAll(PcGroupDTO pcGroup) {
        if (StringUtils.isBlank(pcGroup.getGroupId())) {
            throw new CyServiceException(ResultServiceEnums.PLEASE_SELECT_GROUP.getCode(), ResultServiceEnums.PLEASE_SELECT_GROUP.getMessage());
        }
        return pcGroupServiceImpl.groupDetailsAll(getPaginationUtility(), pcGroup);
    }

    @CyOpeLogAnno(title = "system-数据统计-小组页面", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询数据统计小组组内必修课程数", notes = "查询数据统计小组组内必修课程数")
    @GetMapping(value = "/groupCourseAll")
    public IPage<GroupCourseDTO> groupCourseAll(PcGroupDTO pcGroup) {
        if (StringUtils.isBlank(pcGroup.getGroupId())) {
            throw new CyServiceException(ResultServiceEnums.PLEASE_SELECT_GROUP.getCode(), ResultServiceEnums.PLEASE_SELECT_GROUP.getMessage());
        }
        return pcGroupServiceImpl.groupCourseAll(getPaginationUtility(), pcGroup);
    }

    @CyOpeLogAnno(title = "system-数据统计-小组页面", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询数据统计小组组内未完成课程数", notes = "查询数据统计小组组内未完成课程数")
    @GetMapping(value = "/courseIncompleteAll")
    public IPage<PcGroupCourseDTO> courseIncompleteAll(PcGroupDTO pcGroup) {
        if (StringUtils.isBlank(pcGroup.getGroupId())) {
            throw new CyServiceException(ResultServiceEnums.PLEASE_SELECT_GROUP.getCode(), ResultServiceEnums.PLEASE_SELECT_GROUP.getMessage());
        }
        return pcGroupServiceImpl.courseIncompleteAll(getPaginationUtility(), pcGroup);
    }

    @CyOpeLogAnno(title = "system-数据统计-小组页面", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询数据统计小组组内已完成课程数", notes = "查询数据统计小组组内已完成课程数")
    @GetMapping(value = "/courseCompletedAll")
    public IPage<PcGroupCourseDTO> courseCompletedAll(PcGroupDTO pcGroup) {
        if (StringUtils.isBlank(pcGroup.getGroupId())) {
            throw new CyServiceException(ResultServiceEnums.PLEASE_SELECT_GROUP.getCode(), ResultServiceEnums.PLEASE_SELECT_GROUP.getMessage());
        }
        return pcGroupServiceImpl.courseCompletedAll(getPaginationUtility(), pcGroup);
    }

    @CyOpeLogAnno(title = "system-数据统计-小组页面", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询数据统计小组组内必修考核记录数", notes = "查询数据统计小组组内必修考核记录数")
    @GetMapping(value = "/groupRecordsAll")
    public IPage<GroupRecordDTO> groupRecordsAll(PcGroupDTO pcGroup) {
        if (StringUtils.isBlank(pcGroup.getGroupId())) {
            throw new CyServiceException(ResultServiceEnums.PLEASE_SELECT_GROUP.getCode(), ResultServiceEnums.PLEASE_SELECT_GROUP.getMessage());
        }
        return pcGroupServiceImpl.groupRecordsAll(getPaginationUtility(), pcGroup);
    }

    @CyOpeLogAnno(title = "system-数据统计-考核页面", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "数据统计考核页面分页查询", notes = "数据统计考核页面分页查询")
    @GetMapping(value = "/courseExamineAll")
    public IPage<BLessonDTO> courseExamineAll(BLessonDTO bLessonDTO) {
        return pcGroupServiceImpl.courseExamineAll(getPaginationUtility(), bLessonDTO);
    }

    @CyOpeLogAnno(title = "system-数据统计-考核页面", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "数据统计考核页面考核人数分页查询", notes = "数据统计考核页面考核人数分页查询")
    @GetMapping(value = "/personExamine")
    public IPage<BLessonPersonDTO> personExamine(BLessonPersonDTO bLessonDTO) {
        return pcGroupServiceImpl.personExamine(getPaginationUtility(), bLessonDTO);
    }

    @CyOpeLogAnno(title = "system-数据统计-考核页面", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "数据统计考核页面满分人数分页查询", notes = "数据统计考核页面满分人数分页查询")
    @GetMapping(value = "/examineFullMarks")
    public IPage<BLessonPersonDTO> examineFullMarks(BLessonPersonDTO bLessonDTO) {
        return pcGroupServiceImpl.examineFullMarks(getPaginationUtility(), bLessonDTO);
    }

    @CyOpeLogAnno(title = "system-数据统计-考核页面", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "数据统计考核页面及格人数分页查询", notes = "数据统计考核页面及格人数分页查询")
    @GetMapping(value = "/examineFullPass")
    public IPage<BLessonPersonDTO> examineFullPass(BLessonPersonDTO bLessonDTO) {
        return pcGroupServiceImpl.examineFullPass(getPaginationUtility(), bLessonDTO);
    }

    @CyOpeLogAnno(title = "system-数据统计-小组页面", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询数据统计小组组内人数详情", notes = "查询数据统计小组组内人数详情")
    @GetMapping(value = "/groupUser")
    public IPage<GroupUserDTO> groupUser(GroupUserDTO groupUserDTO) {
        return pcGroupServiceImpl.groupUser(getPaginationUtility(), groupUserDTO);
    }
}
