package org.rcisoft.pc.pcgroup.dao;

import com.baomidou.mybatisplus.core.metadata.IPage;

import java.util.ArrayList;
import java.util.List;

import org.apache.ibatis.annotations.Param;
import org.rcisoft.core.mapper.CyBaseMapper;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.pc.pcgroup.dto.BLessonDTO;
import org.rcisoft.pc.pcgroup.dto.BLessonPersonDTO;
import org.rcisoft.pc.pcgroup.dto.GroupCourseDTO;
import org.rcisoft.pc.pcgroup.dto.GroupPersonDTO;
import org.rcisoft.pc.pcgroup.dto.GroupRecordDTO;
import org.rcisoft.pc.pcgroup.dto.GroupUserDTO;
import org.rcisoft.pc.pcgroup.dto.PcGroupCourseDTO;
import org.rcisoft.pc.pcgroup.dto.PcGroupDTO;
import org.rcisoft.pc.pcgroup.entity.PcGroup;
import org.rcisoft.pc.pcgroupuser.entity.PcGroupUser;

/**
 * Created with cy on 2024年4月10日 下午4:20:18.
 */

public interface PcGroupRepository extends CyBaseMapper<PcGroup> {


    List<PcGroup> queryPcGroups(@Param("entity") PcGroup pcGroup);

    List<PcGroup> listAllLinkGroup();

    /**
     * 分页查询 pcGroup
     */
    IPage<PcGroup> queryPcGroupsPaged(CyPageInfo cyPageInfo, @Param("entity") PcGroup pcGroup);

    //    批量删除小组用户中间表数据
    int deletePcGroupUser(List<PcGroupUser> pcGroupUserList);

    //根据id查询详情
    PcGroup queryPcGroupById(int id);

    //根据用户id查询用户是否有角色
    int queryRoleUserByUserId(@Param("userId") Integer userId);

    //修改改用户id的角色
    void updateRoleUserByUserId(@Param(("userId")) Integer userId, @Param("roleId") Integer roleId);

    /**
     * 数据统计小组分页查询
     *
     * @param paginationUtility
     * @param pcGroup
     * @param deptId
     * @return
     */
    IPage<PcGroupDTO> groupListAll(CyPageInfo paginationUtility, @Param("entity") PcGroupDTO pcGroup, @Param("deptId") String deptId);

    /**
     * 数据统计小组详情页面分页查询
     *
     * @param groupName
     * @return
     */
    IPage<GroupPersonDTO> groupDetailsAll(CyPageInfo<PcGroup> paginationUtility, @Param("entity") PcGroupDTO pcGroup);

    IPage<GroupCourseDTO> groupCourseAll(CyPageInfo<PcGroup> paginationUtility, @Param("entity") PcGroupDTO pcGroup, @Param("deptId") String deptId);

    IPage<GroupRecordDTO> groupRecordsAll(CyPageInfo<PcGroup> paginationUtility, @Param("entity") PcGroupDTO pcGroup);

    /**
     * 查询考核页面分页
     *
     * @param paginationUtility
     * @param bLessonDTO
     * @param deptId
     * @return
     */
    IPage<BLessonDTO> courseExamineAll(CyPageInfo paginationUtility, @Param("entity") BLessonDTO bLessonDTO, @Param("deptId") String deptId);

    /**
     * 查询考核页面考核人数分页
     *
     * @param paginationUtility
     * @param bLessonDTO
     * @return
     */
    IPage<BLessonPersonDTO> personExamine(CyPageInfo<PcGroup> paginationUtility, @Param("entity") BLessonPersonDTO bLessonDTO);

    /**
     * 满分人数
     *
     * @param paginationUtility
     * @param bLessonDTO
     * @return
     */
    IPage<BLessonPersonDTO> examineFullMarks(CyPageInfo<PcGroup> paginationUtility, @Param("entity") BLessonPersonDTO bLessonDTO);

    /**
     * 及格人数
     *
     * @param paginationUtility
     * @param bLessonDTO
     * @return
     */
    IPage<BLessonPersonDTO> examineFullPass(CyPageInfo<PcGroup> paginationUtility, @Param("entity") BLessonPersonDTO bLessonDTO);

    /**
     * 未完成课程
     *
     * @param paginationUtility
     * @param pcGroup
     * @return
     */
    IPage<PcGroupCourseDTO> courseIncompleteAll(CyPageInfo<PcGroup> paginationUtility, @Param("entity") PcGroupDTO pcGroup);

    /**
     * 已完成课程
     *
     * @param paginationUtility
     * @param pcGroup
     * @return
     */
    IPage<PcGroupCourseDTO> courseCompletedAll(CyPageInfo<PcGroup> paginationUtility, @Param("entity") PcGroupDTO pcGroup);

    IPage<GroupUserDTO> groupUser(CyPageInfo<PcGroup> paginationUtility, @Param("userId") String userId, @Param("dto") GroupUserDTO groupUserDTO);

    List<Integer> otherTeamLeaders(@Param("integers") ArrayList<Integer> integers);

    void updateCrew(@Param("integers") ArrayList<Integer> integers, @Param("rolerId") String rolerId);

    int getTotalsExamedNumber(@Param("pcGroup") PcGroupDTO pcGroup);

    int getTotalsNotExamedNumber(@Param("pcGroup") PcGroupDTO pcGroup);

    int getTotalsRecordsInformation(@Param("pcGroup") PcGroupDTO pcGroup);

    ArrayList<String> queryGroupIdByGroupId(@Param("id") int id);
}

