package org.rcisoft.pc.pcgroup.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;

import java.lang.reflect.Array;
import java.util.*;
import java.util.stream.Collectors;
import java.util.stream.Stream;

import lombok.extern.slf4j.Slf4j;
import org.apache.catalina.security.SecurityUtil;
import org.apache.commons.lang3.StringUtils;
import org.rcisoft.business.sysuser.dao.PCSysUserRepository;
import org.rcisoft.core.component.CyInitComp;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.pc.pcgroup.dao.PcGroupRepository;
import org.rcisoft.pc.pcgroup.dto.BLessonDTO;
import org.rcisoft.pc.pcgroup.dto.BLessonPersonDTO;
import org.rcisoft.pc.pcgroup.dto.GroupCourseDTO;
import org.rcisoft.pc.pcgroup.dto.GroupPersonDTO;
import org.rcisoft.pc.pcgroup.dto.GroupRecordDTO;
import org.rcisoft.pc.pcgroup.dto.GroupUserDTO;
import org.rcisoft.pc.pcgroup.dto.PcGroupCourseDTO;
import org.rcisoft.pc.pcgroup.dto.PcGroupDTO;
import org.rcisoft.pc.pcgroup.entity.PcGroup;
import org.rcisoft.pc.pcgroup.service.PcGroupService;
import org.rcisoft.pc.pcgroupuser.dao.PcGroupUserRepository;
import org.rcisoft.pc.pcgroupuser.entity.PcGroupUser;
import org.rcisoft.pc.pcgroupuser.service.PcGroupUserService;
import org.rcisoft.pc.pcroleuser.dao.PcRoleUserRepository;
import org.rcisoft.pc.pcroleuser.entity.PcRoleUser;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

/**
 * Created by cy on 2024年4月10日 下午4:20:18.
 */
@Service
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class PcGroupServiceImpl extends ServiceImpl<PcGroupRepository, PcGroup> implements PcGroupService {

    @Autowired
    private PcGroupUserService pcGroupUserService;
    @Autowired
    private PCSysUserRepository pcSysUserRepository;
    @Autowired
    private CyInitComp cyInitComp;
    @Autowired
    private PcGroupUserRepository pcGroupUserRepository;
    @Autowired
    private PcRoleUserRepository pcRoleUserRepository;
    /**
     * 保存 小组表
     *
     * @param pcGroup
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT, rollbackFor = Exception.class)
    @Override
    public CyPersistModel persist(PcGroup pcGroup) {
        pcGroup.setUnit(CyUserUtil.getAuthenDept());
        //增加操作
        int line = baseMapper.insert(pcGroup);
        List<Integer> pcGroupList = pcGroup.getGroupIdList();
        if (pcGroupList != null && !pcGroupList.isEmpty()) {
            for (Integer userId : pcGroupList) {
                PcGroupUser pcGroupUser = new PcGroupUser();
                pcGroupUser.setGroupId(pcGroup.getBusinessId());
                pcGroupUser.setUserId(userId);
                pcGroupUser.setType(0);
                pcGroupUserService.persist(pcGroupUser);
                //判断当前用户是否有后台角色
                Integer count = baseMapper.queryRoleUserByUserId(userId);
                if (count == 0) {
                    //没有则添加
                    this.pcSysUserRepository.insertUserRole(userId, cyInitComp.getPermission()[3]);
                }
            }
        } else {
            //抛出异常
        }
        List<Integer> groupLeaderIdList = pcGroup.getGroupLeaderIdList();
        if (groupLeaderIdList != null && !groupLeaderIdList.isEmpty()) {
            for (Integer leaderId : groupLeaderIdList) {
                PcGroupUser pcGroupUser = new PcGroupUser();
                pcGroupUser.setGroupId(pcGroup.getBusinessId());
                pcGroupUser.setUserId(leaderId);
                pcGroupUser.setType(1);
                pcGroupUserService.persist(pcGroupUser);
                //判断当前用户是否有后台角色
                Integer count = baseMapper.queryRoleUserByUserId(leaderId);
                if (count == 0) {
                    //没有则添加
                    this.pcSysUserRepository.insertUserRole(leaderId, cyInitComp.getPermission()[2]);
                } else {
                    //有则修改
                    this.baseMapper.updateRoleUserByUserId(leaderId, Integer.valueOf(cyInitComp.getPermission()[2]));
                }
            }
        }
        log.debug(CyUserUtil.getAuthenUsername() + "新增了ID为" +
                pcGroup.getBusinessId() + "的小组表信息");
        return new CyPersistModel(line);
    }

    /**
     * 删除 小组表
     *
     * @param pcGroup
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(PcGroup pcGroup) {
        int line = baseMapper.realDelete(pcGroup);
        log.debug(CyUserUtil.getAuthenUsername() + "删除了ID为" +
                pcGroup.getBusinessId() + "的小组表信息");
        return new CyPersistModel(line);
    }

    /**
     * 逻辑删除 小组表
     *
     * @param pcGroup
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(PcGroup pcGroup) {
        //根据组获取该组的组长
        PcGroup group = this.findById(pcGroup.getBusinessId());
        String groupLeaderIds = group.getGroupLeaderIds();
        if (StringUtils.isNotBlank(groupLeaderIds)) {
            String[] leaderId = groupLeaderIds.split(",");//每一个组长id
            List<Integer> leaderIds = Stream.of(leaderId).map(Integer::valueOf).collect(Collectors.toList());
            //根据leadIds查询pc_group_user表 看是否还有type=1的如果没有就将该用户的pc_role_user设为组员
            for (Integer id : leaderIds) {
                List<PcGroupUser> pcGroupUserList = pcGroupUserRepository.getByUserId(id);
                int type = 0;
                for (PcGroupUser pcGroupUser : pcGroupUserList) {
                    if (pcGroupUser.getType().equals(1)){
                        type = type + 1;
                    }
                }
                if (type <= 1){
                    //就证明当前用户不是其他组的组长
                    //该user在关联表里没有组长的角色 将该user的角色设为组员
                    PcRoleUser pcRoleUser = new PcRoleUser();
                    pcRoleUser.setRoleId(8);//单位组员
                    pcRoleUser.setUserId(id);
                    int i = pcRoleUserRepository.updateByUserId(pcRoleUser);
                }
            }
        }
        pcGroup.setDeleted();
        int line = baseMapper.deleteById(pcGroup);
        PcGroupUser pcGroupUser = new PcGroupUser();
        pcGroupUser.setGroupId(pcGroup.getBusinessId());
        int i = pcGroupUserRepository.deleteByGroupId(pcGroupUser);
        log.debug(CyUserUtil.getAuthenUsername() + "逻辑删除了ID为" +
                pcGroup.getBusinessId() + "的小组表信息");
        return new CyPersistModel(line);
    }

    /**
     * 修改 小组表
     *
     * @param pcGroup
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT, rollbackFor = Exception.class)
    @Override
    public CyPersistModel merge(PcGroup pcGroup) {
        PcGroupUser pcGroupUser = new PcGroupUser();
        pcGroupUser.setGroupId(pcGroup.getBusinessId());
        //查询小组用户关联表
        List<PcGroupUser> pcGroupUserList = pcGroupUserService.findAll(pcGroupUser);
        //如果存在则删除
        if (pcGroupUserList != null && !pcGroupUserList.isEmpty()) {
            baseMapper.deletePcGroupUser(pcGroupUserList);
        }
        //循环插入新的组员
        List<Integer> pcGroupList = pcGroup.getGroupIdList();
        if (pcGroupList != null && !pcGroupList.isEmpty()) {
            for (Integer userId : pcGroupList) {
                PcGroupUser groupUser = new PcGroupUser();
                groupUser.setGroupId(pcGroup.getBusinessId());
                groupUser.setUserId(userId);
                groupUser.setType(0);
                pcGroupUserService.persist(groupUser);
                //判断当前用户是否有后台角色
                Integer count = baseMapper.queryRoleUserByUserId(userId);
                if (count == 0) {
                    //没有则添加
                    this.pcSysUserRepository.insertUserRole(userId, cyInitComp.getPermission()[3]);
                }
            }
        }
        List<Integer> groupLeaderIdList = pcGroup.getGroupLeaderIdList();
        //循环插入新的组长
        if (groupLeaderIdList != null && !groupLeaderIdList.isEmpty()) {
            for (Integer leaderId : groupLeaderIdList) {
                PcGroupUser groupUser = new PcGroupUser();
                groupUser.setGroupId(pcGroup.getBusinessId());
                groupUser.setUserId(leaderId);
                groupUser.setType(1);
                pcGroupUserService.persist(groupUser);
                //判断当前用户是否有后台角色
                Integer count = baseMapper.queryRoleUserByUserId(leaderId);
                if (count == 0) {
                    //没有则添加
                    this.pcSysUserRepository.insertUserRole(leaderId, cyInitComp.getPermission()[2]);
                } else {
                    //有则修改
                    this.baseMapper.updateRoleUserByUserId(leaderId, Integer.valueOf(cyInitComp.getPermission()[2]));
                }
            }
        }
        int line = baseMapper.updateById(pcGroup);
        log.debug(CyUserUtil.getAuthenUsername() + "修改了ID为" + pcGroup.getBusinessId() + "的小组表信息");
        return new CyPersistModel(line);
    }

    /**
     * 根据id查询 小组表
     *
     * @param id
     * @return
     */
    @Override
    public PcGroup findById(int id) {
        //根据小组id 查询当前在小组中的人员list，因为sql 导致长度不够所以将查出list 在拼接到对象中   小组ids，以及 小组的人员姓名
         //小组的人员ids
        ArrayList<String> groupIdList = baseMapper.queryGroupIdByGroupId(id);
        PcGroup pcGroup = baseMapper.queryPcGroupById(id);
        //将小组id 拼接到对象中 将list 拼接成 string
        String[] array = groupIdList.toArray(new String[0]);
        // 将数组转换为字符串并以逗号拼接
        String result = String.join(", ", array);
        pcGroup.setGroupIds(result);

        return pcGroup;
    }

    /**
     * 分页查询 小组表
     *
     * @param pcGroup
     * @return
     */
    @Override
    public IPage<PcGroup> findAllByPagination(CyPageInfo<PcGroup> paginationUtility,
                                              PcGroup pcGroup) {
        pcGroup.setUnit(CyUserUtil.getAuthenDept());
        return baseMapper.queryPcGroupsPaged(paginationUtility, pcGroup);

    }

    /**
     * 查询list 小组表
     *
     * @param pcGroup
     * @return
     */
    @Override
    public List<PcGroup> findAll(PcGroup pcGroup) {
        pcGroup.setUnit(CyUserUtil.getAuthenDept());
        return baseMapper.queryPcGroups(pcGroup);

    }

    /**
     * 查询list 小组表
     *
     * @return
     */
    @Override
    public List<PcGroup> listAllLinkGroup(PcGroup pcGroup) {
        // 获取分组全部信息
        List<PcGroup> allLinkGroupList = baseMapper.listAllLinkGroup();
        // 按照 groupLeaderIds 中每个id 为key 构建map
        // key 为每个组长的id, List<PcGroup> 为每个组长所带领的全部组
        Map<String, List<PcGroup>> allLinkGroupMap = allLinkGroupList.stream()
                .flatMap(group -> {
                    String groupLeaderIdsStr = group.getGroupLeaderIds();
                    return groupLeaderIdsStr != null ?
                            Arrays.stream(groupLeaderIdsStr.split(",")).map(id -> new AbstractMap.SimpleEntry<>(id, group)) :
                            Stream.empty();
                })
                .collect(Collectors.groupingBy(
                        Map.Entry::getKey,
                        HashMap::new,
                        Collectors.mapping(Map.Entry::getValue, Collectors.toList())
                ));
        // 获取当前登录用户id
        String loginUserId = CyUserUtil.getAuthenBusinessId();
        String userId = "";
        if (pcGroup.getBusinessId() != null && StringUtils.isNotBlank(pcGroup.getBusinessId().toString())) {
            userId = String.valueOf(pcGroup.getBusinessId());
        } else {
            userId = loginUserId;
        }
        // 获取当前登录用户全部关联分组
        // 先添加当前等于用户自己的组
        List<PcGroup> loggedderGroupList = allLinkGroupMap.containsKey(userId) ?
                new ArrayList<>(allLinkGroupMap.get(userId)) :
                Collections.emptyList();
        // 记录添加了哪些组
        Set<Integer> groupIdSet = loggedderGroupList.stream()
                .map(PcGroup::getBusinessId)
                .collect(Collectors.toCollection(HashSet::new));
        // 获取 loggedderGroupList 中的全部组员
        Set<String> allMembers = loggedderGroupList.stream()
                .map(PcGroup::getGroupIds)
                .filter(Objects::nonNull)
                .flatMap(groupIdStr -> Arrays.stream(groupIdStr.split(",")))
                .collect(Collectors.toCollection(HashSet::new));
        // 循环全部组员
//        for (String groupIdStr : allMembers) {
//            // 判断当前组员是否为组长
//            if (allLinkGroupMap.containsKey(groupIdStr)) {
//                // 该组员作为组长的组信息
//                List<PcGroup> pcGroupList = allLinkGroupMap.get(groupIdStr);
//                for (PcGroup group : pcGroupList) {
//                    // 判断当前组是否已经添加到 loggedderGroupList 中
//                    if (!groupIdSet.contains(group.getBusinessId())) {
//                        loggedderGroupList.add(group);
//                        groupIdSet.add(group.getBusinessId());
//                    }
//                }
//            }
//        }
        allMembers.stream()
                .filter(allLinkGroupMap::containsKey) // 筛选出作为组长的成员ID
                .flatMap(groupIdStr -> allLinkGroupMap.get(groupIdStr).stream()) // 扁平化为组长管理的所有组的流
                .filter(group -> !groupIdSet.contains(group.getBusinessId())) // 筛选出未添加至groupIdSet的组
                .forEach(group -> {
                    loggedderGroupList.add(group);
                    groupIdSet.add(group.getBusinessId());
                });
        return loggedderGroupList;
    }

    /**
     * 导出小组表
     *
     * @return
     */
    @Override
    public List<PcGroup> export(PcGroup pcGroup) {
        List<PcGroup> pcGroupList = baseMapper.queryPcGroups(pcGroup);
        return pcGroupList;
    }

    /**
     * 数据统计小组分页查询
     *
     * @param groupName
     * @return
     */
    @Override
    public IPage<PcGroupDTO> groupListAll(CyPageInfo<PcGroup> paginationUtility,
                                          PcGroupDTO pcGroup) {
        String deptId = CyUserUtil.getAuthenDept();
        IPage<PcGroupDTO> pcGroupDTOIPage = baseMapper.groupListAll(paginationUtility, pcGroup, deptId);

        pcGroupDTOIPage.getRecords().forEach(pcGroupDTO -> {
            //课程数量等于0跳过
            if (pcGroupDTO.getCourseCount() == 0) {
                pcGroupDTO.setStatusCount1(0);
                pcGroupDTO.setStatusCount2(0);
                pcGroupDTO.setStatusCount3(0);
                return;
            }
            //小组下所有人完成课程的情况 //当前小组必修已完成
            pcGroupDTO.setStatusCount1(baseMapper.getTotalsExamedNumber(pcGroupDTO));
            //必修未完成
            pcGroupDTO.setStatusCount2(baseMapper.getTotalsNotExamedNumber(pcGroupDTO));
            //必修考核记录
            pcGroupDTO.setStatusCount3(baseMapper.getTotalsRecordsInformation(pcGroupDTO));
        });
        return pcGroupDTOIPage;
    }

    @Override
    public IPage<GroupPersonDTO> groupDetailsAll(CyPageInfo<PcGroup> paginationUtility,
                                                 PcGroupDTO pcGroup) {
        return baseMapper.groupDetailsAll(paginationUtility, pcGroup);
    }

    @Override
    public IPage<GroupCourseDTO> groupCourseAll(CyPageInfo<PcGroup> paginationUtility,
                                                PcGroupDTO pcGroup) {

        String deptId = CyUserUtil.getAuthenDept();
        return baseMapper.groupCourseAll(paginationUtility, pcGroup, deptId);
    }

    @Override
    public IPage<GroupRecordDTO> groupRecordsAll(CyPageInfo<PcGroup> paginationUtility,
                                                 PcGroupDTO pcGroup) {
        return baseMapper.groupRecordsAll(paginationUtility, pcGroup);
    }

    @Override
    public IPage<BLessonDTO> courseExamineAll(CyPageInfo<PcGroup> paginationUtility,
                                              BLessonDTO bLessonDTO) {

        String deptId = CyUserUtil.getAuthenDept();
        return baseMapper.courseExamineAll(paginationUtility, bLessonDTO, deptId);
    }

    @Override
    public IPage<BLessonPersonDTO> personExamine(CyPageInfo<PcGroup> paginationUtility,
                                                 BLessonPersonDTO bLessonDTO) {
        return baseMapper.personExamine(paginationUtility, bLessonDTO);
    }

    @Override
    public IPage<BLessonPersonDTO> examineFullMarks(CyPageInfo<PcGroup> paginationUtility,
                                                    BLessonPersonDTO bLessonDTO) {
        return baseMapper.examineFullMarks(paginationUtility, bLessonDTO);
    }

    @Override
    public IPage<BLessonPersonDTO> examineFullPass(CyPageInfo<PcGroup> paginationUtility,
                                                   BLessonPersonDTO bLessonDTO) {
        return baseMapper.examineFullPass(paginationUtility, bLessonDTO);
    }

    @Override
    public IPage<PcGroupCourseDTO> courseIncompleteAll(CyPageInfo<PcGroup> paginationUtility,
                                                       PcGroupDTO pcGroup) {
        return baseMapper.courseIncompleteAll(paginationUtility, pcGroup);
    }

    @Override
    public IPage<PcGroupCourseDTO> courseCompletedAll(CyPageInfo<PcGroup> paginationUtility,
                                                      PcGroupDTO pcGroup) {
        return baseMapper.courseCompletedAll(paginationUtility, pcGroup);
    }

    @Override
    public IPage<GroupUserDTO> groupUser(CyPageInfo<PcGroup> paginationUtility, GroupUserDTO groupUserDTO) {
        String userId = CyUserUtil.getAuthenBusinessId();
        IPage<GroupUserDTO> groupUserDTOIPage = baseMapper.groupUser(paginationUtility, userId, groupUserDTO);
        return groupUserDTOIPage;
    }

    @Override
    public void identityOfTheTeamLeader(PcGroup pcGroup) {
        //在组员的list 中去掉组长的list
        ArrayList<Integer> integers = new ArrayList<>();
        integers.addAll(pcGroup.getGroupIdList());
        integers.removeAll(pcGroup.getGroupLeaderIdList());
        if (integers.size() > 0) {
            List<Integer> integers1 = baseMapper.otherTeamLeaders(integers);
            //integers是组员 integers1是在别的组当组长，也要去掉 将剩下的人的角色改成 资源配置中的数值
        integers.removeAll(integers1);
        baseMapper.updateCrew(integers, cyInitComp.getPermission()[3]);
        }
    }

}
