package org.rcisoft.pc.pcgroupuser.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.pc.pcgroupuser.entity.PcGroupUser;
import org.rcisoft.pc.pcgroupuser.service.PcGroupUserService;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.model.CyGridModel;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;

import java.util.List;

/**
* Created by cy on 2024年4月10日 下午4:20:18.
*/
@RestController
@RequestMapping("/pcgroupuser")
public class PcGroupUserController extends CyPaginationController<PcGroupUser> {


    @Autowired
    private PcGroupUserService pcGroupUserServiceImpl;

    //@PreAuthorize("@cyPerm.hasPerm('sys:roupUser:add')")
    @CyOpeLogAnno(title = "system-小组用户关联表管理-新增小组用户关联表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="添加小组用户关联表", notes="添加小组用户关联表")
    @PostMapping(value = "/add")
    public CyResult add(@Valid PcGroupUser pcGroupUser, BindingResult bindingResult) {
        CyPersistModel data = pcGroupUserServiceImpl.persist(pcGroupUser);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        pcGroupUser);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:roupUser:delete')")
    @CyOpeLogAnno(title = "system-小组用户关联表管理-删除小组用户关联表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="删除小组用户关联表", notes="删除小组用户关联表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable int businessId,PcGroupUser pcGroupUser) {
        pcGroupUser.setBusinessId(businessId);
        CyPersistModel data = pcGroupUserServiceImpl.remove(pcGroupUser);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:roupUser:update')")
    @CyOpeLogAnno(title = "system-小组用户关联表管理-修改小组用户关联表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改小组用户关联表", notes="修改小组用户关联表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable int businessId, @Valid PcGroupUser pcGroupUser, BindingResult bindingResult) {
        pcGroupUser.setBusinessId(businessId);
        CyPersistModel data = pcGroupUserServiceImpl.merge(pcGroupUser);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        pcGroupUser);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:roupUser:query')")
    @CyOpeLogAnno(title = "system-小组用户关联表管理-查询小组用户关联表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单一小组用户关联表", notes="查询单一小组用户关联表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable int businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        pcGroupUserServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:roupUser:list')")
    @CyOpeLogAnno(title = "system-小组用户关联表管理-查询小组用户关联表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询小组用户关联表集合", notes="查询小组用户关联表集合")
    @GetMapping(value = "/listAll")
    public CyResult listAll(PcGroupUser pcGroupUser) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            pcGroupUserServiceImpl.findAll(pcGroupUser));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:roupUser:list')")
    @CyOpeLogAnno(title = "system-小组用户关联表管理-查询小组用户关联表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="分页查询小组用户关联表集合", notes="分页查询小组用户关联表集合")
    @GetMapping(value = "/list")
    public CyGridModel listByPagination(PcGroupUser pcGroupUser) {
        pcGroupUserServiceImpl.findAllByPagination(getPaginationUtility(), pcGroupUser);
        return getGridModelResponse();
    }

    @CyOpeLogAnno(title = "system-小组用户关联表管理-查询小组用户关联表", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出小组用户关联表信息", notes = "导出小组用户关联表信息")
    @GetMapping(value = "/export")
    public void outPcGroupUser(HttpServletResponse response,PcGroupUser pcGroupUser,@PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="小组用户关联表信息.xls";break;
            case "1": excelName="小组用户关联表信息.xlsx";break;
            case "2": excelName="小组用户关联表信息.csv";break;
        }
        List<PcGroupUser> pcGroupUserList = pcGroupUserServiceImpl.export(pcGroupUser);
        CyEpExcelUtil.exportExcel(pcGroupUserList, "小组用户关联表信息", "小组用户关联表信息", PcGroupUser.class, excelName, response);
    }
}
