package org.rcisoft.pc.pcgroupuser.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.pc.pcgroupuser.dao.PcGroupUserRepository;
import org.rcisoft.pc.pcgroupuser.entity.PcGroupUser;
import org.rcisoft.pc.pcgroupuser.service.PcGroupUserService;

import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.rcisoft.core.model.CyPageInfo;

import java.util.List;
import lombok.extern.slf4j.Slf4j;

/**
 * Created by cy on 2024年4月10日 下午4:20:18.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class PcGroupUserServiceImpl extends ServiceImpl<PcGroupUserRepository, PcGroupUser>  implements PcGroupUserService {


    /**
    * 保存 小组用户关联表
    * @param pcGroupUser
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(PcGroupUser pcGroupUser){
        //增加操作
        int line = baseMapper.insertPcGroupUser(pcGroupUser);
        log.debug(CyUserUtil.getAuthenUsername()+"新增了ID为"+
            pcGroupUser.getBusinessId()+"的小组用户关联表信息");
        return new CyPersistModel(line);
    }

    /**
    * 删除 小组用户关联表
    * @param pcGroupUser
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(PcGroupUser pcGroupUser){
        int line = baseMapper.realDelete(pcGroupUser);
        log.debug(CyUserUtil.getAuthenUsername()+"删除了ID为"+
            pcGroupUser.getBusinessId()+"的小组用户关联表信息");
        return new CyPersistModel(line);
    }

    /**
    * 修改 小组用户关联表
    * @param pcGroupUser
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(PcGroupUser pcGroupUser){
        int line = baseMapper.updateById(pcGroupUser);
        log.debug(CyUserUtil.getAuthenUsername()+"修改了ID为"+ pcGroupUser.getBusinessId()+"的小组用户关联表信息");
        return new CyPersistModel(line);
    }

    /**
    * 根据id查询 小组用户关联表
    * @param id
    * @return
    */
    @Override
    public PcGroupUser findById(int id){
        return baseMapper.selectById(id);
    }

    /**
    * 分页查询 小组用户关联表
    * @param pcGroupUser
    * @return
    */
    @Override
    public IPage<PcGroupUser> findAllByPagination(CyPageInfo<PcGroupUser> paginationUtility,
        PcGroupUser pcGroupUser){

        return baseMapper.queryPcGroupUsersPaged(paginationUtility,pcGroupUser);

    }

    /**
    * 查询list 小组用户关联表
    * @param pcGroupUser
    * @return
    */
    @Override
    public List<PcGroupUser> findAll(PcGroupUser pcGroupUser){
        return baseMapper.queryPcGroupUsers(pcGroupUser);

    }

    /**
    * 导出小组用户关联表
    * @return
    */
    @Override
    public List<PcGroupUser> export(PcGroupUser pcGroupUser) {
        List<PcGroupUser> pcGroupUserList = baseMapper.queryPcGroupUsers(pcGroupUser);
        return pcGroupUserList;
    }

}
