package org.rcisoft.pc.pcrole.service.impl;

import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import io.swagger.models.auth.In;
import org.rcisoft.business.sysuser.dao.PCSysUserRepository;
import org.rcisoft.business.sysuser.entity.SysUser;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.aop.CyPageUtilAsp;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.pc.pcrole.dao.PcRoleRepository;
import org.rcisoft.pc.pcrole.entity.PcRole;
import org.rcisoft.pc.pcrole.service.PcRoleService;
import org.rcisoft.core.service.CyBaseService;

import org.rcisoft.pc.pcrolelesson.dao.PcRoleLessonRepository;
import org.rcisoft.pc.pcrolelesson.entity.PcRoleLesson;
import org.rcisoft.pc.pcrolelesson.service.PcRoleLessonService;
import org.rcisoft.pc.pcrolelesson.service.impl.PcRoleLessonServiceImpl;
import org.rcisoft.pc.pcroleuser.dao.PcRoleUserRepository;
import org.rcisoft.pc.pcroleuser.entity.PcRoleUser;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.core.parameters.P;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.rcisoft.core.model.CyPageInfo;

import java.util.*;
import java.util.stream.Collectors;

import lombok.extern.slf4j.Slf4j;

/**
 * Created by cy on 2024年4月9日 上午10:32:58.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class PcRoleServiceImpl extends ServiceImpl<PcRoleRepository, PcRole>  implements PcRoleService {
    @Autowired
    private PcRoleLessonService pcRoleLessonService;

    @Autowired
    private PcRoleLessonRepository pcRoleLessonRepository;

    @Autowired
    private PcRoleUserRepository pcRoleUserRepository;

    @Autowired
    private PCSysUserRepository pcSysUserRepository;

    /**
    * 保存 前台_角色管理
    * @param pcRole
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(PcRole pcRole){
//        pcRole.setUnit(Integer.valueOf(CyUserUtil.getAuthenDept()));
        String authenBusinessId = CyUserUtil.getAuthenBusinessId();
        SysUser user = pcSysUserRepository.selectById(authenBusinessId);
        if (user.getDeptId() != null){
            int intVal = user.getDeptId().intValueExact();
            pcRole.setUnit(intVal);
            //增加操作
            int line = baseMapper.insert(pcRole);
            //在中间表中批量添加数据
            List<Map<String, String>> lessonList = pcRole.getLessonList();
            //判断lessonList不为空
            List<String> firstValues = lessonList.stream()
                    .flatMap(map -> map.values().stream().limit(1))
                    .collect(Collectors.toList());
            if(firstValues!=null && !firstValues.isEmpty()){
                for (String lessonId : firstValues) {
                    PcRoleLesson pcRoleLesson = new PcRoleLesson();
                    pcRoleLesson.setPcRoleId(pcRole.getBusinessId());
                    pcRoleLesson.setLessonId(lessonId);
                    pcRoleLessonService.persist(pcRoleLesson);
                }
            }
            log.debug(CyUserUtil.getAuthenUsername()+"新增了ID为"+
                    pcRole.getBusinessId()+"的前台_角色管理信息");
            return new CyPersistModel(line);
        }
//        pcRole.setUnit(1);
        //角色名验重
//        int count = baseMapper.queryRoleName(pcRole.getName(),pcRole.getUnit());
//        if (count>0){
//            throw new CyServiceException("角色名称已存在");
//        }

        return null;
    }

    /**
    * 删除 前台_角色管理
    * @param pcRole
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(PcRole pcRole){
        int line = baseMapper.realDelete(pcRole);
        log.debug(CyUserUtil.getAuthenUsername()+"删除了ID为"+
            pcRole.getBusinessId()+"的前台_角色管理信息");
        return new CyPersistModel(line);
    }

    /**
    * 逻辑删除 前台_角色管理
    * @param pcRole
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(PcRole pcRole){
        pcRole.setDeleted();
        //逻辑删除角色表
        int line = baseMapper.deleteById(pcRole);
        //批量逻辑删除角色课程中间表
        List<PcRoleLesson> pcRoleLessonList = pcRoleLessonRepository.selectList(new QueryWrapper<PcRoleLesson>().eq("pc_role_id", pcRole.getBusinessId()));
        if (pcRoleLessonList.size() > 0){
          int deleteBatch1 = pcRoleLessonRepository.deleteBatch(pcRoleLessonList);
        }
        //逻辑删除角色用户中间表
        List<PcRoleUser> pcRoleUserList = pcRoleUserRepository.selectList(new QueryWrapper<PcRoleUser>().eq("pc_role_id", pcRole.getBusinessId()));
        if (pcRoleUserList.size()>0){
            int deleteBatch2 = pcRoleUserRepository.deleteBatch(pcRoleUserList);
        }
            log.debug(CyUserUtil.getAuthenUsername()+"逻辑删除了ID为"+
                pcRole.getBusinessId()+"的前台_角色管理信息");
            return new CyPersistModel(line);
    }

    /**
    * 修改 前台_角色管理
    * @param pcRole
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(PcRole pcRole){
        //根据角色id查询中间表中的数据
         PcRoleLesson pcRoleLesson = new PcRoleLesson();
         pcRoleLesson.setPcRoleId(pcRole.getBusinessId());
        List<PcRoleLesson> pcRoleLessonList = pcRoleLessonService.findAll(pcRoleLesson);

        //取出pcRoleLessonList的所有lessonId
        //数据库里的lessonId集合
        List<String> lessonIds = pcRoleLessonList.stream()
                .map(PcRoleLesson::getLessonId)
                .collect(Collectors.toList());
        //前端传过来的lessonId集合
        List<Map<String, String>> lessonList = pcRole.getLessonList();
        List<String> firstValues = lessonList.stream()
                .flatMap(map -> map.values().stream().limit(1))
                .collect(Collectors.toList());
        //找出lessonIds和firstValues不同的
        // 将列表转换为集合以进行差异计算
        ArrayList<String> set1 = new ArrayList<>(lessonIds);
        ArrayList<String> set2 = new ArrayList<>(firstValues);

        //仅在数据库里存在的lessonId集合 需要删除的lessonId集合
        List<String> onlyInSet1 = new ArrayList<>(set1);
        onlyInSet1.removeAll(set2);

        //仅在前端传过来的lessonId集合  需要添加的
        List<String> onlyInSet2 = new ArrayList<>(set2);
        onlyInSet2.removeAll(set1);

        List<PcRoleLesson> pcRoleLessonList1 = new ArrayList<>();
        for (String lessonId : onlyInSet1) {
            PcRoleLesson pcRoleLesson1 = new PcRoleLesson();
            pcRoleLesson1.setLessonId(lessonId);
            pcRoleLesson1.setPcRoleId(pcRole.getBusinessId());
            pcRoleLessonList1.add(pcRoleLesson1);
        }


        if (pcRoleLessonList1!=null && !pcRoleLessonList1.isEmpty()){
            //删除中间表中的数据
            baseMapper.deleteBatchRole(pcRoleLessonList1);
        }

        //在中间表中批量添加数据 添加数据库中不存在 但是前端存在的lessonid
        if(onlyInSet2!=null && !onlyInSet2.isEmpty()){
            for (String lessonId : onlyInSet2) {
                PcRoleLesson pcRoleLesson1 = new PcRoleLesson();
                pcRoleLesson1.setPcRoleId(pcRole.getBusinessId());
                pcRoleLesson1.setLessonId(lessonId);
                pcRoleLessonService.persist(pcRoleLesson1);
            }
        }

        int line = baseMapper.updateById(pcRole);

        log.debug(CyUserUtil.getAuthenUsername()+"修改了ID为"+ pcRole.getBusinessId()+"的前台_角色管理信息");
        return new CyPersistModel(line);
    }

    /**
    * 根据id查询 前台_角色管理
    * @param id
    * @return
    */
    @Override
    public PcRole findById(int id){
        return baseMapper.queryPcRoleById(id);
    }

    /**
    * 分页查询 前台_角色管理
    * @param pcRole
    * @return
    */
    @Override
    public IPage<PcRole> findAllByPagination(CyPageInfo<PcRole> paginationUtility,
        PcRole pcRole){
//        pcRole.setUnit(Integer.valueOf(CyUserUtil.getAuthenDept()));
        String authenBusinessId = CyUserUtil.getAuthenBusinessId();
        SysUser user = pcSysUserRepository.selectById(authenBusinessId);
        IPage<PcRole> pcRoleIPage = new Page<>();
        if (user.getDeptId() != null){
            int intVal = user.getDeptId().intValueExact();
            pcRole.setUnit(intVal);
            pcRoleIPage = baseMapper.queryPcRolesPaged(paginationUtility, pcRole);
        }
        else{
            pcRoleIPage.setTotal(0);
            pcRoleIPage.setRecords(null);
        }
        return pcRoleIPage;

    }

    /**
    * 查询list 前台_角色管理
    * @param pcRole
    * @return
    */
    @Override
    public List<PcRole> findAll(PcRole pcRole){
        String authenDept = CyUserUtil.getAuthenDept();
        List<PcRole> pcRoles = new ArrayList<>();
        if (!authenDept.equals("null")){
            pcRole.setUnit(Integer.valueOf(CyUserUtil.getAuthenDept()));
            pcRoles = baseMapper.queryPcRoles(pcRole);
        }else {
            pcRoles = null;
        }
        return pcRoles;

    }

    /**
    * 导出前台_角色管理
    * @return
    */
    @Override
    public List<PcRole> export(PcRole pcRole) {
        List<PcRole> pcRoleList = baseMapper.queryPcRoles(pcRole);
        return pcRoleList;
    }


    /**
     * 保存 前台_角色管理
     * @param pcRole
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    public CyPersistModel addRoleWithCourse(PcRole pcRole, Integer unitId,Integer isPay){
        //增加操作
        int line = baseMapper.insert(pcRole);

        //在中间表中批量添加数据lessonList = {ArrayList@16282}  size = 1
        List<Map<String, String>> lessonList = pcRole.getLessonList();
        //判断lessonList不为空
        List<String> firstValues = lessonList.stream()
                .flatMap(map -> map.keySet().stream().limit(1))
                .collect(Collectors.toList());
        if(firstValues!=null && !firstValues.isEmpty()){
            for (String lessonId : firstValues) {
                PcRoleLesson pcRoleLesson = new PcRoleLesson();
                pcRoleLesson.setPcRoleId(pcRole.getBusinessId());
                pcRoleLesson.setLessonId(lessonId);
                pcRoleLessonService.saveRoleLesson(pcRoleLesson,unitId,isPay);
            }
        }

        log.debug(CyUserUtil.getAuthenUsername()+"新增了ID为"+
                pcRole.getBusinessId()+"的前台_角色管理信息");
        return new CyPersistModel(line);
    }
}
