package org.rcisoft.pc.pcrolelesson.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.business.blesson.entity.MyGroupStatisticsVO;
import org.rcisoft.business.blesson.entity.PcBlessonDTO;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.pc.pcrolelesson.dto.PcRoleBlessonDTO;
import org.rcisoft.pc.pcrolelesson.entity.PcRoleLesson;
import org.rcisoft.pc.pcrolelesson.service.PcRoleLessonService;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.springframework.security.core.parameters.P;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.model.CyGridModel;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;

import java.util.List;

/**
* Created by cy on 2024年4月9日 下午1:42:43.
*/
@RestController
@RequestMapping("/pcrolelesson")
public class PcRoleLessonController extends CyPaginationController<PcRoleLesson> {


    @Autowired
    private PcRoleLessonService pcRoleLessonServiceImpl;

    //@PreAuthorize("@cyPerm.hasPerm('sys:oleLesson:add')")
    @CyOpeLogAnno(title = "system-前台角色与课程关联表管理-新增前台角色与课程关联表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="添加前台角色与课程关联表", notes="添加前台角色与课程关联表")
    @PostMapping(value = "/add")
    public CyResult add(@Valid PcRoleLesson pcRoleLesson, BindingResult bindingResult) {
        CyPersistModel data = pcRoleLessonServiceImpl.persist(pcRoleLesson);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        pcRoleLesson);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:oleLesson:delete')")
    @CyOpeLogAnno(title = "system-前台角色与课程关联表管理-删除前台角色与课程关联表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="删除前台角色与课程关联表", notes="删除前台角色与课程关联表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable int businessId,PcRoleLesson pcRoleLesson) {
        pcRoleLesson.setBusinessId(businessId);
        CyPersistModel data = pcRoleLessonServiceImpl.remove(pcRoleLesson);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:oleLesson:update')")
    @CyOpeLogAnno(title = "system-前台角色与课程关联表管理-修改前台角色与课程关联表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改前台角色与课程关联表", notes="修改前台角色与课程关联表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable int businessId, @Valid PcRoleLesson pcRoleLesson, BindingResult bindingResult) {
        pcRoleLesson.setBusinessId(businessId);
        CyPersistModel data = pcRoleLessonServiceImpl.merge(pcRoleLesson);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        pcRoleLesson);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:oleLesson:query')")
    @CyOpeLogAnno(title = "system-前台角色与课程关联表管理-查询前台角色与课程关联表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单一前台角色与课程关联表", notes="查询单一前台角色与课程关联表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable int businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        pcRoleLessonServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:oleLesson:list')")
    @CyOpeLogAnno(title = "system-前台角色与课程关联表管理-查询前台角色与课程关联表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询前台角色与课程关联表集合", notes="查询前台角色与课程关联表集合")
    @GetMapping(value = "/listAll")
    public CyResult listAll(PcRoleLesson pcRoleLesson) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            pcRoleLessonServiceImpl.findAll(pcRoleLesson));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:oleLesson:list')")
    @CyOpeLogAnno(title = "system-前台角色与课程关联表管理-查询前台角色与课程关联表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="分页查询前台角色与课程关联表集合", notes="分页查询前台角色与课程关联表集合")
    @GetMapping(value = "/list")
    public CyGridModel listByPagination(PcRoleLesson pcRoleLesson) {
        pcRoleLessonServiceImpl.findAllByPagination(getPaginationUtility(), pcRoleLesson);
        return getGridModelResponse();
    }

    @CyOpeLogAnno(title = "system-前台角色与课程关联表管理-查询前台角色与课程关联表", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出前台角色与课程关联表信息", notes = "导出前台角色与课程关联表信息")
    @GetMapping(value = "/export")
    public void outPcRoleLesson(HttpServletResponse response,PcRoleLesson pcRoleLesson,@PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="前台角色与课程关联表信息.xls";break;
            case "1": excelName="前台角色与课程关联表信息.xlsx";break;
            case "2": excelName="前台角色与课程关联表信息.csv";break;
        }
        List<PcRoleLesson> pcRoleLessonList = pcRoleLessonServiceImpl.export(pcRoleLesson);
        CyEpExcelUtil.exportExcel(pcRoleLessonList, "前台角色与课程关联表信息", "前台角色与课程关联表信息", PcRoleLesson.class, excelName, response);
    }

    /**
     * 角色查询课程信息
     */
    @ApiOperation(value = "角色查询课程信息", notes = "角色查询课程信息")
    @ApiImplicitParams({@ApiImplicitParam(name = "deptId", value = "deptId", required = false, dataType = "varchar"),
        @ApiImplicitParam(name = "roleId", value = "roleId", required = false, dataType = "varchar")
    })
    @GetMapping(value = "/queryCourse")
    public CyResult queryCourseByRoleId(PcRoleBlessonDTO dto) {
        CyPageInfo<PcRoleBlessonDTO> paginationUtility = new CyPageInfo<>();
        paginationUtility.setCurrent(getPaginationUtility().getCurrent());
        paginationUtility.setSize(getPaginationUtility().getSize());
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                pcRoleLessonServiceImpl.queryCourseByRoleId(paginationUtility,dto));
    }

    /**
     * 保存角色看课时间
     */
    @ApiOperation(value = "保存角色看课时间", notes = "保存角色看课时间")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar"),
        @ApiImplicitParam(name = "beginTrialTime", value = "beginTrialTime", required = false, dataType = "varchar"),
        @ApiImplicitParam(name = "endTrialTime", value = "endTrialTime", required = false,dataType = "varchar")
    })
    @PutMapping(value = "/updateTime")
    public CyResult updateTime(@RequestBody PcRoleLesson pcRoleLesson) {
        CyPersistModel data = pcRoleLessonServiceImpl.updateTime(pcRoleLesson);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                pcRoleLesson);
    }


    /**
     * 角色查询课程信息
     */
    @ApiOperation(value = "已购课程角色查询", notes = "已购课程角色查询")
    @ApiImplicitParams({@ApiImplicitParam(name = "roleIds", value = "roleIds", required = false, dataType = "varchar"),
            @ApiImplicitParam(name = "lessonId", value = "lessonId", required = false, dataType = "varchar")
    })
    @GetMapping(value = "/queryRole")
    public CyResult queryRole(PcRoleBlessonDTO dto) {
        CyPageInfo<PcRoleBlessonDTO> paginationUtility = new CyPageInfo<>();
        paginationUtility.setCurrent(getPaginationUtility().getCurrent());
        paginationUtility.setSize(getPaginationUtility().getSize());
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                pcRoleLessonServiceImpl.queryRole(paginationUtility,dto));
    }

    @PutMapping(value = "/updateTimeById")
    public CyResult updateTimeById(@RequestBody PcRoleBlessonDTO pcRoleLesson) {
        CyPersistModel data = pcRoleLessonServiceImpl.updateTimeById(pcRoleLesson);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                pcRoleLesson);
    }
}
