package org.rcisoft.pc.pcrolelesson.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.jetbrains.annotations.NotNull;
import org.rcisoft.business.teatrialcourse.dao.TeaTrialCourseRepository;
import org.rcisoft.business.teatrialcourse.dto.TrialCourseDto;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.pc.pcrolelesson.dao.PcRoleLessonRepository;
import org.rcisoft.pc.pcrolelesson.dto.PcRoleBlessonDTO;
import org.rcisoft.pc.pcrolelesson.entity.PcRoleLesson;
import org.rcisoft.pc.pcrolelesson.service.PcRoleLessonService;
import org.rcisoft.sys.dictionary.entity.DictData;
import org.rcisoft.sys.dictionary.service.DictionaryService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;

/**
 * Created by cy on 2024年4月9日 下午1:42:43.
 */
@Service
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class PcRoleLessonServiceImpl extends ServiceImpl<PcRoleLessonRepository, PcRoleLesson> implements PcRoleLessonService {

    @Autowired
    private DictionaryService dictionaryServiceImpl;

    @Autowired
    private TeaTrialCourseRepository teaTrialCourseRepository;

    @NotNull
    private static List<String> getStrings(String tecClassify, List<DictData> tecClassifyList) {
        String[] tecClassifyValues = tecClassify.split(",");  // 将逗号分隔的多个值分割成数组
        List<String> tecClassifyLabels = new ArrayList<>();
        for (String value : tecClassifyValues) {
            for (DictData dictData : tecClassifyList) {
                if (dictData.getDictValue().equals(value.trim())) {
                    tecClassifyLabels.add(dictData.getDictLabel());  // 将找到的名称添加到集合中
                    break;  // 找到一个匹配即可跳出内层循环
                }
            }
        }
        return tecClassifyLabels;
    }

    /**
     * 保存 前台角色与课程关联表
     *
     * @param pcRoleLesson
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(PcRoleLesson pcRoleLesson) {
        //查询当前课程在该单位下的学习时间
        String authenDept = CyUserUtil.getAuthenDept();
        List<TrialCourseDto> trialCourseDtos = teaTrialCourseRepository.selectByIpUser(authenDept, pcRoleLesson.getLessonId());
        if (CollectionUtils.isNotEmpty(trialCourseDtos)) {
            TrialCourseDto trialCourseDto = trialCourseDtos.get(0);
            Integer isPay = trialCourseDto.getIsPay();//是否付费
            Date endTrialTime = trialCourseDto.getEndTrialTime();
            if (isPay.equals(1)) {
                //付费课程
                Date startTime = new Date();
                Calendar calendar1 = Calendar.getInstance();
                calendar1.setTime(startTime);
                calendar1.add(calendar1.YEAR, 1);//开始时间+1年
                //取calendar.getTime()和calendar1.getTime()的最小值
                long time = endTrialTime.getTime();//结束时间
                long time1 = calendar1.getTime().getTime();//开始时间+1年
                if (time < time1) {
                    //结束时间小  结束时间取结束时间
                    // 获取增加后的日期对象
                    Date date = new Date(time);
                    pcRoleLesson.setStartTime(new Date());
                    pcRoleLesson.setEndTime(date);
                } else {
                    //开始时间+1年 小   结束时间取开始时间+1年
                    Date date1 = new Date(time1);
                    pcRoleLesson.setStartTime(new Date());
                    pcRoleLesson.setEndTime(date1);
                }
            } else {
                //试用课程
                Date beginTrialTime = new Date();
                Calendar calendar2 = Calendar.getInstance();
                calendar2.setTime(beginTrialTime);
                //免费 试用课程增加两周
                calendar2.add(Calendar.WEEK_OF_YEAR, 2);
                //取calendar.getTime()和calendar1.getTime()的最小值
                long time = endTrialTime.getTime();//结束时间
                long time1 = calendar2.getTime().getTime();//开始时间+两周
                if (time < time1) {
                    //结束时间小  结束时间取结束时间
                    // 获取增加后的日期对象
                    Date date = new Date(time);
                    pcRoleLesson.setStartTime(new Date());
                    pcRoleLesson.setEndTime(date);
                } else {
                    //开始时间+1年 小   结束时间取开始时间+1年
                    Date date1 = new Date(time1);
                    pcRoleLesson.setStartTime(new Date());
                    pcRoleLesson.setEndTime(date1);
                }
            }
        }
        //增加操作
        int line = baseMapper.insertPcRoleLesson(pcRoleLesson);
        log.debug(CyUserUtil.getAuthenUsername() + "新增了ID为" +
                pcRoleLesson.getBusinessId() + "的前台角色与课程关联表信息");
        return new CyPersistModel(line);
    }

    /**
     * 删除 前台角色与课程关联表
     *
     * @param pcRoleLesson
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(PcRoleLesson pcRoleLesson) {
        int line = baseMapper.realDelete(pcRoleLesson);
        log.debug(CyUserUtil.getAuthenUsername() + "删除了ID为" +
                pcRoleLesson.getBusinessId() + "的前台角色与课程关联表信息");
        return new CyPersistModel(line);
    }

    /**
     * 修改 前台角色与课程关联表
     *
     * @param pcRoleLesson
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(PcRoleLesson pcRoleLesson) {
        int line = baseMapper.updateById(pcRoleLesson);
        log.debug(CyUserUtil.getAuthenUsername() + "修改了ID为" + pcRoleLesson.getBusinessId() + "的前台角色与课程关联表信息");
        return new CyPersistModel(line);
    }

    /**
     * 根据id查询 前台角色与课程关联表
     *
     * @param id
     * @return
     */
    @Override
    public PcRoleLesson findById(int id) {
        return baseMapper.selectById(id);
    }

    /**
     * 分页查询 前台角色与课程关联表
     *
     * @param pcRoleLesson
     * @return
     */
    @Override
    public IPage<PcRoleLesson> findAllByPagination(CyPageInfo<PcRoleLesson> paginationUtility,
                                                   PcRoleLesson pcRoleLesson) {
        return baseMapper.queryPcRoleLessonsPaged(paginationUtility, pcRoleLesson);

    }

    /**
     * 查询list 前台角色与课程关联表
     *
     * @param pcRoleLesson
     * @return
     */
    @Override
    public List<PcRoleLesson> findAll(PcRoleLesson pcRoleLesson) {
        return baseMapper.queryPcRoleLessons(pcRoleLesson);

    }

    /**
     * 导出前台角色与课程关联表
     *
     * @return
     */
    @Override
    public List<PcRoleLesson> export(PcRoleLesson pcRoleLesson) {
        List<PcRoleLesson> pcRoleLessonList = baseMapper.queryPcRoleLessons(pcRoleLesson);
        return pcRoleLessonList;
    }

    @Override
    public IPage<PcRoleBlessonDTO> queryCourseByRoleId(CyPageInfo<PcRoleBlessonDTO> paginationUtility, PcRoleBlessonDTO dto) {
        //根据角色id 查询课程信息 课程讲师 难度等级 开始结束时间 剩余天数
        IPage<PcRoleBlessonDTO> page = baseMapper.queryCourseByRoleId(paginationUtility, dto);
        List<PcRoleBlessonDTO> dtoList = page.getRecords();
        if (CollectionUtils.isNotEmpty(dtoList)) {
            //时间计算
            dtoList.forEach(dto1 -> {
                //开始时间
                Date startTime = dto1.getStartTime();
                //结束时间
                Date endTime = dto1.getEndTime();
                //现在时间
                Date date = new Date();
                //1 当前时间超过结束时间

                if (date.getTime() > endTime.getTime()) {
                    //剩余天数
                    dto1.setRemainingDays(0);
                }
                //当前时间在开始日期后 结束日期前
                if (date.getTime() > startTime.getTime() && date.getTime() < endTime.getTime()) {
                    //剩余天数 = 结束日期 - 当前日期 /60 / 60 / 24
                    dto1.setRemainingDays((int) ((endTime.getTime() - date.getTime()) / (1000 * 60 * 60 * 24)) + 2);
                    dto1.setRemainingDays((int) ((endTime.getTime() - date.getTime()) / (1000 * 60 * 60 * 24)) + 2);
                }
                //当前时间在开始日期前
                if (date.getTime() < startTime.getTime()) {
                    //剩余天数 = 开始日期 - 当前日期 /60 / 60 / 24
                    dto1.setRemainingDays((int) ((endTime.getTime() - startTime.getTime()) / (1000 * 60 * 60 * 24)) + 1);
                }
            });
            List<DictData> dictDataList = dictionaryServiceImpl.selectByTypes("difficulty_grade");
            //难度等级填充
            dtoList.forEach(dto1 -> {
                String difficultyClassify = dto1.getDifficultyClassify();
                if (difficultyClassify != null && !difficultyClassify.isEmpty()) {
                    //开始学习时间,结束学习时间默认配置
                    if (dto1.getStartTime() == null) {
                        dto1.setStartTime(dto1.getBeginTrialTime());
                    }
                    if (dto1.getEndTime() == null) {
                        dto1.setEndTime(dto1.getEndTrialTime());
                    }
                    List<String> difficultyClassifyLabels = getStrings(difficultyClassify, dictDataList);
                    dto1.setDifficultyClassifyLabels(String.join(",", difficultyClassifyLabels));  // 将名称集合拼接成逗号分隔的字符串，设置到 bLesson 对象中
                }
            });
        }
        return page;
    }

    /**
     * 角色修改看课时间
     *
     * @param pcRoleLesson
     * @return
     */
    @Override
    public CyPersistModel updateTime(PcRoleLesson pcRoleLesson) {
        //修改剩余时间
        LambdaQueryWrapper<PcRoleLesson> qw = new LambdaQueryWrapper<>();
        qw.eq(PcRoleLesson::getPcRoleId, pcRoleLesson.getPcRoleId())
                .eq(PcRoleLesson::getLessonId, pcRoleLesson.getLessonId());
        Integer isPay = pcRoleLesson.getIsPay();
        PcRoleLesson pcRoleLesson1 = baseMapper.selectOne(qw);
        //没动开始时间  动了结束时间的话 只设置结束时间
        if (pcRoleLesson.getStartTime().equals(pcRoleLesson1.getStartTime()) && !pcRoleLesson.getEndTime().equals(pcRoleLesson1.getEndTime())) {
            //只修改结束时间即可
            pcRoleLesson.setEndTime(pcRoleLesson.getEndTime());
        } else {
            Date endTrialTime = pcRoleLesson.getEndTrialTime();
            if (isPay.equals(1)) {
                //付费课程
                Date startTime = pcRoleLesson.getStartTime();
                Calendar calendar1 = Calendar.getInstance();
                calendar1.setTime(startTime);
                calendar1.add(calendar1.YEAR, 1);//开始时间+1年
                //取calendar.getTime()和calendar1.getTime()的最小值
                long time = endTrialTime.getTime();//结束时间
                long time1 = calendar1.getTime().getTime();//开始时间+1年
                if (time < time1) {
                    //结束时间小  结束时间取结束时间
                    // 获取增加后的日期对象
                    Date date = new Date(time);
                    pcRoleLesson.setStartTime(startTime);
                    pcRoleLesson.setEndTime(date);
                } else {
                    //开始时间+1年 小   结束时间取开始时间+1年
                    Date date1 = new Date(time1);
                    pcRoleLesson.setStartTime(startTime);
                    pcRoleLesson.setEndTime(date1);
                }
            } else {
                //试用课程
                Date startTime = pcRoleLesson.getStartTime();
                Calendar calendar2 = Calendar.getInstance();
                calendar2.setTime(startTime);
                //免费 试用课程增加两周
                calendar2.add(Calendar.WEEK_OF_YEAR, 2);
                //取calendar.getTime()和calendar1.getTime()的最小值
                long time = endTrialTime.getTime();//结束时间
                long time1 = calendar2.getTime().getTime();//开始时间+两周
                if (time < time1) {
                    //结束时间小  结束时间取结束时间
                    // 获取增加后的日期对象
                    Date date = new Date(time);
                    pcRoleLesson.setStartTime(startTime);
                    pcRoleLesson.setEndTime(date);
                } else {
                    //开始时间+1年 小   结束时间取开始时间+1年
                    Date date1 = new Date(time1);
                    pcRoleLesson.setStartTime(startTime);
                    pcRoleLesson.setEndTime(date1);
                }
            }
        }
        int update = baseMapper.update(pcRoleLesson, qw);
        return new CyPersistModel(update);
    }

    @Override
    public IPage<PcRoleBlessonDTO> queryRole(CyPageInfo<PcRoleBlessonDTO> paginationUtility,
                                             PcRoleBlessonDTO dto) {
        if (StringUtils.isNotBlank(dto.getRoleIds())) {
            dto.setRoleIdList(Arrays.asList(dto.getRoleIds().split(",")));
        } else {
            dto.setRoleIdList(null);
        }
        IPage<PcRoleBlessonDTO> pcRoleLessonIPage = baseMapper.queryRole(paginationUtility,
                dto);
        if (CollectionUtils.isNotEmpty(pcRoleLessonIPage.getRecords())) {
            pcRoleLessonIPage.getRecords().forEach(dto1 -> {
                if (dto1.getStartTime() == null) {
                    dto1.setStartTime(dto1.getBeginTrialTime());
                }
                if (dto1.getEndTime() == null) {
                    dto1.setEndTime(dto1.getEndTrialTime());
                }
            });
        }
        return pcRoleLessonIPage;
    }

    @Override
    public CyPersistModel updateTimeById(PcRoleBlessonDTO pcRoleLessonDto) {
        if (pcRoleLessonDto.getBusinessId() != null) {
            PcRoleLesson pcRoleLesson = new PcRoleLesson();
            pcRoleLesson.setBusinessId(Integer.valueOf(pcRoleLessonDto.getBusinessId()));
            pcRoleLesson.setStartTime(pcRoleLessonDto.getStartTime());
            pcRoleLesson.setEndTime(pcRoleLessonDto.getEndTime());
            int update = baseMapper.updateById(pcRoleLesson);
            return new CyPersistModel(update);
        }
        return null;
    }

    /**
     * 保存 前台角色与课程关联表
     *
     * @param pcRoleLesson
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    public CyPersistModel saveRoleLesson(PcRoleLesson pcRoleLesson, Integer unitId, Integer isPay) {
        //查询当前课程在该单位下的学习时间
        List<TrialCourseDto> trialCourseDtos = teaTrialCourseRepository.selectByIpUser(String.valueOf(unitId), pcRoleLesson.getLessonId());
        if (CollectionUtils.isNotEmpty(trialCourseDtos)) {
            Date endTrialTime = trialCourseDtos.get(0).getEndTrialTime();//当前课程的结束时间
            if (isPay.equals(1)) {
                //付费课程
                Date beginTrialTime = new Date();
                Calendar calendar1 = Calendar.getInstance();
                calendar1.setTime(beginTrialTime);
                calendar1.add(calendar1.YEAR, 1);//开始时间+1年
                //取calendar.getTime()和calendar1.getTime()的最小值
                long time = endTrialTime.getTime();//结束时间
                long time1 = calendar1.getTime().getTime();//开始时间+1年
                if (time < time1) {
                    //结束时间小  结束时间取结束时间
                    // 获取增加后的日期对象
                    Date date = new Date(time);
                    pcRoleLesson.setStartTime(new Date());
                    pcRoleLesson.setEndTime(date);
                } else {
                    //开始时间+1年 小   结束时间取开始时间+1年
                    Date date1 = new Date(time1);
                    pcRoleLesson.setStartTime(new Date());
                    pcRoleLesson.setEndTime(date1);
                }
            } else {
                //试用课程
                Date beginTrialTime = new Date();
                Calendar calendar2 = Calendar.getInstance();
                calendar2.setTime(beginTrialTime);
                //免费 试用课程增加两周
                calendar2.add(Calendar.WEEK_OF_YEAR, 2);
                //取calendar.getTime()和calendar1.getTime()的最小值
                long time = endTrialTime.getTime();//结束时间
                long time1 = calendar2.getTime().getTime();//开始时间+两周
                if (time < time1) {
                    //结束时间小  结束时间取结束时间
                    // 获取增加后的日期对象
                    Date date = new Date(time);
                    pcRoleLesson.setStartTime(new Date());
                    pcRoleLesson.setEndTime(date);
                } else {
                    //开始时间+1年 小   结束时间取开始时间+1年
                    Date date1 = new Date(time1);
                    pcRoleLesson.setStartTime(new Date());
                    pcRoleLesson.setEndTime(date1);
                }
            }
        }


        //增加操作
        int line = baseMapper.insertPcRoleLesson(pcRoleLesson);
        log.debug(CyUserUtil.getAuthenUsername() + "新增了ID为" +
                pcRoleLesson.getBusinessId() + "的前台角色与课程关联表信息");
        return new CyPersistModel(line);
    }
}
