package org.rcisoft.pc.pcroleuser.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.pc.pcroleuser.entity.PcRoleUser;
import org.rcisoft.pc.pcroleuser.service.PcRoleUserService;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.exception.CyServiceException;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;


import java.util.List;

/**
* Created by cy on 2024年4月10日 下午4:20:18.
*/
@RestController
@RequestMapping("/pcroleuser")
public class PcRoleUserController extends CyPaginationController<PcRoleUser> {


    @Autowired
    private PcRoleUserService pcRoleUserServiceImpl;

    //@PreAuthorize("@cyPerm.hasPerm('sys:oleUser:add')")
    @CyOpeLogAnno(title = "system-用户和前台角色关联表管理-新增用户和前台角色关联表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="添加用户和前台角色关联表", notes="添加用户和前台角色关联表")
    @PostMapping(value = "/add")
    public CyResult add(@Valid PcRoleUser pcRoleUser, BindingResult bindingResult) {
        CyPersistModel data = pcRoleUserServiceImpl.persist(pcRoleUser);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        pcRoleUser);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:oleUser:delete')")
    @CyOpeLogAnno(title = "system-用户和前台角色关联表管理-删除用户和前台角色关联表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="删除用户和前台角色关联表", notes="删除用户和前台角色关联表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable int businessId,PcRoleUser pcRoleUser) {
        pcRoleUser.setBusinessId(businessId);
        CyPersistModel data = pcRoleUserServiceImpl.remove(pcRoleUser);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:oleUser:update')")
    @CyOpeLogAnno(title = "system-用户和前台角色关联表管理-修改用户和前台角色关联表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改用户和前台角色关联表", notes="修改用户和前台角色关联表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable int businessId, @Valid PcRoleUser pcRoleUser, BindingResult bindingResult) {
        pcRoleUser.setBusinessId(businessId);
        CyPersistModel data = pcRoleUserServiceImpl.merge(pcRoleUser);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        pcRoleUser);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:oleUser:query')")
    @CyOpeLogAnno(title = "system-用户和前台角色关联表管理-查询用户和前台角色关联表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单一用户和前台角色关联表", notes="查询单一用户和前台角色关联表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable int businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        pcRoleUserServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:oleUser:list')")
    @CyOpeLogAnno(title = "system-用户和前台角色关联表管理-查询用户和前台角色关联表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询用户和前台角色关联表集合", notes="查询用户和前台角色关联表集合")
    @GetMapping(value = "/listAll")
    public CyResult listAll(PcRoleUser pcRoleUser) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            pcRoleUserServiceImpl.findAll(pcRoleUser));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:oleUser:list')")
    @CyOpeLogAnno(title = "system-用户和前台角色关联表管理-查询用户和前台角色关联表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="分页查询用户和前台角色关联表集合", notes="分页查询用户和前台角色关联表集合")
    @GetMapping(value = "/list")
    public CyGridModel listByPagination(PcRoleUser pcRoleUser) {
        pcRoleUserServiceImpl.findAllByPagination(getPaginationUtility(), pcRoleUser);
        return getGridModelResponse();
    }

    @CyOpeLogAnno(title = "system-用户和前台角色关联表管理-查询用户和前台角色关联表", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出用户和前台角色关联表信息", notes = "导出用户和前台角色关联表信息")
    @GetMapping(value = "/export")
    public void outPcRoleUser(HttpServletResponse response,PcRoleUser pcRoleUser,@PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="用户和前台角色关联表信息.xls";break;
            case "1": excelName="用户和前台角色关联表信息.xlsx";break;
            case "2": excelName="用户和前台角色关联表信息.csv";break;
        }
        List<PcRoleUser> pcRoleUserList = pcRoleUserServiceImpl.export(pcRoleUser);
        CyEpExcelUtil.exportExcel(pcRoleUserList, "用户和前台角色关联表信息", "用户和前台角色关联表信息", PcRoleUser.class, excelName, response);
    }


    @CyOpeLogAnno(title = "system-用户和前台角色关联表管理-批量新增用户和前台角色关联表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="批量新增用户和前台角色关联表", notes="批量新增用户和前台角色关联表")
    @PostMapping(value = "/addRoleUser")
    public CyResult addRoleUser(PcRoleUser pcRoleUser) {
        CyPersistModel data = pcRoleUserServiceImpl.addRoleUser(pcRoleUser);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                pcRoleUser);
    }
}
