package org.rcisoft.pc.pcroleuser.service.impl;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.aop.CyPageUtilAsp;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.pc.pcroleuser.dao.PcRoleUserRepository;
import org.rcisoft.pc.pcroleuser.entity.PcRoleUser;
import org.rcisoft.pc.pcroleuser.service.PcRoleUserService;
import org.rcisoft.core.service.CyBaseService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.rcisoft.core.model.CyPageInfo;

import java.util.List;
import lombok.extern.slf4j.Slf4j;

/**
 * Created by cy on 2024年4月10日 下午4:20:18.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class PcRoleUserServiceImpl extends ServiceImpl<PcRoleUserRepository, PcRoleUser>  implements PcRoleUserService {

    @Autowired
    private PcRoleUserRepository pcRoleUserRepository;

    /**
    * 保存 用户和前台角色关联表
    * @param pcRoleUser
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(PcRoleUser pcRoleUser){
        //增加操作
        int line = baseMapper.insertPcRoleUser(pcRoleUser);
        log.debug(CyUserUtil.getAuthenUsername()+"新增了ID为"+
            pcRoleUser.getBusinessId()+"的用户和前台角色关联表信息");
        return new CyPersistModel(line);
    }

    /**
    * 删除 用户和前台角色关联表
    * @param pcRoleUser
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(PcRoleUser pcRoleUser){
        int line = baseMapper.realDelete(pcRoleUser);
        log.debug(CyUserUtil.getAuthenUsername()+"删除了ID为"+
            pcRoleUser.getBusinessId()+"的用户和前台角色关联表信息");
        return new CyPersistModel(line);
    }

    /**
    * 修改 用户和前台角色关联表
    * @param pcRoleUser
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(PcRoleUser pcRoleUser){
        int line = baseMapper.updateById(pcRoleUser);
        log.debug(CyUserUtil.getAuthenUsername()+"修改了ID为"+ pcRoleUser.getBusinessId()+"的用户和前台角色关联表信息");
        return new CyPersistModel(line);
    }

    /**
    * 根据id查询 用户和前台角色关联表
    * @param id
    * @return
    */
    @Override
    public PcRoleUser findById(int id){
        return baseMapper.selectById(id);
    }

    /**
    * 分页查询 用户和前台角色关联表
    * @param pcRoleUser
    * @return
    */
    @Override
    public IPage<PcRoleUser> findAllByPagination(CyPageInfo<PcRoleUser> paginationUtility,
        PcRoleUser pcRoleUser){
        return baseMapper.queryPcRoleUsersPaged(paginationUtility,pcRoleUser);

    }

    /**
    * 查询list 用户和前台角色关联表
    * @param pcRoleUser
    * @return
    */
    @Override
    public List<PcRoleUser> findAll(PcRoleUser pcRoleUser){
        return baseMapper.queryPcRoleUsers(pcRoleUser);

    }

    /**
    * 导出用户和前台角色关联表
    * @return
    */
    @Override
    public List<PcRoleUser> export(PcRoleUser pcRoleUser) {
        List<PcRoleUser> pcRoleUserList = baseMapper.queryPcRoleUsers(pcRoleUser);
        return pcRoleUserList;
    }

    /**
     * 批量新增
     * @param pcRoleUser
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel addRoleUser(PcRoleUser pcRoleUser) {
        if (pcRoleUser.getUserIds()!=null){
            //删除原有的数据
            int delete = pcRoleUserRepository.deleteByCondition(pcRoleUser.getPcRoleId());
            log.debug("删除原有数据{}",delete);
            List<Integer> ids = JSON.parseArray(pcRoleUser.getUserIds(), Integer.class);
            for (Integer userId : ids) {
                PcRoleUser roleUser = new PcRoleUser();
                roleUser.setPcRoleId(pcRoleUser.getPcRoleId());
                roleUser.setUserId(userId);
                baseMapper.insert(roleUser);
            }
        }
        return new CyPersistModel(1);
    }

}
