package org.rcisoft.pc.statistics.lessonStatistics.controller;


/*固定导入*/
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.core.util.PageUtil;
import org.rcisoft.pc.statistics.lessonStatistics.dto.BarDTO;
import org.rcisoft.pc.statistics.lessonStatistics.dto.LessonStudyDTO;
import org.rcisoft.pc.statistics.lessonStatistics.entity.LessonStatistics;
import org.rcisoft.pc.statistics.lessonStatistics.service.LessonStatisticsService;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.exception.CyServiceException;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;


import java.util.List;

/**
*
 * @author cy
 * @date 2024年4月17日 下午3:50:59
 */
@RestController

@RequestMapping("/lessonstatistics")
public class LessonStatisticsController extends CyPaginationController<LessonStatistics> {


    @Autowired
    private LessonStatisticsService lessonStatisticsServiceImpl;

    //@PreAuthorize("@cyPerm.hasPerm('sys:sonStatistics:add')")
    @CyOpeLogAnno(title = "system-LessonStatistics管理-新增LessonStatistics", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="添加LessonStatistics", notes="添加LessonStatistics")
    @PostMapping(value = "/add")
    public CyResult add(@Valid LessonStatistics lessonStatistics, BindingResult bindingResult) {
        CyPersistModel data = lessonStatisticsServiceImpl.persist(lessonStatistics);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        lessonStatistics);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:sonStatistics:list')")
    @CyOpeLogAnno(title = "system-LessonStatistics管理-查询LessonStatistics", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询LessonStatistics集合", notes="查询LessonStatistics集合")
    @GetMapping(value = "/listAll")
    public CyResult listAll(LessonStatistics lessonStatistics) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            lessonStatisticsServiceImpl.findAll(lessonStatistics));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:sonStatistics:list')")
    @CyOpeLogAnno(title = "system-LessonStatistics管理-查询LessonStatistics", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="分页查询LessonStatistics集合", notes="分页查询LessonStatistics集合")
    @GetMapping(value = "/list")
    public CyGridModel listByPagination(LessonStatistics lessonStatistics) {
        lessonStatisticsServiceImpl.findAllByPagination(getPaginationUtility(), lessonStatistics);
        return getGridModelResponse();
    }
    //技术分类柱状图查询
    @CyOpeLogAnno(title = "system-LessonStatistics管理-查询LessonStatistics", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="技术分类柱状图查询", notes="技术分类柱状图查询")
    @GetMapping(value = "/listByBar")
    public CyResult listByBar(BarDTO barDTO) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            lessonStatisticsServiceImpl.listByBar(barDTO));
    }
    @CyOpeLogAnno(title = "system-LessonStatistics管理-查询LessonStatistics", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出LessonStatistics信息", notes = "导出LessonStatistics信息")
    @GetMapping(value = "/export")
    public void outLessonStatistics(HttpServletResponse response,LessonStatistics lessonStatistics,@PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="LessonStatistics信息.xls";break;
            case "1": excelName="LessonStatistics信息.xlsx";break;
            case "2": excelName="LessonStatistics信息.csv";break;
        }
        List<LessonStatistics> lessonStatisticsList = lessonStatisticsServiceImpl.export(lessonStatistics);
        CyEpExcelUtil.exportExcel(lessonStatisticsList, "LessonStatistics信息", "LessonStatistics信息", LessonStatistics.class, excelName, response);
    }

    /**
     * 学习总人数分页查询
     */
    @CyOpeLogAnno(title = "system-LessonStatistics管理-查询LessonStatistics", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="学习总人数分页查询", notes="学习总人数分页查询")
    @GetMapping(value = "/listTotalByPagination")
    public  CyGridModel listTotalByPagination(LessonStudyDTO lessonStudyDTO) {
        CyPageInfo<LessonStudyDTO> pageInfo = PageUtil.getPageInfo(request);
        lessonStatisticsServiceImpl.findStudyTotalByPagination(pageInfo, lessonStudyDTO);
        return PageUtil.getGridModelResponse(pageInfo);
    }
    /**
     * 学习未开始人数查询
     */
    @CyOpeLogAnno(title = "system-LessonStatistics管理-查询LessonStatistics", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="学习未开始人数查询", notes="学习未开始人数查询")
    @GetMapping(value = "/listNotStartByPagination")
    public  CyGridModel listNotStartByPagination(LessonStudyDTO lessonStudyDTO) {
        CyPageInfo<LessonStudyDTO> pageInfo = PageUtil.getPageInfo(request);
        lessonStatisticsServiceImpl.queryStudyNotStartByPagination(pageInfo, lessonStudyDTO);
        return PageUtil.getGridModelResponse(pageInfo);
    }
    /**
     * 学习中人数查询
     */
    @CyOpeLogAnno(title = "system-LessonStatistics管理-查询LessonStatistics", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="学习中人数查询", notes="学习中人数查询")
    @GetMapping(value = "/listStudyingByPagination")
    public  CyGridModel listStudyingByPagination(LessonStudyDTO lessonStudyDTO) {
        CyPageInfo<LessonStudyDTO> pageInfo = PageUtil.getPageInfo(request);
        lessonStatisticsServiceImpl.queryLessonStudyingByPagination(pageInfo, lessonStudyDTO);
        return PageUtil.getGridModelResponse(pageInfo);
    }
    /**
     * 学习完成人数查询
     */
    @CyOpeLogAnno(title = "system-LessonStatistics管理-查询LessonStatistics", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="学习完成人数查询", notes="学习完成人数查询")
    @GetMapping(value = "/listCompleteByPagination")
    public  CyGridModel listCompleteByPagination(LessonStudyDTO lessonStudyDTO) {
        CyPageInfo<LessonStudyDTO> pageInfo = PageUtil.getPageInfo(request);
        lessonStatisticsServiceImpl.queryLessonStudyCompleteByPagination(pageInfo, lessonStudyDTO);
        return PageUtil.getGridModelResponse(pageInfo);
    }
    /**
     * 参与考核人数查询
     */
    @CyOpeLogAnno(title = "system-LessonStatistics管理-查询LessonStatistics", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="参与考核人数查询", notes="参与考核人数查询")
    @GetMapping(value = "/listAssessmentByPagination")
    public CyGridModel listAssessmentByPagination(LessonStudyDTO lessonStudyDTO) {
        CyPageInfo<LessonStudyDTO> pageInfo = PageUtil.getPageInfo(request);
        lessonStatisticsServiceImpl.queryLessonStudyExamCompleteByPagination(pageInfo, lessonStudyDTO);
        return PageUtil.getGridModelResponse(pageInfo);
    }

}
