package org.rcisoft.pc.statistics.lessonStatistics.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.rcisoft.business.blesson.entity.BLesson;
import org.rcisoft.business.pclessonlearntime.dao.PcLessonLearntimeRepository;
import org.rcisoft.business.pclessonlearntime.entity.PcLessonLearntime;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.aop.CyPageUtilAsp;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.pc.statistics.lessonStatistics.dao.LessonStatisticsRepository;
import org.rcisoft.pc.statistics.lessonStatistics.dto.BarDTO;
import org.rcisoft.pc.statistics.lessonStatistics.dto.LessonStudyDTO;
import org.rcisoft.pc.statistics.lessonStatistics.entity.LessonStatistics;
import org.rcisoft.pc.statistics.lessonStatistics.service.LessonStatisticsService;
import org.rcisoft.core.service.CyBaseService;

import org.rcisoft.sys.dictionary.entity.DictData;
import org.rcisoft.sys.dictionary.service.DictionaryService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.rcisoft.core.model.CyPageInfo;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

import lombok.extern.slf4j.Slf4j;

/**
 * Created by cy on 2024年4月17日 下午3:50:59.
 */
@Service
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class LessonStatisticsServiceImpl extends ServiceImpl<LessonStatisticsRepository, LessonStatistics> implements LessonStatisticsService {

    @Autowired
    private DictionaryService dictionaryServiceImpl;
    @Autowired
    private PcLessonLearntimeRepository pcLessonLearntimeRepository;

    /**
     * 保存
     *
     * @param lessonStatistics
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(LessonStatistics lessonStatistics) {
        //增加操作
        int line = baseMapper.insert(lessonStatistics);
        log.debug(CyUserUtil.getAuthenUsername() + "新增了ID为" +
                lessonStatistics.getBusinessId() + "的信息");
        return new CyPersistModel(line);
    }

    /**
     * 删除
     *
     * @param lessonStatistics
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(LessonStatistics lessonStatistics) {
        int line = baseMapper.realDelete(lessonStatistics);
        log.debug(CyUserUtil.getAuthenUsername() + "删除了ID为" +
                lessonStatistics.getBusinessId() + "的信息");
        return new CyPersistModel(line);
    }

    /**
     * 修改
     *
     * @param lessonStatistics
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(LessonStatistics lessonStatistics) {
        int line = baseMapper.updateById(lessonStatistics);
        log.debug(CyUserUtil.getAuthenUsername() + "修改了ID为" + lessonStatistics.getBusinessId() + "的信息");
        return new CyPersistModel(line);
    }

    /**
     * 根据id查询
     *
     * @param id
     * @return
     */
    @Override
    public LessonStatistics findById(int id) {
        return baseMapper.selectById(id);
    }

    /**
     * 分页查询
     *
     * @param lessonStatistics
     * @return
     */
    @Override
    public IPage<LessonStatistics> findAllByPagination(CyPageInfo<LessonStatistics> paginationUtility,
                                                       LessonStatistics lessonStatistics) {
//          lessonStatistics.setUnit("1");
        lessonStatistics.setUnit(CyUserUtil.getAuthenDept());
        IPage<LessonStatistics> lessonStatisticsIPage = baseMapper.queryLessonStatisticssPaged(paginationUtility, lessonStatistics);
        lessonStatisticsIPage.getRecords().forEach(lessonStatistics1 -> {
            lessonStatistics1.setUnit(CyUserUtil.getAuthenDept());
            //正在进行学习人数  =   总人数 - 未开始 - 已经学习完
            lessonStatistics1.setLearningNumber(lessonStatistics1.getTotalNumber() - lessonStatistics1.getCompletedNumber() - lessonStatistics1.getNotstartedNumber());
            //进行完考核的人数 当 这个组以及的人考完这门课的 查询
            lessonStatistics1.setExamineNumber(pcLessonLearntimeRepository.countLessonByDictData(lessonStatistics1));


        });


        return lessonStatisticsIPage;

    }

    /**
     * 查询list
     *
     * @param lessonStatistics
     * @return
     */
    @Override
    public List<LessonStatistics> findAll(LessonStatistics lessonStatistics) {
        return baseMapper.queryLessonStatisticss(lessonStatistics);

    }

    /**
     * 导出
     *
     * @return
     */
    @Override
    public List<LessonStatistics> export(LessonStatistics lessonStatistics) {
        List<LessonStatistics> lessonStatisticsList = baseMapper.queryLessonStatisticss(lessonStatistics);
        return lessonStatisticsList;
    }

    @Override
    public BarDTO listByBar(BarDTO barDTO) {
        //查询所有的技术分类
        List<DictData> tecClassifyList = dictionaryServiceImpl.selectByTypes("tec_classify");
        //定义一个数组
        List<String> techTypeList = new ArrayList<>();
        //
        List<Integer> lessonCountList = new ArrayList<>();
        //循环取出每一个技术分类的id
        for (DictData dictData : tecClassifyList) {
            //根据技术分类id查询课程数
            String count = baseMapper.countLessonByDictData(dictData.getDictValue(), CyUserUtil.getAuthenDept());
            if (!"0".equals(count)) {
                //将技术分类名称放入数组
                techTypeList.add(dictData.getDictLabel());
                //将课程数放入数组
                lessonCountList.add(Integer.valueOf(count));
            }

        }
        barDTO.setTechTypeList(techTypeList);
        barDTO.setLessonCountList(lessonCountList);
        return barDTO;

    }

    /**
     * 学习总人数分页查询
     */
    @Override
    public IPage<LessonStudyDTO> findStudyTotalByPagination(CyPageInfo<LessonStudyDTO> paginationUtility, LessonStudyDTO lessonStudyDTO) {
//        lessonStudyDTO.setUnit("1");
        lessonStudyDTO.setUnit(CyUserUtil.getAuthenDept());
        IPage<LessonStudyDTO> lessonStudyDTOIPage = baseMapper.queryLessonStudyDTOPaged(paginationUtility, lessonStudyDTO);
        //循环每一条数据
        for (LessonStudyDTO dto : lessonStudyDTOIPage.getRecords()) {
            PcLessonLearntime pcLessonLearntime = new PcLessonLearntime();
            pcLessonLearntime.setLessonId(lessonStudyDTO.getLessonId());
            pcLessonLearntime.setUserId(dto.getUserId());
            ArrayList<BLesson> bLessons = pcLessonLearntimeRepository.isComplete(pcLessonLearntime);
            for (BLesson bLesson : bLessons) {
                //未学完
                if ("1".equals(bLesson.getIsCompleteLearned())) {
                    dto.setStudyStatus("已学完");
                    break;
                } else {
                    dto.setStudyStatus("学习中");
                }
            }
            //查不出集合时
            if (bLessons.size() == 0) {
                dto.setStudyStatus("未学完");
            }

        }
        return lessonStudyDTOIPage;
    }

    @Override
    public IPage<LessonStudyDTO> queryStudyNotStartByPagination(CyPageInfo<LessonStudyDTO> paginationUtility, LessonStudyDTO lessonStudyDTO) {
//        lessonStudyDTO.setUnit("1");
        lessonStudyDTO.setUnit(CyUserUtil.getAuthenDept());
        return baseMapper.queryLessonStudyNotStartPaged(paginationUtility, lessonStudyDTO);
    }

    @Override
    public IPage<LessonStudyDTO> queryLessonStudyingByPagination(CyPageInfo<LessonStudyDTO> paginationUtility, LessonStudyDTO lessonStudyDTO) {
//        lessonStudyDTO.setUnit("1");
        lessonStudyDTO.setUnit(CyUserUtil.getAuthenDept());
        return baseMapper.queryLessonStudyingPaged(paginationUtility, lessonStudyDTO);
    }

    @Override
    public IPage<LessonStudyDTO> queryLessonStudyCompleteByPagination(CyPageInfo<LessonStudyDTO> paginationUtility, LessonStudyDTO lessonStudyDTO) {
//        lessonStudyDTO.setUnit("1");
        lessonStudyDTO.setUnit(CyUserUtil.getAuthenDept());
        return baseMapper.queryLessonStudyCompletePaged(paginationUtility, lessonStudyDTO);
    }

    @Override
    public IPage<LessonStudyDTO> queryLessonStudyExamCompleteByPagination(CyPageInfo<LessonStudyDTO> paginationUtility, LessonStudyDTO lessonStudyDTO) {
//        lessonStudyDTO.setUnit("1");
        lessonStudyDTO.setUnit(CyUserUtil.getAuthenDept());
        return baseMapper.queryLessonStudyExamCompletePaged(paginationUtility, lessonStudyDTO);
    }
}

