package org.rcisoft.pc.statistics.studentStatistics.service.impl;

import cn.hutool.core.bean.BeanUtil;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import org.rcisoft.business.blesson.entity.PcBLessonQuery;
import org.rcisoft.business.blesson.entity.StatisticsDetailVO;
import org.rcisoft.business.blesson.service.impl.BLessonServiceImpl;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.pc.statistics.studentStatistics.dao.StudentStatisticsMapper;
import org.rcisoft.pc.statistics.studentStatistics.entity.dto.StudentStatisticsDTO;
import org.rcisoft.pc.statistics.studentStatistics.entity.dto.StudentStatisticsInformationDTO;
import org.rcisoft.pc.statistics.studentStatistics.entity.dto.StudentStatisticsWithDept;
import org.rcisoft.pc.statistics.studentStatistics.entity.pojo.ClassTable;
import org.rcisoft.pc.statistics.studentStatistics.entity.pojo.StudentStatistics;
import org.rcisoft.pc.statistics.studentStatistics.entity.pojo.StudentStatisticsInformationATemp;
import org.rcisoft.pc.statistics.studentStatistics.entity.pojo.StudentStatisticsInformationB;
import org.rcisoft.pc.statistics.studentStatistics.entity.pojo.StudentStatisticsInformationC;
import org.rcisoft.pc.statistics.studentStatistics.entity.pojo.StudentStatisticsInformationD;
import org.rcisoft.pc.statistics.studentStatistics.entity.pojo.StudentStatisticsPo;
import org.rcisoft.pc.statistics.studentStatistics.entity.ro.StudentStatisticsInformationRO;
import org.rcisoft.pc.statistics.studentStatistics.entity.ro.StudentStatisticsRO;
import org.rcisoft.pc.statistics.studentStatistics.service.StudentStatisticsService;
import org.rcisoft.pc.statistics.studentStatistics.utils.Filtration;
import org.rcisoft.pc.statistics.studentStatistics.utils.Joint;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

@Service
public class StudentStatisticsServiceImpl implements StudentStatisticsService {

    @Autowired
    StudentStatisticsMapper studentStatisticsMapper;

    @Autowired
    private BLessonServiceImpl bLessonService;

    @Override
    public StudentStatisticsRO listAll(StudentStatisticsDTO studentStatisticsDTO) {

        //总记录数
        Integer totalNumber = 0;

        //获取当前登陆人单位id
        Long dept = Long.valueOf(CyUserUtil.getAuthenDept());
        //获取当前登陆人的id
        Long businessId = Long.valueOf(CyUserUtil.getAuthenBusinessId());
        StudentStatisticsWithDept studentStatisticsWithDept = BeanUtil.copyProperties(dept, StudentStatisticsWithDept.class);
        //分页放进去
        studentStatisticsWithDept.setRows(studentStatisticsDTO.getRows());
        studentStatisticsWithDept.setPage(studentStatisticsDTO.getPage());
        studentStatisticsWithDept.setDept(dept);

        //查询总记录数
        if (studentStatisticsWithDept.getGroupName() == null || studentStatisticsWithDept.getGroupName() == "") {
            totalNumber = studentStatisticsMapper.getTotalsRecords(studentStatisticsWithDept, businessId);
        } else {
            totalNumber = studentStatisticsMapper.getTotalsRecordsByGroup(studentStatisticsWithDept);
        }

        if (studentStatisticsDTO.getName()!=null && studentStatisticsDTO.getName()!=""){
            studentStatisticsWithDept.setName(studentStatisticsDTO.getName());
        }
        if (studentStatisticsDTO.getGroupName() != null & studentStatisticsDTO.getGroupName() != ""){
            studentStatisticsWithDept.setGroupName(studentStatisticsDTO.getGroupName());
        }

        //在sys_user中条件分页查询
        List<StudentStatisticsPo> sysUserTable = studentStatisticsMapper.getUserList(businessId, studentStatisticsWithDept, (studentStatisticsWithDept.getPage() - 1) * studentStatisticsWithDept.getRows());

        List<StatisticsDetailVO> statisticsDetailVOList = new ArrayList<>();

        PcBLessonQuery queryDetail = new PcBLessonQuery();

        CyPageInfo<StatisticsDetailVO> pagin = new CyPageInfo<>();
        // 获取当前分页中的组员id
        String userIds = sysUserTable.stream()
                .map(StudentStatisticsPo::getBusinessId)
                .map(String::valueOf)
                .distinct()
                .collect(Collectors.joining(","));
        queryDetail.setUserId(userIds);
        statisticsDetailVOList = bLessonService.getBaseMapper().pagingStudentStatisticsDetail(pagin, queryDetail).getRecords();
        // 将全部统计详情数据按照 userId 分组
        Map<String, List<StatisticsDetailVO>> statisticsDetailVoMap = statisticsDetailVOList.stream()
                .collect(Collectors.groupingBy(StatisticsDetailVO::getUserId));

        if (!sysUserTable.isEmpty()) {
            List<StudentStatisticsPo> studentStatisticsPos = new ArrayList<>();
            for (StudentStatisticsPo myGroupStatisticsVO : sysUserTable) {
                //统计当前用户的计划课程总数，学习中课程数，已学完课程数 参与考核课程数 未考核课程数
                //通过用户id反向找到对应的数据
                StudentStatisticsPo statistics = studentStatisticsMapper.statistics(myGroupStatisticsVO);
                studentStatisticsPos.add(statistics);

            }
            StudentStatisticsRO res = new StudentStatisticsRO();
            res.setTotal(totalNumber);
            res.setRecords(studentStatisticsPos);

            return res;
        /*    for (StudentStatisticsPo myGroupStatisticsVO : sysUserTable) {
                if (statisticsDetailVoMap.containsKey(myGroupStatisticsVO.getBusinessId().toString())) {
                    // 如果存在该用户的统计详情数据
                    List<StatisticsDetailVO> statisticsDetailList = statisticsDetailVoMap.get(myGroupStatisticsVO.getBusinessId().toString());
                    // 根据学习状态进行分组
                    Map<String, Long> learningStateCounts = statisticsDetailList.stream()
                            .collect(Collectors.groupingBy(
                                    StatisticsDetailVO::getLearningState,
                                    Collectors.counting()
                            ));
                    // 根据考核状态进行分组
                    Map<String, Long> isCompleteExamCounts = statisticsDetailList.stream()
                            .collect(Collectors.groupingBy(
                                    detail -> String.valueOf(detail.getIsCompleteExam()),
                                    Collectors.counting()
                            ));
                    // 计划课程总数
                    myGroupStatisticsVO.setTotal(String.valueOf(statisticsDetailList.size()));
                    // 学习中课程数
                    myGroupStatisticsVO.setLearning(String.valueOf(learningStateCounts.getOrDefault("学习中", 0L)));
                    // 已完成课程数
                    myGroupStatisticsVO.setFinish(String.valueOf(learningStateCounts.getOrDefault("已完成", 0L)));
                    // 未开始课程数
                    myGroupStatisticsVO.setNotStart(String.valueOf(learningStateCounts.getOrDefault("未开始", 0L)));
                    // 参与考核课程数
                    myGroupStatisticsVO.setExamedNumber(String.valueOf(isCompleteExamCounts.getOrDefault("1", 0L)));
                    // 未考核课程数
                    myGroupStatisticsVO.setNotExamedNumber(String.valueOf(isCompleteExamCounts.getOrDefault("0", 0L)));
                } else {
                    // 如果不存在该用户的统计详情数据 全部赋 0
                    // 计划课程总数
                    myGroupStatisticsVO.setTotal("0");
                    // 学习中课程数
                    myGroupStatisticsVO.setLearning("0");
                    // 已完成课程数
                    myGroupStatisticsVO.setFinish("0");
                    // 未开始课程数
                    myGroupStatisticsVO.setNotStart("0");
                    // 参与考核课程数
                    myGroupStatisticsVO.setExamedNumber("0");
                    // 未考核课程数
                    myGroupStatisticsVO.setNotExamedNumber("0");
                }
            }*/
        }
//		//根据businessId查询对应小组
//		List<GroupName> groupName = studentStatisticsMapper.getGroupName(sysUserTable);
//
//		//根据businessId查询正在学/已学完课题数
//		List<LearningAndLearned> learningAndLearneds = studentStatisticsMapper.getLessonearntime(sysUserTable);
//
//		//根据businessId查询计划课程总数
//		List<TotalNumber> totalNumbers = studentStatisticsMapper.getTotalClass(sysUserTable);
//
//		//根据businessId查询参与考核与未参与考核数据
//		List<Examed> exameds = studentStatisticsMapper.getExameds(sysUserTable);
//
//		sysUserTable = Joint.getStudentStatistics(sysUserTable, groupName, learningAndLearneds, totalNumbers, exameds);

        //创建返回对象
        StudentStatisticsRO res = new StudentStatisticsRO();
        res.setTotal(totalNumber);
        res.setRecords(sysUserTable);

        return res;
    }

    @Override
    public StudentStatisticsInformationRO getInformation(StudentStatisticsInformationDTO studentStatisticsInformationDTO) {

        studentStatisticsInformationDTO = Filtration.fillBoolean(studentStatisticsInformationDTO);

        //判断点击的类型
        Boolean flagExam = studentStatisticsInformationDTO.getExamedNumber()
                || studentStatisticsInformationDTO.getNotExamedNumber();

        Boolean flagFinish = studentStatisticsInformationDTO.getFinish();

        //创建返回类型
        StudentStatisticsInformationRO res = new StudentStatisticsInformationRO();
        if (!flagExam && !flagFinish) {
            //获取没有状态的列表
            List<StudentStatisticsInformationATemp> temp = studentStatisticsMapper.getInformation(studentStatisticsInformationDTO, (studentStatisticsInformationDTO.getPage() - 1) * studentStatisticsInformationDTO.getRows());

            //获取其中的businessId
            List<StudentStatisticsInformationATemp> status = studentStatisticsMapper.getStatus(temp, studentStatisticsInformationDTO.getBusinessId());

            //拼接字段
            List<ClassTable> data = Joint.getInformation(temp, status);

            //根据条件过滤
            if (studentStatisticsInformationDTO.getTotal()) {
                //获取总记录数
                Integer totals = studentStatisticsMapper.getTotalsRecordsInformation(studentStatisticsInformationDTO);
                res.setRecords(data);
                res.setTotal(totals);
            } else if (studentStatisticsInformationDTO.getLearning()) {
                //获取学习中课程数
                Integer totals = studentStatisticsMapper.getTotalsLearningInformation(studentStatisticsInformationDTO);
                res.setTotal(totals);
                data = Joint.filterLearning(data);
                res.setRecords(data);
            } else if (studentStatisticsInformationDTO.getNotStart()) {
                //获取未开始课程数
                Integer totals = studentStatisticsMapper.getTotalsLearningInformation(studentStatisticsInformationDTO);
                Integer start = studentStatisticsMapper.getTotalsStartInformation(studentStatisticsInformationDTO);
                totals = totals - start;
                res.setTotal(totals);
                data = Joint.filterNotStart(data);
                res.setRecords(data);
            }
        } else if (!flagFinish) {
            if (studentStatisticsInformationDTO.getExamedNumber()) {
                //参与考核
                //查询记录数
                Integer totals = studentStatisticsMapper.getTotalsExamedNumber(studentStatisticsInformationDTO);
                //查询记录
                List<StudentStatisticsInformationB> tempData = studentStatisticsMapper.getExamedInformation(studentStatisticsInformationDTO,
                        (studentStatisticsInformationDTO.getPage() - 1) * studentStatisticsInformationDTO.getRows());
                List<ClassTable> data = new ArrayList<>(tempData.size());

                for (StudentStatisticsInformationB target : tempData) {
                    data.add(target);
                }
                res.setRecords(data);
                res.setTotal(totals);
            } else {
                //未参与考核
                //查询总记录数
                Integer totals = studentStatisticsMapper.getTotalsNotExamedNumber(studentStatisticsInformationDTO);
                //查询记录
                List<StudentStatisticsInformationC> tempData = studentStatisticsMapper.getNotExamedInformation(studentStatisticsInformationDTO,
                        (studentStatisticsInformationDTO.getPage() - 1) * studentStatisticsInformationDTO.getRows());

                List<ClassTable> data = new ArrayList<>(tempData.size());
                for (StudentStatisticsInformationC target : tempData) {
                    data.add(target);
                }
                res.setTotal(totals);
                res.setRecords(data);
            }
        } else {

            //获取已完成课程数
            Integer totals = studentStatisticsMapper.getTotalsFinishInformation(studentStatisticsInformationDTO);
            res.setTotal(totals);

            //查询完成的
            List<StudentStatisticsInformationD> tempData = studentStatisticsMapper.getFinishInformation(studentStatisticsInformationDTO,
                    (studentStatisticsInformationDTO.getPage() - 1) * studentStatisticsInformationDTO.getRows());

            //填充必修字段
            List<ClassTable> data = Joint.filterClassType(tempData);
            res.setRecords(data);
        }
        return res;
    }
}
